package com.sobot.callsdk;

import static com.sobot.callsdk.utils.SobotCallConstant.SOBOT_KEY_INIT;

import android.app.Application;
import android.content.Context;
import android.media.AudioManager;
import android.os.Build;
import android.os.Handler;
import android.text.TextUtils;

import com.sobot.callbase.api.SobotCallBaseUrl;
import com.sobot.callbase.api.utils.CallBaseSharedPreferencesUtils;
import com.sobot.callbase.api.utils.SobotStompEventConstant;
import com.sobot.callbase.listener.SobotCallOption;
import com.sobot.callbase.listener.SobotVoipCallListener;
import com.sobot.callbase.listener.SobotVoipRegisterListener;
import com.sobot.callbase.model.CallSipModel;
import com.sobot.callbase.model.QueueAgentCheckin;
import com.sobot.callbase.model.SobotBusyStatusEntity;
import com.sobot.callbase.model.SobotExtEntity;
import com.sobot.callbase.model.SobotExtensionEntity;
import com.sobot.callbase.model.SobotLoginBindEntity;
import com.sobot.callbase.model.SobotLoginStatusEntity;
import com.sobot.callbase.model.SobotOutboundRoutesEntity;
import com.sobot.callbase.stomp.SobotStompClient;
import com.sobot.callsdk.janus.SobotJanusSipPhoneUtils;
import com.sobot.callsdk.listener.SobotPhoneStatusListener;
import com.sobot.callsdk.listener.SobotRegistrationListener;
import com.sobot.callsdk.model.SobotAgentEntity;
import com.sobot.callsdk.model.SobotCallConfigEntity;
import com.sobot.callsdk.utils.CallSharedPreferencesUtils;
import com.sobot.callsdk.utils.SobotApplication;
import com.sobot.callsdk.utils.SobotCallApiUtils;
import com.sobot.callsdk.utils.SobotCallConstant;
import com.sobot.common.login.SobotLoginTools;
import com.sobot.common.login.callback.SobotResultBlock;
import com.sobot.common.login.callback.SobotResultCode;
import com.sobot.common.login.model.SobotServiceInfoModel;
import com.sobot.common.utils.SobotCommonApi;
import com.sobot.gson.SobotGsonUtil;
import com.sobot.network.http.callback.SobotResultCallBack;
import com.sobot.utils.SobotLogUtils;
import com.sobot.utils.SobotStringUtils;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class SobotCallOpenApi {

    /**
     * 初始化SDK，设置域名
     *
     * @param application 上下文
     * @param config      配置类
     * @param block       回调结果    SobotResultCode.CODE_FAILED,//失败 SobotResultCode.CODE_SUCCEEDED;//成功
     */
    public static void initWithConfig(Application application, SobotCallConfigEntity config, SobotResultBlock block) {
        if (application == null) {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, "initWithConfig 参数 application不能为空", null);
            } else {
                SobotLogUtils.e("initWithConfig 参数 application不能为空");
            }
            return;
        }
        if (config != null) {
            if (!TextUtils.isEmpty(config.getOpenApiHost())) {
                SobotCallBaseUrl.setOpenApiHost(config.getOpenApiHost());
            }
            if (!TextUtils.isEmpty(config.getCallApiHost())) {
                SobotCallBaseUrl.setCallApiHost(config.getCallApiHost());
            }
            if (!TextUtils.isEmpty(config.getStompSocketUri())) {
                SobotCallBaseUrl.setStompSocketUri(config.getStompSocketUri());
            }
            if (!TextUtils.isEmpty(config.getSipProxy())) {
                SobotCallBaseUrl.setSipProxy(config.getSipProxy());
            }
            if (!TextUtils.isEmpty(config.getJanusSocketUri())) {
                SobotCallBaseUrl.setJanusSocketUri(config.getJanusSocketUri());
            }
        }
        disConnnet(application);
        CallSharedPreferencesUtils.getInstance(application).clearAll();
        SobotCommonApi.init(application, SobotCallBaseUrl.getOpenApiHost() + SobotCallBaseUrl.getCallApiHost() + SobotCallBaseUrl.getStompSocketUri());
        SobotApplication.getmInstance().put(SOBOT_KEY_INIT, true);
        if (block != null)
            block.resultBolok(SobotResultCode.CODE_SUCCEEDED, "初始化成功", null);

    }

    //----------------------------登录操作----------------------------

    /**
     * 通过邮箱密码方式登录呼叫系统
     *
     * @param context
     * @param loginUser 客服邮箱
     * @param loginPwd  登录密码
     * @param block     回调结果
     */
    public static void loginWithAcount(Context context, String loginUser, String loginPwd, SobotResultBlock block) {
        Object obj = SobotApplication.getmInstance().get(SOBOT_KEY_INIT);
        if (obj != null) {
            boolean isInit = (boolean) SobotApplication.getmInstance().get(SOBOT_KEY_INIT);
            if (isInit) {
                ZCSobotCallApi.loginUser(context, loginUser, loginPwd, false, new SobotResultBlock() {
                    @Override
                    public void resultBolok(SobotResultCode code, String msg, Object obj) {
                        if (block != null) {
                            block.resultBolok(code, msg, obj);
                        }
                        //sdk 集成方式 0 模块集成 1 接口集成
                        CallSharedPreferencesUtils.getInstance(context).put(SobotCallConstant.SP_KEY_SDK_MODEL_TYPE, SobotCallConstant.SDK_MODEL_CUSTOMER);
                        if (SobotResultCode.CODE_SUCCEEDED.equals(code)) {
                            //登录成功后连接stomp
                            if (!SobotStompClient.getInstance(context).isConnected()) {
                                String accesstoken = SobotLoginTools.getInstance().getAccessToken();
                                String languageStr = CallBaseSharedPreferencesUtils.getInstance(context).get("SobotLanguageStr", "zh");
                                //连接stomp
                                SobotStompClient.getInstance(context).over(SobotStompClient.ConnectionProviderType.OKHTTP, SobotCallBaseUrl.getStompSocketUri() + "?authorization=Bearer " + accesstoken + "&language=" + languageStr, null, null);
                                SobotLogUtils.i("stomp 链接地址=====" + SobotCallBaseUrl.getStompSocketUri() + "?authorization=Bearer " + accesstoken);
                                SobotStompClient.getInstance(context).connectStomp(0);
                            }
                        }
                    }
                });
            } else {
                if (block != null) {
                    block.resultBolok(SobotResultCode.CODE_FAILED, "未初始化：请在Application中调用【SobotCallOpenApi.initWithConfig()】来初始化SDK!", obj);
                } else {
                    SobotLogUtils.e("未初始化：请在Application中调用【SobotCallOpenApi.initWithConfig()】来初始化SDK!");
                }
            }
        } else {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, "请在Application中调用【SobotCallOpenApi.initWithConfig()】来初始化SDK!", obj);
            } else {
                SobotLogUtils.e("请在Application中调用【SobotCallOpenApi.initWithConfig()】来初始化SDK!");
            }
        }
    }

    /**
     * 通过设置公司token方式登录呼叫系统
     *
     * @param context
     * @param loginUser    登录客服账号
     * @param companyToken 公司token
     * @param block        回调结果
     */
    public static void loginWithToken(Context context, String loginUser, String companyToken, SobotResultBlock block) {
        Object obj = SobotApplication.getmInstance().get(SOBOT_KEY_INIT);
        if (obj != null) {
            boolean isInit = (boolean) SobotApplication.getmInstance().get(SOBOT_KEY_INIT);
            if (isInit) {
                ZCSobotCallApi.loginWithCompanyToken(context, loginUser, companyToken, false, new SobotResultBlock() {
                    @Override
                    public void resultBolok(SobotResultCode code, String msg, Object obj) {
                        if (block != null) {
                            block.resultBolok(code, msg, obj);
                        }
                        //sdk 集成方式 0 模块集成 1 接口集成
                        CallSharedPreferencesUtils.getInstance(context).put(SobotCallConstant.SP_KEY_SDK_MODEL_TYPE, SobotCallConstant.SDK_MODEL_CUSTOMER);
                        if (SobotResultCode.CODE_SUCCEEDED.equals(code)) {
                            //登录成功后连接stomp
                            if (!SobotStompClient.getInstance(context).isConnected()) {
                                String accesstoken = SobotLoginTools.getInstance().getAccessToken();
                                String languageStr = CallBaseSharedPreferencesUtils.getInstance(context).get("SobotLanguageStr", "zh");
                                //连接stomp
                                SobotStompClient.getInstance(context).over(SobotStompClient.ConnectionProviderType.OKHTTP, SobotCallBaseUrl.getStompSocketUri() + "?authorization=Bearer " + accesstoken + "&language=" + languageStr, null, null);
                                SobotLogUtils.i("stomp 链接地址=====" + SobotCallBaseUrl.getStompSocketUri() + "?authorization=Bearer " + accesstoken);
                                SobotStompClient.getInstance(context).connectStomp(0);
                            }
                        }
                    }
                });
            } else {
                SobotLogUtils.e("请在Application中调用【SobotCallOpenApi.initWithConfig()】来初始化SDK!");
            }
        } else {
            SobotLogUtils.e("请在Application中调用【SobotCallOpenApi.initWithConfig()】来初始化SDK!");
        }
    }

    /**
     * 通过设置appkey和appid方式登录呼叫系统
     *
     * @param context
     * @param loginUser 登录客服账号
     * @param appKey    登录appKey  找售后同事获取(客户账号开通时会有这个)
     * @param appId     登录appId 找售后同事获取(客户账号开通时会有这个)
     * @param block     回调结果
     */
    public static void loginWithAppkey(Context context, String loginUser, String appKey, String appId, SobotResultBlock block) {
        Object obj = SobotApplication.getmInstance().get(SOBOT_KEY_INIT);
        if (obj != null) {
            boolean isInit = (boolean) SobotApplication.getmInstance().get(SOBOT_KEY_INIT);
            if (isInit) {
                ZCSobotCallApi.loginWithAppkey(context, loginUser, appKey, appId, false, new SobotResultBlock() {
                    @Override
                    public void resultBolok(SobotResultCode code, String msg, Object obj) {
                        if (block != null) {
                            block.resultBolok(code, msg, obj);
                        }
                        //sdk 集成方式 0 模块集成 1 接口集成
                        CallSharedPreferencesUtils.getInstance(context).put(SobotCallConstant.SP_KEY_SDK_MODEL_TYPE, SobotCallConstant.SDK_MODEL_CUSTOMER);
                        if (SobotResultCode.CODE_SUCCEEDED.equals(code)) {
                            //登录成功后连接stomp
                            if (!SobotStompClient.getInstance(context).isConnected()) {
                                String accesstoken = SobotLoginTools.getInstance().getAccessToken();
                                String languageStr = CallBaseSharedPreferencesUtils.getInstance(context).get("SobotLanguageStr", "zh");
                                //连接stomp
                                SobotStompClient.getInstance(context).over(SobotStompClient.ConnectionProviderType.OKHTTP, SobotCallBaseUrl.getStompSocketUri() + "?authorization=Bearer " + accesstoken + "&language=" + languageStr, null, null);
                                SobotLogUtils.i("stomp 链接地址=====" + SobotCallBaseUrl.getStompSocketUri() + "?authorization=Bearer " + accesstoken);
                                SobotStompClient.getInstance(context).connectStomp(0);
                            }
                        }
                    }
                });
            } else {
                SobotLogUtils.e("请在Application中调用【SobotCallOpenApi.initWithConfig()】来初始化SDK!");
            }
        } else {
            SobotLogUtils.e("请在Application中调用【SobotCallOpenApi.initWithConfig()】来初始化SDK!");
        }
    }

    /**
     * 获取登录的座席信息
     *
     * @param context
     */
    public static SobotServiceInfoModel getServiceVoInfos(Context context) {
        SobotServiceInfoModel sobotServiceVo = SobotLoginTools.getInstance().getServiceInfo();
        if (sobotServiceVo != null) {
            return sobotServiceVo;
        } else {
            SobotLogUtils.e("请先调用【 SobotCallOpenApi.loginWithToken() 或者 SobotCallOpenApi.loginWithAcount() 】 方法登录获取座席信息");
        }
        return null;
    }

    /**
     * 查询企业的分机列表
     *
     * @param context
     * @param block
     */
    public static void queryUnusedExts(Context context, SobotResultBlock block) {
        if (!isLogin(context, "SobotCallOpenApi queryUnusedExts", block)) {
            return;
        }
        SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
        SobotCallApiUtils.getZhiChiApi(context).getExtensionList(context, serviceVo.getServiceId(), "1", new SobotResultCallBack<List<SobotExtensionEntity>>() {
            @Override
            public void onSuccess(List<SobotExtensionEntity> sobotExtensionEntities) {
                if (block != null) {
                    block.resultBolok(SobotResultCode.CODE_SUCCEEDED, "调用成功", sobotExtensionEntities);
                }
            }

            @Override
            public void onFailure(Exception e, String des) {
                if (block != null) {
                    block.resultBolok(SobotResultCode.CODE_FAILED, "调用失败", des);
                }
            }
        });
    }

    /**
     * 查询企业的分机列表
     *
     * @param context
     */
    public static void queryUnusedExts(Context context, SobotResultCallBack<List<SobotExtensionEntity>> resultCallBack) {
        if (!isLogin(context, "SobotCallOpenApi queryUnusedExts", null)) {
            return;
        }
        SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
        SobotCallApiUtils.getZhiChiApi(context).getExtensionList(context, serviceVo.getServiceId(), "1", resultCallBack);
    }

    /**
     * 查询座席可用的接听方式
     *
     * @param context
     * @param block
     */
    public static void queryPhoneType(Context context, SobotResultBlock block) {
        if (!isLogin(context, "SobotCallOpenApi queryPhoneType", block)) {
            return;
        }
        SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
        SobotCallApiUtils.getZhiChiApi(context).phoneTypes(context, serviceVo.getServiceId(), "1", new SobotResultCallBack<SobotAgentEntity>() {
            @Override
            public void onSuccess(SobotAgentEntity sobotAgentEntity) {
                if (block != null) {
                    block.resultBolok(SobotResultCode.CODE_SUCCEEDED, "调用成功", sobotAgentEntity.getJson());
                }
            }

            @Override
            public void onFailure(Exception e, String des) {
                if (block != null) {
                    block.resultBolok(SobotResultCode.CODE_FAILED, "调用失败", des);
                }
            }
        });
    }

    /**
     * 查询座席的登录状态
     * 仅仅查询座席有权限的小休状态和自定义小休状态集合
     *
     * @param context
     * @param block
     */
    public static void queryStates(Context context, SobotResultBlock block) {
        if (!isLogin(context, "SobotCallOpenApi queryStates", block)) {
            return;
        }
        SobotCallApiUtils.getZhiChiApi(context).getLoginStatus(context, new SobotResultCallBack<List<SobotLoginStatusEntity>>() {
            @Override
            public void onSuccess(List<SobotLoginStatusEntity> sobotLoginStatusEntities) {
                if (block != null) {
                    block.resultBolok(SobotResultCode.CODE_SUCCEEDED, "调用成功", sobotLoginStatusEntities);
                }
            }

            @Override
            public void onFailure(Exception e, String des) {
                if (block != null) {
                    block.resultBolok(SobotResultCode.CODE_FAILED, "调用失败", des);
                }
            }
        });
    }

    /**
     * 判断是否已经登录成功
     *
     * @param context
     */
    public static boolean isLogin(Context context, String methodName, SobotResultBlock block) {
        if (context == null) {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, methodName + "接口 context 不能为空", null);
            } else {
                SobotLogUtils.e(methodName + "接口 context 不能为空");
            }
            return false;
        }

        if (SobotLoginTools.getInstance().isLogin()) {
            return true;
        }
        if (block != null) {
            block.resultBolok(SobotResultCode.CODE_FAILED, " 调用 " + methodName + " 接口失败", null);
        } else {
            SobotLogUtils.e(" 调用 " + methodName + " 接口失败");
        }
        return false;
    }

    /**
     * 话机注册状态的变化
     * 监听状态： 注册成功、注册失败、注销账号
     */
    public static void setRegistrationListener(SobotVoipRegisterListener voipRegisterListener) {
        if (voipRegisterListener != null) {
            SobotCallOption.voipRegisterListener = voipRegisterListener;
        }
    }


    /**
     * 监听通话状态的变化
     * 监听状态： 用户来电、用户响铃中、通话中、通话结束
     */
    public static void setVoipCallListener(SobotVoipCallListener voipCallListener) {
        if (voipCallListener != null) {
            SobotCallOption.voipCallListener = voipCallListener;
        }
    }


    /**
     * 签入
     * 从一个端调用签入接口会导致其他端断开连接
     *
     * @param context
     * @param agentState 登录状态 可为空， 签入成功后的座席登录状态。 1：在线；2：勿扰。 为空时，默认勿扰。
     * @param phoneType  接听方式 不可为空， pstn：手机；webrtc：网页。
     * @param bindExt    绑定分机账号 不可为空
     * @param bindMobile 绑定电话号码 可为空 ，手机号码或固话号码。接听方式为手机时，绑定电话号码非空，接口指定的绑定电话号码会改变座席设置中绑定的电话号码。不同座席绑定的电话号码不可相同。
     * @param thisQueues 呼叫技能组组号的集合，定义座席可以接待哪些技能组的分配电话。该字段仅限“呼叫功能设置\座席手动选择技能组签入”设置启用之后才生效；未启用时，系统按照座席加入的全部呼叫技能组进行签入。
     * @param block
     */
    public static void agentLogin(Context context, String agentState, String phoneType, String bindExt, String bindMobile, List<String> thisQueues, SobotResultBlock block) {
        String funName = "签入 agentLogin ";
        if (!isLogin(context, funName, block)) {
            return;
        }
        if (TextUtils.isEmpty(phoneType)) {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, funName + " 接口 phoneType 接听方式 不能为空", null);
            } else {
                SobotLogUtils.e(funName + " 接口 phoneType 接听方式 不能为空");
            }
            return;
        }
        if (TextUtils.isEmpty(bindExt)) {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, funName + " 接口 参数bindExt 绑定分机账号 不能为空", null);
            } else {
                SobotLogUtils.e(funName + " 接口 参数bindExt 绑定分机账号 不能为空");
            }
            return;
        }
        if (phoneType.equals("pstn") && TextUtils.isEmpty(bindMobile)) {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, funName + " 接口,手机登录方式 参数bindMobile 绑定电话号码 不能为空", null);
            } else {
                SobotLogUtils.e(funName + " 接口,手机登录方式 参数bindMobile 绑定电话号码  不能为空");
            }
            return;
        }
        if (phoneType.equals("webrtc") && TextUtils.isEmpty(bindExt)) {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, funName + " 接口,sip登录方式 参数bindExt 分机账号不能为空", null);
            } else {
                SobotLogUtils.e(funName + " 接口,sip登录方式 参数bindExt 分机账号不能为空 不能为空");
            }
            return;
        }
        CallSharedPreferencesUtils.getInstance(context).put(SobotCallConstant.AgentLoginInput.phoneType, phoneType);
        CallSharedPreferencesUtils.getInstance(context).put(SobotCallConstant.AgentLoginInput.bindExt, bindExt);
        CallSharedPreferencesUtils.getInstance(context).put(SobotCallConstant.AgentLoginInput.bindMobile, bindMobile);
        String thisQueuesStr = (thisQueues != null && thisQueues.size() > 0) ? SobotGsonUtil.beanToJson(thisQueues) : "";
        CallSharedPreferencesUtils.getInstance(context).put(SobotCallConstant.AgentLoginInput.thisQueues, thisQueuesStr);
        if ("webrtc".equals(phoneType)) {
            //sip方式
            CallSharedPreferencesUtils.getInstance(context).put(SobotCallConstant.SP_KEY_CALL_MODEL_TYPE_V6, SobotCallConstant.CALL_MODEL_SIP);
            SobotJanusSipPhoneUtils.startService(context);
            //查询分机号
            queryUnusedExts(context, new SobotResultBlock() {
                @Override
                public void resultBolok(SobotResultCode code, String msg, Object obj) {
                    if (code == SobotResultCode.CODE_SUCCEEDED) {
                        List<SobotExtensionEntity> list = new ArrayList<>();
                        if (obj != null) {
                            list = (List<SobotExtensionEntity>) obj;
                        }
                        SobotExtensionEntity extEntity = null;
                        for (int i = 0; i < list.size(); i++) {
                            if (list.get(i).getExt().equals(bindExt)) {
                                extEntity = list.get(i);
                            }
                        }
                        if (extEntity == null) {
                            if (block != null) {
                                block.resultBolok(SobotResultCode.CODE_FAILED, funName + " 接口：未查询到该分机号", null);
                            }
                        } else {
                            SobotExtensionEntity finalExtEntity = extEntity;
                            new Handler().postDelayed(new Runnable() {
                                @Override
                                public void run() {
                                    SobotRegistrationListener registerListener = SobotRegistrationListener.getInstance();
                                    registerListener.setContext(context.getApplicationContext());
                                    registerListener.setLineStatus(agentState);
                                    if ("2".equals(agentState)) {
                                        registerListener.setLineStatusName(context.getResources().getString(com.sobot.callsdk.R.string.sobot_custom_do_not_disturb));
                                    } else {
                                        registerListener.setLineStatusName(context.getResources().getString(com.sobot.callsdk.R.string.sobot_custom_v6_free));
                                    }
                                    CallSipModel sipModel = new CallSipModel();
                                    sipModel.setAgentNumber(bindExt);
                                    sipModel.setServerIP(finalExtEntity.getDomain());
                                    sipModel.setAgentPwd(finalExtEntity.getPassword());
                                    registerListener.setSipModel(sipModel);
                                    SobotServiceInfoModel serviceVo = SobotLoginTools.getInstance().getServiceInfo();
                                    SobotPhoneStatusListener phoneStatusListener = SobotPhoneStatusListener.getInstance();
                                    phoneStatusListener.setContext(context);
                                    if (serviceVo != null) {
                                        SobotJanusSipPhoneUtils.setAccount(sipModel.getAgentNumber(), sipModel.getAgentPwd(), sipModel.getServerIP());
                                        SobotJanusSipPhoneUtils.login(context.getApplicationContext());
                                    }
                                }
                            }, 1500);
                            if (block != null) {
                                block.resultBolok(SobotResultCode.CODE_SUCCEEDED, funName + " 调用成功", null);
                            }
                        }
                    } else {
                        if (block != null) {
                            block.resultBolok(SobotResultCode.CODE_FAILED, funName + " 接口：未查询到该分机号", null);
                        }
                    }

                }
            });


        } else if ("pstn".equals(phoneType)) {
            //手机方式
            CallSharedPreferencesUtils.getInstance(context).put(SobotCallConstant.SP_KEY_CALL_MODEL_TYPE_V6, SobotCallConstant.CALL_MODEL_PHONE);
            if (SobotStompClient.getInstance(context).isConnected()) {
                SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
                String currentTime = System.currentTimeMillis() + "";
                SobotStompClient.getInstance(context).send("/cc/app/request", "{\n" +
                        "    \"messageID\": \"" + SobotStompEventConstant.RequestAgentLogin + "\",\n" +
                        "    \"referenceID\": " + currentTime + ",\n" +
                        "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                        "    \"agentType\": \"1\",\n" +
                        "    \"agentState\": \"" + agentState + "\",\n" +
                        "    \"phoneType\": \"" + phoneType + "\",\n" +
                        //手机登录需要必须传正确的分机号
                        "    \"bindExt\": \"" + bindExt + "\",\n" +
                        "    \"bindMobile\": \"" + bindMobile + "\",\n" +
                        "    \"unbindExtOnLogout\": \"false\",\n\"edgeOut\": \"1\"," +
                        "    \"userData\": {\n" +
                        "        \"__fromChannel\": \"SobotMobilePhone\"" +
                        "    },\n" +
                        (SobotStringUtils.isEmpty(thisQueues) ? "" : "    \"thisQueues\": " + thisQueues + " ,\n") +
                        "    \"creationTime\": " + currentTime + "\n" +
                        "}\n").subscribe();
                if (block != null) {
                    block.resultBolok(SobotResultCode.CODE_SUCCEEDED, "调用 SobotCallOpenApi login 成功", null);
                }
            } else {
                //v6 需要连接stomp
                String accesstoken = SobotLoginTools.getInstance().getAccessToken();
                String languageStr = CallBaseSharedPreferencesUtils.getInstance(context).get("SobotLanguageStr", "zh");
                SobotStompClient.getInstance(context).over(SobotStompClient.ConnectionProviderType.OKHTTP, SobotCallBaseUrl.getStompSocketUri() + "?authorization=Bearer " + accesstoken + "&language=" + languageStr, null, null);
                new Handler().postDelayed(new Runnable() {
                    @Override
                    public void run() {
                        if (SobotStompClient.getInstance(context).isConnected()) {
                            SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
                            String currentTime = System.currentTimeMillis() + "";
                            SobotStompClient.getInstance(context).send("/cc/app/request", "{\n" +
                                    "    \"messageID\": \"" + SobotStompEventConstant.RequestAgentLogin + "\",\n" +
                                    "    \"referenceID\": " + currentTime + ",\n" +
                                    "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                                    "    \"agentType\": \"1\",\n" +
                                    "    \"agentState\": \"" + agentState + "\",\n" +
                                    "    \"phoneType\": \"" + phoneType + "\",\n" +
                                    //手机登录需要必须传正确的分机号
                                    "    \"bindExt\": \"" + bindExt + "\",\n" +
                                    "    \"bindMobile\": \"" + bindMobile + "\",\n" +
                                    "    \"unbindExtOnLogout\": \"false\",\n\"edgeOut\": \"1\"," +
                                    "    \"userData\": {\n" +
                                    "        \"__fromChannel\": \"SobotMobilePhone\"" +
                                    "    },\n" +
                                    (SobotStringUtils.isEmpty(thisQueues) ? "" : "    \"thisQueues\": " + thisQueues + " ,\n") +
                                    "    \"creationTime\": " + currentTime + "\n" +
                                    "}\n").subscribe();
                            if (block != null) {
                                block.resultBolok(SobotResultCode.CODE_SUCCEEDED, "调用 SobotCallOpenApi login 成功", null);
                            }
                        } else {
                            if (block != null) {
                                block.resultBolok(SobotResultCode.CODE_FAILED, "调用 SobotCallOpenApi login 失败，原因：Stomp 没有连接上", null);
                            }
                        }
                    }
                }, 1500);

            }
        } else {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, "接听方式 只支持 pstn：手机 和 webrtc：网页", null);
            } else {
                SobotLogUtils.e("接听方式 只支持 pstn：手机 和 webrtc：网页");
            }
        }
    }


    /**
     * 签出
     *
     * @param block
     */
    public static void agentLogout(Context context, SobotResultBlock block) {
        if (!isLogin(context, "SobotCallOpenApi logout", block)) {
            return;
        }
        if (SobotStompClient.getInstance(context).isConnected()) {
            SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
            String currentTime = System.currentTimeMillis() + "";
            //座席签出
            SobotStompClient.getInstance(context).send("/cc/app/request", "{\n" +
                    "    \"messageID\": \"" + SobotStompEventConstant.RequestAgentLogout + "\",\n" +
                    "    \"referenceID\": " + currentTime + ",\n" +
                    "    \"companyId\": \"" + serviceVo.getCompanyId() + "\",\n" +
                    "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                    "    \"agentType\": \"1\",\n" +
                    "    \"creationTime\": " + currentTime + "\n" +
                    "}\n").subscribe();
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_SUCCEEDED, "调用 SobotCallOpenApi logout  成功", null);
            }
        } else {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, "调用SobotCallOpenApi logout 失败，原因：Stomp 没有连接上", null);
            }
        }
    }


    /**
     * 置闲
     *
     * @param block
     */
    public static void agentReady(Context context, SobotResultBlock block) {
        if (!isLogin(context, "SobotCallOpenApi ready", block)) {
            return;
        }
        if (SobotStompClient.getInstance(context).isConnected()) {
            SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
            String currentTime = System.currentTimeMillis() + "";
            //座席置闲
            SobotStompClient.getInstance(context).send("/cc/app/request", "{\n" +
                    "    \"messageID\": \"" + SobotStompEventConstant.RequestAgentReady + "\",\n" +
                    "    \"referenceID\": " + currentTime + ",\n" +
                    "    \"companyId\": \"" + serviceVo.getCompanyId() + "\",\n" +
                    "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                    "    \"agentType\": \"1\",\n" +
                    "    \"creationTime\": " + currentTime + "\n" +
                    "}\n").subscribe();
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_SUCCEEDED, "调用 SobotCallOpenApi ready  成功", null);
            }
        } else {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, "调用SobotCallOpenApi ready 失败，原因：Stomp 没有连接上", null);
            }
        }
    }

    /**
     * 查询座席的签入信息
     *
     * @param context 上下文
     * @param block   回调
     */
    public static void queryLoginBindingInfo(Context context, SobotResultBlock block) {
        if (!isLogin(context, "SobotCallOpenApi queryBusyStatus", block)) {
            return;
        }
        SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
        if (serviceVo == null) {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, "调用失败", null);
            }
            return;
        }
        SobotCallApiUtils.getZhiChiApi(context).queryLoginBindingInfo(context, serviceVo.getServiceId(), new SobotResultCallBack<SobotLoginBindEntity>() {
            @Override
            public void onSuccess(SobotLoginBindEntity loginBindEntity) {
                if (block != null) {
                    block.resultBolok(SobotResultCode.CODE_SUCCEEDED, "调用成功", loginBindEntity.getJson());
                }
            }

            @Override
            public void onFailure(Exception e, String des) {
                if (block != null) {
                    block.resultBolok(SobotResultCode.CODE_FAILED, "调用失败", des);
                }
            }
        });
    }

    /**
     * 查询座席可签入的技能组
     *
     * @param context 上下文
     * @param block   回调
     */
    public static void queryAvailableQueues(Context context, SobotResultBlock block) {
        String funName = "查询座席可签入的技能组: queryAvailableQueues ";
        if (!isLogin(context, funName, block)) {
            return;
        }
        SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
        if (serviceVo == null) {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, funName + "调用失败", null);
            }
            return;
        }
        SobotCallApiUtils.getZhiChiApi(context).queryAvailableQueues(context, serviceVo.getServiceId(), new SobotResultCallBack<List<QueueAgentCheckin>>() {
            @Override
            public void onSuccess(List<QueueAgentCheckin> queueAgentCheckins) {
                if (block != null) {
                    block.resultBolok(SobotResultCode.CODE_SUCCEEDED, funName + "调用成功", queueAgentCheckins);
                }
            }

            @Override
            public void onFailure(Exception e, String des) {
                if (block != null) {
                    block.resultBolok(SobotResultCode.CODE_FAILED, funName + "调用失败:" + des, null);
                }
            }
        });
    }

    /**
     * 查询座席可用置忙原因
     *
     * @param context 上下文
     * @param block   回调
     */
    public static void queryBusyStatus(Context context, SobotResultBlock block) {
        if (!isLogin(context, "SobotCallOpenApi queryBusyStatus", block)) {
            return;
        }
        SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
        if (serviceVo == null) {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, "调用失败", null);
            }
            return;
        }
        SobotCallApiUtils.getZhiChiApi(context).queryBusyStatuses(context, serviceVo.getServiceId(), new SobotResultCallBack<List<SobotBusyStatusEntity>>() {
            @Override
            public void onSuccess(List<SobotBusyStatusEntity> sobotBusyStatusEntities) {
                if (block != null) {
                    block.resultBolok(SobotResultCode.CODE_SUCCEEDED, "调用 queryBusyStatus 成功", sobotBusyStatusEntities);
                }
            }

            @Override
            public void onFailure(Exception e, String des) {
                if (block != null) {
                    block.resultBolok(SobotResultCode.CODE_FAILED, "调用失败", des);
                }
            }
        });
    }

    /**
     * 查询座席可使用分机帐号
     *
     * @param context 上下文
     * @param block   回调
     */
    public static void queryAvailableExts(Context context, SobotResultBlock block) {
        if (!isLogin(context, "SobotCallOpenApi queryBusyStatus", block)) {
            return;
        }
        SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
        if (serviceVo == null) {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, "调用失败", null);
            }
            return;
        }
        SobotCallApiUtils.getZhiChiApi(context).queryAvailableExts(context, serviceVo.getServiceId(), new SobotResultCallBack<List<SobotExtEntity>>() {
            @Override
            public void onSuccess(List<SobotExtEntity> sobotExtEntities) {
                if (block != null) {
                    block.resultBolok(SobotResultCode.CODE_SUCCEEDED, "调用成功", sobotExtEntities);
                }
            }

            @Override
            public void onFailure(Exception e, String des) {
                if (block != null) {
                    block.resultBolok(SobotResultCode.CODE_FAILED, "调用失败", des);
                }
            }
        });
    }

    /**
     * 置忙
     *
     * @param reasonCode 置忙原因 不可为空 ； 置忙后显示的登录状态。 2：勿扰；11：小休；12：小休（培训）；13：小休（会议）；14：小休（用餐）；15：小休（活动）；16：小休（自定义1）；17：小休（自定义2）；18：小休（自定义3）。
     * @param block
     */
    public static void agentNotReady(Context context, String reasonCode, SobotResultBlock block) {
        if (!isLogin(context, "SobotCallOpenApi notReady", block)) {
            return;
        }
        if (TextUtils.isEmpty(reasonCode)) {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, "notReady接口 参数reasonCode 置忙原因 不能为空", null);
            } else {
                SobotLogUtils.e("notReady接口 参数reasonCode 置忙原因 不能为空");
            }
            return;
        }
        if (SobotStompClient.getInstance(context).isConnected()) {
            SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
            String currentTime = System.currentTimeMillis() + "";
            //座席置忙
            SobotStompClient.getInstance(context).send("/cc/app/request", "{\n" +
                    "    \"messageID\": \"" + SobotStompEventConstant.RequestAgentNotReady + "\",\n" +
                    "    \"referenceID\": " + currentTime + ",\n" +
                    "    \"companyId\": \"" + serviceVo.getCompanyId() + "\",\n" +
                    "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                    "    \"agentType\": \"1\",\n" +
                    "    \"reasonCode\": \"" + reasonCode + "\",\n" +
                    "    \"creationTime\": " + currentTime + "\n" +
                    "}\n").subscribe();
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_SUCCEEDED, "调用 SobotCallOpenApi notReady  成功", null);
            }
        } else {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, "调用SobotCallOpenApi notReady 失败，原因：Stomp 没有连接上", null);
            }
        }
    }

    /**
     * 座席重置离线
     *
     * @param block
     */
    public static void resetLogout(Context context, SobotResultBlock block) {
        if (!isLogin(context, "SobotCallOpenApi resetLogout", block)) {
            return;
        }
        if (SobotStompClient.getInstance(context).isConnected()) {
            SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
            String currentTime = System.currentTimeMillis() + "";
            //座重置离线
            SobotStompClient.getInstance(context).send("/cc/app/request", "{\n" +
                    "    \"messageID\": \"" + SobotStompEventConstant.RequestAgentResetLogout + "\",\n" +
                    "    \"referenceID\": " + currentTime + ",\n" +
                    "    \"companyId\": \"" + serviceVo.getCompanyId() + "\",\n" +
                    "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                    "    \"agentType\": \"1\",\n" +
                    "    \"creationTime\": " + currentTime + "\n" +
                    "}\n").subscribe();
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_SUCCEEDED, "调用 SobotCallOpenApi resetLogout 成功", null);
            }
        } else {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, "调用SobotCallOpenApi resetLogout 失败，原因：Stomp 没有连接上", null);
            }
        }
    }


    //----------------------------呼叫操作----------------------------

    /**
     * 外呼
     *
     * @param otherDN          客户号码
     * @param privacyNumber    客户号码加密
     * @param ANI              指定客户侧的外显号码
     * @param outboundPlanCode 指定客户侧的外显号码
     * @param ANI              指定客户侧的外显号码
     * @param block            方法执行回调
     */
    public static void makeCall(Context context, String otherDN, String privacyNumber, String ANI, String outboundPlanCode, String agentANI, SobotResultBlock block) {
        String funName = "外呼 makeCall ";
        if (!isLogin(context, funName, block)) {
            return;
        }
        SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
        String currentTime = System.currentTimeMillis() + "";
        String userData = "";
        if (!TextUtils.isEmpty(privacyNumber)) {
            Map<String, String> map = new HashMap<>();
            map.put("privacyNumber", privacyNumber);
            userData = SobotGsonUtil.beanToJson(map);
        } else {
            userData = "{}";
        }
        if (SobotStompClient.getInstance(context).isConnected()) {
            SobotStompClient.getInstance(context).send("/cc/app/request", "{\n" +
                    "    \"messageID\": \"" + SobotStompEventConstant.RequestMakeCall + "\",\n" +
                    "    \"referenceID\": " + currentTime + ",\n" +
                    "    \"companyId\": \"" + serviceVo.getCompanyId() + "\",\n" +
                    "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                    "    \"agentType\": \"1\",\n" +
                    "    \"otherDN\": \"" + otherDN + "\",\n" +
                    "    \"ANI\": \"" + ANI + "\",\n" +
                    "    \"outboundPlanCode\": \"" + outboundPlanCode + "\",\n" +
                    "    \"agentANI\": \"" + agentANI + "\",\n" +
                    "    \"userData\": " + userData + ",\n" +
                    "    \"creationTime\": " + currentTime + "\n" +
                    "}\n").subscribe();
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_SUCCEEDED, funName + "调用成功", null);
            }
        } else {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, funName + "调用失败，原因：Stomp 没有连接上", null);
            }
        }
    }

    /**
     * 拒接
     */
    public static void rejectCall(Context context, SobotResultBlock block) {
        if (!isLogin(context, "rejectCall", block)) {
            return;
        }
        SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
        String currentTime = System.currentTimeMillis() + "";
        if (SobotStompClient.getInstance(context).isConnected()) {
            SobotStompClient.getInstance(context).send("/cc/app/request", "{\n" +
                    "    \"messageID\": \"" + SobotStompEventConstant.RequestHangup + "\",\n" +
                    "    \"referenceID\": " + currentTime + ",\n" +
                    "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                    "    \"agentType\": \"1\",\n" +
                    "    \"creationTime\": " + currentTime + "\n" +
                    "}\n").subscribe();
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_SUCCEEDED, "调用 rejectCall 成功", null);
            }
        } else {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, "调用 rejectCall 失败，原因：Stomp 没有连接上", null);
            }
        }
    }

    /**
     * 接听
     */
    public static void answer(Context context, String jsep, SobotResultBlock block) {
        if (!isLogin(context, "answer", block)) {
            return;
        }
        if (TextUtils.isEmpty(jsep)) {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, " 接听接口answer SessionDescription 不能为空", null);
            }
            return;
        }
        SobotJanusSipPhoneUtils.accept(context, jsep);
        if (block != null) {
            block.resultBolok(SobotResultCode.CODE_SUCCEEDED, "调用 answer 成功", null);
        }
    }

    /**
     * 挂机
     */
    public static void hangup(Context context, SobotResultBlock block) {
        if (!isLogin(context, "hangup", block)) {
            return;
        }
        SobotJanusSipPhoneUtils.hangUp();
        if (block != null) {
            block.resultBolok(SobotResultCode.CODE_SUCCEEDED, "调用 hangup 成功", null);
        }
    }

    /**
     * 当前用户挂掉电话
     *
     * @param serviceVo 当前用户
     * @param block     回调
     */
    public static void hangup(Context context, SobotServiceInfoModel serviceVo, SobotResultBlock block) {
        String funTag = "hangup";
        String currentTime = System.currentTimeMillis() + "";
        if (SobotStompClient.getInstance(context).isConnected()) {
            //v6的要挂断
            SobotStompClient.getInstance(context).send("/cc/app/request", "{\n" +
                    "    \"messageID\": \"" + SobotStompEventConstant.RequestHangup + "\",\n" +
                    "    \"referenceID\": " + currentTime + ",\n" +
                    "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                    "    \"companyId\": \"" + serviceVo.getCompanyId() + "\",\n" +
                    "    \"agentType\": \"1\",\n" +
                    "    \"creationTime\": " + currentTime + "\n" +
                    "}\n").subscribe();
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_SUCCEEDED, funTag + " 调用成功", null);
            }
        } else {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, funTag + " 调用失败，原因：Stomp 没有连接上", null);
            }
        }
    }

    /**
     * 保持
     */
    public static void holdCall(Context context, SobotResultBlock block) {
        if (!isLogin(context, "holdCall", block)) {
            return;
        }
        SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
        String currentTime = System.currentTimeMillis() + "";
        if (SobotStompClient.getInstance(context).isConnected()) {
            SobotStompClient.getInstance(context).send("/cc/app/request", "{\n" +
                    "    \"messageID\": \"" + SobotStompEventConstant.RequestHoldCall + "\",\n" +
                    "    \"referenceID\": " + currentTime + ",\n" +
                    "    \"companyId\": \"" + serviceVo.getCompanyId() + "\",\n" +
                    "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                    "    \"agentType\": \"1\",\n" +
                    "    \"creationTime\": " + currentTime + "\n" +
                    "}\n").subscribe();
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_SUCCEEDED, "调用 holdCall 成功", null);
            }
        } else {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, "调用 holdCall 失败，原因：Stomp 没有连接上", null);
            }
        }
    }

    /**
     * 取消保持
     */
    public static void retrieveCall(Context context, SobotResultBlock block) {
        String funName = "retrieveCall";
        if (!isLogin(context, funName, block)) {
            return;
        }
        SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
        String currentTime = System.currentTimeMillis() + "";
        if (SobotStompClient.getInstance(context).isConnected()) {
            SobotStompClient.getInstance(context).send("/cc/app/request", "{\n" +
                    "    \"messageID\": \"" + SobotStompEventConstant.RequestRetrieveCall + "\",\n" +
                    "    \"referenceID\": " + currentTime + ",\n" +
                    "    \"companyId\": \"" + serviceVo.getCompanyId() + "\",\n" +
                    "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                    "    \"agentType\": \"1\",\n" +
                    "    \"creationTime\": " + currentTime + "\n" +
                    "}\n").subscribe();
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_SUCCEEDED, funName + "调用成功", null);
            }
        } else {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, funName + "调用失败，原因：Stomp 没有连接上", null);
            }
        }
    }

    /**
     * 静音
     */
    public static void muteCall(Context context, SobotResultBlock block) {
        String funTag = "muteCall";
        if (!isLogin(context, funTag, block)) {
            return;
        }
        SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
        String currentTime = System.currentTimeMillis() + "";
        if (SobotStompClient.getInstance(context).isConnected()) {
            SobotStompClient.getInstance(context).send("/cc/app/request", "{\n" +
                    "    \"messageID\": \"" + SobotStompEventConstant.RequestMute + "\",\n" +
                    "    \"referenceID\": " + currentTime + ",\n" +
                    "    \"companyId\": \"" + serviceVo.getCompanyId() + "\",\n" +
                    "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                    "    \"agentType\": \"1\",\n" +
                    "    \"creationTime\": " + currentTime + "\n" +
                    "}\n").subscribe();
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_SUCCEEDED, funTag + " 调用成功", null);
            }
        } else {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, funTag + " 调用失败，原因：Stomp 没有连接上", null);
            }
        }
    }

    /**
     * 取消静音
     */
    public static void unMuteCall(Context context, SobotResultBlock block) {
        String funTag = "unMuteCall";
        if (!isLogin(context, funTag, block)) {
            return;
        }
        SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
        String currentTime = System.currentTimeMillis() + "";
        if (SobotStompClient.getInstance(context).isConnected()) {
            SobotStompClient.getInstance(context).send("/cc/app/request", "{\n" +
                    "    \"messageID\": \"" + SobotStompEventConstant.RequestUnmute + "\",\n" +
                    "    \"referenceID\": " + currentTime + ",\n" +
                    "    \"companyId\": \"" + serviceVo.getCompanyId() + "\",\n" +
                    "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                    "    \"agentType\": \"1\",\n" +
                    "    \"creationTime\": " + currentTime + "\n" +
                    "}\n").subscribe();
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_SUCCEEDED, funTag + " 调用成功", null);
            }
        } else {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, funTag + " 调用失败，原因：Stomp 没有连接上", null);
            }
        }
    }

    /**
     * 保持取消
     */
    public static void cancalHoldCall(Context context, SobotResultBlock block) {
        String funTag = "cancalHoldCall";
        if (!isLogin(context, funTag, block)) {
            return;
        }
        SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
        String currentTime = System.currentTimeMillis() + "";
        if (SobotStompClient.getInstance(context).isConnected()) {
            SobotStompClient.getInstance(context).send("/cc/app/request", "{\n" +
                    "    \"messageID\": \"" + SobotStompEventConstant.RequestRetrieveCall + "\",\n" +
                    "    \"referenceID\": " + currentTime + ",\n" +
                    "    \"companyId\": \"" + serviceVo.getCompanyId() + "\",\n" +
                    "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                    "    \"agentType\": \"1\",\n" +
                    "    \"creationTime\": " + currentTime + "\n" +
                    "}\n").subscribe();
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_SUCCEEDED, funTag + " 调用成功", null);
            }
        } else {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, funTag + " 调用失败，原因：Stomp 没有连接上", null);
            }
        }
    }

    /**
     * 发送满意度
     *
     * @param autoSatisfy 1-表示手动发送满意度；0或者不传值-自动发送满意度(如果系统设置自动发送满意度)
     */
    public static void sendSatisfacion(Context context, int autoSatisfy, SobotResultBlock block) {
        String funTag = "sendSatisfacion";
        if (!isLogin(context, funTag, block)) {
            return;
        }
        SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
        String currentTime = System.currentTimeMillis() + "";
        if (SobotStompClient.getInstance(context).isConnected()) {
            SobotStompClient.getInstance(context).send("/cc/app/request", "{\n" +
                    "    \"messageID\": \"" + SobotStompEventConstant.RequestHangup + "\",\n" +
                    "    \"referenceID\": " + currentTime + ",\n" +
                    "    \"companyId\": \"" + serviceVo.getCompanyId() + "\",\n" +
                    "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                    "    \"agentType\": \"1\",\n" +
                    "    \"autoSatisfy\": " + (autoSatisfy == 1 ? 1 : 0) + ",\n" +
                    "    \"creationTime\": " + currentTime + "\n" +
                    "}\n").subscribe();
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_SUCCEEDED, funTag + " 调用成功", null);
            }
        } else {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, funTag + " 调用失败，原因：Stomp 没有连接上", null);
            }
        }
    }

    /**
     * 延长整理时长
     *
     * @param delayTime 延长秒数在30-900秒之间
     */
    public static void delayCallAfterWork(Context context, int delayTime, SobotResultBlock block) {
        String funTag = "delayCallAfterWork";
        if (!isLogin(context, funTag, block)) {
            return;
        }
        if (delayTime > 900 || delayTime < 30) {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, "座席可以延长整理时长范围30-900秒", null);
            } else {
                SobotLogUtils.e("座席可以延长整理时长范围30-900秒");
            }
            return;
        }
        SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
        String currentTime = System.currentTimeMillis() + "";
        if (SobotStompClient.getInstance(context).isConnected()) {
            SobotStompClient.getInstance(context).send("/cc/app/request", "{\n" +
                    "    \"messageID\": \"" + SobotStompEventConstant.RequestDelayCallAfterWork + "\",\n" +
                    "    \"referenceID\": " + currentTime + ",\n" +
                    "    \"companyId\": \"" + serviceVo.getCompanyId() + "\",\n" +
                    "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                    "    \"agentType\": \"1\",\n" +
                    "    \"delayTime\": " + delayTime + ",\n" +
                    "    \"creationTime\": " + currentTime + "\n" +
                    "}\n").subscribe();
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_SUCCEEDED, funTag + " 调用成功", null);
            }
        } else {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, funTag + " 调用失败，原因：Stomp 没有连接上", null);
            }
        }
    }

    /**
     * 结束整理
     */
    public static void finishCallAfterWork(Context context, SobotResultBlock block) {
        String funTag = "finishCallAfterWork";
        if (!isLogin(context, funTag, block)) {
            return;
        }
        if (SobotStompClient.getInstance(context).isConnected()) {
            SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
            String currentTime = System.currentTimeMillis() + "";
            //座席置闲
            SobotStompClient.getInstance(context).send("/cc/app/request", "{\n" +
                    "    \"messageID\": \"" + SobotStompEventConstant.RequestAgentReady + "\",\n" +
                    "    \"referenceID\": " + currentTime + ",\n" +
                    "    \"companyId\": \"" + serviceVo.getCompanyId() + "\",\n" +
                    "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                    "    \"agentType\": \"1\",\n" +
                    "    \"creationTime\": " + currentTime + "\n" +
                    "}\n").subscribe();
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_SUCCEEDED, funTag + " 调用成功", null);
            }
        } else {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, funTag + " 调用失败，原因：Stomp 没有连接上", null);
            }
        }
    }

    /**
     * 结束整理并置忙
     */
    public static void finishCallAfterWorkAndBusy(Context context, SobotResultBlock block) {
        String funTag = "finishCallAfterWorkAndBusy";
        if (!isLogin(context, funTag, block)) {
            return;
        }
        if (SobotStompClient.getInstance(context).isConnected()) {
            SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
            String currentTime = System.currentTimeMillis() + "";
            //座席置闲
            SobotStompClient.getInstance(context).send("/cc/app/request", "{\n" +
                    "    \"messageID\": \"" + SobotStompEventConstant.RequestAgentReady + "\",\n" +
                    "    \"referenceID\": " + currentTime + ",\n" +
                    "    \"companyId\": \"" + serviceVo.getCompanyId() + "\",\n" +
                    "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                    "    \"agentType\": \"1\",\n" +
                    "    \"userData\": {\n" +
                    "       \"endACW2Busy\": \"true\"\n" +
                    "    },\n" +
                    "    \"creationTime\": " + currentTime + "\n" +
                    "}\n").subscribe();
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_SUCCEEDED, funTag + " 调用成功", null);
            }
        } else {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, funTag + " 调用失败，原因：Stomp 没有连接上", null);
            }
        }
    }


    /**
     * 发送按键
     *
     * @param dtmfDigits 按键对应值:一次请求发送一个按键值，如，801#，则依次发送8、0、1、#这些按键请求
     */
    public static void sendDtmf(Context context, String dtmfDigits, SobotResultBlock block) {
        String funTag = "sendDtmf";
        if (!isLogin(context, funTag, block)) {
            return;
        }
        if (SobotStringUtils.isEmpty(dtmfDigits)) {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, "按键值为空，请重新输入", null);
            } else {
                SobotLogUtils.e("按键值为空，请重新输入");
            }
            return;
        }
        if (dtmfDigits.length() > 1) {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, "按键值输入异常，一次只能发送一个按键值", null);
            } else {
                SobotLogUtils.e("按键值输入异常，一次只能发送一个按键值");
            }
            return;
        }
        if (SobotStompClient.getInstance(context).isConnected()) {
            SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
            String currentTime = System.currentTimeMillis() + "";
            //座席置闲
            SobotStompClient.getInstance(context).send("/cc/app/request", "{\n" +
                    "    \"messageID\": \"" + SobotStompEventConstant.RequestSendDtmf + "\",\n" +
                    "    \"referenceID\": " + currentTime + ",\n" +
                    "    \"companyId\": \"" + serviceVo.getCompanyId() + "\",\n" +
                    "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                    "    \"agentType\": \"1\",\n" +
                    "    \"dtmfDigits\": \"" + dtmfDigits + "\",\n" +
                    "    \"creationTime\": " + currentTime + "\n" +
                    "}\n").subscribe();
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_SUCCEEDED, funTag + " 调用成功", null);
            }
        } else {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, funTag + " 调用失败，原因：Stomp 没有连接上", null);
            }
        }
    }

    /**
     * 查询座席的外呼路由规则
     *
     * @param context
     */
    public static void queryOutBoudRoutesRules(Context context, SobotResultBlock block) {
        String funTag = "queryOutBoudRoutesRules";
        if (!isLogin(context, funTag, block)) {
            return;
        }

        SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
        SobotCallApiUtils.getZhiChiApi(context).queryOutBoudRoutesRules(context, serviceVo.getServiceId(), new SobotResultCallBack<SobotOutboundRoutesEntity>() {
            @Override
            public void onSuccess(SobotOutboundRoutesEntity o) {
                if (block != null) {
                    block.resultBolok(SobotResultCode.CODE_SUCCEEDED, funTag + " 调用成功", o.getJson());
                }
            }

            @Override
            public void onFailure(Exception e, String des) {
                if (block != null) {
                    block.resultBolok(SobotResultCode.CODE_FAILED, funTag + "：" + des, null);
                }
            }
        });

    }

    /**
     * 切换座席的外呼外显规则
     *
     * @param explicitRule   外显规则:1：企业号码池随机匹配；2：动态外显号码方案匹配；3：座席号码池指定；单选；
     * @param explicitCode   动态外显方案编码: 外显规则为动态外显号码方案时必传
     * @param explicitNumber 外显号码:不使用外显规则，直接指定企业的某外显号码呼叫客户，外显号码和外显规则至少需要传一个
     */
    public static void switchOutBoudRoutesRules(Context context, String explicitRule, String explicitCode, String explicitNumber, SobotResultBlock block) {
        String funTag = "switchOutBoudRoutesRules";
        if (!isLogin(context, funTag, block)) {
            return;
        }
        if (SobotStringUtils.isEmpty(explicitRule)) {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, "外显规则必填项，不能为空", null);
            } else {
                SobotLogUtils.e("外显规则必填项，不能为空");
            }
            return;
        }
        if (explicitRule.equals("2")) {
            if (SobotStringUtils.isEmpty(explicitCode)) {
                if (block != null) {
                    block.resultBolok(SobotResultCode.CODE_FAILED, "外显规则为动态外显号码方案时，动态外显方案编码不能为空", null);
                } else {
                    SobotLogUtils.e("外显规则为动态外显号码方案时，动态外显方案编码不能为空");
                }
                return;
            }
        }

        SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
        SobotCallApiUtils.getZhiChiApi(context).switchOutBoudRoutesRules(context, serviceVo.getServiceId(), explicitRule, explicitCode, explicitNumber, new SobotResultCallBack<SobotOutboundRoutesEntity>() {
            @Override
            public void onSuccess(SobotOutboundRoutesEntity outboundRoutesEntity) {
                if (block != null) {
                    block.resultBolok(SobotResultCode.CODE_SUCCEEDED, funTag + " 调用成功", outboundRoutesEntity.getJson());
                }
            }

            @Override
            public void onFailure(Exception e, String des) {
                if (block != null) {
                    block.resultBolok(SobotResultCode.CODE_FAILED, funTag + "：" + des, null);
                }
            }
        });
    }

    /**
     * 断开socket链接
     */
    public static void disConnnet(Context context) {
        if (SobotStompClient.getInstance(context) != null) {
            SobotStompClient.getInstance(context).disconnect();
        }
        if (context == null) return;
        SobotServiceInfoModel serviceVoModel = SobotLoginTools.getInstance().getServiceInfo();
        if (serviceVoModel != null) {
            if (SobotJanusSipPhoneUtils.isServiceRun()) {
                SobotJanusSipPhoneUtils.logoutUser();
                SobotRegistrationListener.getInstance().isLogin = false;
                SobotJanusSipPhoneUtils.stopService(context);
            }
        } else {
            if (SobotJanusSipPhoneUtils.isServiceRun()) {
                SobotJanusSipPhoneUtils.logoutUser();
                SobotRegistrationListener.getInstance().isLogin = false;
                SobotJanusSipPhoneUtils.stopService(context);
            }
        }
    }

    /**
     * 发送满意度
     *
     * @param autoSatisfy 1-表示手动发送满意度；0或者不传值-自动发送满意度(如果系统设置自动发送满意度)；
     * @param block
     */
    public static void sendSatisfaction(Context context, int autoSatisfy, SobotResultBlock block) {
        if (!isLogin(context, "SobotCallOpenApi logout", block)) {
            return;
        }
        if (SobotStompClient.getInstance(context).isConnected()) {
            SobotServiceInfoModel serviceVo = getServiceVoInfos(context);
            String currentTime = System.currentTimeMillis() + "";
            //座席签出
            SobotStompClient.getInstance(context).send("/cc/app/request", "{\n" +
                    "    \"messageID\": \"" + SobotStompEventConstant.RequestHangup + "\",\n" +
                    "    \"referenceID\": " + currentTime + ",\n" +
                    "    \"companyId\": \"" + serviceVo.getCompanyId() + "\",\n" +
                    "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                    "    \"agentType\": \"1\",\n" +
                    "    \"autoSatisfy\": " + autoSatisfy + ",\n" +
                    "    \"creationTime\": " + currentTime + "\n" +
                    "}\n").subscribe();
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_SUCCEEDED, "调用 SobotCallOpenApi logout  成功", null);
            }
        } else {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, "调用SobotCallOpenApi logout 失败，原因：Stomp 没有连接上", null);
            }
        }
    }

    /**
     * 自动切换麦克风扬声器为 打开/关闭
     *
     * @param context
     * @param block
     */
    public static void changedPlayCategory(Context context, boolean on, SobotResultBlock block) {
        if (context == null) {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, "开启/关闭免提 changedPlayCategory接口 context 不能为空", null);
            } else {
                SobotLogUtils.e("开启/关闭免提 changedPlayCategory接口 context 不能为空");
            }
            return;
        }
        try {
            AudioManager audioManager = (AudioManager) context.getSystemService(Context.AUDIO_SERVICE);
            boolean speakerPhoneType;
            if (audioManager != null) {
                if (!on) {
                    if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
                        audioManager.setMode(AudioManager.MODE_IN_COMMUNICATION);
                        //设置音量，解决有些机型切换后没声音或者声音突然变大的问题;
                        audioManager.setStreamVolume(AudioManager.STREAM_VOICE_CALL,
                                audioManager.getStreamMaxVolume(AudioManager.STREAM_VOICE_CALL),
                                AudioManager.FLAG_PLAY_SOUND);
                    } else {
                        audioManager.setMode(AudioManager.MODE_IN_CALL);
                        audioManager.setStreamVolume(AudioManager.STREAM_VOICE_CALL,
                                audioManager.getStreamMaxVolume(AudioManager.STREAM_VOICE_CALL),
                                AudioManager.FLAG_PLAY_SOUND);
                    }
                    //扬声器关闭，此方法调用之前需要先设置好mode
                    audioManager.setSpeakerphoneOn(false);
                    speakerPhoneType = false;
                } else {
                    audioManager.setMode(AudioManager.MODE_IN_COMMUNICATION);
                    audioManager.setStreamVolume(AudioManager.STREAM_VOICE_CALL,
                            audioManager.getStreamMaxVolume(AudioManager.STREAM_VOICE_CALL),
                            AudioManager.FLAG_PLAY_SOUND);
                    audioManager.setSpeakerphoneOn(true);
                    speakerPhoneType = true;
                }
                if (block != null) {
                    block.resultBolok(SobotResultCode.CODE_FAILED, "开启/关闭免提 changedPlayCategory接口 成功", speakerPhoneType);
                } else {
                    SobotLogUtils.e("开启/关闭免提 changedPlayCategory接口 成功，当前：" + speakerPhoneType);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 查询 麦克风扬声器是否打开
     *
     * @param context
     * @param block
     * @return true ：扬声器打开 ；false : 扬声器关闭
     */
    public static void searchPlayCategory(Context context, SobotResultBlock block) {
        if (context == null) {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, "开启/关闭免提 changedPlayCategory接口 context 不能为空", null);
            } else {
                SobotLogUtils.e("开启/关闭免提 changedPlayCategory接口 context 不能为空");
            }
        }
        try {
            AudioManager audioManager = (AudioManager) context.getSystemService(Context.AUDIO_SERVICE);
            if (audioManager != null) {
                if (block != null) {
                    block.resultBolok(SobotResultCode.CODE_SUCCEEDED, "开启/关闭免提 changedPlayCategory接口 成功", audioManager.isSpeakerphoneOn());
                } else {
                    SobotLogUtils.e("开启/关闭免提 changedPlayCategory接口 成功");
                }
            }
        } catch (Exception e) {
            if (block != null) {
                block.resultBolok(SobotResultCode.CODE_FAILED, "开启/关闭免提 changedPlayCategory接口 失败:未获取到声音配置", null);
            } else {
                SobotLogUtils.e("开启/关闭免提 changedPlayCategory接口 失败:未获取到声音配置");
            }
            e.printStackTrace();
        }
    }
}
