package com.sobot.callsdk;

import static com.sobot.callsdk.utils.SobotCallConstant.SOBOT_KEY_INIT;

import android.Manifest;
import android.app.Activity;
import android.app.Application;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.content.res.Resources;
import android.os.Build;
import android.text.TextUtils;

import androidx.core.content.ContextCompat;

import com.sobot.callbase.api.SobotCallBaseUrl;
import com.sobot.callbase.api.utils.CallBaseSharedPreferencesUtils;
import com.sobot.callbase.constant.SobotCallBaseConstant;
import com.sobot.callbase.stomp.SobotStompClient;
import com.sobot.callsdk.activity.SobotCallActivity;
import com.sobot.callsdk.api.SobotCallService;
import com.sobot.callsdk.api.SobotCallServiceFactory;
import com.sobot.callsdk.listener.SobotRegistrationListener;
import com.sobot.callsdk.model.SobotCallConfigEntity;
import com.sobot.callsdk.sip.SobotSipUtils;
import com.sobot.callsdk.utils.CallSharedPreferencesUtils;
import com.sobot.callsdk.utils.MyActivityLifeCycle;
import com.sobot.callsdk.utils.SobotApplication;
import com.sobot.callsdk.utils.SobotCallApiUtils;
import com.sobot.callsdk.utils.SobotCallConstant;
import com.sobot.common.login.SobotLoginTools;
import com.sobot.common.login.callback.SobotResultBlock;
import com.sobot.common.login.callback.SobotResultCode;
import com.sobot.common.login.model.SobotServiceInfoModel;
import com.sobot.common.utils.SobotCommonApi;
import com.sobot.utils.SobotLogUtils;
import com.sobot.utils.SobotSharedPreferencesUtil;
import com.sobot.utils.SobotStringUtils;
import com.sobot.utils.SobotSystemUtils;
import com.sobot.widget.SobotWidgetApi;
import com.sobot.widget.ui.SobotBaseConstant;
import com.sobot.widget.ui.SobotMarkConfig;

import java.util.Locale;

public class ZCSobotCallApi {

    /**
     * 初始化SDK
     *
     * @param application
     */
    public static void init(Application application) {
        if (application == null) {
            SobotLogUtils.e("init 参数 application不能为空");
            return;
        }
        application.registerActivityLifecycleCallbacks(MyActivityLifeCycle.getInstance());
        SobotCommonApi.init(application, SobotCallBaseUrl.getOpenApiHost() + SobotCallBaseUrl.getCallApiHost() + SobotCallBaseUrl.getStompSocketUri());
        disConnnet(application);
        CallSharedPreferencesUtils.getInstance(application).clearAll();
        SobotApplication.getmInstance().put(SOBOT_KEY_INIT, true);
        SobotWidgetApi.setSwitchMarkStatus(SobotMarkConfig.SHOW_PERMISSION_TIPS_POP, true);
    }

    /**
     * 设置域名
     *
     * @param application
     * @param config      接口域名
     */
    public static void setHost(Application application, SobotCallConfigEntity config) {
        if (application == null) {
            SobotLogUtils.e("initWithHost 参数 application不能为空");
            return;
        }
        if (config != null) {
            if (!TextUtils.isEmpty(config.getOpenApiHost())) {
                SobotCallBaseUrl.setOpenApiHost(config.getOpenApiHost());
            }
            if (!TextUtils.isEmpty(config.getCallApiHost())) {
                SobotCallBaseUrl.setCallApiHost(config.getCallApiHost());
            }
            if (!TextUtils.isEmpty(config.getStompSocketUri())) {
                SobotCallBaseUrl.setStompSocketUri(config.getStompSocketUri());
            }
            if (!TextUtils.isEmpty(config.getSipProxy())) {
                SobotCallBaseUrl.setSipProxy(config.getSipProxy());
            }
            if (!TextUtils.isEmpty(config.getJanusSocketUri())) {
                SobotCallBaseUrl.setJanusSocketUri(config.getJanusSocketUri());
            }
        }
        SobotCommonApi.init(application, SobotCallBaseUrl.getOpenApiHost() + SobotCallBaseUrl.getCallApiHost() + SobotCallBaseUrl.getStompSocketUri());
    }

    /**
     * 通过邮箱密码方式启动呼叫系统，进入首页
     *
     * @param context
     * @param loginUser 客服账号
     * @param loginPwd  登录密码
     */
    public static void startWithAcount(Context context, String loginUser, String loginPwd, SobotResultBlock block) {
        Object obj = SobotApplication.getmInstance().get(SOBOT_KEY_INIT);
        if (obj != null) {
            boolean isInit = (boolean) SobotApplication.getmInstance().get(SOBOT_KEY_INIT);
            if (isInit) {
                loginUser(context, loginUser, loginPwd, true, block);
            } else {
                SobotLogUtils.e("请在Application中调用【ZCSobotCallApi.initWithHost()】来初始化SDK!");
            }
        } else {
            SobotLogUtils.e("请在Application中调用【ZCSobotCallApi.initWithHost()】来初始化SDK!");
        }
    }

    /**
     * 通过设置公司token方式启动呼叫系统，进入首页
     *
     * @param context
     * @param loginUser    客服账号
     * @param companyToken 公司token
     * @param block        回调结果 可为空
     */
    public static void startWithToken(Context context, String loginUser, String companyToken, SobotResultBlock block) {
        Object obj = SobotApplication.getmInstance().get(SOBOT_KEY_INIT);
        if (obj != null) {
            boolean isInit = (boolean) SobotApplication.getmInstance().get(SOBOT_KEY_INIT);
            if (isInit) {
                loginWithCompanyToken(context, loginUser, companyToken, true, block);
            } else {
                SobotLogUtils.e("请在Application中调用【ZCSobotCallApi.initWithHost()】来初始化SDK!");
            }
        } else {
            SobotLogUtils.e("请在Application中调用【ZCSobotCallApi.initWithHost()】来初始化SDK!");
        }
    }

    /**
     * 通过设置appkey和appid方式启动呼叫系统，进入首页
     *
     * @param context
     * @param loginUser 客服账号
     * @param appKey    登录appKey  找售后同事获取(客户账号开通时会有这个)
     * @param appId     登录appId 找售后同事获取(客户账号开通时会有这个)
     * @param block     回调结果 可为空
     */
    public static void startWithAppkey(Context context, String loginUser, String appKey, String appId, SobotResultBlock block) {
        Object obj = SobotApplication.getmInstance().get(SOBOT_KEY_INIT);
        if (obj != null) {
            boolean isInit = (boolean) SobotApplication.getmInstance().get(SOBOT_KEY_INIT);
            if (isInit) {
                loginWithAppkey(context, loginUser, appKey, appId, true, block);
            } else {
                SobotLogUtils.e("请在Application中调用【ZCSobotCallApi.initWithHost()】来初始化SDK!");
            }
        } else {
            SobotLogUtils.e("请在Application中调用【ZCSobotCallApi.initWithHost()】来初始化SDK!");
        }
    }

    /**
     * 通过邮箱密码方式登录呼叫SDK
     *
     * @param context
     * @param loginUser 客服账号
     * @param loginPwd  登录密码
     * @param block     回调结果 可为空
     */
    public static void loginUser(Context context, String loginUser, String loginPwd, boolean isGoToActivity, SobotResultBlock block) {
        if (context == null) {
            if (block != null)
                block.resultBolok(SobotResultCode.CODE_FAILED, "startAuthWithAcount 参数 context不能为空", null);
            SobotLogUtils.e("startAuthWithAcount 参数 context不能为空");
            return;
        }
        if (TextUtils.isEmpty(loginUser)) {
            if (block != null)
                block.resultBolok(SobotResultCode.CODE_FAILED, "客服账户不能为空", null);
            SobotLogUtils.e("客服账户不能为空");
            return;
        }
        if (TextUtils.isEmpty(loginPwd)) {
            if (block != null)
                block.resultBolok(SobotResultCode.CODE_FAILED, "登录密码不能为空", null);
            SobotLogUtils.e("登录密码不能为空");
            return;
        }
        CallSharedPreferencesUtils.getInstance(context).put(SobotCallConstant.SOBOT_CALL_KEY_LOGIN_FROM, 0);
        SobotCallService zhiChiApi = SobotCallServiceFactory.createZhiChiApi(context);
        SobotLoginTools.getInstance().doLogin(context, context, false, SobotCallBaseUrl.getOpenApiHost(), SobotCallBaseUrl.getCallApiHost(), loginUser, loginPwd, null, new com.sobot.common.login.callback.SobotResultBlock() {
            @Override
            public void resultBolok(com.sobot.common.login.callback.SobotResultCode code, String msg, Object obj) {
                if (code == com.sobot.common.login.callback.SobotResultCode.CODE_SUCCEEDED) {
                    SobotServiceInfoModel serviceVoModel = SobotLoginTools.getInstance().getServiceInfo();
                    if (serviceVoModel != null) {
                        updateLanguage(context, serviceVoModel);
                        if (serviceVoModel.getCallV6Flag() == 1) {
                            //v6 获取到当前公司设置的呼叫客服状态列表
                            SobotCallApiUtils.getLoginStatusV6(zhiChiApi, this, context, null);
                        } else {
                            //获取到当前公司设置的呼叫客服状态列表
                            SobotCallApiUtils.getCallServiceStatusList(zhiChiApi, this, context, null);
                        }
                        if (isGoToActivity) {
                            Intent classificationIntent = new Intent(context, SobotCallActivity.class);
                            classificationIntent.putExtra("callV6Flag", serviceVoModel.getCallV6Flag());
                            context.startActivity(classificationIntent);
                        }
                        if (block != null)
                            block.resultBolok(SobotResultCode.CODE_SUCCEEDED, "登录成功", "");
                    } else {
                        if (block != null)
                            block.resultBolok(SobotResultCode.CODE_FAILED, "登录失败", obj);
                    }
                } else {
                    if (block != null)
                        block.resultBolok(SobotResultCode.CODE_FAILED, msg, obj);
                }
            }
        });
    }

    /**
     * 通过设置公司token方式登录呼叫系统
     *
     * @param context
     * @param loginUser      客服账号
     * @param companyToken   公司token
     * @param isGoToActivity 是否跳转到呼叫中心页面 true 跳转，false 不跳转
     * @param block          回调结果 可为空
     */
    public static void loginWithCompanyToken(Context context, String loginUser, String companyToken, boolean isGoToActivity, SobotResultBlock block) {
        if (context == null) {
            SobotLogUtils.e("startAuthWithAcount 参数 context不能为空");
            return;
        }
        if (TextUtils.isEmpty(loginUser)) {
            if (block != null)
                block.resultBolok(SobotResultCode.CODE_FAILED, "客服账户不能为空", null);
            SobotLogUtils.e("客服账户不能为空");
            return;
        }
        if (TextUtils.isEmpty(companyToken)) {
            if (block != null)
                block.resultBolok(SobotResultCode.CODE_FAILED, "登录token不能为空", null);
            SobotLogUtils.e("登录token不能为空");
            return;
        }
        CallSharedPreferencesUtils.getInstance(context).put(SobotCallConstant.SOBOT_CALL_KEY_LOGIN_FROM, 0);
        SobotCallService zhiChiApi = SobotCallServiceFactory.createZhiChiApi(context);
        SobotLoginTools.getInstance().loginWithCompanyToken(context, context, false, SobotCallBaseUrl.getOpenApiHost(), SobotCallBaseUrl.getCallApiHost(), loginUser, companyToken, null, new com.sobot.common.login.callback.SobotResultBlock() {
            @Override
            public void resultBolok(com.sobot.common.login.callback.SobotResultCode code, String msg, Object obj) {
                if (code == com.sobot.common.login.callback.SobotResultCode.CODE_SUCCEEDED) {
                    SobotServiceInfoModel serviceVoModel = SobotLoginTools.getInstance().getServiceInfo();
                    if (serviceVoModel != null) {
                        updateLanguage(context, serviceVoModel);
                        if (serviceVoModel.getCallV6Flag() == 1) {
                            //v6 获取到当前公司设置的呼叫客服状态列表
                            SobotCallApiUtils.getLoginStatusV6(zhiChiApi, this, context, null);
                        } else {
                            //获取到当前公司设置的呼叫客服状态列表
                            SobotCallApiUtils.getCallServiceStatusList(zhiChiApi, this, context, null);
                        }
                        if (isGoToActivity) {
                            Intent classificationIntent = new Intent(context, SobotCallActivity.class);
                            classificationIntent.putExtra("callV6Flag", serviceVoModel.getCallV6Flag());
                            context.startActivity(classificationIntent);
                        }
                        if (block != null)
                            block.resultBolok(SobotResultCode.CODE_SUCCEEDED, "登录成功", "");
                    } else {
                        if (block != null)
                            block.resultBolok(SobotResultCode.CODE_FAILED, "登录失败", obj);
                    }
                } else {
                    if (block != null)
                        block.resultBolok(SobotResultCode.CODE_FAILED, msg, obj);
                }
            }
        });
    }


    /**
     * 通过设置appkey和appid方式登录呼叫系统
     *
     * @param context
     * @param loginUser      客服账号
     * @param appKey         登录appKey  找售后同事获取(客户账号开通时会有这个)
     * @param appId          登录appId 找售后同事获取(客户账号开通时会有这个)
     * @param isGoToActivity 是否跳转到呼叫中心页面 true 跳转，false 不跳转
     * @param block          回调结果 可为空
     */
    public static void loginWithAppkey(Context context, String loginUser, String appKey, String appId, boolean isGoToActivity, SobotResultBlock block) {
        if (context == null) {
            SobotLogUtils.e("startAuthWithAcount 参数 context不能为空");
            return;
        }
        if (TextUtils.isEmpty(loginUser)) {
            if (block != null)
                block.resultBolok(SobotResultCode.CODE_FAILED, "客服账户不能为空", null);
            SobotLogUtils.e("客服账户不能为空");
            return;
        }
        if (TextUtils.isEmpty(appKey) || TextUtils.isEmpty(appId)) {
            if (block != null)
                block.resultBolok(SobotResultCode.CODE_FAILED, "appKey、appId不能为空", null);
            SobotLogUtils.e("appKey、appId不能为空");
            return;
        }
        CallSharedPreferencesUtils.getInstance(context).put(SobotCallConstant.SOBOT_CALL_KEY_LOGIN_FROM, 0);
        SobotCallService zhiChiApi = SobotCallServiceFactory.createZhiChiApi(context);
        SobotLoginTools.getInstance().loginWithAppkey(context, context, false, SobotCallBaseUrl.getOpenApiHost(), SobotCallBaseUrl.getCallApiHost(), loginUser, appKey, appId, null, new com.sobot.common.login.callback.SobotResultBlock() {
            @Override
            public void resultBolok(com.sobot.common.login.callback.SobotResultCode code, String msg, Object obj) {
                if (code == com.sobot.common.login.callback.SobotResultCode.CODE_SUCCEEDED) {
                    SobotServiceInfoModel serviceVoModel = SobotLoginTools.getInstance().getServiceInfo();
                    if (serviceVoModel != null) {
                        updateLanguage(context, serviceVoModel);
                        if (serviceVoModel.getCallV6Flag() == 1) {
                            //v6 获取到当前公司设置的呼叫客服状态列表
                            SobotCallApiUtils.getLoginStatusV6(zhiChiApi, this, context, null);
                        } else {
                            //获取到当前公司设置的呼叫客服状态列表
                            SobotCallApiUtils.getCallServiceStatusList(zhiChiApi, this, context, null);
                        }
                        if (isGoToActivity) {
                            Intent classificationIntent = new Intent(context, SobotCallActivity.class);
                            classificationIntent.putExtra("callV6Flag", serviceVoModel.getCallV6Flag());
                            context.startActivity(classificationIntent);
                        }
                        if (block != null)
                            block.resultBolok(SobotResultCode.CODE_SUCCEEDED, "登录成功", "");
                    } else {
                        if (block != null)
                            block.resultBolok(SobotResultCode.CODE_FAILED, "登录失败", obj);
                    }
                } else {
                    if (block != null)
                        block.resultBolok(SobotResultCode.CODE_FAILED, msg, obj);
                }
            }
        });
    }

    public static void updateLanguage(Context context, SobotServiceInfoModel serviceVoModel) {
        if (serviceVoModel != null) {
            String language = "";
            if (!SobotStringUtils.isEmpty(serviceVoModel.getServiceLanguage())) {
                language = serviceVoModel.getServiceLanguage();
            } else if (!SobotStringUtils.isEmpty(serviceVoModel.getServiceLanguage())) {
                language = serviceVoModel.getServiceLanguage();
            }
            if (!TextUtils.isEmpty(language) && !"".equals(language)) {
                Locale locale = null;
                if ("zh".equals(language)) {
                    //中文
                    locale = new Locale("zh");
                } else if ("en".equals(language)) {
                    //英文
                    locale = new Locale("en");
                } else {
                    locale = new Locale("zh");
                }
                //多语言语言设置,初始化之后设置有效，之前无效（初始化会清理语言设置）
                CallSharedPreferencesUtils.getInstance(context).put("SobotLanguage", locale);
                CallBaseSharedPreferencesUtils.getInstance(context).put("SobotLanguageStr", language);
            }
        }
    }

    public static void updateLanguage(Context context, String language) {
        if (!TextUtils.isEmpty(language)) {
            Locale locale = null;
            if ("zh".equals(language)) {
                //中文
                locale = new Locale("zh");
            } else if ("en".equals(language)) {
                //英文
                locale = new Locale("en");
            } else {
                locale = new Locale("zh");
            }
            //多语言语言设置,初始化之后设置有效，之前无效（初始化会清理语言设置）
            CallSharedPreferencesUtils.getInstance(context).put("SobotLanguage", locale);
            CallBaseSharedPreferencesUtils.getInstance(context).put("SobotLanguageStr", language);
        }
    }


    /**
     * 退出登录
     *
     * @param context
     * @param loginAcount 登录账号
     * @param block       回调结果 可为空
     */
    public static void out(Context context, String loginAcount, SobotResultBlock block) {
        SobotLoginTools.getInstance().logOut(context, SobotCallBaseUrl.getOpenApiHost(), loginAcount, new SobotResultBlock() {
            @Override
            public void resultBolok(SobotResultCode code, String msg, Object obj) {
                SobotLoginTools.getInstance().clearLoginInfo();
                if (block != null) {
                    block.resultBolok(code, msg, obj);
                }
            }
        });
        disConnnet(context);
        CallSharedPreferencesUtils.getInstance(context).clearAll();
    }

    /**
     * 断开socket链接
     */
    public static void disConnnet(Context context) {
        if (SobotStompClient.getInstance(context) != null) {
            SobotStompClient.getInstance(context).disconnect();
        }
        if (context == null) return;
        SobotServiceInfoModel serviceVoModel = SobotLoginTools.getInstance().getServiceInfo();
        if (serviceVoModel != null) {
            if (SobotSipUtils.isServiceRun(serviceVoModel.getCallV6Flag() == 1 ? true : false)) {
                SobotSipUtils.logoutUser(serviceVoModel.getCallV6Flag() == 1 ? true : false);
                SobotRegistrationListener.getInstance().isLogin = false;
                SobotSipUtils.stopService(serviceVoModel.getCallV6Flag() == 1 ? true : false, context);
            }
        } else {
            if (SobotSipUtils.isServiceRun(false)) {
                SobotSipUtils.logoutUser(false);
                SobotRegistrationListener.getInstance().isLogin = false;
                SobotSipUtils.stopService(false, context);
            }
        }
    }

    /**
     * 日志显示
     *
     * @param isShow true 显示；false 不显示，默认不显示
     */
    public static void setShowLogDebug(boolean isShow) {
        SobotCommonApi.setShowLogDebug(isShow);
        SobotSipUtils.isOpenLog(isShow);
    }


    /**
     * 检查录音权限
     *
     * @return true, 已经获取权限;false,没有权限,尝试获取
     */
    public static boolean checkAudioPermission(Activity activity) {
        if (Build.VERSION.SDK_INT >= 23 && SobotSystemUtils.getTargetSdkVersion(activity) >= 23) {
            if (ContextCompat.checkSelfPermission(activity, Manifest.permission.RECORD_AUDIO)
                    != PackageManager.PERMISSION_GRANTED) {
                activity.requestPermissions(new String[]{Manifest.permission.RECORD_AUDIO},
                        SobotBaseConstant.SOBOT_CODE_PERMISSIONS_REQUEST);
                return false;
            }
        }
        return true;
    }

    /**
     * 获取开关状态
     *
     * @param markConfig 开关名
     * @return
     * @see SobotMarkConfig 取值
     */
    public static boolean getSwitchMarkStatus(int markConfig) {
        if ((markConfig & (markConfig - 1)) == 0)
            return SobotMarkConfig.getON_OFF(markConfig);
        else {
            throw new Resources.NotFoundException("markConfig 必须为2的指数次幂");
        }
    }

    /**
     * 设置开关状态
     *
     * @param markConfig 开关名 必须为 2 的非负数整数次幂
     * @param isOn
     * @see SobotMarkConfig 取值
     */
    public static void setSwitchMarkStatus(int markConfig, boolean isOn) {
        if ((markConfig & (markConfig - 1)) == 0)
            SobotMarkConfig.setON_OFF(markConfig, isOn);
        else {
            throw new Resources.NotFoundException("markConfig 必须为2的指数次幂");
        }
    }

    /**
     * 设置当前呼叫版本
     *
     * @param context
     * @param version
     */
    public static void setCallVersion(Context context, String userId, int version) {
        SobotSharedPreferencesUtil.getInstance(context).put(userId + "_email", version);
    }

    /**
     * 获取呼叫当前版本
     *
     * @param context
     * @return
     */
    public static int getCallVersion(Context context, String userId) {
        int version = SobotSharedPreferencesUtil.getInstance(context).get(userId + "_email", 0);
        return version;
    }

    /**
     * 删除呼叫当前版本
     *
     * @param context
     * @return
     */
    public static void deleteCallVersion(Context context, String userId) {
        SobotSharedPreferencesUtil.getInstance(context).remove(userId + "_email");
    }


    /**
     * app内部更新客户选中的呼叫版本
     *
     * @param context
     * @param callVersion 账号是v1还是v6 1:v1,6:v6
     * @param block       回调结果 可为空
     */

    public static void updateLoginUserInfo(Context context,
                                           int callVersion, SobotResultBlock block) {
        if (context == null) {
            SobotLogUtils.e("appLoginUser 参数 context不能为空");
            return;
        }
        CallSharedPreferencesUtils.getInstance(context).put(SobotCallConstant.SOBOT_CALL_KEY_LOGIN_FROM, 1);
        SobotCallService zhiChiApi = SobotCallServiceFactory.createZhiChiApi(context);
        SobotServiceInfoModel serviceVoModel = SobotLoginTools.getInstance().getServiceInfo();
        if (serviceVoModel != null) {
            //指定是v1还是v6
            int cv = 0;
            if (callVersion == 0) {
                cv = getCallVersion(context, serviceVoModel.getServiceId());
            } else {
                cv = callVersion;
            }
            if (cv == 1) {
                serviceVoModel.setCallV6Flag(0);
            } else if (cv == 6) {
                serviceVoModel.setCallV6Flag(1);
            }
            SobotLoginTools.getInstance().setServiceInfo(serviceVoModel);
            if (serviceVoModel.getCallV6Flag() == 1) {
                //v6账号
                SobotCallApiUtils.getLoginStatusV6(zhiChiApi, context, context, null);
                if (block != null) {
                    block.resultBolok(SobotResultCode.CODE_SUCCEEDED, "", "");
                }
            } else {
                //获取到当前公司设置的呼叫客服状态列表
                SobotCallApiUtils.getCallServiceStatusList(zhiChiApi, context, context, null);
                if (block != null) {
                    block.resultBolok(SobotResultCode.CODE_SUCCEEDED, "", "");
                }

            }
        }
    }
}
