package com.sobot.callsdk.activity;

import android.app.Activity;
import android.content.pm.ActivityInfo;
import android.graphics.Rect;
import android.os.Build;
import android.os.Bundle;
import android.view.Gravity;
import android.view.MotionEvent;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;

import androidx.annotation.Nullable;

import com.sobot.callsdk.ZCSobotCallApi;
import com.sobot.common.utils.SobotResourceUtils;
import com.sobot.widget.ui.SobotMarkConfig;
import com.sobot.widget.ui.notchlib.SobotINotchScreen;
import com.sobot.widget.ui.notchlib.SobotNotchScreenManager;


/**
 * 从界面下方弹出的activity
 *
 */
public abstract class SobotDialogBaseActivity extends SobotCallBaseActivity {


    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        if (Build.VERSION.SDK_INT != Build.VERSION_CODES.O) {
            if (!ZCSobotCallApi.getSwitchMarkStatus(SobotMarkConfig.LANDSCAPE_SCREEN)) {
                setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_UNSPECIFIED);//竖屏
            } else {
                setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_SENSOR_LANDSCAPE);//横屏

            }
        }
        super.onCreate(savedInstanceState);

        //窗口对齐屏幕宽度
        Window win = this.getWindow();
        WindowManager.LayoutParams lp = win.getAttributes();
        lp.width = WindowManager.LayoutParams.MATCH_PARENT;
        lp.height = WindowManager.LayoutParams.WRAP_CONTENT;
        lp.gravity = Gravity.BOTTOM;
        win.setAttributes(lp);
    }


    public static void displayInNotch(Activity activity, final View view) {
        if (ZCSobotCallApi.getSwitchMarkStatus(SobotMarkConfig.LANDSCAPE_SCREEN) && ZCSobotCallApi.getSwitchMarkStatus(SobotMarkConfig.DISPLAY_INNOTCH) && view != null && activity != null) {
            // 获取刘海屏信息
            SobotNotchScreenManager.getInstance().getNotchInfo(activity, new SobotINotchScreen.NotchScreenCallback() {
                @Override
                public void onResult(SobotINotchScreen.NotchScreenInfo notchScreenInfo) {
                    if (notchScreenInfo.hasNotch) {
                        for (Rect rect : notchScreenInfo.notchRects) {
                            view.setPadding((rect.right > 110 ? 110 : rect.right), view.getPaddingTop(), view.getPaddingRight(), view.getPaddingBottom());
                        }
                    }
                }
            });

        }
    }

    public boolean onTouchEvent(MotionEvent event) {
        if (event.getAction() == MotionEvent.ACTION_DOWN) {
            if (event.getY() <= 0) {
                finish();
            }
        }
        return true;
    }


    @Override
    public void onBackPressed() {
        finish();
    }

    @Override
    public void finish() {
        super.finish();
        overridePending();
    }

    private void overridePending() {
        overridePendingTransition(SobotResourceUtils.getIdByName(
                getApplicationContext(), "anim", "sobot_popupwindow_in"),
                SobotResourceUtils.getIdByName(getApplicationContext(),
                        "anim", "sobot_popupwindow_out"));
    }

    public Activity getContext() {
        return SobotDialogBaseActivity.this;
    }
}
