package com.sobot.callsdk.api;

import android.content.Context;

import com.sobot.callbase.api.SobotCallBaseCode;
import com.sobot.callbase.api.SobotCallBaseCodeThird;
import com.sobot.callbase.api.SobotCallBaseResult;
import com.sobot.callbase.api.SobotStringResultCallBack;
import com.sobot.callbase.model.CallNumberCity;
import com.sobot.callbase.model.CallSipModel;
import com.sobot.callbase.model.CallTaskContactModel;
import com.sobot.callbase.model.CallTaskDetailsModel;
import com.sobot.callbase.model.CanSubmitSummaryModel;
import com.sobot.callbase.model.EnterPriseModel;
import com.sobot.callbase.model.QueueAgentCheckin;
import com.sobot.callbase.model.SobotAgentInfoEntity;
import com.sobot.callbase.model.SobotBusyStatusEntity;
import com.sobot.callbase.model.SobotCallListSecondEntity;
import com.sobot.callbase.model.SobotCallStatusEntity;
import com.sobot.callbase.model.SobotCountryRegion;
import com.sobot.callbase.model.SobotCusFieldEntity;
import com.sobot.callbase.model.SobotExtEntity;
import com.sobot.callbase.model.SobotExtensionEntity;
import com.sobot.callbase.model.SobotLoginBindEntity;
import com.sobot.callbase.model.SobotLoginStatusEntity;
import com.sobot.callbase.model.SobotOutboundRoutesEntity;
import com.sobot.callbase.model.SobotSummaryClassifies;
import com.sobot.callbase.model.SobotSummaryEntity;
import com.sobot.callbase.model.SobotSummaryProgress;
import com.sobot.callbase.model.SobotSummaryTemplate;
import com.sobot.callbase.model.callinfo.CallDetailEntity;
import com.sobot.callbase.model.callinfo.CallMainCDRInfo;
import com.sobot.callbase.model.placename.AreaModel;
import com.sobot.callbase.model.placename.CityModel;
import com.sobot.callbase.model.placename.CountryModel;
import com.sobot.callbase.model.placename.ProvinceModel;
import com.sobot.callsdk.model.SobotAgentEntity;
import com.sobot.callsdk.model.SobotCall3Response;
import com.sobot.callsdk.model.SobotCallCenterStatus;
import com.sobot.callsdk.model.SobotCallCustomerModel;
import com.sobot.callsdk.model.SobotCallRecordDetailEntity;
import com.sobot.callsdk.model.SobotCallRecordEntity;
import com.sobot.callsdk.model.SobotCallTaskEntity;
import com.sobot.callsdk.v1.entity.v1.SobotCallContactPlan;
import com.sobot.callsdk.v1.entity.v1.SobotCallRecordV1;
import com.sobot.callsdk.v1.entity.v1.SobotCallSeatCurrentStatus;
import com.sobot.callsdk.v1.entity.v1.SobotCallTaskDetailsModel;
import com.sobot.callsdk.v1.entity.v1.SobotCallTaskModel;
import com.sobot.callsdk.v1.entity.v1.SobotWorkOrderUser;
import com.sobot.network.http.callback.SobotResultCallBack;

import java.util.List;
import java.util.Map;

/**
 * 对外输出接口类
 */
public interface SobotCallService {
    /**
     * 获取AccessToken接口
     */
    void getAccessToken(Object cancelTag, String token, SobotResultCallBack<Object> resultCallBack);

    /**
     * @param user 新增客户信息
     */
    void addCustomerInfo(Object tag, SobotCallCustomerModel user, boolean isNew, SobotResultCallBack<SobotCallCustomerModel> resultCallBack);

    /**
     * @param user 编辑客户信息
     */
    void updateCustomerInfo(Object tag, SobotCallCustomerModel user, SobotResultCallBack<SobotCallCustomerModel> resultCallBack);

    /**
     * 获取客户信息-根据手机号
     *
     * @param phtone 手机号
     */
    void getCustomerInfoByPhone(Object tag, String phtone, SobotResultCallBack<SobotCallCustomerModel> resultCallBack);


    //--------------------------呼叫V1接口 start -------------------------------

    /**
     * 查询自定义状态列表接口
     */
    void getCallServiceStatus(Object tag, Context context, SobotResultCallBack<SobotCall3Response<SobotCallCenterStatus>> resultCallBack);

    /**
     * 查询技能组
     */
    void queryGroupListV1(Object tag, Context context, SobotResultCallBack<SobotCallBaseCodeGroup> resultCallBack);

    /**
     * 获取座席状态
     */
    void appGetAgentStatus(Context context, SobotResultCallBack<SobotCallSeatCurrentStatus> resultCallBack);


    /**
     * 呼叫中心 根据电话号码查询客户信息
     */
    void getAppUserListByCallNum(Object tag, Context context, String tel, SobotResultCallBack<List<SobotWorkOrderUser>> resultCallBack);


    /**
     * 设置座席状态
     *
     * @param tag
     * @param context
     * @param agentStatus    座席状态
     * @param resultCallBack
     */
    void appSetAgentStatus(Object tag, Context context, String agentStatus, SobotResultCallBack<SobotCallBaseCode> resultCallBack);

    /**
     * 电话条登出
     *
     * @param tag
     * @param model
     * @param number
     * @param resultCallBack
     */
    void appAgentLogout(Object tag, Context context, int model, String number, SobotResultCallBack<SobotCallBaseCode> resultCallBack);

    /**
     * 电话条登陆
     */
    void appAgentLogin(Object tag, Context context, int model, String number, SobotResultCallBack<SobotCallBaseCode> resultCallBack);


    /**
     * 获取账号登陆模式
     *
     * @param tag
     * @param resultCallBack
     */
    void appAgentLoginModel(Object tag, Context context, SobotResultCallBack<SobotCallBaseCodeThird> resultCallBack);

    /**
     * 获取SIP账号注册信息
     */
    void appGetSipMsg(Object tag, Context context, String agentNumber, SobotResultCallBack<CallSipModel> resultCallBack);

    /**
     * 外呼
     *
     * @param cancelTag
     * @param resultCallBack
     */
    void callOut(Object cancelTag, Context context, int hiddenFlag, String taskDetailId, String taskId, String calleeNumber, String groupId, SobotResultCallBack<SobotCallBaseResult> resultCallBack);

    /**
     * V1挂断
     *
     * @param cancelTag
     * @param context
     * @param resultCallBack
     */
    void hungUp(Object cancelTag, Context context, SobotStringResultCallBack<SobotCallBaseResult> resultCallBack);

    /**
     * 呼叫任务列表
     *
     * @param pageNo   页码
     * @param pageSize 每页条数
     */
    void getAllTaskDetails(Object cancelTag, Context context, int pageNo, int pageSize, SobotResultCallBack<List<SobotCallTaskModel>> resultCallBack);

    /**
     * 呼叫任务列表 V6
     *
     * @param pageNo   页码
     * @param pageSize 每页条数
     */
    void getTaskListV6(Object cancelTag, Context context,String name, int pageNo, int pageSize, SobotResultCallBack<List<SobotCallTaskEntity>> resultCallBack);

    /**
     * 获取任务详情
     *
     * @param taskId   任务id
     * @param pageNo   页码
     * @param pageSize 每页条数
     */
    void getOneTaskDetails(Object cancelTag, Context context, String taskId, int pageNo, int pageSize, SobotResultCallBack<List<SobotCallTaskDetailsModel>> resultCallBack);

    /**
     * V6获取任务详情
     *
     * @param taskId   任务id
     * @param pageNo   页码
     * @param pageSize 每页条数
     */
    void getTaskDetailsV6(Object cancelTag, Context context, String taskId,String type,String value,String name, int pageNo, int pageSize, SobotResultCallBack<SobotCallListSecondEntity<CallTaskDetailsModel>> resultCallBack);

    /**
     * V6获取任务详情 呼叫
     */
    void taskCallV6(Object cancelTag, Context context, String recordId, String campaignId, SobotResultCallBack<String> resultCallBack);

    /**
     * 通话记录列表
     *
     * @param pageNo   页码
     * @param pageSize 每页条数
     */
    void getCallRecord(Object cancelTag, Context context, int pageNo, int pageSize, SobotResultCallBack<List<SobotCallRecordV1>> resultCallBack);

    /**
     * 一个手机号的通话详情
     *
     * @param pageNo   页码
     * @param pageSize 每页条数
     * @param callee   手机号
     */
    void getAppServiceCallRecordByPhone(Object cancelTag, Context context, int pageNo, int pageSize, String callee, SobotResultCallBack<SobotCallBaseCodeRecord> resultCallBack);

    /**
     * 联系计划列表
     *
     * @param pageNo   页码
     * @param pageSize 每页条数
     */
    void getAllCallContactPlan(Object cancelTag, Context context, int pageNo, int pageSize, SobotResultCallBack<List<SobotCallContactPlan>> resultCallBack);

    /**
     * 添加计划
     *
     * @param taskIdName   任务名称
     * @param taskDetailId 任务详情id
     * @param plan         计划
     */
    void addCallContactPlanInfo(Object cancelTag, Context context, String taskIdName, String taskDetailId, SobotCallContactPlan plan, SobotResultCallBack<SobotCallBaseCode> resultCallBack);

    /**
     * 更新计划
     *
     * @param plan 计划
     */
    void updateCallContactPlanInfo(Object cancelTag, Context context, SobotCallContactPlan plan, SobotResultCallBack<SobotCallBaseCode> resultCallBack);

    /**
     * 删除计划
     *
     * @param id 计划id
     */
    void deleteCallContactPlanInfo(Object cancelTag, Context context, String id, SobotResultCallBack<SobotCallBaseResult> resultCallBack);

    //--------------------------呼叫V1接口 end -------------------------------


    //--------------------------呼叫V6接口 start -------------------------------


    /**
     * 查询登录状态字典
     *
     * @param cancelTag
     * @param resultCallBack
     */
    void getLoginStatus(Object cancelTag, SobotResultCallBack<List<SobotLoginStatusEntity>> resultCallBack);

    /**
     * 查询座席接听方式
     *
     * @param cancelTag
     * @param agentID        必填 座席工号 或 座席id；值的内容由agentType值决定；
     * @param agentType      选填 0：座席工号；1：座席id;为空时，默认座席工号。
     * @param resultCallBack
     */
    void phoneTypes(Object cancelTag, String agentID, String agentType, SobotResultCallBack<SobotAgentEntity> resultCallBack);


    /**
     * 查询分机帐号接口
     *
     * @param cancelTag
     * @param ext        分机号；
     * @param agentID        必填 座席工号 或 座席id；值的内容由agentType值决定；
     * @param agentType      选填 0：座席工号；1：座席id;为空时，默认座席工号。
     * @param currPage      当前页
     * @param pageSize      每页个数
     * @param resultCallBack
     */
    void getExtensionList(Object cancelTag,String ext, String agentID, String agentType,int currPage,int pageSize,SobotResultCallBack<List<SobotExtensionEntity>> resultCallBack);
    void getExtensionList(Object cancelTag, String agentID, String agentType,SobotResultCallBack<List<SobotExtensionEntity>> resultCallBack);

    /**
     * 修改分机语言编码
     *
     * @param cancelTag
     */
    void editExtsLangCode(Object cancelTag, String agentID, String agentType, String ext, String langCodeTxt, SobotResultCallBack<SobotExtensionEntity> resultCallBack);

    /**
     * 查询通话记录
     *
     * @param startTime      必填 开始时间毫秒数，当天时间的前三个月
     * @param endTime        必填 开始时间毫秒数，当天时间的23点59分
     * @param callType       呼叫类型 2: 呼入; 3: 外呼;可传多个："2,3"
     * @param callResult     通话结果:1.其他原因无法应答 2.欠费 3.客户号码黑名单 4.未找到座席侧 5.客户速挂6.座席侧未接听 7.客户未接听 8.双方已接听 9.中继号码停用 ;可传多个："5,8"
     * @param customerId     客户Id
     * @param customerNumber 客户号码
     * @param pageNo         必填
     * @param pageSize       必填
     */
    void getCallRecordList(Object cancelTag, long startTime, long endTime, String callType, String callResult, String customerId, String customerNumber, int pageNo, int pageSize, boolean hidePhone, SobotResultCallBack<List<SobotCallRecordEntity>> resultCallBack);


    /**
     * 获取通话详情
     *
     * @param callID 主会话ID
     */
    void getCallDetails(Object cancelTag, String callID, SobotResultCallBack<CallDetailEntity> resultCallBack);

    /**
     * 根据主会话查所有的子会话
     *
     * @param callID 主会话ID
     */
    void getCallRecordOne(Object cancelTag, String callID, SobotResultCallBack<List<SobotCallRecordDetailEntity>> resultCallBack);

    //重连恢复座席状态
    void recoverAgentStatus(Object canceTag, Context context, String simpSessionId, String currentInstanceId, SobotResultCallBack<SobotAgentInfoEntity> resultCallBack);

    //重连恢复座席状态
    void recoverAgentCallStatus(Object canceTag, Context context, String simpSessionId, String currentInstanceId, SobotResultCallBack<SobotCallStatusEntity> resultCallBack);

    /**
     * 查询座席的外呼路由规则
     *
     * @param context
     */
    void queryOutBoudRoutesRules(Context context, String serviceId, SobotResultCallBack<SobotOutboundRoutesEntity> block);

    /**
     * 切换座席的外呼外显规则
     *
     * @param explicitRule   外显规则:1：企业号码池随机匹配；2：动态外显号码方案匹配；3：座席号码池指定；单选；
     * @param explicitCode   动态外显方案编码: 外显规则为动态外显号码方案时必传
     * @param explicitNumber 外显号码:不使用外显规则，直接指定企业的某外显号码呼叫客户，外显号码和外显规则至少需要传一个
     */
    void switchOutBoudRoutesRules(Context context, String serviceId, String explicitRule, String explicitCode, String explicitNumber, SobotResultCallBack<SobotOutboundRoutesEntity> block);

    /**
     * 查询座席可用的置忙原因
     *
     * @param serviceId 客服id
     */
    void queryBusyStatuses(Context context, String serviceId, SobotResultCallBack<List<SobotBusyStatusEntity>> block);

    /**
     * 查询座席可使用分机帐号
     *
     * @param serviceId 客服id
     */
    void queryAvailableExts(Context context, String serviceId, SobotResultCallBack<List<SobotExtEntity>> block);

    /**
     * 查询座席可签入的技能组
     *
     * @param serviceId 客服id
     */
    void queryAvailableQueues(Context context, String serviceId, SobotResultCallBack<List<QueueAgentCheckin>> block);

    /**
     * 查询座席可签入的技能组
     *
     * @param serviceId 客服id
     */
    void queryLoginBindingInfo(Context context, String serviceId, SobotResultCallBack<SobotLoginBindEntity> block);

    /**
     * 查询电话区号
     */
    void searchCallingCodeV6(Context context, SobotResultCallBack<String> block);

    /**
     * 查询电话区号列表
     */
    void searchAreaListV6(Context context, SobotResultCallBack<List<SobotCountryRegion>> block);

    /**
     * 修改电话区号
     */
    void updateAreaV6(Context context, String callingCode, SobotResultCallBack block);

    /**
     * 获取服务总结配置
     */
    void getSummaryConfig(Context context, SobotResultCallBack resultCallBack);

    /**
     * 获取服务总结 分类
     *
     * @param planType         Default value : 1
     * @param classifyParentId 父级分类id，有值查询此分类的下级所有分类
     */
    void getSummaryClassifies(Context context, String planType, String classifyParentId, SobotResultCallBack<List<SobotSummaryClassifies>> resultCallBack);

    /**
     * 获取服务总结--模板
     */
    void getSummaryTemplates(Context context, int currPage, int pageSize, SobotResultCallBack<List<SobotSummaryTemplate>> resultCallBack);

    /**
     * 获取自定义字段
     */
    void getCusFieldInfoList(Context context, int businessType, SobotResultCallBack<List<SobotCusFieldEntity>> resultCallBack);

    /**
     * 查询总结
     *
     * @param context
     * @param resultCallBack
     */
    void searchSummary(Context context, String callID, SobotResultCallBack<SobotSummaryEntity> resultCallBack);

    /**
     * 状态记录
     *
     * @param context
     * @param resultCallBack
     */
    void handleProgress(Context context, SobotResultCallBack<List<SobotSummaryProgress>> resultCallBack);

    /**
     * 提交会话总结
     *
     * @param context
     * @param summaryModel
     * @param planType 方案
     * @param resultCallBack
     */
    void submitSummary(Context context, SobotSummaryEntity summaryModel,int planType, SobotResultCallBack resultCallBack);

    /**
     * 保存客户信息
     *
     * @param context
     * @param customer
     * @param resultCallBack
     */
    void saveCustom(Context context, SobotCallCustomerModel customer, Map<String ,String> cusList, SobotResultCallBack<SobotCallCustomerModel> resultCallBack);
    /**
     * 保存客户信息
     *
     * @param context
     * @param customer
     * @param resultCallBack
     */
    void updateCustom(Context context, SobotCallCustomerModel customer, Map<String ,String> cusList, SobotResultCallBack<SobotCallCustomerModel> resultCallBack);

    /**
     * 查询客户信息
     *
     * @param context
     * @param customerId
     * @param resultCallBack
     */
    void searchCustomById(Context context, String customerId, SobotResultCallBack<SobotCallCustomerModel> resultCallBack);

    /**
     * 合并客户
     *
     * @param context
     * @param customer
     * @param resultCallBack
     */
    void mergeCustom(Context context, SobotCallCustomerModel customer, SobotResultCallBack<SobotCallCustomerModel> resultCallBack);

    void associationCustom(Context context, String callId, String customId, SobotResultCallBack resultCallBack);

    void getCountryList(Context context, SobotResultCallBack<List<CountryModel>> resultCallBack);

    /**
     * 获取省或这州
     *
     * @param context
     * @param countryId
     * @param resultCallBack
     */
    void getProvinceListByCountryId(Context context, String countryId, SobotResultCallBack<List<ProvinceModel>> resultCallBack);

    void getCityList(Context context, String provinceId, SobotResultCallBack<List<CityModel>> resultCallBack);

    void getAreaList(Context context, String cityId, SobotResultCallBack<List<AreaModel>> resultCallBack);

    /**
     * 获取企业列表
     *
     * @param context
     * @param pageNo
     * @param pageSize
     * @param searchValue    搜索企业名字
     * @param resultCallBack
     */
    void getEnterpriseList(Context context, int pageNo, int pageSize, String searchValue, SobotResultCallBack<List<EnterPriseModel>> resultCallBack);


    /**
     * @param context
     * @param searchType     搜索类型 4：号码，1：昵称
     * @param searchValue    搜索值
     * @param resultCallBack
     */
    void searchCustom(Context context, String searchType, String searchValue, SobotResultCallBack resultCallBack);

    /**
     * 回拨
     */
    void callbacks(Context context, String fromCallID, String sourceType, String sourceId, String switchCurrentTabs, SobotResultCallBack
            resultCallBack);

    /**
     * 查询技能组开关权限
     *
     * @param context
     * @param resultCallBack
     */
    void queueCheckin(Context context, SobotResultCallBack resultCallBack);

    /**
     * 查询通话是否可以提交服务总结
     *
     * @param context
     * @param callId         通话id
     * @param resultCallBack
     */
    void queueCanSubmitSummary(Context context, String callId, SobotResultCallBack<CanSubmitSummaryModel> resultCallBack);
    //--------------------------呼叫V6接口 end -------------------------------

    /**
     * 查询号码归属地
     *
     * @param context
     * @param callId         callId
     * @param resultCallBack
     */
    void queueNumberInfo(Context context,String callId,SobotResultCallBack<CallNumberCity> resultCallBack);

    /**
     * 任务详情查询
     * @param campaignId 任务id (路径中字段)
     * @param recordId 任务明细id  (路径中字段)
     */
    void taskDetail(Context context,String campaignId,String recordId,SobotResultCallBack<CallTaskContactModel> callBack);

    /**
     * 任务详情修改
     * @param campaignId 任务id (路径中字段)
     * @param recordId 任务明细id  (路径中字段)
     * @param dataFields 导入字段列表
     */
    void editTaskDetail(Context context, String campaignId, String recordId, String dataFields, SobotResultCallBack callBack);

    /**
     * 查询任务总结
     * @param campaignId 任务id (路径中字段)
     * @param recordId 任务明细id  (路径中字段)
     */
    void taskSummary(Context context,String campaignId,String recordId,SobotResultCallBack<CallTaskContactModel> callBack);

    /**
     * 更新任务总结
     * @param campaignId 任务id (路径中字段)
     * @param recordId 任务明细id  (路径中字段)
     * @param dataFields 更新参数
     */
    void updateTaskSummary(Context context, String campaignId, String recordId, String dataFields, SobotResultCallBack callBack);

    /**
     * 外呼任务通话记录查询
     * @param campaignId 任务id
     * @param campaignRecordId 任务明细id
     */
    void taskRecord(Context context, String campaignId, String campaignRecordId, SobotResultCallBack<List<CallMainCDRInfo>> callBack);
    //--------------------------呼叫V6接口 end -------------------------------
}