package com.sobot.callsdk.dialog;

import android.app.Activity;
import android.text.Editable;
import android.text.TextWatcher;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.sobot.callsdk.R;
import com.sobot.utils.SobotStringUtils;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class InputPhoneDialog extends SobotBottomDialog implements View.OnClickListener {
    private LinearLayout coustom_pop_layout, sobot_negativeButton;
    private EditText et_phone;
    private TextView tv_error_text;
    private Button btn_confirm;
    private PhoneListener listener;
    private Activity activity;
    private String phone;

    public InputPhoneDialog(Activity context, PhoneListener listener, String phone) {
        super(context);
        activity = context;
        this.phone = phone;
        this.listener = listener;
    }

    public void setPhone(String phone) {
        this.phone = phone;
        if (et_phone != null) {
            et_phone.setText(phone);
        }
    }

    @Override
    protected int getLayout() {
        return R.layout.call_dialog_input_phone;
    }

    @Override
    protected View getDialogContainer() {
        if (coustom_pop_layout == null) {
            coustom_pop_layout = findViewById(R.id.sobot_container);
        }
        return coustom_pop_layout;
    }

    @Override
    protected void initData() {

    }

    @Override
    protected void initView() {
        sobot_negativeButton = findViewById(R.id.sobot_negativeButton);
        btn_confirm = findViewById(R.id.btn_confirm);
        tv_error_text = findViewById(R.id.tv_error_text);
        et_phone = findViewById(R.id.et_phone);
        if (!SobotStringUtils.isEmpty(phone)) {
            et_phone.setText(phone);
        }
        et_phone.addTextChangedListener(new TextWatcher() {
            @Override
            public void beforeTextChanged(CharSequence s, int start, int count, int after) {
                et_phone.setBackgroundResource(R.drawable.call_gray_bg_5dp);
                tv_error_text.setVisibility(View.GONE);
            }

            @Override
            public void onTextChanged(CharSequence s, int start, int before, int count) {

            }

            @Override
            public void afterTextChanged(Editable s) {

            }
        });
        sobot_negativeButton.setOnClickListener(this);
        btn_confirm.setOnClickListener(this);
    }

    @Override
    public void onClick(View v) {

        if (v == sobot_negativeButton) {
            //关闭
            dismiss();
        } else if (btn_confirm == v) {
            btn_confirm.requestFocus();
            //回传手机号
            String phone = et_phone.getText().toString().trim();
            if(SobotStringUtils.isEmpty(phone)){
                et_phone.setBackgroundResource(R.drawable.call_error_bg_5dp);
                tv_error_text.setText(R.string.sobot_call_search_tip);
                tv_error_text.setVisibility(View.VISIBLE);
                return;
            }
            Pattern p = Pattern.compile("[0-9]*");
            Matcher m = p.matcher(phone);
            if (!m.matches()) {
                et_phone.setBackgroundResource(R.drawable.call_error_bg_5dp);
                tv_error_text.setText(R.string.call_login_phone_length_hint);
                tv_error_text.setVisibility(View.VISIBLE);
                return;
            }
            if (phone.length() < 3 || phone.length() > 16) {
                et_phone.setBackgroundResource(R.drawable.call_error_bg_5dp);
                tv_error_text.setText(R.string.call_login_phone_length_hint);
                tv_error_text.setVisibility(View.VISIBLE);
                return;
            }
            if (listener != null) {
                listener.setPhone(phone);
            }
            dismiss();
        }
    }

    @Override
    public void dismiss() {
        try {
            if (isShowing()) {
                super.dismiss();
            }
        } catch (Exception e) {
//            e.printStackTrace();
        }
    }

    public interface PhoneListener {
        void setPhone(String phone);
    }
}
