package com.sobot.callsdk.janus;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.os.Build;
import android.text.TextUtils;

import com.sobot.callbase.api.SobotCallBaseUrl;
import com.sobot.callbase.janus.SobotJanusClient;
import com.sobot.callsdk.service.SobotJanusService;
import com.sobot.utils.SobotLogUtils;

public class SobotJanusSipPhoneUtils {

    private static String mUsername, mPassword, mServerIp;
    private static String TAG = SobotJanusSipPhoneUtils.class.getSimpleName();

    /**
     * 开启服务
     *
     * @param context 上下文
     */
    public static void startService(Context context) {
        if (!SobotJanusService.isServiceRunning()) {
            Intent baresipServiceIntent = new Intent(context, SobotJanusService.class);
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
                context.startForegroundService(baresipServiceIntent);
            } else {
                context.startService(baresipServiceIntent);
            }
        }
    }

    /**
     * 检验服务是否正在运行
     *
     * @return true 正在运行； false 服务已停止
     */
    public static boolean isServiceRun() {
        if (SobotJanusService.isServiceRunning()) {
            return true;
        } else {
            return false;
        }
    }

    /**
     * 关闭服务
     *
     * @param context 上下文
     */
    public static void stopService(Context context) {
        Intent intent = new Intent(context, SobotJanusService.class);
        context.stopService(intent);
    }


    /**
     * 设置 sip 账户信息
     *
     * @param userName 账号名
     * @param password 密码
     * @param serverIp 注册地址
     */
    public static void setAccount(String userName, String password, String serverIp) {
        mUsername = userName;
        mPassword = password;
        mServerIp = serverIp;
    }


    /**
     * 登录到 SIP 服务器
     */
    public static void login(Context context) {
        if (context != null) {
            registerUser();
        }
    }


    /**
     * 注册到服务器
     */
    private static void registerUser() {
        if (TextUtils.isEmpty(mUsername)) {
            SobotLogUtils.i("账号名 mUsername  不能为空  ");
            return;
        }
        if (TextUtils.isEmpty(mPassword)) {
            SobotLogUtils.i("密码 mPassword 不能为空  ");
            return;
        }
        if (TextUtils.isEmpty(mServerIp)) {
            SobotLogUtils.i("注册地址 mServerIp 不能为空 ");
            return;
        }
        SobotLogUtils.i("registerUser mUsername = " + mUsername);
        SobotLogUtils.i("registerUser mPassword = " + mPassword);
        SobotLogUtils.i("registerUser mServerIp = " + mServerIp);
        SobotJanusClient.getInstance().register(SobotCallBaseUrl.getSipProxy(), "sip:" + mUsername + "@" + mServerIp, mPassword);
    }


    /**
     * 注销账户
     */
    public static void logoutUser() {
        SobotJanusClient.getInstance().unRegister(null, false);
    }

    /**
     * 座席振铃
     */
    public static void callRingin(Activity context) {
//        Intent intent = new Intent(context, SobotJanusService.class);
//        intent.setAction("call ringing");
//        context.startService(intent);
    }

    /**
     * 接通电话
     */
    public static void accept(Context context, String jsep) {
        Intent baresipServiceIntent = new Intent(context, SobotJanusService.class);
        baresipServiceIntent.setAction("accept");
        baresipServiceIntent.putExtra("jsep", jsep);
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
            context.startForegroundService(baresipServiceIntent);
        } else {
            context.startService(baresipServiceIntent);
        }
    }

    /**
     * 挂断电话
     */
    public static void hangUp() {
        SobotJanusClient.getInstance().hangUp();
    }


    /**
     * 切换静音
     *
     * @param isMicMuted 是否静音
     */
    public static void toggleMicro(boolean isMicMuted) {

    }

    /**
     * 日志开关
     *
     * @param isOpenLog true 打开 false 关闭 默认打开
     */
    public static void isOpenLog(boolean isOpenLog) {
        if (isOpenLog) {

        } else {

        }
    }


    public static String getmUsername() {
        return mUsername;
    }

}
