package com.sobot.callsdk.listener;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;

import com.sobot.callbase.listener.SobotCallOption;
import com.sobot.callsdk.sip.SobotSipUtils;
import com.sobot.callsdk.sip.callback.SobotPhoneCallback;
import com.sobot.callsdk.utils.CallSharedPreferencesUtils;
import com.sobot.callsdk.utils.SobotCallConstant;
import com.sobot.callsdk.v1.activity.SobotCallStatusActivity;
import com.sobot.callsdk.v6.activity.CallStatusActivity;
import com.sobot.common.login.SobotLoginTools;
import com.sobot.common.login.model.SobotServiceInfoModel;
import com.sobot.common.utils.SobotGlobalContext;
import com.sobot.utils.SobotLogUtils;

//话机通话状态监听 单例 内部使用
public class SobotPhoneStatusListener extends SobotPhoneCallback {

    private Context context;

    private SobotPhoneStatusListener() {
    }

    private CallBack callBack;

    private static class SinglenHander {
        private static final SobotPhoneStatusListener instance = new SobotPhoneStatusListener();
    }

    public static SobotPhoneStatusListener getInstance() {
        return SinglenHander.instance;
    }

    @Override
    public void incomingCall(String jsep, boolean isCallPhone, String userPhoneNumber) {
        if (isCallPhone) {
            SobotLogUtils.i("主叫端打电话 来电通知");
            SobotServiceInfoModel serviceVo = SobotLoginTools.getInstance().getServiceInfo();
            if (serviceVo != null) {
                SobotLogUtils.i("主叫端打电话 来电通知 主动接听---------用户电话" + userPhoneNumber);
                Activity activity = SobotGlobalContext.getInstance().currentActivity();
                if (activity != null) {
                    SobotSipUtils.accept(serviceVo.getCallV6Flag() == 1 ? true : false, activity, jsep);
                } else {
                    SobotSipUtils.accept(serviceVo.getCallV6Flag() == 1 ? true : false, context, jsep);
                }
            }
        } else {
            //sdk 集成方式 0 模块集成 1 接口集成
            int sdk_model_type = CallSharedPreferencesUtils.getInstance(context).get(SobotCallConstant.SP_KEY_SDK_MODEL_TYPE, SobotCallConstant.SDK_MODEL_MODULE);
            if (sdk_model_type == 0) {
                //模块集成 才能启动内部页面，如果是接口集成，通过来电监听外抛给客户自定处理（客户启动自己的页面）
                Activity activity = SobotGlobalContext.getInstance().currentActivity();
                SobotServiceInfoModel serviceVo = SobotLoginTools.getInstance().getServiceInfo();
                if (serviceVo != null) {
                    if (serviceVo.getCallV6Flag() == 1) {
                        //跳转到来电界面
                        if (activity == null) {
                            Intent intent = CallStatusActivity.initCallMeIntent(context, "");
                            intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
                            if (jsep != null) {
                                intent.putExtra("incomimgJsep", jsep.toString());
                            }
                            context.startActivity(intent);
                        } else {
                            if (!(activity instanceof CallStatusActivity)) {
                                Intent intent = CallStatusActivity.initCallMeIntent(context, "");
                                intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
                                if (jsep != null) {
                                    intent.putExtra("incomimgJsep", jsep.toString());
                                }
                                context.startActivity(intent);
                            }
                        }
                        SobotLogUtils.i("v6 收到用户端打电话 来电通知---------用户电话" + userPhoneNumber);
                    } else {
                        //跳转到来电界面
                        if (activity == null) {
                            Intent intent = SobotCallStatusActivity.initCallMeIntent(context, "", "", "", "", 0, SobotCallConstant.CALL_MODEL_SIP);
                            intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
                            context.startActivity(intent);
                        } else {
                            if (!(activity instanceof SobotCallStatusActivity)) {
                                Intent intent = SobotCallStatusActivity.initCallMeIntent(context, "", "", "", "", 0, SobotCallConstant.CALL_MODEL_SIP);
                                intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
                                context.startActivity(intent);
                            }
                        }
                        SobotLogUtils.i("v1 收到用户端打电话 来电通知");
                    }
                }
            }
        }
        if (SobotCallOption.voipCallListener != null) {
            SobotCallOption.voipCallListener.onCallIncoming(jsep, isCallPhone, userPhoneNumber);
        }
    }

    @Override
    public void callEnd() {
        if (SobotCallOption.voipCallListener != null) {
            SobotCallOption.voipCallListener.onCallDisconnected();
        }
        SobotLogUtils.i("通话结束");
        try {
            Thread.sleep(500);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
        //通话结束,关闭通话界面,返回上个界面
        SobotGlobalContext.getInstance(context).finishActivity(SobotCallStatusActivity.class);
    }

    @Override
    public void callConnected() {
        if (SobotCallOption.voipCallListener != null) {
            SobotCallOption.voipCallListener.onCallConnected();
        }
        SobotLogUtils.i("接通中。。。");
        if (this.callBack != null) {
            callBack.callStatus("接通中");
        }
    }

    public void setContext(Context context) {
        this.context = context.getApplicationContext();
    }

    public void setCallBack(CallBack callBack) {
        this.callBack = callBack;
    }

    public interface CallBack {
        void callStatus(String lineStatus);

    }
}
