package com.sobot.callsdk.service;

import android.app.Notification;
import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.app.Service;

import androidx.lifecycle.Observer;

import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;
import android.content.res.AssetFileDescriptor;
import android.content.res.Configuration;
import android.content.res.Resources;
import android.media.MediaPlayer;
import android.os.Binder;
import android.os.Build;
import android.os.Handler;
import android.os.IBinder;
import android.os.LocaleList;
import android.text.TextUtils;
import android.util.DisplayMetrics;
import android.view.View;
import android.view.animation.BounceInterpolator;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.TextView;

import com.sobot.callbase.CallPermissionManager;
import com.sobot.callbase.api.SobotCallBaseUrl;
import com.sobot.callbase.api.utils.CallBaseSharedPreferencesUtils;
import com.sobot.callbase.api.utils.SobotStompEventConstant;
import com.sobot.callbase.constant.SobotCallLiveDataBusKey;
import com.sobot.callbase.janus.SobotJanusClient;
import com.sobot.callbase.model.CallCurrentStatusModel;
import com.sobot.callbase.model.CallStompMsgModel;
import com.sobot.callbase.model.SobotAgentStatusInfo;
import com.sobot.callbase.model.SobotCallEvent;
import com.sobot.callbase.model.SobotCallStatusEntity;
import com.sobot.callbase.model.SobotEventAgentLogin;
import com.sobot.callbase.stomp.SobotStompClient;
import com.sobot.callbase.utils.CommonUtils;
import com.sobot.callbase.websocket.SobotWebSocketManager;
import com.sobot.callbase.websocket.WebSocketHandler;
import com.sobot.callbase.websocket.netchange.NetStateChangeObserver;
import com.sobot.callbase.websocket.netchange.NetworkType;
import com.sobot.callbase.websocket.netchange.SobotNetStateChangeReceiver;
import com.sobot.callbase.widget.floatwindow.FloatingWindowPermissionUtil;
import com.sobot.callbase.widget.floatwindow.IFloatWindow;
import com.sobot.callbase.widget.floatwindow.MoveType;
import com.sobot.callbase.widget.floatwindow.Screen;
import com.sobot.callbase.widget.floatwindow.SobotFloatWindow;
import com.sobot.callsdk.R;
import com.sobot.callsdk.SobotCallOpenApi;
import com.sobot.callsdk.janus.SobotJanusSipPhoneUtils;
import com.sobot.callsdk.listener.SobotPhoneStatusListener;
import com.sobot.callsdk.listener.SobotRegistrationListener;
import com.sobot.callsdk.utils.CallSharedPreferencesUtils;
import com.sobot.callsdk.utils.CallStatusUtils;
import com.sobot.callsdk.utils.MyActivityLifeCycle;
import com.sobot.callsdk.utils.SobotCallConstant;
import com.sobot.callsdk.v6.activity.CallStatusActivity;
import com.sobot.callsdk.v6.callenum.CallStage;
import com.sobot.callsdk.v6.constant.SobotCallLiveDataBusV6Key;
import com.sobot.common.login.SobotLoginTools;
import com.sobot.common.login.callback.SobotResultBlock;
import com.sobot.common.login.callback.SobotResultCode;
import com.sobot.common.login.model.SobotServiceInfoModel;
import com.sobot.common.login.permission.SobotPermissionManager;
import com.sobot.gson.SobotGsonUtil;
import com.sobot.utils.SobotLogUtils;
import com.sobot.utils.SobotStringUtils;
import com.sobot.widget.livedatabus.SobotLiveEventBus;
import com.sobot.widget.ui.toast.SobotToastUtil;

import org.json.JSONException;
import org.json.JSONObject;
import org.webrtc.AudioSource;
import org.webrtc.AudioTrack;
import org.webrtc.DataChannel;
import org.webrtc.DefaultVideoDecoderFactory;
import org.webrtc.DefaultVideoEncoderFactory;
import org.webrtc.EglBase;
import org.webrtc.IceCandidate;
import org.webrtc.MediaConstraints;
import org.webrtc.MediaStream;
import org.webrtc.PeerConnection;
import org.webrtc.PeerConnectionFactory;
import org.webrtc.RtpReceiver;
import org.webrtc.SdpObserver;
import org.webrtc.SessionDescription;
import org.webrtc.VideoDecoderFactory;
import org.webrtc.VideoEncoderFactory;

import java.io.IOException;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;

public class SobotJanusService extends Service implements NetStateChangeObserver {
    private static boolean isServiceRunning;
    private static boolean isRegistedSuccess;//是否注册成功
    PeerConnectionFactory peerConnectionFactory;
    PeerConnection peerConnection;
    EglBase.Context eglBaseContext;

    public static final String AUDIO_TRACK_ID = "audiotrack";
    public static final String LOCAL_AUDIO_STREAM = "localAudioStream";
    List streamList;
    //声音调节
    public static final int VOLUME = 10;

    public Intent intent;
    //收到 网络变化广播connectivity_action的次数，0的时候不重启janus websocket 的连接
    public int connectivity_action_count = 0;

    int callType = 0;//1 手机号方式,0 webrtc
    private String tag = "SobotJanusService";

    private String jsepStr;//来电

    public void onCreate() {
        super.onCreate();
        try {
            //将服务提升为可见服务
            setForeground();
            changeAppLanguage();
            isServiceRunning = true;
            isRegistedSuccess = false;
        } catch (Exception e) {
        }
    }

    //国际化，指定语言
    public void changeAppLanguage() {
        try {
            Locale locale = (Locale) CallSharedPreferencesUtils.getInstance(SobotJanusService.this).get("SobotLanguage", Locale.class);
            if (locale != null) {
                Resources resources = getResources();
                DisplayMetrics metrics = resources.getDisplayMetrics();
                Configuration configuration = resources.getConfiguration();
                //Android 7.0以上的方法
                if (Build.VERSION.SDK_INT >= 24) {
                    configuration.setLocale(locale);
                    configuration.setLocales(new LocaleList(locale));
                    createConfigurationContext(configuration);
                    //实测，updateConfiguration这个方法虽然很多博主说是版本不适用
                    //但是我的生产环境androidX+Android Q环境下，必须加上这一句，才可以通过重启App来切换语言
                    resources.updateConfiguration(configuration, metrics);
                } else if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN_MR1) {
                    //Android 4.1 以上方法
                    configuration.setLocale(locale);
                    resources.updateConfiguration(configuration, metrics);
                } else {
                    configuration.locale = locale;
                    resources.updateConfiguration(configuration, metrics);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private Observer<CallStompMsgModel> stompMsgObserver;//stomp 消息事件
    private Observer<String> getCallingWoIdObserver;//工单回复界面电话回复获取当前正在通话的工单id(可以为空)

    private void receiveStompMsg() {
        if (stompMsgObserver == null) {
            stompMsgObserver = new Observer<CallStompMsgModel>() {
                @Override
                public void onChanged(CallStompMsgModel stompMsgModel) {
                    if (stompMsgModel != null) {
                        SobotLogUtils.i("SobotJanusService 收到stomp 消息:" + SobotStringUtils.checkStringIsNull(stompMsgModel.getStompMessageID()));
                        String stompMessageID = SobotStringUtils.checkStringIsNull(stompMsgModel.getStompMessageID());
                        String stompMessageContent = SobotStringUtils.checkStringIsNull(stompMsgModel.getStompMessageContent());
                        String agentStatusInfoStr = SobotStringUtils.checkStringIsNull(stompMsgModel.getAgentStatusInfo());//坐席信息
                        String agentCallStatusInfo = SobotStringUtils.checkStringIsNull(stompMsgModel.getAgentCallStatusInfo());//坐席状态
                        //当前连接客户端类型 系统-客服APP-Android端  : SysAppAndroid  ; 系统-客服APP-IOS端 : SysAppIos
                        String clientType = SobotStringUtils.checkStringIsNull(stompMsgModel.getClientType());
                        String errorMessage = SobotStringUtils.checkStringIsNull(stompMsgModel.getErrorMessage());
                        if (!TextUtils.isEmpty(stompMessageContent) && !TextUtils.isEmpty(stompMessageID)) {
                            if (SobotStompEventConstant.EventAgentLogout.equals(stompMessageID) || SobotStompEventConstant.EventAgentConnectionChanged.equals(stompMessageID)) {
                                //签出后停止铃声
                                stopRinging();
                                //销毁通话状态浮层
                                if (SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT) != null) {
                                    SobotFloatWindow.destroy(SobotCallConstant.CALL_STATUS_FLOAT);
                                }
                                //销毁来电通知浮层
                                if (SobotFloatWindow.get(SobotCallConstant.CALL_FLOAT_INCOMING_NOTICE) != null) {
                                    SobotFloatWindow.destroy(SobotCallConstant.CALL_FLOAT_INCOMING_NOTICE);
                                }
                                SobotCallEvent event = SobotGsonUtil.jsonToBean(stompMessageContent, SobotCallEvent.class);
                                if (event != null) {
                                    Map<String, String> attachedDataMap = event.getAttachedData();
                                    boolean force = false;
                                    String operationAgentName = "";
                                    if (attachedDataMap != null) {
                                        for (Map.Entry<String, String> entry : attachedDataMap.entrySet()) {
                                            if ("force".equals(entry.getKey())) {
                                                force = Boolean.parseBoolean(entry.getValue());
                                            }
                                            if ("operationAgentName".equals(entry.getKey())) {
                                                operationAgentName = entry.getValue();
                                            }
                                        }
                                    }
                                    if (force) {
                                        //强制离线
                                        String mMessageTop = getResources().getString(R.string.call_force_offline);
                                        String mMessage = getResources().getString(R.string.call_force_tip).replace("#name#", operationAgentName).replace("#status#", getResources().getString(R.string.sobot_custom_offline));
                                        showTipFloat(mMessageTop, mMessage, 0);
                                    }
                                }
                            } else if (SobotStompEventConstant.EventRinging.equals(stompMessageID) || SobotStompEventConstant.EventDialing.equals(stompMessageID)) {
                                arrangeDuration = 0;//重置  0 会移除会话小结倒计时
                                //呼入座席响铃事件 ||     外呼返回振铃事件
                                if (callType == 1) {
                                    //手机方式
                                    intent = CallStatusActivity.initCallMeIntent(getApplicationContext(), "");
                                    //sdk 集成方式 0 模块集成 1 接口集成
                                    int sdk_model_type = CallSharedPreferencesUtils.getInstance(SobotJanusService.this).get(SobotCallConstant.SP_KEY_SDK_MODEL_TYPE, SobotCallConstant.SDK_MODEL_MODULE);
                                    if (sdk_model_type == 0) {
                                        //跳转到来电界面
                                        intent.setFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP | Intent.FLAG_ACTIVITY_CLEAR_TOP |
                                                Intent.FLAG_ACTIVITY_NEW_TASK);
                                        intent.putExtra("stompMessageID", stompMessageID);
                                        intent.putExtra("stompMessageContent", stompMessageContent);
                                        intent.putExtra("inComingcallType", callType);
                                        SobotJanusService.this.startActivity(intent);
                                    }
                                }
                                if (!MyActivityLifeCycle.getInstance().isForground()) {
                                    SobotLogUtils.d("显示启动浮窗来电");
                                    SobotCallEvent event = SobotGsonUtil.jsonToBean(stompMessageContent, SobotCallEvent.class);
                                    if (event != null) {
                                        Map<String, String> attachedDataMap = event.getAttachedData();
                                        String customerNick = "";
                                        String customerPhone = "";
                                        String customerProvince = "";
                                        String customerCity = "";
                                        String customerAddress = "";//用户地址
                                        long callDurationStart = System.currentTimeMillis();//振铃开始时间
                                        if (attachedDataMap != null) {
                                            for (Map.Entry<String, String> entry : attachedDataMap.entrySet()) {
                                                if ("customerNick".equals(entry.getKey())) {
                                                    customerNick = entry.getValue();
                                                }
                                                if ("_otherAgentName".equals(entry.getKey())) {
                                                    _otherAgentName = entry.getValue();
                                                }
                                                if ("customerProvince".equals(entry.getKey())) {
                                                    customerProvince = entry.getValue();
                                                }
                                                if ("customerCity".equals(entry.getKey())) {
                                                    customerCity = entry.getValue();
                                                }
                                            }
                                        }
                                        //用户昵称
                                        if (SobotStringUtils.isEmpty(customerNick)) {
                                            customerNick = getResources().getString(R.string.call_unknown_customer);
                                        }
                                        if (!TextUtils.isEmpty(customerProvince) && !TextUtils.isEmpty(customerCity)) {
                                            customerAddress = customerProvince + "-" + customerCity;
                                        } else if (!TextUtils.isEmpty(customerProvince)) {
                                            customerAddress = customerProvince;
                                        } else if (!TextUtils.isEmpty(customerCity)) {
                                            customerAddress = customerCity;
                                        } else {
                                            customerAddress = "";
                                        }
                                        if ("Internal".equals(SobotStringUtils.checkStringIsNull(event.getCallType()))) {
                                            customerNick = _otherAgentName;
                                        }
                                        //用户手机号
                                        if (!SobotStringUtils.isEmpty(event.getOtherDN())) {
                                            customerPhone = event.getOtherDN();
                                        }
                                        if (FloatingWindowPermissionUtil.hasSuspendedWindowPermission(SobotJanusService.this.getApplicationContext())) {
                                            //app在后台时 来电通知 浮层
                                            IFloatWindow iFloatWindow = SobotFloatWindow.get(SobotCallConstant.CALL_FLOAT_INCOMING_NOTICE);

                                            if (iFloatWindow != null) {
                                                iFloatWindow.show();
                                            } else {
                                                SobotFloatWindow.B floatWindow = SobotFloatWindow
                                                        .with(SobotJanusService.this.getApplicationContext())
                                                        .setView(R.layout.call_float_incoming_notice)
                                                        .setTag(SobotCallConstant.CALL_FLOAT_INCOMING_NOTICE)
                                                        .setX(Screen.width, 0.01f)
                                                        .setY(Screen.height, 0.02f)
                                                        .setWidth(Screen.width, 0.99f)
                                                        .setMoveType(MoveType.inactive)
                                                        .setDesktopShow(true);
                                                floatWindow.build();
                                                if (SobotFloatWindow.get(SobotCallConstant.CALL_FLOAT_INCOMING_NOTICE) != null) {
                                                    SobotFloatWindow.get(SobotCallConstant.CALL_FLOAT_INCOMING_NOTICE).show();
                                                }
                                            }
                                            View statusFloatView = SobotFloatWindow.get(SobotCallConstant.CALL_FLOAT_INCOMING_NOTICE).getView();
                                            if (statusFloatView != null) {
                                                ImageView iv_logo = statusFloatView.findViewById(R.id.iv_logo);
                                                if (CommonUtils.getAppIcon(getApplicationContext(), CommonUtils.getPackageName(getApplicationContext())) != 0) {
                                                    iv_logo.setVisibility(View.VISIBLE);
                                                    iv_logo.setImageResource(CommonUtils.getAppIcon(getApplicationContext(), CommonUtils.getPackageName(getApplicationContext())));
                                                } else {
                                                    iv_logo.setVisibility(View.GONE);
                                                }
                                                TextView tv_customer_nick = statusFloatView.findViewById(R.id.tv_customer_nick);
                                                TextView tv_customer_no = statusFloatView.findViewById(R.id.tv_customer_no);
                                                TextView tv_accept = statusFloatView.findViewById(R.id.tv_accept);
                                                TextView tv_hung = statusFloatView.findViewById(R.id.tv_hung);
                                                TextView tv_address = statusFloatView.findViewById(R.id.tv_address);

                                                if (callType == 1) {
                                                    tv_accept.setVisibility(View.GONE);
                                                    tv_hung.setVisibility(View.GONE);
                                                }
                                                tv_customer_nick.setText(SobotStringUtils.checkStringIsNull(customerNick));
                                                tv_customer_no.setText(SobotStringUtils.checkStringIsNull(customerPhone));
                                                tv_address.setText(SobotStringUtils.checkStringIsNull(customerAddress));
                                                statusFloatView.setOnClickListener(new View.OnClickListener() {
                                                    @Override
                                                    public void onClick(View v) {
                                                        Intent intent = CallStatusActivity.initCallMeIntent(getApplicationContext(), "");
                                                        //跳转到来电界面
                                                        intent.setFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP | Intent.FLAG_ACTIVITY_CLEAR_TOP |
                                                                Intent.FLAG_ACTIVITY_NEW_TASK);
                                                        intent.putExtra("stompMessageID", stompMessageID);
                                                        intent.putExtra("stompMessageContent", stompMessageContent);
                                                        intent.putExtra("incomimgJsep", jsepStr);
                                                        intent.putExtra("callDurationStart", callDurationStart);
                                                        intent.putExtra("inComingcallType", 1);
                                                        SobotJanusService.this.startActivity(intent);
                                                        if (SobotFloatWindow.get(SobotCallConstant.CALL_FLOAT_INCOMING_NOTICE) != null) {
                                                            SobotFloatWindow.destroy(SobotCallConstant.CALL_FLOAT_INCOMING_NOTICE);
                                                        }
                                                    }
                                                });
                                                tv_accept.setOnClickListener(new View.OnClickListener() {
                                                    @Override
                                                    public void onClick(View v) {
                                                        Intent intent = CallStatusActivity.initCallMeIntent(getApplicationContext(), "");
                                                        //跳转到来电界面
                                                        intent.setFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP | Intent.FLAG_ACTIVITY_CLEAR_TOP |
                                                                Intent.FLAG_ACTIVITY_NEW_TASK);
                                                        intent.putExtra("stompMessageID", stompMessageID);
                                                        intent.putExtra("stompMessageContent", stompMessageContent);
                                                        intent.putExtra("inComingcallType", 1);
                                                        intent.putExtra("incomimgJsep", jsepStr);
                                                        intent.putExtra("callDurationStart", callDurationStart);
                                                        intent.putExtra("isAutoAccept", true);
                                                        SobotJanusService.this.startActivity(intent);
                                                        if (SobotFloatWindow.get(SobotCallConstant.CALL_FLOAT_INCOMING_NOTICE) != null) {
                                                            SobotFloatWindow.destroy(SobotCallConstant.CALL_FLOAT_INCOMING_NOTICE);
                                                        }
                                                    }
                                                });
                                                tv_hung.setOnClickListener(new View.OnClickListener() {
                                                    @Override
                                                    public void onClick(View v) {
                                                        SobotCallOpenApi.hangup(getApplicationContext(), null);
                                                        if (SobotFloatWindow.get(SobotCallConstant.CALL_FLOAT_INCOMING_NOTICE) != null) {
                                                            SobotFloatWindow.destroy(SobotCallConstant.CALL_FLOAT_INCOMING_NOTICE);
                                                        }
                                                    }
                                                });
                                            }
                                        }
                                    }
                                }
                            } else if (SobotStompEventConstant.EventEstablished.equals(stompMessageID)) {
                                stopRinging();
                                SobotCallOpenApi.changedPlayCategory(getApplicationContext(), false, null);
                                //通话接通了
                                IFloatWindow iFloatWindow = SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT);
                                View statusFloatView;
                                if (iFloatWindow != null) {
                                    statusFloatView = iFloatWindow.getView();
                                    if (statusFloatView != null) {
                                        TextView tv_call_statue = statusFloatView.findViewById(R.id.tv_call_statue);
                                        if (tv_call_statue != null) {
                                            tv_call_statue.setText(getResources().getString(R.string.sobot_custom_tonghuazhong));
                                        }
                                        TextView tv_data = statusFloatView.findViewById(R.id.tv_data);
                                        if (tv_data != null && !SobotStringUtils.isEmpty(tv_data.getText().toString())) {
                                            CallCurrentStatusModel callCurrentStatusModel = SobotGsonUtil.jsonToBean(tv_data.getText().toString(), CallCurrentStatusModel.class);
                                            if (callCurrentStatusModel != null) {
                                                //通话接通了
                                                callCurrentStatusModel.setCurrentStatus(4);
                                                long cur = System.currentTimeMillis();
                                                callCurrentStatusModel.setCurrentCallDuration(cur);
                                                callCurrentStatusModel.setCurrentUserDuration(cur);//咨询 用户通话 重新开始计时
                                                callCurrentStatusModel.setCurrentThirdDuration(cur);//三方坐席 通话  重新开始计时
                                                SobotCallEvent event = SobotGsonUtil.jsonToBean(stompMessageContent, SobotCallEvent.class);
                                                if (event != null) {
                                                    callCurrentStatusModel.setCallType(SobotStringUtils.checkStringIsNull(event.getCallType()));
                                                    callCurrentStatusModel.setCallId(SobotStringUtils.checkStringIsNull(event.getCallID()));
                                                    Map<String, String> attachedDataMap = event.getAttachedData();
                                                    if (attachedDataMap != null) {
                                                        for (Map.Entry<String, String> entry : attachedDataMap.entrySet()) {
                                                            if ("_otherAgentName".equals(entry.getKey())) {
                                                                callCurrentStatusModel.set_otherAgentName(SobotStringUtils.checkStringIsNull(entry.getValue()));
                                                            }
                                                        }
                                                    }
                                                    String otherDNRole = event.getOtherDNRole();
                                                    if (!TextUtils.isEmpty(otherDNRole)) {
                                                        if (otherDNRole.equals(CallStage.ConsultBy.getValue())) {
                                                            callCurrentStatusModel.setCurrentStatus(5);
                                                            callCurrentStatusModel.setCurrentThirdDuration(System.currentTimeMillis());//三方坐席 通话  开始计时
                                                        }
                                                    }
                                                }
                                            }
                                            String callCurrentStatusModelStr = SobotGsonUtil.beanToJson(callCurrentStatusModel);
                                            if (tv_data != null && !SobotStringUtils.isEmpty(callCurrentStatusModelStr)) {
                                                tv_data.setText(callCurrentStatusModelStr);
                                            }
                                        }
                                    }
                                }
                                if (!MyActivityLifeCycle.getInstance().isForground() && callType == 1) {
                                    SobotLogUtils.d("显示启动浮窗通话中");
                                    if (FloatingWindowPermissionUtil.hasSuspendedWindowPermission(SobotJanusService.this.getApplicationContext())) {
                                        IFloatWindow iFloatWindow1 = SobotFloatWindow.get(SobotCallConstant.CALL_FLOAT_INCOMING_NOTICE);
                                        View statusFloatView1 = null;
                                        if (iFloatWindow1 != null) {
                                            statusFloatView1 = iFloatWindow1.getView();
                                            if (statusFloatView1 != null) {
                                                ImageView iv_logo = statusFloatView1.findViewById(R.id.iv_logo);
                                                if (CommonUtils.getAppIcon(getApplicationContext(), CommonUtils.getPackageName(getApplicationContext())) != 0) {
                                                    iv_logo.setVisibility(View.VISIBLE);
                                                    iv_logo.setImageResource(CommonUtils.getAppIcon(getApplicationContext(), CommonUtils.getPackageName(getApplicationContext())));
                                                } else {
                                                    iv_logo.setVisibility(View.GONE);
                                                }
                                                TextView tv_accept = statusFloatView1.findViewById(R.id.tv_accept);
                                                TextView tv_hung = statusFloatView1.findViewById(R.id.tv_hung);
                                                TextView tv_customer_nick = statusFloatView1.findViewById(R.id.tv_customer_nick);
                                                TextView tv_customer_no = statusFloatView1.findViewById(R.id.tv_customer_no);
                                                TextView tv_address = statusFloatView1.findViewById(R.id.tv_address);
                                                statusFloatView1.setOnClickListener(new View.OnClickListener() {
                                                    @Override
                                                    public void onClick(View v) {
                                                        long callDurationStart = System.currentTimeMillis();//振铃开始时间
                                                        Intent intent = CallStatusActivity.initCallMeIntent(getApplicationContext(), "");
                                                        //跳转到来电界面
                                                        intent.setFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP | Intent.FLAG_ACTIVITY_CLEAR_TOP |
                                                                Intent.FLAG_ACTIVITY_NEW_TASK);
                                                        long cur = System.currentTimeMillis();
                                                        intent.putExtra("stompMessageID", stompMessageID);
                                                        intent.putExtra("stompMessageContent", stompMessageContent);
                                                        intent.putExtra("incomimgJsep", jsepStr);
                                                        intent.putExtra("callDurationStart", callDurationStart);
                                                        intent.putExtra("inComingcallType", 1);
                                                        intent.putExtra("customerNick", tv_customer_nick != null ? tv_customer_nick.getText().toString() : "");
                                                        intent.putExtra("customerPhone", tv_customer_no != null ? tv_customer_no.getText().toString() : "");
                                                        intent.putExtra("customerAddress", tv_address != null ? tv_address.getText().toString() : "");
                                                        intent.putExtra("currentCallDuration", cur);

                                                        SobotJanusService.this.startActivity(intent);
                                                        if (SobotFloatWindow.get(SobotCallConstant.CALL_FLOAT_INCOMING_NOTICE) != null) {
                                                            SobotFloatWindow.destroy(SobotCallConstant.CALL_FLOAT_INCOMING_NOTICE);
                                                        }
                                                    }
                                                });
                                                tv_accept.setVisibility(View.GONE);
                                                tv_hung.setVisibility(View.GONE);
                                            }
                                            iFloatWindow1.show();
                                        }
                                    }
                                }
                            } else if (SobotStompEventConstant.EventPartyChanged.equals(stompMessageID)) {
                                stopRinging();
                                IFloatWindow iFloatWindow = SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT);
                                View statusFloatView;
                                if (iFloatWindow != null) {
                                    statusFloatView = iFloatWindow.getView();
                                    TextView tv_data = statusFloatView.findViewById(R.id.tv_data);
                                    if (tv_data != null && !SobotStringUtils.isEmpty(tv_data.getText().toString())) {
                                        CallCurrentStatusModel callCurrentStatusModel = SobotGsonUtil.jsonToBean(tv_data.getText().toString(), CallCurrentStatusModel.class);
                                        if (callCurrentStatusModel != null) {
                                            SobotCallEvent event = SobotGsonUtil.jsonToBean(stompMessageContent, SobotCallEvent.class);
                                            if (event != null) {
                                                String thirdDNRole = event.getThirdDNRole();
                                                if (!TextUtils.isEmpty(thirdDNRole)) {
                                                    if (thirdDNRole.equals(CallStage.ConferenceBy.getValue())) {
                                                        //咨询后会议（三方）
                                                        callCurrentStatusModel.setCurrentStatus(6);
                                                    }
                                                    if (thirdDNRole.equals(CallStage.TransferBy.getValue())) {
                                                        //咨询后转移
                                                        callCurrentStatusModel.setCurrentStatus(7);
                                                    }
                                                }
                                            }
                                        }
                                        String callCurrentStatusModelStr = SobotGsonUtil.beanToJson(callCurrentStatusModel);
                                        if (tv_data != null && !SobotStringUtils.isEmpty(callCurrentStatusModelStr)) {
                                            tv_data.setText(callCurrentStatusModelStr);
                                        }
                                    }
                                }
                            } else if (SobotStompEventConstant.EventPartyDeleted.equals(stompMessageID)) {
                                stopRinging();
                                IFloatWindow iFloatWindow = SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT);
                                View statusFloatView;
                                if (iFloatWindow != null) {
                                    statusFloatView = iFloatWindow.getView();
                                    TextView tv_data = statusFloatView.findViewById(R.id.tv_data);
                                    if (tv_data != null && !SobotStringUtils.isEmpty(tv_data.getText().toString())) {
                                        CallCurrentStatusModel callCurrentStatusModel = SobotGsonUtil.jsonToBean(tv_data.getText().toString(), CallCurrentStatusModel.class);
                                        if (callCurrentStatusModel != null) {
                                            SobotCallEvent event = SobotGsonUtil.jsonToBean(stompMessageContent, SobotCallEvent.class);
                                            if (event != null) {
                                                String thirdDNRole = event.getThirdDNRole();
                                                if (!TextUtils.isEmpty(thirdDNRole)) {
                                                    if (thirdDNRole.equals(CallStage.DeletedBy.getValue())) {
                                                        //三方后转移
                                                        callCurrentStatusModel.setCurrentStatus(7);
                                                    } else if (thirdDNRole.equals(CallStage.BargeinTo.getValue())) {
                                                        //强插着 离开 恢复通话中
                                                        callCurrentStatusModel.setCurrentStatus(4);
                                                    }
                                                }
                                            }
                                        }
                                        String callCurrentStatusModelStr = SobotGsonUtil.beanToJson(callCurrentStatusModel);
                                        if (tv_data != null && !SobotStringUtils.isEmpty(callCurrentStatusModelStr)) {
                                            tv_data.setText(callCurrentStatusModelStr);
                                        }
                                    }
                                }
                            } else if (SobotStompEventConstant.EventPartyAdded.equals(stompMessageID)) {
                                stopRinging();
                                //强插 三方
                                SobotCallEvent event = SobotGsonUtil.jsonToBean(stompMessageContent, SobotCallEvent.class);
                                String _otherAgentName = "";
                                if (event != null) {
                                    Map<String, String> attachedDataMap = event.getAttachedData();
                                    if (attachedDataMap != null) {
                                        for (Map.Entry<String, String> entry : attachedDataMap.entrySet()) {
                                            if ("_otherAgentName".equals(entry.getKey())) {
                                                _otherAgentName = entry.getValue();
                                            }
                                        }
                                    }
                                }
                                IFloatWindow iFloatWindow = SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT);
                                View statusFloatView;
                                if (iFloatWindow != null) {
                                    statusFloatView = iFloatWindow.getView();
                                    TextView tv_data = statusFloatView.findViewById(R.id.tv_data);
                                    if (tv_data != null && !SobotStringUtils.isEmpty(tv_data.getText().toString())) {
                                        CallCurrentStatusModel callCurrentStatusModel = SobotGsonUtil.jsonToBean(tv_data.getText().toString(), CallCurrentStatusModel.class);
                                        if (callCurrentStatusModel != null) {
                                            callCurrentStatusModel.set_otherAgentName(_otherAgentName);
                                            callCurrentStatusModel.setCurrentThirdDuration(System.currentTimeMillis());//三方坐席 通话  开始计时
                                            callCurrentStatusModel.setCurrentStatus(9);
                                        }
                                        String callCurrentStatusModelStr = SobotGsonUtil.beanToJson(callCurrentStatusModel);
                                        if (tv_data != null && !SobotStringUtils.isEmpty(callCurrentStatusModelStr)) {
                                            tv_data.setText(callCurrentStatusModelStr);
                                        }
                                    }
                                }
                                String top = getResources().getString(R.string.call_str_intrusion_call);
                                String tempName = String.format(getResources().getString(R.string.call_str_joined_third_party), SobotStringUtils.checkStringIsNull(_otherAgentName));
                                showTipFloat(top, tempName, 0);
                            } else if (SobotStompEventConstant.EventDelayCallAfterWork.equals(stompMessageID)) {
                                //会话小结延长
                                arrangeDuration = 60 + arrangeDuration;
                                String tip = String.format(getResources().getString(R.string.call_str_extend_tip), "60");
                                SobotToastUtil.showCustomToast(SobotJanusService.this, tip);
                            } else if (SobotStompEventConstant.EventReleased.equals(stompMessageID)) {
                                stopRinging();
                                if (peerConnection != null) {
                                    peerConnection.close();
                                    peerConnection = null;
                                }
                                SobotCallOpenApi.changedPlayCategory(SobotJanusService.this, false, null);
                                //通话结束了
                                SobotCallEvent eventAgent = SobotGsonUtil.jsonToBean(stompMessageContent, SobotCallEvent.class);
                                if (eventAgent != null) {
                                    wrapUpDuration = eventAgent.getWrapUpDuration();
                                    arrangeDuration = eventAgent.getWrapUpDuration();
                                    if (eventAgent.getWrapUpDuration() > 0) {
                                        showWrapUp();
                                    } else {
                                        arrangeDuration = 0;//重置  0 会移除会话小结倒计时
                                        //没打通 销毁通话状态浮层
                                        if (SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT) != null) {
                                            SobotFloatWindow.destroy(SobotCallConstant.CALL_STATUS_FLOAT);
                                        }
                                    }
                                    Map<String, String> attachedDataMap = eventAgent.getAttachedData();
                                    if (!SobotStringUtils.isEmpty(eventAgent.getThirdDNRole()) && CallStage.InterceptBy.getValue().equals(eventAgent.getThirdDNRole())) {
                                        //抢接
                                        String _thirdAgentName = "";
                                        if (attachedDataMap != null) {
                                            for (Map.Entry<String, String> entry : attachedDataMap.entrySet()) {
                                                if ("_thirdAgentName".equals(entry.getKey())) {
                                                    _thirdAgentName = entry.getValue();
                                                }
                                            }
                                        }
                                        if (SobotStringUtils.isEmpty(_thirdAgentName)) {
                                            _thirdAgentName = eventAgent.getThirdDN();
                                        }
                                        String mMessage = String.format(getResources().getString(R.string.call_str_be_snatched_tip), SobotStringUtils.checkStringIsNull(_thirdAgentName));
                                        String mMessageTop = getResources().getString(R.string.call_str_be_snatched);
                                        showTipFloat(mMessageTop, mMessage, 0);
                                    }
                                    String campaignRecordId = "";
                                    if (attachedDataMap != null) {
                                        for (Map.Entry<String, String> entry : attachedDataMap.entrySet()) {
                                            if ("campaignRecordId".equals(entry.getKey())) {
                                                campaignRecordId = entry.getValue();
                                            }
                                        }
                                    }
                                    //通话结束后刷新任务界面UI
                                    HashMap<String, Object> map = new HashMap<>();
                                    map.put("campaignRecordId", campaignRecordId);
                                    map.put("bridgeUepoch", eventAgent.getBridgeUepoch());
                                    SobotLiveEventBus.get(SobotCallLiveDataBusV6Key.SOBOT_ACTION_CALL_RELEASED).post(map);
                                }
                                //空闲 来电提醒浮层
                                if (SobotFloatWindow.get(SobotCallConstant.CALL_FLOAT_INCOMING_NOTICE) != null) {
                                    SobotFloatWindow.destroy(SobotCallConstant.CALL_FLOAT_INCOMING_NOTICE);
                                }
                            } else if (SobotStompEventConstant.EventAgentReady.equals(stompMessageID)) {
                                stopRinging();
                                CallSharedPreferencesUtils.getInstance(SobotJanusService.this).put(SobotCallConstant.callLoginStatus, CallStatusUtils.V6_FREE);
                                arrangeDuration = 0;//重置  0 会移除会话小结倒计时
                                //空闲 销毁通话状态浮层
                                if (SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT) != null) {
                                    SobotFloatWindow.destroy(SobotCallConstant.CALL_STATUS_FLOAT);
                                }
                                SobotCallEvent event = SobotGsonUtil.jsonToBean(stompMessageContent, SobotCallEvent.class);
                                if (event != null) {
                                    Map<String, String> attachedDataMap = event.getAttachedData();
                                    boolean force = false;
                                    String operationAgentName = "";
                                    if (attachedDataMap != null) {
                                        for (Map.Entry<String, String> entry : attachedDataMap.entrySet()) {
                                            if ("force".equals(entry.getKey())) {
                                                force = Boolean.parseBoolean(entry.getValue());
                                            }
                                            if ("operationAgentName".equals(entry.getKey())) {
                                                operationAgentName = entry.getValue();
                                            }
                                        }
                                    }
                                    if (force) {
                                        //强制置闲 operationAgentName、force
                                        String mMessageTop = getResources().getString(R.string.call_force_online);
                                        String mMessage = getResources().getString(R.string.call_force_tip).replace("#name#", operationAgentName).replace("#status#", getResources().getString(R.string.sobot_custom_v6_free));
                                        showTipFloat(mMessageTop, mMessage, 0);
                                    }
                                }
                            } else if (SobotStompEventConstant.EventAgentNotReady.equals(stompMessageID)) {
                                stopRinging();
                                SobotEventAgentLogin agentStatus = SobotGsonUtil.jsonToBean(stompMessageContent, SobotEventAgentLogin.class);
                                if (agentStatus != null) {
                                    if (!SobotStringUtils.isEmpty(agentStatus.getReasonCode())) {
                                        CallSharedPreferencesUtils.getInstance(SobotJanusService.this.getApplicationContext()).put(SobotCallConstant.callLoginStatus, SobotStringUtils.checkStringIsNull(agentStatus.getReasonCode()) + "");
                                        if (CallStatusUtils.V6_SYSYTEM_BUSY.equals(agentStatus.getReasonCode())) {
                                            //系统锁定
                                            String mMessageTop = getResources().getString(R.string.call_str_system_Lock);
                                            String mMessage = getResources().getString(R.string.call_str_system_Lock_tip);
                                            showTipFloat(mMessageTop, mMessage, 1);
                                        }
                                    }
                                    Map<String, String> attachedDataMap = agentStatus.getAttachedData();
                                    boolean force = false;
                                    String operationAgentName = "";
                                    if (attachedDataMap != null) {
                                        for (Map.Entry<String, String> entry : attachedDataMap.entrySet()) {
                                            if ("force".equals(entry.getKey())) {
                                                force = Boolean.parseBoolean(entry.getValue());
                                            }
                                            if ("operationAgentName".equals(entry.getKey())) {
                                                operationAgentName = entry.getValue();
                                            }
                                        }
                                    }
                                    if (force) {
                                        //强制置忙
                                        String mMessageTop = getResources().getString(R.string.call_force_busy);
                                        String mMessage = getResources().getString(R.string.call_force_tip).replace("#name#", operationAgentName).replace("#status#", getResources().getString(R.string.sobot_custom_do_not_disturb));
                                        showTipFloat(mMessageTop, mMessage, 0);
                                    }
                                }
                            } else if (SobotStompEventConstant.EventWebSocketSession.equals(stompMessageID)) {
                                //恢复话务状态
                                if (SobotStompEventConstant.clientType.equals(clientType)) {
                                    if (!TextUtils.isEmpty(agentStatusInfoStr)) {
                                        SobotAgentStatusInfo agentStatusInfo = SobotGsonUtil.jsonToBean(agentStatusInfoStr, SobotAgentStatusInfo.class);
                                        if (agentStatusInfo != null) {
                                            String statusId;//1-就绪；2-忙碌；4-话后小结；5-外呼振铃；6-呼入响铃；7-通话；8-保持；98-系统锁定
                                            if (!SobotStringUtils.isEmpty(agentStatusInfo.getWorkStatus())) {
                                                statusId = agentStatusInfo.getWorkStatus();
                                            } else {
                                                statusId = agentStatusInfo.getAgentState();
                                            }
                                            SobotCallStatusEntity callStatusEntity = SobotGsonUtil.jsonToBean(agentCallStatusInfo, SobotCallStatusEntity.class);
                                            if (!SobotStringUtils.isEmpty(statusId)) {
//                                        V6_OUTBOUND_RINGING = "5";//外呼振铃
//                                        V6_INCOMING_RING = "6";//呼入响铃
//                                        V6_DURING = "7";//通话
//                                        String V6_HOLD = "8";//保持
                                                if (CallStatusUtils.V6_OUTBOUND_RINGING.equals(statusId) || CallStatusUtils.V6_INCOMING_RING.equals(statusId)) {
                                                    //振铃中
                                                } else if (CallStatusUtils.V6_DURING.equals(statusId) || CallStatusUtils.V6_HOLD.equals(statusId)) {
                                                    stopRinging();
                                                    //通话中
                                                    IFloatWindow iFloatWindow = SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT);
                                                    View statusFloatView;
                                                    if (iFloatWindow != null) {
                                                        statusFloatView = iFloatWindow.getView();
                                                        if (statusFloatView != null) {
                                                            TextView tv_call_statue = statusFloatView.findViewById(R.id.tv_call_statue);
                                                            if (tv_call_statue != null) {
                                                                tv_call_statue.setText(getResources().getString(R.string.sobot_custom_tonghuazhong));
                                                            }
                                                            TextView tv_data = statusFloatView.findViewById(R.id.tv_data);
                                                            if (tv_data != null && !SobotStringUtils.isEmpty(tv_data.getText().toString())) {
                                                                CallCurrentStatusModel callCurrentStatusModel = SobotGsonUtil.jsonToBean(tv_data.getText().toString(), CallCurrentStatusModel.class);
                                                                if (callCurrentStatusModel != null) {
                                                                    //通话接通了
                                                                    callCurrentStatusModel.setCurrentStatus(4);
                                                                }
                                                                String callCurrentStatusModelStr = SobotGsonUtil.beanToJson(callCurrentStatusModel);
                                                                if (tv_data != null && !SobotStringUtils.isEmpty(callCurrentStatusModelStr)) {
                                                                    tv_data.setText(callCurrentStatusModelStr);
                                                                }
                                                            }
                                                        }
                                                    }
                                                } else if (CallStatusUtils.V6_SYSYTEM_BUSY.equals(statusId)) {
                                                    stopRinging();
                                                    if (peerConnection != null) {
                                                        peerConnection.close();
                                                        peerConnection = null;
                                                    }
                                                    //系统锁定
                                                    String mMessageTop = getResources().getString(R.string.call_str_system_Lock);
                                                    String mMessage = getResources().getString(R.string.call_str_system_Lock_tip);
                                                    showTipFloat(mMessageTop, mMessage, 0);
                                                    //没有话务信息，相当于通话已经结束
                                                    if (SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT) != null) {
                                                        SobotFloatWindow.destroy(SobotCallConstant.CALL_STATUS_FLOAT);
                                                    }
                                                    if (SobotFloatWindow.get(SobotCallConstant.CALL_FLOAT_INCOMING_NOTICE) != null) {
                                                        SobotFloatWindow.destroy(SobotCallConstant.CALL_FLOAT_INCOMING_NOTICE);
                                                    }
                                                } else if (CallStatusUtils.V6_FINISHING.equals(statusId)) {
                                                    stopRinging();
                                                    if (peerConnection != null) {
                                                        peerConnection.close();
                                                        peerConnection = null;
                                                    }
                                                    //会话小结
                                                    if (callStatusEntity != null) {
                                                        if (callStatusEntity.getWrapUpDuration() > 0 && callStatusEntity.getAcwRemainTime() > 0) {
                                                            //弹出会话小结浮层
                                                            wrapUpDuration = callStatusEntity.getWrapUpDuration();
                                                            arrangeDuration = callStatusEntity.getAcwRemainTime();
                                                            showWrapUp();
                                                        } else {
                                                            if (SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT) != null) {
                                                                SobotFloatWindow.destroy(SobotCallConstant.CALL_STATUS_FLOAT);
                                                            }
                                                        }
                                                    } else {
                                                        if (SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT) != null) {
                                                            SobotFloatWindow.destroy(SobotCallConstant.CALL_STATUS_FLOAT);
                                                        }
                                                        if (SobotFloatWindow.get(SobotCallConstant.CALL_FLOAT_INCOMING_NOTICE) != null) {
                                                            SobotFloatWindow.destroy(SobotCallConstant.CALL_FLOAT_INCOMING_NOTICE);
                                                        }
                                                    }
                                                } else {
                                                    stopRinging();
                                                    if (peerConnection != null) {
                                                        peerConnection.close();
                                                        peerConnection = null;
                                                    }
                                                    //没有话务信息，相当于通话已经结束
                                                    if (SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT) != null) {
                                                        SobotFloatWindow.destroy(SobotCallConstant.CALL_STATUS_FLOAT);
                                                    }
                                                    if (SobotFloatWindow.get(SobotCallConstant.CALL_FLOAT_INCOMING_NOTICE) != null) {
                                                        SobotFloatWindow.destroy(SobotCallConstant.CALL_FLOAT_INCOMING_NOTICE);
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            } else if (SobotStompEventConstant.EventUnreachable.equals(stompMessageID)) {
                                //Ping话机不可用事件
                                String mMessageTop = getResources().getString(R.string.call_str_tip);
                                String mMessage = getResources().getString(R.string.call_str_telephone_strip_error);
                                showTipFloat(mMessageTop, mMessage, 0);
                            }
                        }
                    }
                }
            };
            //收到 stomp 消息
            SobotLiveEventBus.get(SobotCallLiveDataBusKey.RECEIVE_STOMP_MSG, CallStompMsgModel.class)
                    .observeForever(stompMsgObserver);
        }
        if (getCallingWoIdObserver == null) {
            getCallingWoIdObserver = new Observer<String>() {
                @Override
                public void onChanged(String str) {
                    IFloatWindow iFloatWindow = SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT);
                    View statusFloatView;
                    if (iFloatWindow != null) {
                        statusFloatView = iFloatWindow.getView();
                        if (statusFloatView != null) {
                            TextView tv_data = statusFloatView.findViewById(R.id.tv_data);
                            if (tv_data != null && !SobotStringUtils.isEmpty(tv_data.getText().toString())) {
                                CallCurrentStatusModel callCurrentStatusModel = SobotGsonUtil.jsonToBean(tv_data.getText().toString(), CallCurrentStatusModel.class);
                                if (callCurrentStatusModel != null && SobotStringUtils.isNoEmpty(callCurrentStatusModel.getSourceId())) {
                                    SobotLiveEventBus.get(SobotCallLiveDataBusKey.SOBOT_LIVEBUS_BACK_CALLING_WOID).post(callCurrentStatusModel.getSourceId());
                                }
                            }
                        }
                    }

                }
            };
            //获取正在通话中通话工单id
            SobotLiveEventBus.get(SobotCallLiveDataBusKey.SOBOT_LIVEBUS_GET_CALLING_WOID, String.class)
                    .observeForever(getCallingWoIdObserver);
        }
    }

    private Handler mHandler;

    private int arrangeDuration;//通话整理中 倒计时
    private int wrapUpDuration;//通话整理中 时长

    //点击通话浮层刷新界面的需要信息
    private String _otherAgentName = "";//用户 昵称

    CallCurrentStatusModel callCurrentStatusModel;


    //显示会话小结弹窗
    private void showWrapUp() {
        if (FloatingWindowPermissionUtil.hasSuspendedWindowPermission(SobotJanusService.this.getApplicationContext())) {
            //更新通话状态浮层 为通话中
            IFloatWindow iFloatWindow = SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT);

            if (iFloatWindow != null) {
                if (iFloatWindow.getX() > (Screen.width / 2)) {
                    iFloatWindow.updateX(Screen.width, 0.73f);
                }
                iFloatWindow.show();
            } else {
                SobotFloatWindow.B floatWindow = SobotFloatWindow
                        .with(SobotJanusService.this.getApplicationContext())
                        .setView(R.layout.call_float_window)
                        .setTag(SobotCallConstant.CALL_STATUS_FLOAT)
                        .setX(Screen.width, 0.73f)
                        .setY(Screen.height, 0.2f)
                        .setMoveType(MoveType.slide)
                        .setMoveStyle(500, new BounceInterpolator())
                        .setDesktopShow(true);
                floatWindow.build();
                if (SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT) != null) {
                    SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT).show();
                }
            }
            View statusFloatView = SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT).getView();
            ImageView iv_call = statusFloatView.findViewById(R.id.iv_call);
            iv_call.setVisibility(View.GONE);
            TextView tv_call_statue = statusFloatView.findViewById(R.id.tv_call_statue);
            TextView tv_complete = statusFloatView.findViewById(R.id.tv_complete);
            TextView tv_extend = statusFloatView.findViewById(R.id.tv_extend);
            TextView tv_set_busy = statusFloatView.findViewById(R.id.tv_set_busy);
            ImageView iv_expand = statusFloatView.findViewById(R.id.iv_expand);
            tv_complete.setVisibility(View.VISIBLE);
            tv_extend.setVisibility(View.GONE);
            tv_set_busy.setVisibility(View.GONE);
            tv_call_statue.setText(getResources().getString(R.string.sobot_call_finishing) + " " + arrangeDuration + getResources().getString(R.string.sobot_call_second));

            if (CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_DHT_YCZLSC) || CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_DHT_JSZLBZM)) {
                iv_expand.setVisibility(View.VISIBLE);
            } else {
                iv_expand.setVisibility(View.GONE);
            }

            String finishing = SobotJanusService.this.getResources().getString(R.string.sobot_call_finishing);
            String second = getResources().getString(R.string.sobot_call_second);
            if (mHandler == null) {
                mHandler = new Handler();
            }
            mHandler.postDelayed(new Runnable() {
                @Override
                public void run() {
                    tv_call_statue.setText(finishing + " " + (arrangeDuration > 0 ? (--arrangeDuration) : 0) + second);
                    SobotLogUtils.i("会话小结倒计时：" + arrangeDuration);
                    if (arrangeDuration == 0) {
                        if (SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT) != null) {
                            SobotFloatWindow.destroy(SobotCallConstant.CALL_STATUS_FLOAT);
                        }
                        mHandler.removeCallbacks(this);
                    } else {
                        mHandler.postDelayed(this, 1000);
                    }
                }
            }, 1000);
            iv_expand.setTag(0);//收起
            iv_expand.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    int isExpand = (int) iv_expand.getTag();
                    if (isExpand == 0) {
                        //展开
                        tv_complete.setVisibility(View.VISIBLE);
                        iv_expand.setVisibility(View.VISIBLE);
                        iv_expand.setImageResource(R.drawable.icon_call_arraw_up);
                        iv_expand.setTag(1);
                        //延长整理时间
                        if (CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_DHT_YCZLSC)) {
                            tv_extend.setVisibility(View.VISIBLE);
                        } else {
                            tv_extend.setVisibility(View.GONE);
                        }
                        //结束整理并置忙
                        if (CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_DHT_JSZLBZM)) {
                            tv_set_busy.setVisibility(View.VISIBLE);
                        } else {
                            tv_set_busy.setVisibility(View.GONE);
                        }
                    } else {
                        //收起
                        tv_complete.setVisibility(View.VISIBLE);
                        tv_extend.setVisibility(View.GONE);
                        tv_set_busy.setVisibility(View.GONE);
                        iv_expand.setVisibility(View.VISIBLE);
                        iv_expand.setImageResource(R.drawable.icon_call_arraw_down);
                        iv_expand.setTag(0);
                    }
                }
            });
            tv_complete.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    arrangeDuration = 0;//重置  0 会移除会话小结倒计时
                    //结束整理
                    SobotCallOpenApi.finishCallAfterWork(SobotJanusService.this.getApplicationContext(), new SobotResultBlock() {
                        @Override
                        public void resultBolok(SobotResultCode code, String msg, Object obj) {
                            if (SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT) != null) {
                                SobotFloatWindow.destroy(SobotCallConstant.CALL_STATUS_FLOAT);
                            }
                        }
                    });
                }
            });
            tv_extend.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    //延长整理时长
                    SobotCallOpenApi.delayCallAfterWork(SobotJanusService.this.getApplicationContext(), 60, new SobotResultBlock() {
                        @Override
                        public void resultBolok(SobotResultCode code, String msg, Object obj) {
                        }
                    });
                }
            });
            tv_set_busy.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    arrangeDuration = 0;//重置  0 会移除会话小结倒计时
                    //勿扰
                    SobotCallOpenApi.agentNotReady(SobotJanusService.this.getApplicationContext(), "2", new SobotResultBlock() {
                        @Override
                        public void resultBolok(SobotResultCode code, String msg, Object obj) {
                            if (SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT) != null) {
                                SobotFloatWindow.destroy(SobotCallConstant.CALL_STATUS_FLOAT);
                            }
                        }
                    });
                }
            });
            statusFloatView.setOnClickListener(null);
        }
    }

    /**
     * 显示提示浮层
     *
     * @param mMessageTop
     * @param mMessage
     * @param type        type==1  应用在后台不提示
     */
    private void showTipFloat(String mMessageTop, String mMessage, int type) {
        if (!MyActivityLifeCycle.getInstance().isForground()) {
            if (type == 1) {
                //应用在后台不提示
                CallSharedPreferencesUtils.getInstance(SobotJanusService.this).put("showTipFloat", true);
            }
            return;
        }
        if (FloatingWindowPermissionUtil.hasSuspendedWindowPermission(SobotJanusService.this.getApplicationContext())) {
            //提示浮层
            IFloatWindow iFloatWindow = SobotFloatWindow.get(SobotCallConstant.CALL_TIP_FLOAT);

            if (iFloatWindow != null) {
                iFloatWindow.show();
            } else {
                SobotFloatWindow.B floatWindow = SobotFloatWindow
                        .with(SobotJanusService.this.getApplicationContext())
                        .setView(R.layout.call_dialog_common_tip)
                        .setTag(SobotCallConstant.CALL_TIP_FLOAT)
                        .setX(Screen.width, 0.1f)
                        .setY(Screen.height, 0.36f)
                        .setWidth(Screen.width, 0.8f)
                        .setMoveType(MoveType.inactive)
                        .setDesktopShow(true);
                floatWindow.build();
                if (SobotFloatWindow.get(SobotCallConstant.CALL_TIP_FLOAT) != null) {
                    SobotFloatWindow.get(SobotCallConstant.CALL_TIP_FLOAT).show();
                }
            }
            View statusFloatView = SobotFloatWindow.get(SobotCallConstant.CALL_TIP_FLOAT).getView();
            TextView tv_message_top = statusFloatView.findViewById(R.id.tv_message_top);
            TextView tv_message = statusFloatView.findViewById(R.id.tv_message);
            tv_message_top.setText(SobotStringUtils.checkStringIsNull(mMessageTop));
            tv_message.setText(SobotStringUtils.checkStringIsNull(mMessage));
            Button btn_cancel = statusFloatView.findViewById(R.id.btn_cancel);
            btn_cancel.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    if (SobotFloatWindow.get(SobotCallConstant.CALL_TIP_FLOAT) != null) {
                        SobotFloatWindow.destroy(SobotCallConstant.CALL_TIP_FLOAT);
                    }
                }
            });
            statusFloatView.setOnClickListener(null);
        } else {
            if (!SobotStringUtils.isEmpty(mMessageTop) || !SobotStringUtils.isEmpty(mMessage)) {
                String tip = "";
                if (!SobotStringUtils.isEmpty(mMessage)) {
                    tip = tip + SobotStringUtils.checkStringIsNull(mMessage);
                } else {
                    if (!SobotStringUtils.isEmpty(mMessageTop)) {
                        tip = tip + SobotStringUtils.checkStringIsNull(mMessageTop);
                    }
                }
                if (!SobotStringUtils.isEmpty(tip)) {
                    SobotToastUtil.showCustomLongToast(SobotJanusService.this, tip);
                }
            }
        }
    }

    @Override
    public void onDestroy() {
        SobotLogUtils.d("SobotJanusService onDestroy");
        if (stompMsgObserver != null) {
            SobotLiveEventBus.get(SobotCallLiveDataBusKey.RECEIVE_STOMP_MSG, CallStompMsgModel.class).removeObserver(stompMsgObserver);
        }
        if (getCallingWoIdObserver != null) {
            SobotLiveEventBus.get(SobotCallLiveDataBusKey.SOBOT_LIVEBUS_GET_CALLING_WOID, String.class).removeObserver(getCallingWoIdObserver);
        }
        try {
            isServiceRunning = false;
            isRegistedSuccess = false;
            if (SobotStompClient.getInstance(SobotJanusService.this) != null && SobotStompClient.getInstance(SobotJanusService.this).isConnected()) {
                SobotStompClient.getInstance(SobotJanusService.this).disconnect();
            }
            SobotNetStateChangeReceiver.unRegisterObserver(this);
            SobotNetStateChangeReceiver.unRegisterReceiver(this.getApplicationContext());

            this.abandonAudioFocus();
            this.stopRinging();
            if (peerConnection != null) {
                peerConnection.close();
                peerConnection = null;
            }
            PeerConnectionFactory.stopInternalTracingCapture();
            PeerConnectionFactory.shutdownInternalTracer();
            SobotJanusClient.getInstance().disConnect();
            //WebSocket要置为空，否则再次重连不重新创建
            WebSocketHandler.setDefaultWebSocket(null);
        } catch (Exception e) {
        }
        super.onDestroy();
    }


    @Override
    public int onStartCommand(Intent intent, int flags, int startId) {
        String action = "";
        if (intent == null) {
            action = "Start";
            SobotLogUtils.d("SobotJanusService onStartCommand with null intent");
        } else {
            action = intent.getAction();
            SobotLogUtils.d("SobotJanusService onStartCommand action " + action);
            callType = intent.getIntExtra("callType", 0);
        }
        if (callType != 1 && !SobotJanusClient.getInstance().isConnected()) {
            //webrtc
            SobotNetStateChangeReceiver.registerReceiver(this.getApplicationContext());
            SobotNetStateChangeReceiver.registerObserver(this);
            eglBaseContext = EglBase.create().getEglBaseContext();
            peerConnectionFactory = createPeerConnectionFactory();
            SobotJanusClient.getInstance().setJanusCallback(janusCallback);
            //连接websecket
            SobotJanusClient.getInstance().connect(this, SobotCallBaseUrl.getJanusSocketUri());
        }
        receiveStompMsg();
        if (!TextUtils.isEmpty(action)) {
            switch (action) {
                case "accept":
                    try {
                        String jsepStr = intent.getStringExtra("jsep");
                        JSONObject jsep = new JSONObject(jsepStr);
                        if (jsep != null && peerConnection != null) {
                            String sdp = jsep.getString("sdp");
                            SessionDescription.Type sessionDescriptionType = SessionDescription.Type.fromCanonicalForm(jsep.optString("type"));
                            peerConnection.setRemoteDescription(new SdpObserver() {
                                @Override
                                public void onCreateSuccess(SessionDescription sdp) {
                                    SobotLogUtils.d("SobotJanusService setRemoteDescription onCreateSuccess");
                                }

                                @Override
                                public void onSetSuccess() {
                                    SobotLogUtils.d("SobotJanusService setRemoteDescription onSetSuccess");
                                    // 这时应该回复网关一个 start ，附带自己的 sdp answer
                                    createAnswer(peerConnection, new CreateAnswerCallback() {
                                        @Override
                                        public void onSetAnswerSuccess(SessionDescription sdp) {
                                            // 接通
                                            SobotJanusClient.getInstance().getInstance().accept(sdp);
                                        }

                                        @Override
                                        public void onSetAnswerFailed(String error) {

                                        }
                                    });
                                }

                                @Override
                                public void onCreateFailure(String error) {
                                    SobotLogUtils.d("SobotJanusService setRemoteDescription onCreateFailure " + error);
                                }

                                @Override
                                public void onSetFailure(String error) {
                                    SobotLogUtils.d("SobotJanusService setRemoteDescription onSetFailure " + error);
                                }
                            }, new SessionDescription(sessionDescriptionType, sdp));
                        }
                    } catch (Exception e) {
                    }
                    break;
            }
        }
        return super.onStartCommand(intent, flags, startId);
    }


    @Override
    public IBinder onBind(Intent intent) {
        return null;
    }

    private SobotJanusClient.JanusCallback janusCallback = new SobotJanusClient.JanusCallback() {
        @Override
        public void onCreateSession(BigInteger sessionId, boolean isAutoRegister) {
            //加载sip插件
            SobotJanusClient.getInstance().attachPlugin("janus.plugin.sip", isAutoRegister);
        }

        @Override
        public void onClaimSuccess() {
            iceRestart();
        }

        @Override
        public void onAttached(BigInteger handleId, boolean isAutoRegister) {
            SobotLogUtils.d("sobotjanusservice onAttached ,isAutoRegister =" + isAutoRegister);
            if (isAutoRegister) {
                SobotJanusSipPhoneUtils.login(SobotJanusService.this.getApplicationContext());
            }
        }

        @Override
        public void onSubscribeAttached(BigInteger handleId, BigInteger feedId) {

        }

        @Override
        public void onDetached(BigInteger handleId) {
        }

        @Override
        public void onHangup() {

        }

        @Override
        public void onMessage(BigInteger sender, BigInteger handleId, JSONObject msg, JSONObject jsep) {
            if (!msg.has("sip")) {
                return;
            }
            try {
                if (jsep != null) {
                    jsepStr = jsep.toString();
                }
                String type = msg.optString("sip", "");
                if ("event".equals(type)) {
                    JSONObject result = null;
                    if (msg.has("result") && !msg.isNull("result")) {
                        result = msg.getJSONObject("result");
                    }
                    if (result != null && result.has("event")) {
                        String event = result.optString("event", "");
                        if (!TextUtils.isEmpty(event)) {
                            if ("registered".equals(event)) {
                                //注册成功
                                SobotServiceInfoModel serviceVo = SobotLoginTools.getInstance().getServiceInfo();
                                if (serviceVo != null && serviceVo.getCallV6Flag() == 1) {
                                    String accesstoken = SobotLoginTools.getInstance().getAccessToken();
                                    //v6 需要连接stomp
                                    if (!SobotStompClient.getInstance(SobotJanusService.this).isConnected()) {
                                        String languageStr = CallBaseSharedPreferencesUtils.getInstance(SobotJanusService.this).get("SobotLanguageStr", "zh");
                                        SobotStompClient.getInstance(SobotJanusService.this).over(SobotStompClient.ConnectionProviderType.OKHTTP, SobotCallBaseUrl.getStompSocketUri() + "?authorization=Bearer " + accesstoken + "&language=" + languageStr, null, null);
                                        SobotStompClient.getInstance(SobotJanusService.this).connectStomp(0);
                                        SobotLogUtils.i("janus stomp 再次链接");
                                    }
                                }
                                SobotLogUtils.d("janus=========注册成功");
                                isRegistedSuccess = true;
                                //注册成功
                                if (SobotCallConstant.CALL_MODEL_SIP == CallSharedPreferencesUtils.getInstance(getApplicationContext()).get(SobotCallConstant.SP_KEY_CALL_MODEL_TYPE_V6, SobotCallConstant.CALL_MODEL_PHONE)) {
                                    SobotRegistrationListener.getInstance().registrationOK();
                                }
                            } else if ("unregistered".equals(event)) {
                                //取消注册
                                SobotLogUtils.e("janus=========取消注册");
                                isRegistedSuccess = false;
                                SobotRegistrationListener.getInstance().registrationCleared();
                            } else if ("registration_failed".equals(event)) {
                                //注册失败
                                SobotLogUtils.e("janus=========注册失败");
                                isRegistedSuccess = false;
                                SobotRegistrationListener.getInstance().registrationFailed();
                            } else if ("hangup".equals(event)) {
                                //通话挂断
                                SobotLogUtils.d("janus=========通话挂断");
                                stopRinging();
                                SobotPhoneStatusListener.getInstance().callEnd();
                                if (peerConnection != null) {
                                    peerConnection.close();
                                    peerConnection = null;
                                }
                            } else if ("accepted".equals(event)) {
                                //通话已经建立
                                SobotLogUtils.d("janus=========通话已经建立");
                                stopRinging();
                                SobotPhoneStatusListener.getInstance().callConnected();
                                //更新通话状态浮层 为通话中
                                IFloatWindow iFloatWindow = SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT);
                                if (iFloatWindow != null) {
                                    View statusFloatView = iFloatWindow.getView();
                                    TextView fStatusTV = statusFloatView.findViewById(R.id.tv_call_statue);
                                    fStatusTV.setText(getResources().getString(R.string.sobot_custom_tonghuazhong));
                                }
                                if (jsep != null && peerConnection != null) {
                                    String sdpStr = jsep.getString("sdp");
                                    SessionDescription.Type sessionDescriptionType = SessionDescription.Type.fromCanonicalForm(jsep.optString("type"));
                                    peerConnection.setRemoteDescription(new SdpObserver() {
                                        @Override
                                        public void onCreateSuccess(SessionDescription sdp) {
                                            SobotLogUtils.d("SobotJanusService setRemoteDescription onCreateSuccess");
                                        }

                                        @Override
                                        public void onSetSuccess() {
                                            SobotLogUtils.d("SobotJanusService setRemoteDescription onSetSuccess");
                                        }

                                        @Override
                                        public void onCreateFailure(String error) {
                                            SobotLogUtils.d("SobotJanusService setRemoteDescription onCreateFailure " + error);
                                        }

                                        @Override
                                        public void onSetFailure(String error) {
                                            SobotLogUtils.d("SobotJanusService setRemoteDescription onSetFailure " + error);
                                        }
                                    }, new SessionDescription(sessionDescriptionType, sdpStr));
                                }
                            } else if ("incomingcall".equals(event) && jsep != null) {
                                //响铃来电
                                SobotLogUtils.d("janus=========来电了");
                                //来电手机号
                                String incomingPhone = result.optString("displayname", "");
                                if (!TextUtils.isEmpty(incomingPhone)) {
                                    incomingPhone = incomingPhone.replace("\"", "");
                                }
                                intent = CallStatusActivity.initCallMeIntent(getApplicationContext(), incomingPhone);
                                if (jsep != null) {
                                    intent.putExtra("incomimgJsep", jsep.toString());
                                }
                                String call_info = msg.optString("call_info", "");
                                if (!TextUtils.isEmpty(call_info) && call_info.contains("answer-after=0")) {
                                    //外呼场景来电不响铃
                                    SobotLogUtils.d("janus=========外呼来电不响铃");
                                    if (jsep != null) {
                                        SobotPhoneStatusListener.getInstance().incomingCall(jsep.toString(), true, incomingPhone);
                                    }
                                } else {
                                    //响铃来电
                                    startRinging();
                                    if (jsep != null) {
                                        SobotCallOpenApi.changedPlayCategory(SobotJanusService.this.getApplicationContext(), true, null);
                                        SobotPhoneStatusListener.getInstance().incomingCall(jsep.toString(), false, incomingPhone);
                                    }
                                }
                                peerConnection = createPeerConnection();
                            }
                        }
                    } else {
                        if (msg.has("error_code")) {
                            if (msg.optString("error_code", "").equals("445")) {
                                isRegistedSuccess = true;
                                //之前已经注册成功了 直接用就行
                                if (SobotCallConstant.CALL_MODEL_SIP == CallSharedPreferencesUtils.getInstance(getApplicationContext()).get(SobotCallConstant.SP_KEY_CALL_MODEL_TYPE_V6, SobotCallConstant.CALL_MODEL_PHONE)) {
                                    SobotRegistrationListener.getInstance().registrationOK();
                                }
                            }

                        }

                    }
                }
            } catch (JSONException e) {
                e.printStackTrace();
            }
        }

        @Override
        public void onIceCandidate(BigInteger handleId, JSONObject candidate) {
            try {
                if (!candidate.has("completed") && peerConnection != null) {
                    // 添加对方的ice
                    peerConnection.addIceCandidate(new IceCandidate(candidate.getString("sdpMid"),
                            candidate.getInt("sdpMLineIndex"), candidate.getString("candidate")));
                }
            } catch (JSONException e) {
                e.printStackTrace();
            }
        }

        @Override
        public void onDestroySession(BigInteger sessionId) {

        }

        @Override
        public void onError(int code, String reason) {
            //  "code": 458,
            //  "reason": "No such session 3137677776181713"
            if (code == 458) {
                SobotJanusClient.getInstance().createSession(true);
            } else if (code == 457) {
                //  "code": 457,
                //    "reason": "Unhandled request 'claim' at this path"
                SobotJanusClient.getInstance().createSession(true);
            }
        }
    };


    private PeerConnectionFactory createPeerConnectionFactory() {
        final VideoEncoderFactory encoderFactory;
        final VideoDecoderFactory decoderFactory;

        encoderFactory = new DefaultVideoEncoderFactory(
                eglBaseContext, false /* enableIntelVp8Encoder */, true);
        decoderFactory = new DefaultVideoDecoderFactory(eglBaseContext);

        PeerConnectionFactory.initialize(PeerConnectionFactory.InitializationOptions.builder(this)
                .setEnableInternalTracer(true)
                .createInitializationOptions());

        PeerConnectionFactory.Builder builder = PeerConnectionFactory.builder()
                .setVideoEncoderFactory(encoderFactory)
                .setVideoDecoderFactory(decoderFactory);
        builder.setOptions(null);

        return builder.createPeerConnectionFactory();
    }

    private PeerConnection createPeerConnection() {
        streamList = new ArrayList<>();
        //ICE服务器列表
        List<PeerConnection.IceServer> iceServerList = new ArrayList<>();
        //去掉ICE服务器 防止国外账号通话没声音(备用链路,直连janus语音不通，走转发才行)
//        iceServerList.add(new PeerConnection.IceServer("turns:ice-turn.sg.sobot.cc:443?transport=udp", "sobot", "sobot"));
        PeerConnection.RTCConfiguration rtcConfig = new PeerConnection.RTCConfiguration(iceServerList);
        PeerConnection peerConnection = peerConnectionFactory.createPeerConnection(rtcConfig, peerConnectionObserver);
        startLocalAudioCapture(peerConnection);
        return peerConnection;
    }

    //配置本地音频轨
    private void startLocalAudioCapture(PeerConnection peerConnection) {
        if (peerConnection == null) {
            return;
        }
        //语音
        MediaConstraints audioConstraints = new MediaConstraints();
        //回声消除
        audioConstraints.mandatory.add(new MediaConstraints.KeyValuePair("googEchoCancellation", "true"));
        //自动增益
        audioConstraints.mandatory.add(new MediaConstraints.KeyValuePair("googAutoGainControl", "true"));
        //高音过滤
        audioConstraints.mandatory.add(new MediaConstraints.KeyValuePair("googHighpassFilter", "true"));
        //噪音处理
        audioConstraints.mandatory.add(new MediaConstraints.KeyValuePair("googNoiseSuppression", "true"));
        AudioSource audioSource = peerConnectionFactory.createAudioSource(audioConstraints);
        AudioTrack audioTrack = peerConnectionFactory.createAudioTrack(AUDIO_TRACK_ID, audioSource);
        MediaStream localMediaStream = peerConnectionFactory.createLocalMediaStream(LOCAL_AUDIO_STREAM);
        localMediaStream.addTrack(audioTrack);
//        audioTrack.setVolume(VOLUME);
        peerConnection.addTrack(audioTrack, streamList);
        peerConnection.addStream(localMediaStream);
    }

    void iceRestart() {
        if (peerConnection != null && SobotJanusClient.getInstance().isConnected()) {
            SobotLogUtils.i("SobotJanusService IceRestart");
            createOffer(peerConnection, new CreateOfferCallback() {
                @Override
                public void onCreateOfferSuccess(SessionDescription sdp) {
                    SobotJanusClient.getInstance().update(sdp);
                }

                @Override
                public void onCreateFailed(String error) {

                }
            });
        }
    }

    private PeerConnection.Observer peerConnectionObserver = new PeerConnection.Observer() {
        @Override
        public void onSignalingChange(PeerConnection.SignalingState newState) {
            SobotLogUtils.d("sobotjanusservice onSignalingChange " + newState);
        }

        @Override
        public void onIceConnectionChange(PeerConnection.IceConnectionState newState) {
            SobotLogUtils.d("sobotjanusservice onIceConnectionChange " + newState);
            if (newState != null && newState == PeerConnection.IceConnectionState.FAILED) {
                iceRestart();
            }
        }

        @Override
        public void onIceConnectionReceivingChange(boolean receiving) {
            SobotLogUtils.d("sobotjanusservice onIceConnectionReceivingChange " + receiving);
        }

        @Override
        public void onIceGatheringChange(PeerConnection.IceGatheringState newState) {
            SobotLogUtils.d("sobotjanusservice onIceGatheringChange " + newState);
            if (newState == PeerConnection.IceGatheringState.COMPLETE) {
                SobotJanusClient.getInstance().trickleCandidateComplete();
            }
        }

        @Override
        public void onIceCandidate(IceCandidate candidate) {
            SobotLogUtils.d("sobotjanusservice onIceCandidate");
            SobotJanusClient.getInstance().trickleCandidate(candidate);
        }

        @Override
        public void onIceCandidatesRemoved(IceCandidate[] candidates) {
            SobotLogUtils.d("sobotjanusservice onIceCandidatesRemoved");
            if (peerConnection != null) {
                peerConnection.removeIceCandidates(candidates);
            }
        }

        @Override
        public void onAddStream(MediaStream stream) {
            SobotLogUtils.d("sobotjanusservice onAddStream:" + stream);
            List<AudioTrack> audioTracks = stream.audioTracks;
            if (audioTracks != null && audioTracks.size() > 0) {
                AudioTrack audioTrack = audioTracks.get(0);
                if (audioTrack != null) {
                    audioTrack.setVolume(VOLUME);
                }
            }
        }

        @Override
        public void onRemoveStream(MediaStream stream) {
            SobotLogUtils.d("sobotjanusservice onRemoveStream");
        }

        @Override
        public void onDataChannel(DataChannel dataChannel) {

        }

        @Override
        public void onRenegotiationNeeded() {

        }

        @Override
        public void onAddTrack(RtpReceiver receiver, MediaStream[] mediaStreams) {
            SobotLogUtils.d("sobotjanusservice onAddTrack ");
        }
    };


    private void createOffer(PeerConnection peerConnection, CreateOfferCallback
            callback) {
        if (peerConnection == null) {
            return;
        }
        MediaConstraints mediaConstraints = new MediaConstraints();
        mediaConstraints.mandatory.add(new MediaConstraints.KeyValuePair("offerToReceiveAudio", "true")); // 允许音频
        mediaConstraints.mandatory.add(new MediaConstraints.KeyValuePair("offerToReceiveVideo", "false"));// 不允许视频
        mediaConstraints.mandatory.add(new MediaConstraints.KeyValuePair("IceRestart", "true")); //IceRestart 的首字母I需要大写 不然ice重启后onIceConnectionChange 还是连接不上
//        mediaConstraints.optional.add(new MediaConstraints.KeyValuePair("DtlsSrtpKeyAgreement", "true"));
        peerConnection.createOffer(new SdpObserver() {
            @Override
            public void onCreateSuccess(SessionDescription sdp) {
                SobotLogUtils.d("SobotJanusService createOffer onCreateSuccess " + sdp.toString());
                // 将会话描述设置在本地
                peerConnection.setLocalDescription(new SdpObserver() {
                    @Override
                    public void onCreateSuccess(SessionDescription sdp) {

                        SobotLogUtils.d("SobotJanusService createOffer setLocalDescription onCreateSuccess");
                    }

                    @Override
                    public void onSetSuccess() {
                        SobotLogUtils.d("SobotJanusService createOffer setLocalDescription onSetSuccess");
                    }

                    @Override
                    public void onCreateFailure(String error) {
                        SobotLogUtils.d("SobotJanusService createOffer setLocalDescription onCreateFailure " + error);
                    }

                    @Override
                    public void onSetFailure(String error) {
                        SobotLogUtils.d("SobotJanusService createOffer setLocalDescription onSetFailure " + error);
                    }
                }, sdp);

                if (callback != null) {
                    callback.onCreateOfferSuccess(sdp);
                }
            }

            @Override
            public void onSetSuccess() {
                SobotLogUtils.d("SobotJanusService createOffer onSetSuccess");
            }

            @Override
            public void onCreateFailure(String error) {
                SobotLogUtils.d("SobotJanusService createOffer onCreateFailure " + error);
                if (callback != null) {
                    callback.onCreateFailed(error);
                }
            }

            @Override
            public void onSetFailure(String error) {
                SobotLogUtils.d("SobotJanusService createOffer onSetFailure " + error);
                if (callback != null) {
                    callback.onCreateFailed(error);
                }
            }
        }, mediaConstraints);
    }

    private void createAnswer(PeerConnection peerConnection, CreateAnswerCallback
            callback) {
        MediaConstraints mediaConstraints = new MediaConstraints();
        mediaConstraints.mandatory.add(new MediaConstraints.KeyValuePair("offerToReceiveAudio", "true")); // 允许音频
        mediaConstraints.mandatory.add(new MediaConstraints.KeyValuePair("offerToReceiveVideo", "false"));// 不允许视频
        mediaConstraints.optional.add(new MediaConstraints.KeyValuePair("DtlsSrtpKeyAgreement", "true")); // 加密
        peerConnection.createAnswer(new SdpObserver() {
            @Override
            public void onCreateSuccess(SessionDescription sdp) {
                SobotLogUtils.d("SobotJanusService createAnswer onCreateSuccess");
                SobotLogUtils.d(sdp.type + "-------------------------" + sdp.description);
                // 将会话描述设置在本地
                peerConnection.setLocalDescription(new SdpObserver() {
                    @Override
                    public void onCreateSuccess(SessionDescription sdp) {
                    }

                    @Override
                    public void onSetSuccess() {
                        // send answer sdp
                        SobotLogUtils.d("SobotJanusService createAnswer setLocalDescription onSetSuccess");
                        if (callback != null) {
                            callback.onSetAnswerSuccess(sdp);
                        }
                    }

                    @Override
                    public void onCreateFailure(String s) {
                        SobotLogUtils.d("SobotJanusService createAnswer setLocalDescription onCreateFailure " + s);
                        if (callback != null) {
                            callback.onSetAnswerFailed(s);
                        }
                    }

                    @Override
                    public void onSetFailure(String s) {
                        SobotLogUtils.d("SobotJanusService createAnswer setLocalDescription onSetFailure " + s);
                        if (callback != null) {
                            callback.onSetAnswerFailed(s);
                        }
                    }
                }, sdp);
            }

            @Override
            public void onSetSuccess() {
                SobotLogUtils.d("SobotJanusService createAnswer onSetSuccess");
            }

            @Override
            public void onCreateFailure(String s) {
                SobotLogUtils.d("SobotJanusService createAnswer onCreateFailure " + s);
            }

            @Override
            public void onSetFailure(String s) {
                SobotLogUtils.d("SobotJanusService createAnswer onSetFailure " + s);
            }
        }, mediaConstraints);
    }

    @Override
    public void onNetDisconnected() {

    }

    //上次网络变化时间
    private long lastConnectivitytime = 0;

    @Override
    public void onNetConnected(NetworkType networkType) {
        //CONNECTIVITY_ACTION 粘性广播，一注册就会收到这个广播，第一次不处理 webrtc登录才恢复WebSocket
        if (connectivity_action_count > 0 && callType != 1) {
            long currentTime = Calendar.getInstance().getTimeInMillis();
            if (currentTime - lastConnectivitytime > 2000) {
                //两次收到网络变化广播时间超过2s 才执行逻辑
                lastConnectivitytime = currentTime;
                if (WebSocketHandler.getDefault() != null) {
                    if (WebSocketHandler.getDefault().getSetting().reconnectWithNetworkChanged()) {
                        WebSocketHandler.getDefault().reconnect();
                    }
                }
                if (!WebSocketHandler.getAllWebSocket().isEmpty()) {
                    Map<String, SobotWebSocketManager> webSocketManagerMap = WebSocketHandler.getAllWebSocket();
                    for (String key : webSocketManagerMap.keySet()) {
                        SobotWebSocketManager item = webSocketManagerMap.get(key);
                        if (item != null && item.getSetting().reconnectWithNetworkChanged()) {
                            item.reconnect();
                        }
                    }
                }
            }
        }
        connectivity_action_count++;
    }


    interface CreateAnswerCallback {
        void onSetAnswerSuccess(SessionDescription sdp);

        void onSetAnswerFailed(String error);
    }


    interface CreateOfferCallback {
        void onCreateOfferSuccess(SessionDescription sdp);

        void onCreateFailed(String error);
    }

    public static final boolean isServiceRunning() {
        return SobotJanusService.isServiceRunning;
    }

    public static final boolean isRegistedSuccess() {
        return SobotJanusService.isRegistedSuccess;
    }

    /*******************************提升服务级别****************************/
    private AssistServiceConnection mAssistConnection;
    private final int PID = 99998;

    public void setForeground() {
        // sdk < 18 , 直接调用startForeground即可,不会在通知栏创建通知
        if (Build.VERSION.SDK_INT < 18) {
            this.startForeground(PID, getNotification());
            return;
        }
        if (Build.VERSION.SDK_INT >= 25) {
            this.startForeground(PID, getNotification());
            return;
        }

        if (null == mAssistConnection) {
            mAssistConnection = new AssistServiceConnection();
        }

        this.bindService(new Intent(this, AssistService.class), mAssistConnection,
                Service.BIND_AUTO_CREATE);
    }

    private static final String SOBOT_CHANNEL_ID = "sobot_custom_channel_id";
    private static final String SOBOT_CHANNEL_NAME = "sobot";

    private Notification getNotification() {
        if (Build.VERSION.SDK_INT >= 26) {
            NotificationManager manager = (NotificationManager) getApplicationContext().getSystemService(Context.NOTIFICATION_SERVICE);
            Notification.Builder bulider;
            if (manager != null) {
                bulider = new Notification.Builder(getApplicationContext(), SOBOT_CHANNEL_ID);
                NotificationChannel mChannel = new NotificationChannel(SOBOT_CHANNEL_ID, SOBOT_CHANNEL_NAME, NotificationManager.IMPORTANCE_DEFAULT);
                manager.createNotificationChannel(mChannel);
                return bulider.build();
            } else {
                return null;
            }
        } else {
            return new Notification();
        }
    }

    public static class AssistService extends Service {
        public AssistService() {
            super();
        }

        public class LocalBinder extends Binder {
            public AssistService getService() {
                return AssistService.this;
            }
        }

        @Override
        public IBinder onBind(Intent intent) {
            return new LocalBinder();
        }

        @Override
        public void onDestroy() {
            super.onDestroy();
        }

    }

    private class AssistServiceConnection implements ServiceConnection {
        @Override
        public void onServiceDisconnected(ComponentName name) {
        }

        @Override
        public void onServiceConnected(ComponentName name, IBinder binder) {
            // sdk >=18
            // 的，会在通知栏显示service正在运行，这里不要让用户感知，所以这里的实现方式是利用2个同进程的service，利用相同的notificationID，
            // 2个service分别startForeground，然后只在1个service里stopForeground，这样即可去掉通知栏的显示
            Service assistService = ((AssistService.LocalBinder) binder).getService();
            SobotJanusService.this.startForeground(PID, getNotification());
            assistService.startForeground(PID, getNotification());
            assistService.stopForeground(true);

            SobotJanusService.this.unbindService(mAssistConnection);
            mAssistConnection = null;
        }

    }

    private MediaPlayer mediaPlayer;

    private final void startRinging() {
        mediaPlayer = new MediaPlayer();
        AssetFileDescriptor file = getResources().openRawResourceFd(R.raw.bell_ring);
        try {
            mediaPlayer.setDataSource(file.getFileDescriptor(), file.getStartOffset(),
                    file.getLength());
            mediaPlayer.prepare();
            file.close();
        } catch (IOException e) {
            e.printStackTrace();
        }
        mediaPlayer.setVolume(0.5f, 0.5f);
        mediaPlayer.setLooping(true);
        mediaPlayer.start();
    }

    private final void stopRinging() {
        if (mediaPlayer != null) {
            mediaPlayer.stop();
            mediaPlayer.release();
            mediaPlayer = null;
        }
    }

    private final void requestAudioFocus(int type) {

    }

    private final void abandonAudioFocus() {
    }
}
