package com.sobot.callsdk.v1.activity;

import android.content.Context;
import android.content.Intent;
import android.graphics.Color;
import android.graphics.drawable.Drawable;
import android.text.Editable;
import android.text.TextUtils;
import android.text.TextWatcher;
import android.view.View;
import android.view.inputmethod.InputMethodManager;
import android.widget.EditText;
import android.widget.LinearLayout;
import android.widget.TextView;

import androidx.annotation.Nullable;

import com.sobot.callbase.api.SobotCallBaseCode;
import com.sobot.callbase.api.utils.SobotCallUtils;
import com.sobot.callbase.dialog.SobotCallCommonDialog;
import com.sobot.callsdk.R;
import com.sobot.callsdk.activity.SobotCallBaseActivity;
import com.sobot.callsdk.api.SobotCallBaseCodeGroup;
import com.sobot.callsdk.utils.CallSharedPreferencesUtils;
import com.sobot.callsdk.utils.SobotCallConstant;
import com.sobot.callsdk.v1.entity.v1.SobotCallContactPlan;
import com.sobot.callsdk.v1.entity.v1.SobotRemindInfo;
import com.sobot.network.http.callback.SobotResultCallBack;
import com.sobot.utils.SobotDateUtil;
import com.sobot.utils.SobotStringUtils;
import com.sobot.widget.ui.toast.SobotToastUtil;

import java.util.Date;

/**
 * 创建联系计划
 */
public class SobotAddCallPlanActivity extends SobotCallBaseActivity implements View.OnClickListener{

    private LinearLayout phoneParent;//联系计划电话的父布局，查看联系计划详情显示电话
    private View lineCrude;//计划名称下面的粗线
    private View lineFine;//计划名称下面的细线
    private TextView contactPlanPhone;//显示手机号码
    private EditText contactPlanName;//计划名称输入框
    private TextView contactPlanTime;//时间显示
    private TextView contactPlanRemind;//提醒显示
    private EditText contactPlanRemark;//备注输入框
    private TextView mRightMenuBtn;

    private boolean fromFlag;//true是创建联系计划，false是编辑联系计划
    private SobotCallContactPlan model;//编辑联系计划
    private String userPhone;//创建联系计划时，传过来的用户电话
    private String taskIdName;//任务名称
    private String taskDetailId;//任务详情id
    private int hiddenFlag;//手机号隐藏标志


    @Override
    protected int getContentViewResId() {
        return R.layout.sobot_activity_add_call_plan;
    }

    @Override
    protected void initView() {
        phoneParent = findViewById(R.id.contact_play_lable_phone_ll);
        contactPlanPhone = findViewById(R.id.contact_play_phone);
        contactPlanName = findViewById(R.id.contact_play_name);


        lineCrude = findViewById(R.id.contact_play_lable_name_line_crude);
        lineFine = findViewById(R.id.contact_play_lable_name_line_fine);
        contactPlanTime = findViewById(R.id.contact_play_appointment);
        contactPlanRemind = findViewById(R.id.contact_play_remind);
        contactPlanRemark = findViewById(R.id.contact_play_remark);
        fromFlag = getIntent().getBooleanExtra("fromFlag", false);
        userPhone = getIntent().getStringExtra("userPhone");
        taskIdName = getIntent().getStringExtra("taskIdName");
        taskDetailId = getIntent().getStringExtra("taskDetailId");
        hiddenFlag = getIntent().getIntExtra("hiddenFlag", 0);
        Drawable drawable = getResources().getDrawable(getResDrawableId("sobot_call_title_back_selector"));
        drawable.setBounds(0, 0, drawable.getMinimumWidth(), drawable.getMinimumHeight());
        getLeftMenu().setCompoundDrawables(drawable, null, null, null);
        if (fromFlag) {
            setTitle(getResources().getString(R.string.sobot_create_contact_plan));
        } else {
            model = (SobotCallContactPlan) getIntent().getSerializableExtra("model");
            if (model != null) {
                setTitle(model.getTaskName());
            }
        }
        mRightMenuBtn = getRightMenu();
        showRightMenu(0, getResources().getString(R.string.sobot_call_save), true, new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (fromFlag) {
                    addAppCallContactPlanInfo();
                } else {
                    updateAppCallContactPlanInfo();
                }
            }
        });
    }

    @Override
    protected void initData() {
        setViews();
    }
    private void setViews() {
        if (fromFlag) {
            phoneParent.setVisibility(View.GONE);
            lineCrude.setVisibility(View.VISIBLE);
            lineFine.setVisibility(View.GONE);

            contactPlanTime.setText(SobotDateUtil.toDate(System.currentTimeMillis(), SobotDateUtil.DATE_FORMAT));
            contactPlanRemind.setText(getResources().getString(R.string.sobot_plan_remind_5m));
            contactPlanRemind.setTag("5");
        } else {
            setContactPlan();
            phoneParent.setVisibility(View.VISIBLE);
            lineCrude.setVisibility(View.GONE);
            lineFine.setVisibility(View.VISIBLE);
        }
        contactPlanName.addTextChangedListener(textWatcher);
        contactPlanTime.addTextChangedListener(textWatcher);
        contactPlanRemind.addTextChangedListener(textWatcher);
        contactPlanRemark.addTextChangedListener(textWatcher);

        contactPlanTime.setOnClickListener(this);
        contactPlanRemind.setOnClickListener(this);
        contactPlanPhone.setOnClickListener(this);
        mRightMenuBtn.setAlpha(0.5f);
        mRightMenuBtn.setClickable(false);
        mRightMenuBtn.setEnabled(false);
    }
    private TextWatcher textWatcher = new TextWatcher() {
        @Override
        public void beforeTextChanged(CharSequence s, int start, int count, int after) {
        }

        @Override
        public void onTextChanged(CharSequence s, int start, int before, int count) {
        }

        @Override
        public void afterTextChanged(Editable s) {
            if (!TextUtils.isEmpty(contactPlanName.getText().toString())) {
                mRightMenuBtn.setAlpha(1f);
                mRightMenuBtn.setClickable(true);
                mRightMenuBtn.setEnabled(true);
                mRightMenuBtn.setTextColor(Color.parseColor("#ffffff"));
            } else {
                mRightMenuBtn.setAlpha(0.5f);
                mRightMenuBtn.setClickable(false);
                mRightMenuBtn.setEnabled(false);
                mRightMenuBtn.setTextColor(Color.parseColor("#bae6e7"));
            }
        }
    };
    private void setContactPlan() {
        if (model == null) {
            return;
        }

        String phoneNum = model.getCustomerPhoneNo();
        phoneNum= SobotCallUtils.hidePhone(phoneNum,model.getHiddenFlag());
        contactPlanPhone.setText(phoneNum);
        contactPlanName.setText(model.getTaskName());
        contactPlanTime.setText(SobotDateUtil.toDate(Long.parseLong(model.getPlanTime()) * 1000, SobotDateUtil.DATE_FORMAT));
        if (!TextUtils.isEmpty(model.getRemindTime())) {
            if ("60".equals(model.getRemindTime())) {
                contactPlanRemind.setText(getResources().getString(R.string.sobot_plan_remind_1h) );
                contactPlanRemind.setTag(model.getRemindTime());
            } else if ("180".equals(model.getRemindTime())) {
                contactPlanRemind.setText(getResources().getString(R.string.sobot_plan_remind_3h));
                contactPlanRemind.setTag(model.getRemindTime());
            } else {
                contactPlanRemind.setText(getResources().getString(R.string.sobot_plan_remind_advance) + model.getRemindTime() + getResources().getString(R.string.sobot_plan_remind_minute));
                contactPlanRemind.setTag(model.getRemindTime());
            }
        }

        contactPlanRemark.setText(model.getRemarks());
    }

    private SobotCallContactPlan getContactPlan() {
        SobotCallContactPlan param = new SobotCallContactPlan();
        if (fromFlag) {
            param.setCustomerPhoneNo(userPhone);
            param.setHiddenFlag(hiddenFlag);
        } else {
            param.setId(model.getId());
            param.setHiddenFlag(model.getHiddenFlag());
        }

        param.setTaskName(contactPlanName.getText().toString());
        param.setPlanTime(contactPlanTime.getText().toString());
        param.setRemarks(contactPlanRemark.getText().toString());
        if (null != contactPlanRemind.getTag()) {
            param.setRemindTime(contactPlanRemind.getTag().toString());
        }
        return param;
    }

    //新增联系计划
    private void addAppCallContactPlanInfo() {
        zhiChiApi.addCallContactPlanInfo(SobotAddCallPlanActivity.this, this, taskIdName, taskDetailId, getContactPlan(), new SobotResultCallBack<SobotCallBaseCode>() {
            @Override
            public void onSuccess(SobotCallBaseCode result) {
                if(SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())){
                    SobotToastUtil.showCustomToast(SobotAddCallPlanActivity.this,getResources().getString(R.string.sobot_call_saved),R.drawable.sobot_iv_call_right);
                    setResult(SobotCallConstant.ACTIVITY_RESULT_NEED_REFRESH);
                    finish();
                }
            }

            @Override
            public void onFailure(Exception e, String des) {
                SobotToastUtil.showCustomToast(SobotAddCallPlanActivity.this,des);
            }
        });
    }

    //编辑联系计划
    private void updateAppCallContactPlanInfo() {
        zhiChiApi.updateCallContactPlanInfo(SobotAddCallPlanActivity.this, SobotAddCallPlanActivity.this, getContactPlan(), new SobotResultCallBack<SobotCallBaseCode>() {
            @Override
            public void onSuccess(SobotCallBaseCode sobotCallBaseCode) {
                SobotToastUtil.showCustomToast(SobotAddCallPlanActivity.this,getResources().getString(R.string.sobot_call_saved),R.drawable.sobot_iv_call_right);
                setResult(SobotCallConstant.ACTIVITY_RESULT_NEED_REFRESH);
                finish();
            }

            @Override
            public void onFailure(Exception e, String des) {
                SobotToastUtil.showCustomToast(SobotAddCallPlanActivity.this,des);
            }
        });
    }

    @Override
    public void onClick(View v) {
        if(v==contactPlanTime){
            //选择时间
            String content = contactPlanTime.getText().toString();
            Date date = null;
            if (!TextUtils.isEmpty(content)) {
                date = SobotDateUtil.parse(content, SobotDateUtil.DATE_FORMAT);
            }
            hideKeyboard(contactPlanTime);
            SobotCallUtils.openTimePickerView(SobotAddCallPlanActivity.this,contactPlanTime,date);
        }else if(v==contactPlanRemind){
            //选择提醒
            String remindTime = contactPlanRemind.getText().toString();
            Intent intent = new Intent(SobotAddCallPlanActivity.this, SobotCallPlanRemindActivity.class);
            if (!TextUtils.isEmpty(remindTime)) {
                intent.putExtra("remindTime", remindTime);
            }
            startActivityForResult(intent, 101);
        }else if(v == contactPlanPhone){
            //呼叫号码
            String phoneNum = contactPlanPhone.getText().toString();
            if (!TextUtils.isEmpty(phoneNum)) {
                SobotCallCommonDialog dialog = new SobotCallCommonDialog(phoneNum,
                        getResources().getString(R.string.sobot_call_up), new SobotCallCommonDialog.OnBtnClickListener() {
                    @Override
                    public void onClick() {
                        //调用呼叫接口打电话
                        if (!TextUtils.isEmpty(phoneNum)) {
                            //调用呼叫接口打电话
                            if(isCallV6()){
                                Intent intent = SobotCallStatusActivity.initIntent(SobotAddCallPlanActivity.this, phoneNum,"","");
                                intent.setFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP | Intent.FLAG_ACTIVITY_CLEAR_TOP |
                                        Intent.FLAG_ACTIVITY_NEW_TASK);
                                startActivity(intent);
                            }else{
                                final String groupId = CallSharedPreferencesUtils.getInstance(getApplicationContext()).get( SobotCallConstant.SP_KEY_CALL_GROUP_ID, "");
                                if (TextUtils.isEmpty(groupId)) {
                                    zhiChiApi.queryGroupListV1(SobotAddCallPlanActivity.this, SobotAddCallPlanActivity.this, new SobotResultCallBack<SobotCallBaseCodeGroup>() {
                                        @Override
                                        public void onSuccess(SobotCallBaseCodeGroup stringSobotCallBaseCodeThird) {
                                            if(stringSobotCallBaseCodeThird!=null && !SobotStringUtils.isEmpty(stringSobotCallBaseCodeThird.item)){
                                                CallSharedPreferencesUtils.getInstance(getApplicationContext()).put( SobotCallConstant.SP_KEY_CALL_GROUP_ID,stringSobotCallBaseCodeThird.item);
                                                Intent intent = SobotCallStatusActivity.initIntent(SobotAddCallPlanActivity.this, phoneNum,stringSobotCallBaseCodeThird.item,"");
                                                intent.setFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP | Intent.FLAG_ACTIVITY_CLEAR_TOP |
                                                        Intent.FLAG_ACTIVITY_NEW_TASK);
                                                startActivity(intent);
                                            }
                                        }

                                        @Override
                                        public void onFailure(Exception e, String des) {

                                        }
                                    });
                                }else{
                                    Intent intent = SobotCallStatusActivity.initIntent(SobotAddCallPlanActivity.this, phoneNum,groupId,"");
                                    intent.setFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP | Intent.FLAG_ACTIVITY_CLEAR_TOP |
                                            Intent.FLAG_ACTIVITY_NEW_TASK);
                                    startActivity(intent);
                                }
                            }

                        } else {
                            SobotToastUtil.showCustomToast(getSobotBaseActivity(), getResources().getString(R.string.sobot_please_input_phone_number));
                        }
                    }
                }, getResources().getString(R.string.sobot_call_cancel), null);
                dialog.setCanceledOnTouchOutside(false);
                dialog.show(getSupportFragmentManager(), "dialog");
            }
        }
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, @Nullable Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        if (requestCode == 101 && null != data) {
            SobotRemindInfo model = (SobotRemindInfo) data.getSerializableExtra("remindModel");
            if (model != null && !TextUtils.isEmpty(model.getDataName())) {
                contactPlanRemind.setText(model.getDataName());
                contactPlanRemind.setTag(model.getDataStatus());
            }
        }
    }
    public void hideKeyboard(final View view) {
        if (view == null) {
            return;
        }
        InputMethodManager imm =
                (InputMethodManager) view.getContext().getSystemService(Context.INPUT_METHOD_SERVICE);
        if (imm != null) {
            imm.hideSoftInputFromWindow(view.getWindowToken(), 0);
        }
    }

}