package com.sobot.callsdk.v1.activity;

import android.content.Intent;
import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.os.Handler;
import android.text.Editable;
import android.text.TextUtils;
import android.text.TextWatcher;
import android.view.View;
import android.widget.EditText;
import android.widget.ImageView;
import android.widget.TextView;

import androidx.localbroadcastmanager.content.LocalBroadcastManager;

import com.sobot.callsdk.R;
import com.sobot.callsdk.activity.SobotCallBaseActivity;
import com.sobot.callsdk.model.SobotCallCustomerModel;
import com.sobot.callsdk.utils.SobotCallConstant;
import com.sobot.network.http.callback.SobotResultCallBack;
import com.sobot.utils.SobotRegularUtils;
import com.sobot.utils.SobotStringUtils;
import com.sobot.widget.ui.toast.SobotToastUtil;

/**
 * 新增、编辑客户信息
 */
public class SobotCallCustomerActivity extends SobotCallBaseActivity implements View.OnClickListener{

    private EditText et_user_nike;
    private EditText et_user_email;
    private EditText et_user_phone;
    private ImageView iv_delete_user_name;
    private ImageView iv_delete_user_email;
    private ImageView iv_delete_user_phone;
    private TextView tv_commit_user;

    private SobotCallCustomerModel mCallCostomer;//编辑的用户
    private String userPhone,encryptUserPhone;
    private int hiddenFlag;
    private boolean workFlag = false;// false不是客户,表示新增客户信息,true 是客户,表示编辑客户信息


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
    }

    @Override
    protected int getContentViewResId() {
        return R.layout.sobot_activity_call_user;
    }

    @Override
    protected void initView() {
        Drawable drawable = getResources().getDrawable(getResDrawableId("sobot_call_title_back_selector"));
        drawable.setBounds(0, 0, drawable.getMinimumWidth(), drawable.getMinimumHeight());
        getLeftMenu().setCompoundDrawables(drawable, null, null, null);
        tv_commit_user = findViewById(getResId("tv_commit_user"));
        tv_commit_user.setOnClickListener(this);
        et_user_nike = findViewById(getResId("et_user_nike"));
        et_user_email = findViewById(getResId("et_user_email"));
        et_user_phone = findViewById(getResId("et_user_phone"));
        iv_delete_user_name = findViewById(getResId("iv_delete_user_name"));
        iv_delete_user_email = findViewById(getResId("iv_delete_user_email"));
        iv_delete_user_phone = findViewById(getResId("iv_delete_user_phone"));
        iv_delete_user_name.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                et_user_nike.setText("");
            }
        });
        iv_delete_user_email.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                et_user_email.setText("");
            }
        });
        iv_delete_user_phone.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                et_user_phone.setText("");
            }
        });
        showDeleteImageView(et_user_email, iv_delete_user_email);
        showDeleteImageView(et_user_nike, iv_delete_user_name);
        showDeleteImageView(et_user_phone, iv_delete_user_phone);
    }

    public void showDeleteImageView(EditText editText, final ImageView imageView) {
        if (editText != null && imageView != null) {
            editText.addTextChangedListener(new TextWatcher() {
                @Override
                public void beforeTextChanged(CharSequence s, int start, int count, int after) {

                }

                @Override
                public void onTextChanged(CharSequence s, int start, int before, int count) {
                    if (!TextUtils.isEmpty(s.toString())) {
                        imageView.setVisibility(View.VISIBLE);
                    } else {
                        imageView.setVisibility(View.GONE);
                    }
                }

                @Override
                public void afterTextChanged(Editable s) {

                }
            });
        }
    }


    @Override
    protected void initData() {
        mCallCostomer = (SobotCallCustomerModel) getIntent().getSerializableExtra("work_order_user");
        userPhone = getIntent().getStringExtra("userPhone");
        encryptUserPhone = getIntent().getStringExtra("EncryptUserPhone");
        hiddenFlag = getIntent().getIntExtra("hiddenFlag",-1);
        workFlag = getIntent().getBooleanExtra("workFlag",false);
        if(mCallCostomer!=null && mCallCostomer.isUser()){
            setTitle(getResources().getString(R.string.sobot_edit_user_string));
            et_user_nike.setText(mCallCostomer.getNick());
            et_user_phone.setText(mCallCostomer.getTel());
            et_user_email.setText(mCallCostomer.getEmail());
        }else{
            setTitle(getResources().getString(R.string.sobot_add_user_string));
            if(mCallCostomer==null){
                if(!SobotStringUtils.isEmpty(encryptUserPhone)){
                    requestCustomerByPhone(userPhone);
                }else{
                    requestCustomerByPhone(encryptUserPhone);
                }
            }
        }

    }
    private void requestCustomerByPhone(String phone){
        zhiChiApi.getCustomerInfoByPhone(this, phone, new SobotResultCallBack<SobotCallCustomerModel>() {
            @Override
            public void onSuccess(SobotCallCustomerModel sobotCallCustomerModel) {
                mCallCostomer =sobotCallCustomerModel;
                if (sobotCallCustomerModel == null || !sobotCallCustomerModel.isUser()) {
                    // 不是客户
                    mCallCostomer = new SobotCallCustomerModel();
                    mCallCostomer.setTel(phone);
                    mCallCostomer.setHiddenFlag(hiddenFlag);
                } else {
                    workFlag = true;
                    // 是客户
                    mCallCostomer.setTel(phone);
                    mCallCostomer.setHiddenFlag(hiddenFlag);
                    setTitle(getResources().getString(R.string.sobot_edit_user_string));
                }
                et_user_nike.setText(mCallCostomer.getNick());
                et_user_phone.setText(userPhone);
                et_user_email.setText(mCallCostomer.getEmail());
            }

            @Override
            public void onFailure(Exception e, String des) {

            }
        });
    }

    @Override
    public void onClick(View v) {
        int id = v.getId();
        if (id == tv_commit_user.getId()) {
            if (SobotStringUtils.isEmpty(et_user_nike.getText().toString().trim())) {
                SobotToastUtil.showCustomToast(getSobotBaseContext(), getResources().getString(R.string.sobot_call_customer_name_tip));
                return;
            }
            if (!TextUtils.isEmpty(et_user_email.getText().toString().trim())) {
                if (!SobotRegularUtils.isEmail(et_user_email.getText().toString().trim())) {
                    SobotToastUtil.showCustomToast(getSobotBaseContext(), getResources().getString(R.string.sobot_call_customer_email_tip));
                    return;
                }
            }
            if(mCallCostomer==null){
                mCallCostomer = new SobotCallCustomerModel();
            }
            if (!TextUtils.isEmpty(et_user_phone.getText().toString().trim())) {
                if(et_user_phone.getText().toString().trim().contains("*")){
                    //验证手机号
                    mCallCostomer.setTel(encryptUserPhone);
                }else{
                    //步验证手机号，放后端验证--v2.1.2
//                    if (!SobotRegularUtils.isMobileSimple(et_user_phone.getText().toString().trim())) {
//                        SobotToastUtil.showCustomToast(getSobotBaseContext(), getResources().getString(R.string.sobot_call_customer_phone_tip"));
//                        return;
//                    }
                    mCallCostomer.setTel(et_user_phone.getText().toString().trim());
                }

            }else{

                SobotToastUtil.showCustomToast(getSobotBaseContext(), getResources().getString(R.string.sobot_call_customer_phone_null_tip));
                return;
            }

            mCallCostomer.setEmail(et_user_email.getText().toString().trim());
            mCallCostomer.setNick(et_user_nike.getText().toString().trim());
            if(workFlag){
                //编辑
                zhiChiApi.updateCustomerInfo(SobotCallCustomerActivity.this, mCallCostomer, new SobotResultCallBack<SobotCallCustomerModel>() {
                    @Override
                    public void onSuccess(SobotCallCustomerModel baseCodeThird) {
                        if (baseCodeThird != null) {
                            if (!TextUtils.isEmpty(baseCodeThird.getId())) {
                                SobotToastUtil.showCustomToast(getSobotBaseContext(), getResources().getString(R.string.sobot_call_save_success));

//                                Intent intent = new Intent();
//                                LocalBroadcastManager localBroadcastManager = LocalBroadcastManager.getInstance(getSobotBaseContext());
//                                intent.setAction(SobotCallConstant.SOBOT_SAVE_CUSTOMER_INFO);
//                                intent.putExtra("userId", baseCodeThird.getId());
//                                intent.putExtra("userName", baseCodeThird.getNick());
//                                localBroadcastManager.sendBroadcast(intent);
                            }
                        }
                        new Handler().postDelayed(new Runnable() {
                            @Override
                            public void run() {
                                setResult(RESULT_OK);
                                finish();
                            }
                        }, 1000);
                    }

                    @Override
                    public void onFailure(Exception e, String des) {
                        SobotToastUtil.showCustomToast(getSobotBaseContext(), des);
                    }
                });
            }else{
                //新增
                zhiChiApi.addCustomerInfo(SobotCallCustomerActivity.this, mCallCostomer,false, new SobotResultCallBack<SobotCallCustomerModel>() {
                    @Override
                    public void onSuccess(SobotCallCustomerModel baseCodeThird) {
                        if (baseCodeThird != null) {
                            if (!TextUtils.isEmpty(baseCodeThird.getId())) {
                                SobotToastUtil.showCustomToast(getSobotBaseContext(), getResources().getString(R.string.sobot_call_save_success));
                                Intent intent = new Intent();
                                LocalBroadcastManager localBroadcastManager = LocalBroadcastManager.getInstance(getSobotBaseContext());
                                intent.setAction(SobotCallConstant.SOBOT_SAVE_CUSTOMER_INFO);
                                intent.putExtra("userId", baseCodeThird.getId());
                                intent.putExtra("userName", baseCodeThird.getNick());
                                localBroadcastManager.sendBroadcast(intent);
                            }
                        }
                        new Handler().postDelayed(new Runnable() {
                            @Override
                            public void run() {
                                setResult(RESULT_OK);
                                finish();
                            }
                        }, 1000);
                    }

                    @Override
                    public void onFailure(Exception e, String des) {
                        SobotToastUtil.showCustomToast(getSobotBaseContext(), des);
                    }
                });
            }
        }
    }
}