package com.sobot.callsdk.v1.activity;

import android.content.Intent;
import android.graphics.drawable.Drawable;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.sobot.callsdk.R;
import com.sobot.callsdk.activity.SobotCallBaseActivity;
import com.sobot.callsdk.api.SobotCallBaseCodeRecord;
import com.sobot.callsdk.model.SobotCallCustomerModel;
import com.sobot.callsdk.model.SobotCallDetailInfo;
import com.sobot.callsdk.model.SobotCallRecordDetailEntity;
import com.sobot.callsdk.utils.SobotCallConstant;
import com.sobot.callsdk.v1.adapter.SobotCallRecordDetailAdapter;
import com.sobot.network.http.callback.SobotResultCallBack;
import com.sobot.utils.SobotStringUtils;
import com.sobot.widget.loading.SobotLoadingLayout;
import com.sobot.widget.refresh.layout.SobotRefreshLayout;
import com.sobot.widget.refresh.layout.api.RefreshLayout;
import com.sobot.widget.refresh.layout.footer.ClassicsFooter;
import com.sobot.widget.refresh.layout.header.ClassicsHeader;
import com.sobot.widget.refresh.layout.listener.OnLoadMoreListener;
import com.sobot.widget.refresh.layout.listener.OnRefreshListener;
import com.sobot.widget.ui.toast.SobotToastUtil;

import java.util.ArrayList;
import java.util.List;

/**
 * 通话记录详情页面
 */
public class SobotCallRecordDetailsActivity extends SobotCallBaseActivity implements SobotCallRecordDetailAdapter.OnCreatePlanClickListener,View.OnClickListener {

    int pageNo = 1;
    int pageSize = 20;
    private SobotRefreshLayout refreshLayout;
    private RecyclerView recyclerView;
    private SobotLoadingLayout loadingLayout;
    private boolean isHasMoreData = false;
    private List<Object> mDate;
    private SobotCallRecordDetailAdapter mAdapter;

    private String mCallee;
    private SobotCallCustomerModel mCallUser;
    private String callID;
    private int callType;
    protected int hiddenFlag;
    private boolean isCallV6=false;

    @Override
    protected int getContentViewResId() {
        return R.layout.sobot_activity_call_record_desc;
    }

    @Override
    protected void initView() {
        setTitle(getString(R.string.sobot_call_details));
        isCallV6 = isCallV6();
        Drawable drawable = getResources().getDrawable(R.drawable.sobot_call_title_back_selector);
        drawable.setBounds(0, 0, drawable.getMinimumWidth(), drawable.getMinimumHeight());
        getLeftMenu().setCompoundDrawables(drawable, null, null, null);
        if (getIntent() != null) {
            mCallee = getIntent().getStringExtra("callee");
            hiddenFlag = getIntent().getIntExtra("hiddenFlag", 0);
            callID = getIntent().getStringExtra("callID");
            callType = getIntent().getIntExtra("callType",-1);
        }

        refreshLayout = findViewById(getResId("sobot_srl_call_record"));
        recyclerView = findViewById(getResId("sobot_rv_record_list"));
        loadingLayout = findViewById(getResId("sobot_loading_layout"));

        //列表
        recyclerView.setLayoutManager(new LinearLayoutManager(getSobotBaseContext()));
        mDate = new ArrayList<>();
        mAdapter = new SobotCallRecordDetailAdapter(this,mDate,this);
        recyclerView.setAdapter(mAdapter);

        //下拉刷新控件
        refreshLayout.setRefreshHeader(new ClassicsHeader(this));
        refreshLayout.setRefreshFooter(new ClassicsFooter(this));
        refreshLayout.setEnableLoadMore(true);
        refreshLayout.setOnLoadMoreListener(new OnLoadMoreListener() {
            @Override
            public void onLoadMore(@NonNull  RefreshLayout refreshLayout) {
                if (isHasMoreData) {
                    if(isCallV6){
                        requestDateV6(pageNo+1);
                    }else{
                        requestDate(pageNo+1);
                    }
                } else {
                    refreshLayout.setNoMoreData(true);
                }
            }
        });
        refreshLayout.setOnRefreshListener(new OnRefreshListener() {
            @Override
            public void onRefresh(@NonNull  RefreshLayout refreshLayout) {
                pageNo = 1;
                if(isCallV6){
                    requestDateV6(pageNo);
                }else{
                    requestDate(pageNo);
                }
            }
        });
        refreshLayout.setNoMoreData(true);

        //是否显示无内容
        loadingLayout.setRetryListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                pageNo = 1;
                if(isCallV6){
                    requestDateV6(pageNo);
                }else{
                    requestDate(pageNo);
                }
            }
        });

    }

    @Override
    protected void initData() {
        if(SobotStringUtils.isEmpty(mCallee)) return;
        //根据手机号查询详情
        requestCustomerByPhone(mCallee);
        if(isCallV6){
            requestDateV6(pageNo);
        }else{
            requestDate(pageNo);
        }
    }
    private void requestCustomerByPhone(String phone){
        zhiChiApi.getCustomerInfoByPhone(this, phone, new SobotResultCallBack<SobotCallCustomerModel>() {
            @Override
            public void onSuccess(SobotCallCustomerModel sobotCallCustomerModel) {
                if(null!=sobotCallCustomerModel) {
                    mCallUser = sobotCallCustomerModel;
                }else{
                    mCallUser = new SobotCallCustomerModel();
                    mCallUser.setTel(mCallee);
                }
                mCallUser.setV6(isCallV6);
                int img;
                mCallUser.setEncryptCustomerNumber(mCallee);
                mCallUser.setHiddenFlag(hiddenFlag);
                mDate.add(0, mCallUser);
                mAdapter.notifyDataSetChanged();
                if ( !mCallUser.isUser()) {
                    // 不是客户
                    img = R.drawable.sobot_call_user_add;
                } else {
                    // 是客户
                    img = R.drawable.sobot_call_personal_info;
//                    getRightMenu().setVisibility(View.GONE);
                }
                Drawable drawable = getResources().getDrawable(img);
                drawable.setBounds(0, 0, drawable.getMinimumWidth(), drawable.getMinimumHeight());
                getRightMenu().setCompoundDrawables(drawable, null, null, null);
                getRightMenu().setVisibility(View.VISIBLE);
            }

            @Override
            public void onFailure(Exception e, String des) {
            }
        });
    }


    public void requestDateV6(int pageIndex){
        zhiChiApi.getCallRecordOne(this, callID, new SobotResultCallBack<List<SobotCallRecordDetailEntity>>() {
            @Override
            public void onSuccess(List<SobotCallRecordDetailEntity> sobotCallRecordEntities) {
                refreshLayout.finishRefresh();//停止刷新
                pageNo = pageIndex;
                if(pageIndex==1){
                    mDate.clear();//刷新时清空列表
                    if (mCallUser != null ) {
                        mDate.add(0,mCallUser);
                    }
                }
                if(null != sobotCallRecordEntities && sobotCallRecordEntities.size()>0){
                    //添加callType
                    if(callType > 0){
                        for (SobotCallRecordDetailEntity detail :
                                sobotCallRecordEntities) {
                            detail.setCallType(callType);
                        }
                    }
                }

                if(sobotCallRecordEntities.size()<pageSize){
                    //加载完毕
                    isHasMoreData = false;
                    refreshLayout.setNoMoreData(true);
                }else{
                    //有 下一页
                    isHasMoreData = true;
                    refreshLayout.setNoMoreData(false);
                }
                mDate.addAll(sobotCallRecordEntities);
                mAdapter.notifyDataSetChanged();
                loadingLayout.showContent();//显示列表
                refreshLayout.finishLoadMore();
            }

            @Override
            public void onFailure(Exception e, String des) {
                refreshLayout.finishLoadMore();
                refreshLayout.finishRefresh();
                if (pageIndex == 1) {
                    loadingLayout.showEmpty();
                }
                SobotToastUtil.showCustomToast(getApplicationContext(), SobotStringUtils.isEmpty(des) ? getResources().getString(R.string.sobot_call_net_error_string) : des, R.drawable.sobot_icon_warning_attention);
            }
        });
    }
    public void requestDate(int pageIndex){
        zhiChiApi.getAppServiceCallRecordByPhone(this, this,  pageIndex, pageSize,mCallee, new SobotResultCallBack<SobotCallBaseCodeRecord>() {
            @Override
            public void onSuccess(SobotCallBaseCodeRecord result) {
                List<SobotCallDetailInfo> list =  result.items;

                refreshLayout.finishRefresh();//停止刷新
                pageNo = pageIndex;
                if(pageIndex==1){
                    mDate.clear();//刷新时清空列表
                    if (mCallUser != null ) {
                        mDate.add(0,mCallUser);
                    }
                }
                if(list.size()<pageSize){
                    //加载完毕
                    isHasMoreData = false;
                    refreshLayout.setNoMoreData(true);
                }else{
                    //有 下一页
                    isHasMoreData = true;
                    refreshLayout.setNoMoreData(false);
                }

                mDate.addAll(list);
                mAdapter.notifyDataSetChanged();
                loadingLayout.showContent();//显示列表
                refreshLayout.finishLoadMore();
            }

            @Override
            public void onFailure(Exception e, String des) {
                refreshLayout.finishLoadMore();
                refreshLayout.finishRefresh();
                if (pageIndex == 1) {
                    loadingLayout.showEmpty();
                }
                SobotToastUtil.showCustomToast(getApplicationContext(), SobotStringUtils.isEmpty(des) ? getResources().getString(R.string.sobot_call_net_error_string) : des, R.drawable.sobot_icon_warning_attention);
            }
        });
    }

    @Override
    public void onCreatePlanClick(String telPhone) {
        //创建联系计划
        Intent intent = new Intent(SobotCallRecordDetailsActivity.this, SobotAddCallPlanActivity.class);
        intent.putExtra("fromFlag", true);
        intent.putExtra("userPhone", telPhone);
        startActivity(intent);
    }

    @Override
    public void onClick(View v) {
    }

    @Override
    protected void onRightMenuClick(View view) {
        super.onRightMenuClick(view);
        //编辑/新建客户信息
        Intent intent = new Intent(SobotCallRecordDetailsActivity.this, SobotCallCustomerActivity.class);
        intent.putExtra("userPhone", mCallUser.getEncryptCustomerNumber());
        intent.putExtra("EncryptUserPhone", mCallUser.getTel());
        intent.putExtra("hiddenFlag", hiddenFlag);

        if (mCallUser == null || !mCallUser.isUser()) {
            // 不是客户
            intent.putExtra("workFlag", false);//这个属性用来表示是编辑用户信息还是新增用户信息。false表示新增用户信息

        } else {
            //是客户
            intent.putExtra("workFlag", true);//这个属性用来表示是编辑用户信息还是新增用户信息。false表示新增用户信息
        }
        startActivityForResult(intent, SobotCallConstant.ACTIVITY_RESULT_NEED_REFRESH);
    }

}