package com.sobot.callsdk.v1.activity;

import android.annotation.SuppressLint;
import android.content.Context;
import android.content.Intent;
import android.graphics.drawable.AnimationDrawable;
import android.os.Handler;
import android.text.TextUtils;
import android.view.View;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.sobot.callbase.api.SobotCallBaseResult;
import com.sobot.callbase.api.SobotStringResultCallBack;
import com.sobot.callbase.api.utils.SobotStompEventConstant;
import com.sobot.callbase.stomp.SobotStompClient;
import com.sobot.callsdk.R;
import com.sobot.callsdk.activity.SobotCallBaseActivity;
import com.sobot.callsdk.listener.SobotPhoneStatusListener;
import com.sobot.callsdk.listener.SobotRegistrationListener;
import com.sobot.callsdk.sip.SobotSipUtils;
import com.sobot.callsdk.utils.CallSharedPreferencesUtils;
import com.sobot.callsdk.utils.CallStatusUtils;
import com.sobot.callsdk.utils.SobotCallConstant;
import com.sobot.callsdk.v1.entity.v1.SobotCallSeatCurrentStatus;
import com.sobot.callsdk.v1.entity.v1.SobotWorkOrderUser;
import com.sobot.common.login.SobotLoginTools;
import com.sobot.common.login.model.SobotServiceInfoModel;
import com.sobot.gson.SobotGsonUtil;
import com.sobot.network.http.callback.SobotResultCallBack;
import com.sobot.pictureframe.SobotBitmapUtil;
import com.sobot.utils.SobotLogUtils;
import com.sobot.utils.SobotStringUtils;
import com.sobot.widget.ui.image.SobotRCImageView;
import com.sobot.widget.ui.permission.SobotPermissionListenerImpl;
import com.sobot.widget.ui.toast.SobotToastUtil;

import java.util.HashMap;
import java.util.List;
import java.util.Map;


public class SobotCallStatusActivity extends SobotCallBaseActivity {

    TextView mTvNick;
    TextView mTvNum;
    TextView mTvStatus;//未接通-通话状态，接通后-显示时间
    ImageView mIvAnim;
    SobotRCImageView mIvHead;
    ImageView mIvHangUp;
    ImageView ivAccept;
    LinearLayout callAcceptLl;
    LinearLayout callHangUpLl;

    private String mNum;//加密号，用于拨号
    private String mScreenNum;//屏显号码
    private boolean isCall;
    private long callDuration = 0;

    //任务呼叫
    private String taskId, recordId, taskDetailId, groupId, campaignId;
    private int hiddenFlag;

    private boolean callRunning;
    private Handler mHandler;

    private SobotServiceInfoModel serviceVo;

    /**
     * @param context
     * @param num       必填  外呼电话
     * @param groupId   选填  外呼技能组
     * @param screenNum 选填  外呼电话
     * @return
     */
    public static Intent initIntent(Context context, String num, String groupId, String screenNum) {
        Intent intent = new Intent(context, SobotCallStatusActivity.class);
        intent.putExtra("num", num);
        intent.putExtra("screenNum", screenNum);
        intent.putExtra("groupId", groupId);
        intent.putExtra("isCallOut", true);
        return intent;
    }

    /**
     * @param context
     * @param num       必填  外呼电话
     * @param screenNum 必填  外呼电话
     * @return
     */
    public static Intent initIntent(Context context, String num, String screenNum) {
        Intent intent = new Intent(context, SobotCallStatusActivity.class);
        intent.putExtra("num", num);
        intent.putExtra("screenNum", screenNum);
        intent.putExtra("isCallOut", true);
        return intent;
    }

    public static Intent initCallMeIntent(Context context, String num) {
        Intent intent = new Intent(context, SobotCallStatusActivity.class);
        intent.putExtra("num", num);
        intent.putExtra("isCallOut", false);
        return intent;

    }

    public static Intent initCallMeIntent(Context context, String num, String groupId, String img, String nick, int hiddenFlag, int callModelSip) {
        Intent intent = new Intent(context, SobotCallStatusActivity.class);
        intent.putExtra("num", num);
        intent.putExtra("hiddenFlag", hiddenFlag);
        intent.putExtra("groupId", groupId);
        intent.putExtra("img", img);
        intent.putExtra("nick", nick);
        intent.putExtra("modelType", callModelSip);
        intent.putExtra("isCallOut", false);
        return intent;
    }

    @Override
    protected int getContentViewResId() {
        return R.layout.sobot_activity_call_sip_status;
    }


    @Override
    protected void initView() {
        mHandler = new Handler();
        serviceVo = SobotLoginTools.getInstance().getServiceInfo();
        mTvNick = findViewById(R.id.tv_nick);
        mTvNum = findViewById(R.id.tv_num);
        mTvStatus = findViewById(R.id.tv_status);
        mIvAnim = findViewById(R.id.iv_anim);
        mIvHead = findViewById(R.id.iv_head);
        mIvHead.setRoundAsCircle(true);
        mIvHangUp = findViewById(R.id.iv_hang_up);
        ivAccept = findViewById(R.id.iv_accept);
        callAcceptLl = findViewById(R.id.call_accept_ll);
        callHangUpLl = findViewById(R.id.call_hang_up_ll);
        ivAccept.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                accept();
            }
        });
        mIvHangUp.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                hangUp();
            }
        });
    }

    @Override
    protected void initData() {
        //判断是否登录
        String call_loingStatus = CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).get(SobotCallConstant.callLoginStatus, CallStatusUtils.OFF_LINE);
        if (call_loingStatus.equals(CallStatusUtils.V6_FINISHING)) {
            //判断是否正在整理中
            SobotToastUtil.showToast(getSobotBaseActivity(), getResources().getString(R.string.sobot_error_switch_status));
            finish();

        } else if (call_loingStatus.equals(CallStatusUtils.OFF_LINE) || call_loingStatus.equals(CallStatusUtils.BUSY)) {
            SobotToastUtil.showToast(getSobotBaseActivity(), getResources().getString(R.string.sobot_call_error_hint));
            finish();
        } else {
            if (getIntent() != null) {
                mNum = getIntent().getStringExtra("num");
                mScreenNum = getIntent().getStringExtra("screenNum");
                groupId = getIntent().getStringExtra("groupId");
                taskDetailId = getIntent().getStringExtra("taskDetailId");
                isCall = getIntent().getBooleanExtra("isCallOut", true);
                recordId = getIntent().getStringExtra("recordId");
                campaignId = getIntent().getStringExtra("campaignId");
                taskId = getIntent().getStringExtra("taskId");
                hiddenFlag = getIntent().getIntExtra("hiddenFlag", 0);
            }
            mTvNum.setVisibility(View.VISIBLE);
            if (SobotStringUtils.isEmpty(mScreenNum)) {
                mScreenNum = mNum;
            }
            mTvNum.setText(mScreenNum);

            //权限判断
            permissionListener = new SobotPermissionListenerImpl() {
                @Override
                public void onPermissionSuccessListener() {
                    //离线状态弹出座席登录弹窗
                    init();
                }
            };
            //判断是否有权限
            if (checkIsShowPermissionPop(getResources().getString(R.string.sobot_microphone), getResources().getString(R.string.sobot_microphone_yongtu), 2, 3)) {
                finish();
            }
            if (!checkAudioPermission()) {
                finish();
            }
            init();
        }
    }

    private void init() {
        if (isCall) {//打电话
            String call_loingStatus = CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).get(SobotCallConstant.callLoginStatus, CallStatusUtils.OFF_LINE);
            if (call_loingStatus.equals(CallStatusUtils.V6_FINISHING)) {
                SobotToastUtil.showToast(getSobotBaseActivity(), getResources().getString(R.string.sobot_error_switch_status));
                return;
            }
            mTvStatus.setText(getResources().getString(R.string.sobot_call_dialing));
            callout();
        } else {//来电
            mTvStatus.setText(getResources().getString(R.string.sobot_call_ringing));
            initCallInData();
        }
        AnimationDrawable anim = (AnimationDrawable) mIvAnim.getBackground();
        anim.start();
    }


    SobotPhoneStatusListener phoneStatusListener = SobotPhoneStatusListener.getInstance();
    SobotRegistrationListener registrationListener = SobotRegistrationListener.getInstance();


    private void taskCallOut() {

    }

    private void callout() {
        callAcceptLl.setVisibility(View.GONE);
        serviceVo = SobotLoginTools.getInstance().getServiceInfo();
        int callWay;
        if (serviceVo.getCallV6Flag() == 1) {
            callWay = CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).get(SobotCallConstant.SP_KEY_CALL_MODEL_TYPE_V6, SobotCallConstant.CALL_MODEL_PHONE);
        } else {
            callWay = CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).get(SobotCallConstant.SP_KEY_CALL_MODEL_TYPE_V1, SobotCallConstant.CALL_MODEL_PHONE);
        }
        if (callWay == SobotCallConstant.CALL_MODEL_SIP) {
            phoneStatusListener.setCallBack(new SobotPhoneStatusListener.CallBack() {
                @Override
                public void callStatus(String lineStatus) {
                    //通话中
                    callRunning = true;
                }
            });
            SobotSipUtils.addPhoneCallStatesback(serviceVo.getCallV6Flag() == 1 ? true : false, registrationListener, phoneStatusListener);

        }
        if (serviceVo != null) {
            if (serviceVo.getCallV6Flag() == 1) {
                if (!TextUtils.isEmpty(mScreenNum)) {
                    Map<String, String> map = new HashMap<>();
                    map.put("privacyNumber", mNum);
                    String userData = SobotGsonUtil.beanToJson(map);
                    if (!SobotStringUtils.isEmpty(recordId) && !SobotStringUtils.isEmpty(campaignId)) {
                        //调用呼叫接口打电话
                        zhiChiApi.taskCallV6(SobotCallStatusActivity.this, SobotCallStatusActivity.this, recordId, campaignId, new SobotResultCallBack<String>() {
                            @Override
                            public void onSuccess(String msg) {
                                if (!SobotStringUtils.isEmpty(msg)) {
                                    SobotToastUtil.showCustomToast(SobotCallStatusActivity.this, msg);
                                }
                            }

                            @Override
                            public void onFailure(Exception e, String des) {
                                SobotToastUtil.showCustomToast(SobotCallStatusActivity.this, SobotStringUtils.isEmpty(des) ? getResources().getString(R.string.sobot_call_net_error_string) : des);
                                finish();
                            }
                        });
                    } else {
                        String currentTime = System.currentTimeMillis() + "";
                        SobotStompClient.getInstance(getSobotBaseActivity()).send("/cc/app/request", "{\n" +
                                "    \"messageID\": \"" + SobotStompEventConstant.RequestMakeCall + "\",\n" +
                                "    \"referenceID\": " + currentTime + "," +
                                "    \"companyId\": \"" + serviceVo.getCompanyId() + "\",\n" +
                                "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                                "    \"agentType\": \"1\",\n" +
                                "    \"otherDN\": \"" + mScreenNum + "\",\n" +
                                "    \"userData\": " + userData + ",\n" +
                                "    \"creationTime\": " + currentTime + "\n" +
                                "}\n").subscribe();
                    }
                } else {
                    SobotToastUtil.showToast(getSobotBaseActivity(), getResources().getString(R.string.sobot_call_error1_hint));
                    finish();
                }
            } else {
                zhiChiApi.callOut(this, getSobotBaseActivity(), hiddenFlag, taskDetailId, taskId, mNum, groupId, new SobotResultCallBack<SobotCallBaseResult>() {
                    @Override
                    public void onSuccess(SobotCallBaseResult baseResult) {
                        if (SobotCallConstant.RESULT_SUCCESS_CODE.equals(baseResult.getRetCode())) {
                            pollingStatus();
                        } else {
                            SobotToastUtil.showCustomToast(getSobotBaseActivity(), baseResult.getRetMsg());
                            finish();
                        }
                    }

                    @Override
                    public void onFailure(Exception e, String des) {
                        finish();
                    }
                });
            }
        }

    }

    /**
     * 呼进来的电话
     */
    protected void initCallInData() {
        callAcceptLl.setVisibility(View.VISIBLE);
        serviceVo = SobotLoginTools.getInstance().getServiceInfo();
        if (serviceVo.getCallV6Flag() == 0) {
            //v1 才走
            pollingStatus();
        }
    }


    //接听
    public void accept() {
        callRunning = true;
        SobotSipUtils.accept(serviceVo.getCallV6Flag() == 1 ? true : false, this, getIntent().getStringExtra("incomimgJsep"));//接听
        callAcceptLl.setVisibility(View.GONE);
    }

    Runnable timeRunnable = new Runnable() {
        @Override
        public void run() {
            if (callRunning) {
                mHandler.postDelayed(this, 1000);
                mTvStatus.setText(formatCallTimeDuration(callDuration++));
            }
        }
    };

    // 挂断
    public void hangUp() {
        callAcceptLl.setVisibility(View.GONE);
        callHangUpLl.setAlpha(0.5f);
        callHangUpLl.setClickable(false);
        callHangUpLl.setEnabled(false);
        if (serviceVo == null) {
            serviceVo = SobotLoginTools.getInstance().getServiceInfo();
        }
        if (serviceVo != null) {
            if (serviceVo.getCallV6Flag() == 1) {
                //v6的要挂断
                String currentTime = System.currentTimeMillis() + "";
                SobotStompClient.getInstance(getSobotBaseActivity()).send("/cc/app/request", "{\n" +
                        "    \"messageID\": \"" + SobotStompEventConstant.RequestHangup + "\",\n" +
                        "    \"referenceID\": " + currentTime + ",\n" +
                        "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                        "    \"companyId\": \"" + serviceVo.getCompanyId() + "\",\n" +
                        "    \"agentType\": \"1\",\n" +
                        "    \"creationTime\": " + currentTime + "\n" +
                        "}\n").subscribe();

            } else {
                //V1调用挂断接口
                zhiChiApi.hungUp(SobotCallStatusActivity.this, getApplicationContext(), new SobotStringResultCallBack<SobotCallBaseResult>() {
                    @Override
                    public void onSuccess(SobotCallBaseResult sobotCallBaseResult) {
                        SobotLogUtils.d("====v1挂断====code==" + sobotCallBaseResult.getRetCode());
                    }

                    @Override
                    public void onFailure(Exception e, String des) {
                        e.printStackTrace();
                        SobotLogUtils.d("====v1挂断======");
                    }
                });
            }
            SobotSipUtils.hangUp(serviceVo.getCallV6Flag() == 1);
        }
        callRunning = false;
        finish();
    }

    @Override
    public void onBackPressed() {
        if (callRunning) {
            return;
        }
        super.onBackPressed();
    }


    /**
     * 获取通话时长
     *
     * @param seconds
     * @return
     */
    public static String formatCallTimeDuration(long seconds) {
        if (seconds <= 0) return "00:00:00";
        StringBuffer sb = new StringBuffer();
        sb.append(String.format("%02d", seconds / 60 / 60));
        sb.append(":").append(String.format("%02d", (seconds / 60) % 60));
        sb.append(":").append(String.format("%02d", seconds % 60));
        return sb.toString();

    }

    @Override
    protected void onDestroy() {
        if (mHandler != null) {
            mHandler.removeCallbacks(timeRunnable);
            mHandler.removeCallbacks(mRunnable);
        }
        super.onDestroy();
    }


    private boolean isFirst = true;

    private void pollingStatus() {
        mHandler.removeCallbacks(mRunnable);
        mHandler.postDelayed(mRunnable, 3 * 1000);
    }

    @SuppressLint("SetTextI18n")
    private Runnable mRunnable = new Runnable() {
        @Override
        public void run() {
            zhiChiApi.appGetAgentStatus(getSobotBaseActivity(), new SobotResultCallBack<SobotCallSeatCurrentStatus>() {
                @Override
                public void onSuccess(SobotCallSeatCurrentStatus model) {
                    if (model != null) {
                        if (!TextUtils.isEmpty(model.getUserPhone())) {
                            mNum = model.getUserPhone();
                        }
                        if (!TextUtils.isEmpty(mNum) && isFirst) {
                            getCallPhoneMessage();
                        }
                        if (!TextUtils.isEmpty(model.getAgentStatus())) {
                            if (CallStatusUtils.isRinging(model.getAgentStatus())) {
                                if (!TextUtils.isEmpty(model.getCallWay()) && SobotCallConstant.CALL_MODEL_PHONE_STR.equals(model.getCallWay())) {
                                    if (TextUtils.isEmpty(model.getAgentNumber())) {
                                        mTvStatus.setText(getResources().getString(R.string.sobot_please_use_phone_answer));
                                    } else {
                                        mTvStatus.setText(getResources().getString(R.string.sobot_please_use) + " " + model.getAgentNumber() + " " + getResources().getString(R.string.sobot_phone_answer));
                                    }
                                } else {
                                    mHandler.postDelayed(timeRunnable, 1000);
                                }
                            } else if (CallStatusUtils.LITTLE_HUGH_.equals(model.getAgentStatus()) || CallStatusUtils.FREE.equals(model.getAgentStatus())) {
                                //收到对方挂断后，自己挂断
                                finish();
                            }
                        }
                    }
                    pollingStatus();
                }

                @Override
                public void onFailure(Exception e, String des) {
                    pollingStatus();
                }
            });
        }
    };

    /**
     * 获取电话信息
     */
    private void getCallPhoneMessage() {
        zhiChiApi.getAppUserListByCallNum(SobotCallStatusActivity.this, getSobotBaseActivity(), mNum, new SobotResultCallBack<List<SobotWorkOrderUser>>() {
            @Override
            public void onSuccess(List<SobotWorkOrderUser> orderUserList) {
                if (orderUserList != null) {
                    isFirst = false;
                    String phoneNum = mNum;
                    try {
                        if (orderUserList.size() > 0) {
                            SobotWorkOrderUser user = orderUserList.get(0);
                            if (TextUtils.isEmpty(user.getNick())) {
                                mTvNick.setText(phoneNum);
                                mTvNum.setVisibility(View.GONE);
                            } else {
                                mTvNum.setText(TextUtils.isEmpty(mScreenNum) ? phoneNum : mScreenNum);
                                mTvNum.setVisibility(View.VISIBLE);
                                mTvNick.setText(user.getNick());
                            }
                            SobotBitmapUtil.display(getSobotBaseActivity(), user.getImg(), mIvHead
                                    , R.drawable.sobot_default_head, R.drawable.sobot_default_head);
                        } else {
                            mTvNick.setText(phoneNum);
                            mTvNum.setVisibility(View.GONE);
                        }
                    } catch (Exception e) {
                        e.printStackTrace();
                    }

                }
            }

            @Override
            public void onFailure(Exception e, String des) {

            }
        });
    }

}
