package com.sobot.callsdk.v1.adapter;

import android.content.Context;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.sobot.callbase.api.utils.SobotCallUtils;
import com.sobot.callsdk.R;
import com.sobot.callsdk.v1.entity.v1.SobotCallContactPlan;
import com.sobot.callsdk.v1.viewholder.SobotCallPlanVH;
import com.sobot.utils.SobotDateUtil;

import java.util.List;

/**
 * @author: Sobot
 * 联系计划
 * 2022/7/12
 */
public class SobotCallPlanAdapter extends RecyclerView.Adapter{
    private Context mContext;
    private List<SobotCallContactPlan> mData;
    private OnItemClickListener listener;

    public SobotCallPlanAdapter(Context mContext, List<SobotCallContactPlan> mData,OnItemClickListener listener) {
        this.mContext = mContext;
        this.mData = mData;
        this.listener = listener;
    }

    @NonNull
    @Override
    public RecyclerView.ViewHolder onCreateViewHolder(@NonNull ViewGroup viewGroup, int i) {
        View v = LayoutInflater.from(mContext).inflate(R.layout.sobot_item_call_plan, viewGroup, false);
        RecyclerView.ViewHolder vh = new SobotCallPlanVH(v);
        return vh;
    }

    @Override
    public void onBindViewHolder(@NonNull RecyclerView.ViewHolder vh, int i) {
        SobotCallContactPlan data = mData.get(i);
        SobotCallPlanVH viewHolder = (SobotCallPlanVH)vh;
        if (data != null && !TextUtils.isEmpty(data.getCustomerPhoneNo())) {
            String phoneNum = data.getCustomerPhoneNo();
            viewHolder.tv_content.setText(SobotCallUtils.hidePhone(phoneNum,data.getHiddenFlag()));
            viewHolder.tv_time.setText(mContext.getResources().getString(R.string.sobot_call_plan_time) + SobotDateUtil.toDate(Long.parseLong(data.getPlanTime()) * 1000, SobotDateUtil.DATE_FORMAT3));
            viewHolder.tv_detail.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    if(listener!=null){
                        listener.onItemDetail(data);
                    }
                }
            });
            viewHolder.menuLayout.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    if(listener!=null){
                        listener.onItemDelete(data,vh.getAdapterPosition());
                    }
                }
            });
            viewHolder.contentLayout.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    if(listener!=null){
                        listener.onItemClick(data);
                    }
                }
            });
        }
    }

    @Override
    public int getItemCount() {
        return mData.size();
    }

    public interface OnItemClickListener {
        void onItemClick(SobotCallContactPlan record);
        void onItemDetail(SobotCallContactPlan record);
        void onItemDelete(SobotCallContactPlan record,int position);
    }


}
