package com.sobot.callsdk.v1.sipphonelibrary;

import android.app.Notification;
import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.app.Service;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;
import android.os.Binder;
import android.os.Build;
import android.os.IBinder;

import com.sobot.callsdk.sip.callback.SobotPhoneCallback;
import com.sobot.callsdk.sip.callback.SobotRegistrationCallback;

import org.linphone.core.LinphoneCall;
import org.linphone.core.LinphoneCore;
import org.linphone.core.LinphoneCoreFactory;
import org.linphone.core.LinphoneCoreFactoryImpl;
import org.linphone.core.LinphoneCoreListenerBase;
import org.linphone.core.LinphoneProxyConfig;


public class SobotPhoneService extends Service {

    private static SobotPhoneService instance;
    private LinphoneCoreListenerBase mListener;
    private static SobotPhoneCallback sPhoneCallback;
    private static SobotRegistrationCallback sRegistrationCallback;

    public static void addPhoneCallback(SobotPhoneCallback phoneCallback) {
        sPhoneCallback = phoneCallback;
    }

    public static void addRegistrationCallback(SobotRegistrationCallback registrationCallback) {
        sRegistrationCallback = registrationCallback;
    }

    public static void addPhoneCallStatesback(SobotRegistrationCallback registrationCallback, SobotPhoneCallback phoneCallback) {
        sRegistrationCallback = registrationCallback;
        sPhoneCallback = phoneCallback;
    }

    public static Context instance() {
        if (instance != null) {
            return instance;
        }
        return null;
    }


    @Override
    public void onCreate() {
        super.onCreate();
        SobotLogUtil.i("-----------SobotPhoneService  onCreate");
        // Needed in order for the two next calls to succeed, libraries must have been loaded first
        LinphoneCoreFactory.instance().setLogCollectionPath(getFilesDir().getAbsolutePath());
        LinphoneCoreFactoryImpl.instance();
        SobotPhoneManager.createAndStart(SobotPhoneService.this);
        instance = this;
        SobotPhoneManager.getLc().addListener(mListener = new LinphoneCoreListenerBase() {

            @Override
            public void callState(LinphoneCore lc, LinphoneCall call, LinphoneCall.State state, String message) {
                SobotLogUtil.i("callState: --->  " + state);
                SobotLogUtil.i("callState message: --->  " + message);
                if (instance == null) {
                    SobotLogUtil.i("Service not ready, discarding call state change to" + state);
                    return;
                }
                if (state == LinphoneCall.State.IncomingReceived) {
                    if (sPhoneCallback != null) {
                        //  SobotPhoneUtils.toggleSpeaker(true);
                        sPhoneCallback.incomingCall("", true,"");
                    }
                }
                if (state == LinphoneCall.State.CallEnd || state == LinphoneCall.State.Error) {
                    //CallEnd通话结束    Error通话错误
                    //将以上状态都统一成通话结束
                    if (sPhoneCallback != null) {
                        sPhoneCallback.callEnd();
                    }
                }
                if (state == LinphoneCall.State.Connected) {
                    //接通中
                    if (sPhoneCallback != null) {
                        sPhoneCallback.callConnected();
                    }
                }
            }

            @Override
            public void globalState(LinphoneCore lc, LinphoneCore.GlobalState state, String message) {
                SobotLogUtil.i("GlobalState: --->  " + state);
                SobotLogUtil.i("GlobalState message: --->  " + message);
            }

            @Override
            public void registrationState(LinphoneCore lc, LinphoneProxyConfig cfg, LinphoneCore.RegistrationState state, String smessage) {
                SobotLogUtil.i("registrationState:--->  " + state);
                SobotLogUtil.i("registrationState message:---> " + smessage);
                if (sRegistrationCallback != null) {
                    if (state == LinphoneCore.RegistrationState.RegistrationOk && SobotPhoneManager.getLc().getDefaultProxyConfig() != null && SobotPhoneManager.getLc().getDefaultProxyConfig().isRegistered()) {
                        SobotPhoneManager.getLc().enableKeepAlive(true);
                        sRegistrationCallback.registrationOK();
                    } else if (state == LinphoneCore.RegistrationState.RegistrationFailed) {
                        sRegistrationCallback.registrationFailed();
                    } else if (state == LinphoneCore.RegistrationState.RegistrationCleared) {
                        sRegistrationCallback.registrationCleared();
                    } else if (state == LinphoneCore.RegistrationState.RegistrationNone) {
                        sRegistrationCallback.registrationCleared();
                    }
                }
            }
        });
        //将服务提升为可见服务
        setForeground();
    }


    /*******************************提升服务级别****************************/
    private AssistServiceConnection mAssistConnection;
    private final int PID = 99998;

    public void setForeground() {
        // sdk < 18 , 直接调用startForeground即可,不会在通知栏创建通知
        if (Build.VERSION.SDK_INT < 18) {
            this.startForeground(PID, getNotification());
            return;
        }
        if (Build.VERSION.SDK_INT >= 25) {
            SobotPhoneService.this.startForeground(PID, getNotification());
            return;
        }

        if (null == mAssistConnection) {
            mAssistConnection = new AssistServiceConnection();
        }

        this.bindService(new Intent(this, AssistService.class), mAssistConnection,
                Service.BIND_AUTO_CREATE);
    }

    private class AssistServiceConnection implements ServiceConnection {
        @Override
        public void onServiceDisconnected(ComponentName name) {
        }

        @Override
        public void onServiceConnected(ComponentName name, IBinder binder) {

            // sdk >=18
            // 的，会在通知栏显示service正在运行，这里不要让用户感知，所以这里的实现方式是利用2个同进程的service，利用相同的notificationID，
            // 2个service分别startForeground，然后只在1个service里stopForeground，这样即可去掉通知栏的显示
            Service assistService = ((AssistService.LocalBinder) binder).getService();
            SobotPhoneService.this.startForeground(PID, getNotification());
            assistService.startForeground(PID, getNotification());
            assistService.stopForeground(true);

            SobotPhoneService.this.unbindService(mAssistConnection);
            mAssistConnection = null;
        }
    }

    private static final String SOBOT_CHANNEL_ID = "sobot_custom_channel_id";
    private static final String SOBOT_CHANNEL_NAME = "重要通知";

    private Notification getNotification() {
        if (Build.VERSION.SDK_INT >= 26) {
            NotificationManager manager = (NotificationManager) getApplicationContext().getSystemService(Context.NOTIFICATION_SERVICE);
            Notification.Builder bulider;
            if (manager != null) {
                bulider = new Notification.Builder(getApplicationContext(), SOBOT_CHANNEL_ID);
                NotificationChannel mChannel = new NotificationChannel(SOBOT_CHANNEL_ID, SOBOT_CHANNEL_NAME, NotificationManager.IMPORTANCE_DEFAULT);
                manager.createNotificationChannel(mChannel);
                return bulider.build();
            } else {
                return null;
            }
        } else {
            return new Notification();
        }
    }

    public static class AssistService extends Service {
        public AssistService() {
            super();
        }

        public class LocalBinder extends Binder {
            public AssistService getService() {
                return AssistService.this;
            }
        }

        @Override
        public IBinder onBind(Intent intent) {
            return new LocalBinder();
        }

        @Override
        public void onDestroy() {
            super.onDestroy();
        }

    }

    public static boolean isReady() {
        SobotLogUtil.i("------isReady===" + instance);
        return instance != null;
    }

    @Override
    public void onDestroy() {

        stopForeground(true);
        SobotLogUtil.i("-----------SobotPhoneService  destroy");
        LinphoneCore lc = SobotPhoneManager.getLcIfManagerNotDestroyOrNull();
        if (lc != null) {
            lc.removeListener(mListener);
        }
        if (sRegistrationCallback != null) {
            sRegistrationCallback = null;
        }
        if (sPhoneCallback != null) {
            sPhoneCallback = null;
        }
        instance = null;
        SobotPhoneManager.destroy();
        super.onDestroy();
    }

    @Override
    public IBinder onBind(Intent intent) {
        return null;
    }
}
