package com.sobot.callsdk.v6.activity;

import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;

import com.sobot.callbase.utils.CommonUtils;
import com.sobot.callbase.utils.SobotDateUtils;
import com.sobot.callsdk.R;
import com.sobot.callsdk.activity.SobotCallBaseActivity;
import com.sobot.widget.ui.calenderview.Calendar;
import com.sobot.widget.ui.calenderview.CalendarLayout;
import com.sobot.widget.ui.calenderview.CalendarUtil;
import com.sobot.widget.ui.calenderview.CalendarView;

import java.util.TimeZone;


/**
 * 日期选择控件
 * Created by jinxl on 2017/9/1.
 */

public class CustomCalenderActivity extends SobotCallBaseActivity implements
        CalendarView.OnCalendarInterceptListener,
        CalendarView.OnCalendarRangeSelectListener,
        CalendarView.OnMonthChangeListener,View.OnClickListener{
    TextView sobot_text_title;
    private TextView tv_calender;
    private TextView tv_right;
    private CalendarView mCalendarView;
    private CalendarLayout mCalendarLayout;
    private TextView tv_date;
    private long startTime=-1,endTime=-1;
    private int mCalendarHeight;
    private String zone;
    private Button done_button;
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
    }
    @Override
    protected void initView(){
        if(getIntent()!=null){
            startTime = getIntent().getLongExtra("startTime",-1);
            endTime = getIntent().getLongExtra("endTime",-1);
        }
        zone = CommonUtils.getTimeZone();
        done_button = findViewById(R.id.done_button);
        done_button.setOnClickListener(this);
        sobot_text_title = findViewById(R.id.sobot_text_title);
        sobot_text_title.setVisibility(View.VISIBLE);
        sobot_text_title.setText(R.string.call_pick_time_custom);
        TextView tv_right = findViewById(R.id.sobot_tv_right);
        tv_right.setText(R.string.sobot_call_cancel);
        tv_right.setVisibility(View.VISIBLE);
        tv_right.setOnClickListener(this);

        tv_date = findViewById(R.id.tv_date);
        tv_calender = findViewById(R.id.tv_calender);
        mCalendarLayout = findViewById(R.id.calendarLayout);
        if(!TextUtils.isEmpty(zone)){
            CalendarUtil.zone = zone;
        }
        //开始时间
        mCalendarView = findViewById(R.id.calendarView);
        mCalendarView.setOnCalendarRangeSelectListener(this);
        mCalendarView.setOnMonthChangeListener(this);
        //设置日期拦截事件，当前有效
        mCalendarView.setOnCalendarInterceptListener(this);

        mCalendarHeight = dipToPx(this, 46);

        mCalendarView.setRange(2013, 1, 1,

                mCalendarView.getCurYear(), mCalendarView.getCurMonth(), mCalendarView.getCurDay()

                ,zone);
        if(startTime>0){
            mCalendarView.setSelectStartCalendar(CalendarUtil.getCalendarByLong(startTime));
        }
        if(endTime>0){
            mCalendarView.setSelectEndCalendar(CalendarUtil.getCalendarByLong(endTime));
        }
        mCalendarView.post(new Runnable() {
            @Override
            public void run() {
                mCalendarView.scrollToCurrent();
            }
        });

    }

    /**
     * dp转px
     *
     * @param context context
     * @param dpValue dp
     * @return px
     */
    private static int dipToPx(Context context, float dpValue) {
        final float scale = context.getResources().getDisplayMetrics().density;
        return (int) (dpValue * scale + 0.5f);
    }
    @Override
    protected void initData() {
        int year = mCalendarView.getCurYear();
        int month = mCalendarView.getCurMonth();
        String date_formate= getResources().getString(R.string.call_date_formate);
        tv_calender.setText(date_formate.replace("yyyy",year+"").replace("MM",month+""));

    }

    @Override
    protected int getContentViewResId() {
        return R.layout.activity_custom_calender;
    }

    @Override
    public void onMonthChange(int year, int month) {
        runOnUiThread(new Runnable() {
            @Override
            public void run() {
                String date_formate= getResources().getString(R.string.call_date_formate);
                tv_calender.setText(date_formate.replace("yyyy",year+"").replace("MM",month+""));
            }
        });
    }

    @Override
    public void onCalendarSelectOutOfRange(Calendar calendar) {
        // TODO: 2018/9/13 超出范围提示
    }

    @Override
    public void onSelectOutOfRange(Calendar calendar, boolean isOutOfMinRange) {
        Toast.makeText(this,
                calendar.toString() + (isOutOfMinRange ? "小于最小选择范围" : "超过最大选择范围"),
                Toast.LENGTH_SHORT).show();
    }

    @Override
    public void onCalendarRangeSelect(Calendar calendar, boolean isEnd) {
        if(!TextUtils.isEmpty(zone)) {
            SobotDateUtils.ymd.setTimeZone(TimeZone.getTimeZone(zone));
        }
        if (isEnd) {
            endTime = calendar.getTimeInMillis();
            if(startTime>0){
                tv_date.setText(SobotDateUtils.ymd.format(startTime)+ " / " + SobotDateUtils.ymd.format(endTime));
            }else{
                tv_date.setText( " / " + SobotDateUtils.ymd.format(endTime));
            }
        } else {
            if(startTime==calendar.getTimeInMillis()){
                endTime = calendar.getTimeInMillis();
            }else {
                startTime = calendar.getTimeInMillis();
                endTime=0;
            }
            if(endTime>0){
                tv_date.setText(SobotDateUtils.ymd.format(startTime)+ " / " + SobotDateUtils.ymd.format(endTime));
            }else{
                tv_date.setText(SobotDateUtils.ymd.format(startTime)+ " / " );
            }
        }
    }

    @Override
    public boolean onCalendarIntercept(Calendar calendar) {
        return false;
    }

    @Override
    public void onCalendarInterceptClick(Calendar calendar, boolean isClick) {
        Toast.makeText(this,
                calendar.toString() + (isClick ? "拦截不可点击" : "拦截设定为无效日期"),
                Toast.LENGTH_SHORT).show();
    }

    @Override
    public void onClick(View v) {
        if(v.getId()==R.id.sobot_tv_right){
            //清空选择
            mCalendarView.clearSelectRange();
            tv_date.setText(" " );
            startTime =-1;
            endTime = -1;
        }else if(v.getId() ==R.id.done_button){
            //确定
            Intent intent  = new Intent();
            intent.putExtra("startDate", startTime);
            intent.putExtra("endDate", endTime);
            setResult(1, intent);
            finish();
        }
    }
}
