package com.sobot.callsdk.v6.activity;

import android.content.Intent;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.View;
import android.widget.CompoundButton;
import android.widget.ImageView;
import android.widget.RadioButton;
import android.widget.TextView;

import androidx.annotation.Nullable;
import androidx.appcompat.app.AppCompatActivity;

import com.sobot.callbase.utils.CommonUtils;
import com.sobot.callbase.utils.SobotDateUtils;
import com.sobot.callbase.widget.SobotRadioGroup;
import com.sobot.callsdk.R;
import com.sobot.callsdk.utils.CallStatusUtils;
import com.sobot.callsdk.utils.SobotCallConstant;
import com.sobot.utils.SobotLogUtils;

import java.util.Date;
import java.util.TimeZone;

/**
 * 搜索客户的筛选条件
 */
public class CustomPickActivity extends AppCompatActivity implements View.OnClickListener, CompoundButton.OnCheckedChangeListener {

    private long startTime;
    private long endTime;
    private String callType;
    private String answerStatus;

    private SobotRadioGroup rg_search_time;
    private RadioButton rb_zidingyi;
    private RadioButton rb_call_in,rb_call_out,rv_noanswer,rv_answered,rv_call_fail;
    private TextView tv_close;//筛选
    private ImageView tv_title_back;//返回
    private String zone="";
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_custom_pick);
        zone = CommonUtils.getTimeZone();
        if(getIntent()!=null) {
            startTime = getIntent().getLongExtra("startTime", 0);
            endTime = getIntent().getLongExtra("endTime", 0);
            callType = getIntent().getStringExtra("callType");
            answerStatus = getIntent().getStringExtra("answerStatus");
        }
        if(!TextUtils.isEmpty(zone)){
            SobotDateUtils.ymd.setTimeZone(TimeZone.getTimeZone(zone));
        }
        rg_search_time = findViewById(R.id.rg_search_time);
        tv_title_back = findViewById(R.id.tv_title_back);
        rb_zidingyi = findViewById(R.id.rb_zidingyi);
        rb_call_in = findViewById(R.id.rb_call_in);
        rb_call_out = findViewById(R.id.rb_call_out);
        rv_noanswer = findViewById(R.id.rv_noanswer);
        rv_answered = findViewById(R.id.rv_answered);
        rv_call_fail = findViewById(R.id.rv_call_fail);
        rv_noanswer.setOnCheckedChangeListener(this);
        rv_answered.setOnCheckedChangeListener(this);
        rv_call_fail.setOnCheckedChangeListener(this);
        rb_call_in.setOnCheckedChangeListener(this);
        rb_call_out.setOnCheckedChangeListener(this);
        RadioButton rb_call_type_all =findViewById(R.id.rb_call_type_all);
        rb_call_type_all.setOnCheckedChangeListener(this);
        RadioButton rv_result_all =findViewById(R.id.rv_result_all);
        rv_result_all.setOnCheckedChangeListener(this);
        rb_call_type_all.setChecked(true);
        rv_result_all.setChecked(true);
        tv_close = findViewById(R.id.tv_close);
        tv_close.setOnClickListener(this);
        tv_title_back.setOnClickListener(this);
        rb_zidingyi.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                //打开日历选择
                Intent intent = new Intent(getApplicationContext(), CustomCalenderActivity.class);
                intent.putExtra("startTime",startTime);
                intent.putExtra("endTime",endTime);
                startActivityForResult(intent, 1);
            }
        });
        if(startTime == -1 && endTime == -1){
            rg_search_time.check(R.id.rb_no_limit);
        } else if(startTime>0&& endTime>0) {
            if (startTime ==SobotDateUtils.getDayStart(zone) && endTime == SobotDateUtils.getDayEnd(zone)){
                rg_search_time.check(R.id.rb_today);
            } else if (startTime == SobotDateUtils.getYesterDayStart(zone) && endTime == SobotDateUtils.getYesterDayEnd(zone)) {
                rg_search_time.check(R.id.rb_yesterday);
            } else if (startTime == SobotDateUtils.getWeekStart(zone) &&  endTime ==SobotDateUtils.getWeekEnd(zone)) {
                rg_search_time.check(R.id.rb_curweek);
            } else if (startTime == SobotDateUtils.getLastWeekStart(zone) &&  endTime ==SobotDateUtils.getLastWeekEnd(zone)) {
                rg_search_time.check(R.id.rb_lastweek);
            } else if (startTime == SobotDateUtils.getMonthStart(zone) &&  endTime ==SobotDateUtils.getMonthEnd(zone)) {
                rg_search_time.check(R.id.rb_curmonth);
            } else if (startTime == SobotDateUtils.getLastMonthStart(zone) && endTime ==SobotDateUtils.getLastMonthEnd(zone)) {
                rg_search_time.check(R.id.rb_last_month);
            }else {
                Date startD = new Date(startTime);
                Date endD = new Date(endTime);
                rg_search_time.check(R.id.rb_zidingyi);
                rb_zidingyi.setText(SobotDateUtils.ymd.format(startD)+" ~ "+ SobotDateUtils.ymd.format(endD));
            }
        }

        if (answerStatus.contains(CallStatusUtils.CALL_STATUS_UNANSWERED)) {
            rv_noanswer.setChecked(true);
        }
        if ( answerStatus.contains(CallStatusUtils.CALL_STATUS_ANSWERED)) {
            rv_answered.setChecked(true);
        }
        if (answerStatus.contains(CallStatusUtils.CALL_STATUS_REJECT)) {
            rv_call_fail.setChecked(true);
        }
        if (callType.contains(CallStatusUtils.CALL_TYPE_IN)) {
            rb_call_in.setChecked(true);
        }
        if (callType.contains(CallStatusUtils.CALL_TYPE_OUT)) {
            rb_call_out.setChecked(true);
        }
    }

    @Override
    public void onClick(View v) {
        if(v==tv_title_back){
            finish();
        }else if(v==tv_close){
            StringBuilder answerSb = new StringBuilder();
            if (rv_noanswer.isChecked()) {
                if(answerSb.length()>0){
                    answerSb.append(",");
                }
                answerSb.append(CallStatusUtils.CALL_STATUS_UNANSWERED);
            }
            if (rv_answered.isChecked()) {
                if(answerSb.length()>0){
                    answerSb.append(",");
                }
                answerSb.append(CallStatusUtils.CALL_STATUS_ANSWERED);
                answerStatus = CallStatusUtils.CALL_STATUS_ANSWERED;
            }
            if (rv_call_fail.isChecked()) {
                if(answerSb.length()>0){
                    answerSb.append(",");
                }
                answerSb.append(CallStatusUtils.CALL_STATUS_REJECT);
            }
            answerStatus = answerSb.toString();

            StringBuilder typeSb = new StringBuilder();
            if (rb_call_in.isChecked()) {
                if(typeSb.length()>0){
                    typeSb.append(",");
                }
                typeSb.append(CallStatusUtils.CALL_TYPE_IN);
            }
            if (rb_call_out.isChecked()) {
                if(typeSb.length()>0){
                    typeSb.append(",");
                }
                typeSb.append(CallStatusUtils.CALL_TYPE_OUT);
            }
            callType = typeSb.toString();

            int checkedTime = rg_search_time.getCheckedRadioButtonId();
            if (checkedTime == R.id.rb_no_limit) {
                startTime = -1;
                endTime = -1;
            } else if (checkedTime == R.id.rb_today) {
                startTime = SobotDateUtils.getDayStart(zone);
                endTime = SobotDateUtils.getDayEnd(zone);
            } else if (checkedTime == R.id.rb_yesterday) {
                startTime = SobotDateUtils.getYesterDayStart(zone);
                endTime = SobotDateUtils.getYesterDayEnd(zone);
            } else if (checkedTime == R.id.rb_curweek) {
                startTime = SobotDateUtils.getWeekStart(zone);
                endTime = SobotDateUtils.getWeekEnd(zone);
            } else if (checkedTime == R.id.rb_lastweek) {
                startTime = SobotDateUtils.getLastWeekStart(zone);
                endTime = SobotDateUtils.getLastWeekEnd(zone);
            } else if (checkedTime == R.id.rb_curmonth) {
                startTime = SobotDateUtils.getMonthStart(zone);
                endTime = SobotDateUtils.getMonthEnd(zone);
            } else if (checkedTime == R.id.rb_last_month) {
                startTime = SobotDateUtils.getLastMonthStart(zone);
                endTime = SobotDateUtils.getLastMonthEnd(zone);
            }
            SobotLogUtils.d(startTime + "====chu======" + endTime);
            Intent intent = new Intent();
            intent.putExtra("startTime", startTime);
            intent.putExtra("endTime", endTime);
            intent.putExtra("answerStatus", answerStatus);
            intent.putExtra("callType", callType);
            setResult(SobotCallConstant.ACTIVITY_RESULT_GET_CONDITION, intent);
            finish();
        }
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, @Nullable Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        if (resultCode == 1) {
            long sTime = data.getLongExtra("startDate", -1);
            long eTime = data.getLongExtra("endDate", -1);
            if (sTime > 0 && eTime >= 0) {
                Date startDate = new Date();
                startDate.setTime(sTime);
                Date endDate = new Date();
                endDate.setTime(eTime);
                startTime = SobotDateUtils.getDayStart(startDate, zone);
                //最后的设置为23.59.59
                endTime = SobotDateUtils.getDayEnd(endDate, zone);
                rb_zidingyi.setText(SobotDateUtils.ymd.format(startTime) + " ~ " + SobotDateUtils.ymd.format(endTime));
            }else {
                startTime = -1;
                endTime =-1;
                rb_zidingyi.setText(R.string.call_pick_time_custom);
            }

        }
    }

    @Override
    public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
        if (isChecked){
            buttonView.setTextColor(getResources().getColor(R.color.call_pick_text_seleced));
        }else{
            buttonView.setTextColor(getResources().getColor(R.color.call_wenzi_gray1));

        }
    }
}