package com.sobot.callsdk.v6.activity;

import android.os.Bundle;
import android.text.TextUtils;
import android.view.View;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.sobot.callbase.api.utils.SobotStompEventConstant;
import com.sobot.callbase.dialog.SobotCallCommonDialog;
import com.sobot.callbase.model.PhoneType;
import com.sobot.callbase.model.QueueAgentCheckin;
import com.sobot.callbase.model.SobotExtensionEntity;
import com.sobot.callbase.model.SobotLoginBindEntity;
import com.sobot.callbase.stomp.SobotStompClient;
import com.sobot.callbase.widget.floatwindow.SobotFloatWindow;
import com.sobot.callsdk.R;
import com.sobot.callsdk.activity.SobotCallBaseActivity;
import com.sobot.callsdk.dialog.CallTipDialog;
import com.sobot.callsdk.dialog.SelectSpeechCodeDialog;
import com.sobot.callsdk.utils.CallSharedPreferencesUtils;
import com.sobot.callsdk.utils.CallStatusUtils;
import com.sobot.callsdk.utils.SobotCallConstant;
import com.sobot.common.login.SobotLoginTools;
import com.sobot.common.login.model.SobotServiceInfoModel;
import com.sobot.network.http.callback.SobotResultCallBack;
import com.sobot.widget.ui.toast.SobotToastUtil;

import java.util.List;

/**
 * 签入后个人信息
 */
public class SignInInfoActivity extends SobotCallBaseActivity implements View.OnClickListener {
    private TextView sobot_text_title;
    private TextView tv_type;
    private TextView tv_mobile;
    private TextView tv_code;//语音编码
    private TextView tv_ext_num;
    private TextView tv_group;
    private ImageView iv_code;
    private TextView btn_outline;

    private LinearLayout ll_phone, ll_code;
    private SelectSpeechCodeDialog selectSpeechCodeDialog;

    private SobotServiceInfoModel serviceVo;
    private String ext, langCode;
    protected SobotLoginBindEntity loginBind;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
    }

    @Override
    protected int getContentViewResId() {
        return R.layout.activity_sign_info;
    }

    @Override
    protected void initView() throws InterruptedException {
        tv_type = findViewById(R.id.tv_type);
        tv_mobile = findViewById(R.id.tv_mobile);
        tv_ext_num = findViewById(R.id.tv_ext_num);
        tv_group = findViewById(R.id.tv_group);
        tv_code = findViewById(R.id.tv_code);
        ll_phone = findViewById(R.id.ll_phone);
        ll_code = findViewById(R.id.ll_code);
        iv_code = findViewById(R.id.iv_code);
        btn_outline = findViewById(R.id.btn_outline);
        sobot_text_title = findViewById(R.id.sobot_text_title);
        sobot_text_title.setVisibility(View.VISIBLE);
        sobot_text_title.setText(R.string.call_sign_info);
        btn_outline.setOnClickListener(this);
        iv_code.setOnClickListener(this);
        tv_code.setOnClickListener(this);
    }

    @Override
    protected void initData() {
        serviceVo = SobotLoginTools.getInstance().getServiceInfo();
        if (serviceVo == null) {
            finish();
        }
        zhiChiApi.queryLoginBindingInfo(this, serviceVo.getServiceId(), new SobotResultCallBack<SobotLoginBindEntity>() {
            @Override
            public void onSuccess(SobotLoginBindEntity sobotLoginBindEntity) {
                initInfo(sobotLoginBindEntity);
            }

            @Override
            public void onFailure(Exception e, String des) {

            }
        });

    }

    private void initInfo(SobotLoginBindEntity sobotLoginBindEntity) {
        if (sobotLoginBindEntity != null) {
            loginBind = sobotLoginBindEntity;
            ext = sobotLoginBindEntity.getExt();
            tv_ext_num.setText(sobotLoginBindEntity.getExt());
            tv_mobile.setText(sobotLoginBindEntity.getPhone());
            List<QueueAgentCheckin> list = sobotLoginBindEntity.getReceptionQueues();
            if (list != null && list.size() > 0) {
                StringBuilder sb = new StringBuilder();
                for (int i = 0; i < list.size(); i++) {
                    if (i != 0) {
                        sb.append(",");
                    }
                    sb.append(list.get(i).getQueueName());
                }
                tv_group.setText(sb.toString());
            } else {
                tv_group.setText("--");
            }
            getExtensionList();
            int callWay =SobotCallConstant.CALL_MODEL_SIP;
            List<PhoneType>  typeList = sobotLoginBindEntity.getPhoneTypes();
            for (int i = 0; i < typeList.size(); i++) {
                if(typeList.get(i).isDefaultPhoneType()){
                    if("pstn".equals(typeList.get(i).getPhoneType())){
                        callWay=SobotCallConstant.CALL_MODEL_PHONE;
                    }
                }
            }
            setCallWay(callWay);
        } else {
            int callWay = CallSharedPreferencesUtils.getInstance(SignInInfoActivity.this).get(SobotCallConstant.AgentLoginInput.phoneType, SobotCallConstant.CALL_MODEL_PHONE);
            setCallWay(callWay);
            ext = CallSharedPreferencesUtils.getInstance(SignInInfoActivity.this).get(SobotCallConstant.AgentLoginInput.bindExt);
            String mobile = CallSharedPreferencesUtils.getInstance(SignInInfoActivity.this).get(SobotCallConstant.AgentLoginInput.bindMobile);
            String group = CallSharedPreferencesUtils.getInstance(SignInInfoActivity.this).get(SobotCallConstant.AgentLoginInput.groupName);
            tv_ext_num.setText(ext);
            tv_mobile.setText(mobile);
            tv_group.setText(group);
        }
    }

    private void setCallWay(int callWay) {
        //查询接口
        if (callWay == SobotCallConstant.CALL_MODEL_PHONE) {
            ll_code.setVisibility(View.GONE);
            ll_phone.setVisibility(View.VISIBLE);
            tv_type.setText(R.string.sobot_phone);
        } else {
            ll_code.setVisibility(View.VISIBLE);
            ll_phone.setVisibility(View.GONE);
            tv_type.setText(R.string.call_source_app);
        }
    }

    //v6 获取分机账号列表
    private void getExtensionList() {
        zhiChiApi.getExtensionList(this, serviceVo.getServiceId(), "1", new SobotResultCallBack<List<SobotExtensionEntity>>() {
            @Override
            public void onSuccess(List<SobotExtensionEntity> extensionModelList) {
                if (extensionModelList != null) {
                    for (int i = 0; i < extensionModelList.size(); i++) {
                        SobotExtensionEntity extensionEntity = extensionModelList.get(i);
                        if (extensionEntity.getBindStatus() == 1) {
                            extensionEntity.setSelect(true);
                            tv_ext_num.setText(extensionEntity.getExt());
                            tv_code.setText(extensionEntity.getLangCodeTxt());
                        }
                    }
                }
            }

            @Override
            public void onFailure(Exception e, String des) {

            }
        });
    }

    @Override
    public void onClick(View v) {
        if (v == tv_code) {
            //选择语音编码
            if (null == selectSpeechCodeDialog) {
                selectSpeechCodeDialog = new SelectSpeechCodeDialog(SignInInfoActivity.this, new SelectSpeechCodeDialog.SpeechCodeListener() {
                    @Override
                    public void setType(String code) {
                        langCode = code;
                        tv_code.setText(code);
                        editLangCode(code);
                    }
                }, tv_code.getText().toString());
            } else {
                selectSpeechCodeDialog.setCode(tv_code.getText().toString());
            }
            selectSpeechCodeDialog.show();
        } else if (v == btn_outline) {
            if (SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT) != null && SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT).isShowing()) {
                //通话没结束，不能切换坐席状态
                SobotToastUtil.showCustomToast(getApplicationContext(), getString(R.string.call_retcode_330035));
                return;
            }
            String call_loingStatus = CallSharedPreferencesUtils.getInstance(this).get(SobotCallConstant.callLoginStatus, CallStatusUtils.V6_OFFLINE);

            if (CallStatusUtils.V6_FINISHING.equals(call_loingStatus)) {
                SobotToastUtil.showToast(getApplicationContext(), getResources().getString(R.string.sobot_error_switch_status));
                return;
            }

            SobotCallCommonDialog dialog = new SobotCallCommonDialog(getResources().getString(R.string.call_sign_offline_tip),
                    getResources().getString(R.string.sobot_custom_offline), new SobotCallCommonDialog.OnBtnClickListener() {
                @Override
                public void onClick() {
                    //离线
                    SobotServiceInfoModel sobotServiceVo = SobotLoginTools.getInstance().getServiceInfo();
                    if (sobotServiceVo != null) {
                        //座席签出
                        String currentTime = System.currentTimeMillis() + "";
                        SobotStompClient.getInstance(getSobotBaseActivity()).send("/cc/app/request", "{\n" +
                                "    \"messageID\": \"" + SobotStompEventConstant.RequestAgentLogout + "\",\n" +
                                "    \"referenceID\": " + currentTime + ",\n" +
                                "    \"companyId\": \"" + serviceVo.getCompanyId() + "\",\n" +
                                "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                                "    \"agentType\": \"1\",\n" +
                                "    \"creationTime\": " + currentTime + "\n" +
                                "}\n").subscribe();
                        SobotToastUtil.showToast(getApplicationContext(),getResources().getString(R.string.call_offline_success));
                        finish();
                    }
                }
            }, getResources().getString(R.string.sobot_btn_cancle), null);
            dialog.show(getSupportFragmentManager(), "dialog");

        } else if (v == iv_code) {
            //提示
            CallTipDialog tipDialog = new CallTipDialog(getString(R.string.call_speech_code_tip_top), getString(R.string.call_speech_code_tip));
            tipDialog.setCancelable(true);
            tipDialog.show(getSupportFragmentManager(), "tipDialog");
        }
    }

    /**
     * 设置语音编码
     *
     * @param code
     */
    private void editLangCode(String code) {
        zhiChiApi.editExtsLangCode(SignInInfoActivity.this, serviceVo.getServiceId(), "1", ext, code, new SobotResultCallBack<SobotExtensionEntity>() {
            @Override
            public void onSuccess(SobotExtensionEntity sobotExtensionEntity) {
                SobotToastUtil.showToast(getApplicationContext(), getString(R.string.sobot_call_edit_success));
            }

            @Override
            public void onFailure(Exception e, String des) {
                SobotToastUtil.showToast(getApplicationContext(), TextUtils.isEmpty(des) ? "" : des);
            }
        });
    }

    @Override
    protected void onDestroy() {
        if (selectSpeechCodeDialog != null && selectSpeechCodeDialog.isShowing()) {
            selectSpeechCodeDialog.dismiss();
        }
        super.onDestroy();
    }
}