package com.sobot.callsdk.v6.adapter;

import android.content.Context;
import android.graphics.Color;
import android.text.Spannable;
import android.text.SpannableString;
import android.text.TextUtils;
import android.text.style.ForegroundColorSpan;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.CheckBox;
import android.widget.ImageView;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.sobot.callbase.model.SobotSummaryClassifies;
import com.sobot.callsdk.R;

import java.util.List;

public class CallClassifyAdapter extends RecyclerView.Adapter {
    private List<SobotSummaryClassifies> list;
    private int summaryClassificationLevelLimit = 0;//服务分类可选层级限制 0:任意级; 1:末级
    private Context mContext;
    private OnItemClickListener itemClickListener;
    private String select = "";

    public CallClassifyAdapter(Context context, List<SobotSummaryClassifies> list, int summaryClassificationLevelLimit, OnItemClickListener itemClickListener) {
        this.mContext = context;
        this.list = list;
        this.summaryClassificationLevelLimit = summaryClassificationLevelLimit;
        this.itemClickListener = itemClickListener;
    }

    public List<SobotSummaryClassifies> getList() {
        return list;
    }

    public void setDate(String select) {
        this.select = select;
        notifyDataSetChanged();
    }

    @NonNull
    @Override
    public RecyclerView.ViewHolder onCreateViewHolder(@NonNull ViewGroup viewGroup, int i) {
        View v = LayoutInflater.from(mContext).inflate(R.layout.sobot_item_select_classify, viewGroup, false);
        return new MyViewHolder(v);
    }

    @Override
    public void onBindViewHolder(@NonNull RecyclerView.ViewHolder viewHolder, int i) {
        SobotSummaryClassifies checkin = list.get(i);
        MyViewHolder vh = (MyViewHolder) viewHolder;
        int index = i;
        if (checkin != null) {
            String name = checkin.getClassifyName();
            SpannableString spannableString = new SpannableString(name);
            if (name.contains(select)) {
                spannableString.setSpan(new ForegroundColorSpan(Color.parseColor("#09AEB0")), name.indexOf(select), name.indexOf(select) + select.length(), Spannable.SPAN_EXCLUSIVE_EXCLUSIVE);
            }
            vh.tv_classify_name.setText(spannableString);
            vh.cb_group.setChecked(checkin.isChecked());
            if (summaryClassificationLevelLimit == 0) {
                vh.cb_group.setVisibility(View.VISIBLE);
                vh.cb_group.setClickable(true);
                vh.cb_group.setOnClickListener(new View.OnClickListener() {
                    @Override
                    public void onClick(View v) {
                        if (itemClickListener != null) {
                            itemClickListener.onItemCheck(checkin, index);
                        }
                    }
                });
            } else if (summaryClassificationLevelLimit == 1) {
                vh.cb_group.setClickable(false);
                if (checkin.isHasSonDirectory()) {
                    vh.cb_group.setVisibility(View.GONE);
                } else {
                    vh.cb_group.setVisibility(View.VISIBLE);
                }
            }
            if (!TextUtils.isEmpty(checkin.getClassifyCode())) {
                String code = checkin.getClassifyCode();
                SpannableString spannableCode = new SpannableString(code);
                if (code.contains(select)) {
                    spannableCode.setSpan(new ForegroundColorSpan(Color.parseColor("#09AEB0")), code.indexOf(select), code.indexOf(select) + select.length(), Spannable.SPAN_EXCLUSIVE_EXCLUSIVE);
                }
                vh.tv_classfiy_code.setText(spannableCode);
                vh.tv_classfiy_code.setVisibility(View.VISIBLE);
            } else {
                vh.tv_classfiy_code.setVisibility(View.GONE);
            }
            if (checkin.isHasSonDirectory()) {
                vh.iv_arrow.setVisibility(View.VISIBLE);
            } else {
                vh.iv_arrow.setVisibility(View.GONE);
            }
            vh.itemView.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    if (itemClickListener != null) {
                        itemClickListener.onItemClick(checkin, index);
                    }
                }
            });

        }
    }

    @Override
    public int getItemCount() {
        return list.size();
    }

    class MyViewHolder extends RecyclerView.ViewHolder {
        private CheckBox cb_group;
        private TextView tv_classify_name;
        private TextView tv_classfiy_code;
        private ImageView iv_arrow;

        public MyViewHolder(@NonNull View itemView) {
            super(itemView);
            tv_classify_name = itemView.findViewById(R.id.tv_classify_name);
            tv_classfiy_code = itemView.findViewById(R.id.tv_classfiy_code);
            cb_group = itemView.findViewById(R.id.cb_group);
            iv_arrow = itemView.findViewById(R.id.iv_arrow);
        }
    }

    public interface OnItemClickListener {
        void onItemClick(SobotSummaryClassifies info, int index);

        void onItemCheck(SobotSummaryClassifies info, int index);
    }
}
