package com.sobot.callsdk.v6.adapter;

import android.content.Context;
import android.graphics.Color;
import android.text.Spannable;
import android.text.SpannableString;
import android.text.TextUtils;
import android.text.style.ForegroundColorSpan;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.sobot.callbase.api.utils.SobotCallUtils;
import com.sobot.callbase.utils.SobotStringUtils;
import com.sobot.callsdk.R;
import com.sobot.callsdk.model.SobotCallRecordEntity;

import java.util.List;

/**
 * @author: Sobot
 * 通话记录
 * 2022/7/12
 */
public class CallHistoryAdapter extends RecyclerView.Adapter {
    private Context mContext;
    private List<SobotCallRecordEntity> mData;
    private OnItemClickListener itemListener;
    private String select ="";

    public CallHistoryAdapter(Context mContext, List<SobotCallRecordEntity> mData, OnItemClickListener itemListener) {
        this.mContext = mContext;
        this.mData = mData;
        this.itemListener = itemListener;
    }

    @NonNull
    @Override
    public RecyclerView.ViewHolder onCreateViewHolder(@NonNull ViewGroup viewGroup, int i) {
        View v = LayoutInflater.from(mContext).inflate(R.layout.sobot_item_call_history, viewGroup, false);
        RecyclerView.ViewHolder vh = new ViewHolder(v);
        return vh;
    }
    public void setDate(String select) {
        this.select = select;
        notifyDataSetChanged();
    }
    @Override
    public void onBindViewHolder(@NonNull RecyclerView.ViewHolder vh, int i) {
        ViewHolder viewHolder = (ViewHolder) vh;
        SobotCallRecordEntity info = mData.get(i);

        // callResult 1.呼叫失败 2.座席未接听 3.座席已接听
// (3: 呼出;2: 呼入)
        if(info.getCallType()==2){
            //呼入
            viewHolder.iv_call_status.setImageResource(R.drawable.sobot_call_in);
            viewHolder.tv_call_custom_name.setTextColor(mContext.getResources().getColor(R.color.call_wenzi_gray1));
            if(info.getCallResult()==1 || info.getBridgeTime()==0){
                //未接
                viewHolder.tv_call_custom_name.setTextColor(mContext.getResources().getColor(R.color.sobot_call_wenzi_red));
                viewHolder.iv_call_status.setImageResource(R.drawable.call_unanswered_in);
            }
        }else {
            //呼出
            viewHolder.iv_call_status.setImageResource(R.drawable.call_icon_out);
            viewHolder.tv_call_custom_name.setTextColor(mContext.getResources().getColor(R.color.call_wenzi_gray1));
            if(info.getCallResult()==1 || info.getBridgeTime()==0){
                //未接
                viewHolder.tv_call_custom_name.setTextColor(mContext.getResources().getColor(R.color.sobot_call_wenzi_red));
                viewHolder.iv_call_status.setImageResource(R.drawable.call_unanswered);
            }
        }
        viewHolder.tv_call_time.setText(SobotCallUtils.formatCallRecordTime(mContext, info.getStartTime()));
        if(!SobotStringUtils.isEmpty(info.getCustomerNick())){
            String customerNick = info.getCustomerNick();
            SpannableString spannableString = new SpannableString(customerNick);
            if(customerNick.contains(select)){
                spannableString.setSpan(new ForegroundColorSpan(Color.parseColor("#09AEB0")), customerNick.indexOf(select),customerNick.indexOf(select)+select.length(), Spannable.SPAN_EXCLUSIVE_EXCLUSIVE);
            }
            viewHolder.tv_call_custom_name.setText(spannableString);
        }else{
            viewHolder.tv_call_custom_name.setText(R.string.call_unknown_customer);
        }
        String from = "";
        if(!TextUtils.isEmpty(info.getAreaProvince())&&!TextUtils.isEmpty(info.getAreaCity())){
            from = info.getAreaProvince()+"/"+info.getAreaCity();
        }
        String screenNumber = info.getScreenNumber()+"  "+from;
        SpannableString spannableString = new SpannableString(screenNumber);
        if(screenNumber.contains(select)){
            spannableString.setSpan(new ForegroundColorSpan(Color.parseColor("#09AEB0")), screenNumber.indexOf(select),screenNumber.indexOf(select)+select.length(), Spannable.SPAN_EXCLUSIVE_EXCLUSIVE);
        }
        viewHolder.tv_call_custom_phone.setText(spannableString);

        ////呼叫类型: 1.呼叫 2.转移 3.咨询 4.监听 5.抢接 6.强插
        if(info.getDialType() == 2) {
            viewHolder.tv_call_custom_label.setVisibility(View.VISIBLE);
            String s = mContext.getResources().getString(R.string.call_str_transfer);
            viewHolder.tv_call_custom_label.setText(String.format(s,!TextUtils.isEmpty(info.getFromAgentName())?info.getFromAgentName():""));
        }else if(info.getDialType() == 3){
            viewHolder.tv_call_custom_label.setVisibility(View.VISIBLE);
            String s = mContext.getResources().getString(R.string.call_str_zixun);
            viewHolder.tv_call_custom_label.setText(String.format(s,!TextUtils.isEmpty(info.getFromAgentName())?info.getFromAgentName():""));
        }else {
            viewHolder.tv_call_custom_label.setVisibility(View.GONE);
        }

        viewHolder.itemView.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                //拨号
                if (itemListener != null) {
                    itemListener.onItemClick(info);
                }
            }
        });
    }

    @Override
    public int getItemCount() {
        return mData.size();
    }

    class ViewHolder extends RecyclerView.ViewHolder {
        ImageView iv_call_status;
        TextView tv_call_custom_phone;
        TextView tv_call_custom_name;
        TextView tv_call_time;
        TextView tv_call_custom_label;

        public ViewHolder(@NonNull View itemView) {
            super(itemView);
            iv_call_status = itemView.findViewById(R.id.iv_call_status);
            tv_call_custom_name = itemView.findViewById(R.id.tv_call_custom_name);
            tv_call_custom_phone = itemView.findViewById(R.id.tv_call_custom_phone);
            tv_call_time = itemView.findViewById(R.id.tv_call_time);
            tv_call_custom_label = itemView.findViewById(R.id.tv_call_custom_label);
        }
    }

    public interface OnItemClickListener {
        void onItemClick(SobotCallRecordEntity record);
    }

}
