package com.sobot.callsdk.v6.adapter;

import android.content.Context;
import android.graphics.Color;
import android.media.AudioAttributes;
import android.media.AudioFocusRequest;
import android.media.AudioManager;
import android.media.PlaybackParams;
import android.os.Build;
import android.os.Handler;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.PopupWindow;
import android.widget.SeekBar;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.sobot.callbase.CallPermissionManager;
import com.sobot.callbase.dialog.SobotActionItem;
import com.sobot.callbase.model.callinfo.CallMainCDRInfo;
import com.sobot.callbase.model.callinfo.CallSatisfactionModel;
import com.sobot.callbase.utils.SobotDateUtils;
import com.sobot.callbase.utils.SobotStringUtils;
import com.sobot.callbase.widget.voice.AudioInfoModel;
import com.sobot.callbase.widget.voice.AudioPlayCallBack;
import com.sobot.callbase.widget.voice.AudioPlayPresenter;
import com.sobot.callbase.widget.voice.AudioTools;
import com.sobot.callsdk.R;
import com.sobot.callsdk.v6.dialog.CallSpeedMenu;
import com.sobot.common.login.SobotLoginTools;
import com.sobot.common.login.permission.SobotPermissionManager;
import com.sobot.gson.SobotGsonUtil;
import com.sobot.utils.SobotDensityUtil;
import com.sobot.utils.SobotLogUtils;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 任务通话记录
 */
public class CallTaskRecordAdapter extends RecyclerView.Adapter {
    private Context mContext;
    private List<CallMainCDRInfo> mData;
    private String zone;
    private boolean isPauseRecording;//是否暂停播放录音
    private long playingRecordingDuration;//正在播放的录音时长
    private String playingRecordingUrl;//正在播放的录音地址

    private TextView m_voice_time;
    private SeekBar m_voice_schedule;
    private ImageView m_voice_play;//播放
    private ImageView m_voice_pause;//暂停
    private Runnable runnable;
    private PopupWindow popupWindow;
    private Handler handler = new Handler();
    //语音相关， 听筒模式转换
    public AudioManager audioManager = null; // 声音管理器
    private AudioFocusRequest mFocusRequest;
    private AudioManager.OnAudioFocusChangeListener audioFocusChangeListener;
    private AudioAttributes mAttribute;
    AudioPlayPresenter mAudioPlayPresenter = null;
    AudioPlayCallBack mAudioPlayCallBack = null;

    public CallTaskRecordAdapter(Context mContext, List<CallMainCDRInfo> mData, String zone) {
        this.mContext = mContext;
        this.mData = mData;
        this.zone = zone;
    }

    @NonNull
    @Override
    public RecyclerView.ViewHolder onCreateViewHolder(@NonNull ViewGroup viewGroup, int i) {
        View v = LayoutInflater.from(mContext).inflate(R.layout.call_item_task_record, viewGroup, false);
        RecyclerView.ViewHolder vh = new CallTaskRecordVH(v);
        return vh;
    }

    @Override
    public void onBindViewHolder(@NonNull RecyclerView.ViewHolder vh, int index) {
        CallMainCDRInfo callMainCDRInfo = mData.get(index);
        CallTaskRecordVH viewHolder = (CallTaskRecordVH) vh;
        if (callMainCDRInfo != null) {
            if (index == (getItemCount() - 1)) {
                viewHolder.v_line_end.setVisibility(View.GONE);
            } else {
                viewHolder.v_line_end.setVisibility(View.VISIBLE);
            }
            if (index == 0) {
                viewHolder.v_line.setBackgroundColor(Color.TRANSPARENT);
            } else {
                viewHolder.v_line.setBackgroundColor(mContext.getResources().getColor(R.color.call_line_second));
            }
            //时间
            viewHolder.tv_time.setText(SobotDateUtils.formatYMDHM(callMainCDRInfo.getStartTime(), zone));
            //  通话类型【0.未知；1.内部通话； 2.呼入；3.外呼；4咨询；webcall】
            if (callMainCDRInfo.getCallType() == 1) {
                viewHolder.tv_call_type.setText(mContext.getResources().getString(R.string.sobot_custom_tnternal_call));
            } else if (callMainCDRInfo.getCallType() == 2) {
                viewHolder.tv_call_type.setText(mContext.getResources().getString(R.string.sobot_call_record_in));
            } else if (callMainCDRInfo.getCallType() == 3) {
                viewHolder.tv_call_type.setText(mContext.getResources().getString(R.string.call_pick_type_out));
            } else {
                viewHolder.tv_call_type.setText("- -");
            }
            //客户号码
            viewHolder.tv_customer_phone.setText(TextUtils.isEmpty(callMainCDRInfo.getScreenNumber()) ? "- -" : callMainCDRInfo.getScreenNumber());//客户号码
            //归属地
            if (TextUtils.isEmpty(callMainCDRInfo.getAreaProvince()) && TextUtils.isEmpty(callMainCDRInfo.getAreaCity())) {
                viewHolder.tv_belonging_place.setText("- -");
            } else if (!TextUtils.isEmpty(callMainCDRInfo.getAreaProvince()) && !TextUtils.isEmpty(callMainCDRInfo.getAreaCity())) {
                viewHolder.tv_belonging_place.setText(callMainCDRInfo.getAreaProvince() + "-" + callMainCDRInfo.getAreaCity());
            } else if (TextUtils.isEmpty(callMainCDRInfo.getAreaCity())) {
                viewHolder.tv_belonging_place.setText(callMainCDRInfo.getAreaProvince());
            } else if (TextUtils.isEmpty(callMainCDRInfo.getAreaProvince())) {
                viewHolder.tv_belonging_place.setText(callMainCDRInfo.getAreaCity());
            }
            //中继号码
            viewHolder.tv_relay_number.setText(callMainCDRInfo.getGatewayNumber());
            if (TextUtils.isEmpty(callMainCDRInfo.getBelongAgentName())) {
                viewHolder.tv_answering_seat.setText("- -");
            } else {
                viewHolder.tv_answering_seat.setText(callMainCDRInfo.getBelongAgentName() + (TextUtils.isEmpty(callMainCDRInfo.getBelongAgentID()) ? "" : ("(" + callMainCDRInfo.getBelongAgentID() + ")")));
            }

            //通话时长
            viewHolder.tv_call_duration.setText(SobotDateUtils.formatCallTimeDuration(callMainCDRInfo.getDuration()));
            //通话结果
            if (callMainCDRInfo.getCallResult() == 1) {
                viewHolder.tv_call_result.setText(mContext.getResources().getString(R.string.call_str_other_reasons));
            } else if (callMainCDRInfo.getCallResult() == 2) {
                viewHolder.tv_call_result.setText(mContext.getResources().getString(R.string.call_str_arrears));
            } else if (callMainCDRInfo.getCallResult() == 3) {
                viewHolder.tv_call_result.setText(mContext.getResources().getString(R.string.call_str_customer_number_blacklist));
            } else if (callMainCDRInfo.getCallResult() == 4) {
                viewHolder.tv_call_result.setText(mContext.getResources().getString(R.string.call_str_seat_side_not_found));
            } else if (callMainCDRInfo.getCallResult() == 5) {
                viewHolder.tv_call_result.setText(mContext.getResources().getString(R.string.call_str_customer_quick_hang));
            } else if (callMainCDRInfo.getCallResult() == 6) {
                viewHolder.tv_call_result.setText(mContext.getResources().getString(R.string.call_str_seat_side_not_answering));
            } else if (callMainCDRInfo.getCallResult() == 7) {
                viewHolder.tv_call_result.setText(mContext.getResources().getString(R.string.call_str_customer_not_answering));
            } else if (callMainCDRInfo.getCallResult() == 8) {
                viewHolder.tv_call_result.setText(mContext.getResources().getString(R.string.call_str_both_answered));
            } else if (callMainCDRInfo.getCallResult() == 9) {
                viewHolder.tv_call_result.setText(mContext.getResources().getString(R.string.call_str_relay_number_disabled));
            } else if (callMainCDRInfo.getCallResult() == 10) {
                viewHolder.tv_call_result.setText(mContext.getResources().getString(R.string.call_result_not_assigned));
            } else if (callMainCDRInfo.getCallResult() == 21) {
                viewHolder.tv_call_result.setText(mContext.getResources().getString(R.string.call_result_customer_answered));
            } else if (callMainCDRInfo.getCallResult() == 22) {
                viewHolder.tv_call_result.setText(mContext.getResources().getString(R.string.cal_result_system_unanswered));
            } else {
                viewHolder.tv_call_result.setText("- -");
            }
            //满意度
            if (!TextUtils.isEmpty(callMainCDRInfo.getSatisfyResult())) {
                List<CallSatisfactionModel> list = SobotGsonUtil.jsonToList(callMainCDRInfo.getSatisfyResult(), CallSatisfactionModel.class);
                viewHolder.tv_satisfaction.setText(callMainCDRInfo.getSatisfyResult());
                StringBuffer tempSB = new StringBuffer();
                if (list != null && list.size() > 0) {
                    for (int i = 0; i < list.size(); i++) {
                        CallSatisfactionModel satisfactionModel = list.get(i);
                        if (!TextUtils.isEmpty(satisfactionModel.getKey())) {
                            tempSB.append(SobotStringUtils.checkStringIsNull(satisfactionModel.getKey())).append(" ").append(SobotStringUtils.checkStringIsNull(satisfactionModel.getKeyName())).append(";");
                        }
                    }
                }
                viewHolder.tv_satisfaction.setText(tempSB.toString());
            } else {
                viewHolder.tv_satisfaction.setText("- -");
            }
            //通话id
            viewHolder.tv_call_id.setText(TextUtils.isEmpty(callMainCDRInfo.getCallID()) ? "- -" : callMainCDRInfo.getCallID());
        }
        //是否有录音
        if (!SobotStringUtils.isEmpty(callMainCDRInfo.getRecordUrl()) && CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_THXQ_LYBF)) {
            //有录音
            viewHolder.ll_voice_sound.setVisibility(View.VISIBLE);
            AudioInfoModel au = new AudioInfoModel();
            au.setAudioUrl(callMainCDRInfo.getRecordUrl()+ "?Authorization=" + SobotLoginTools.getInstance().getAccessToken());
            au.setDuration(callMainCDRInfo.getDuration());
            au.setSpeed(callMainCDRInfo.getTmpSpeed());
            viewHolder.tv_voice_time.setText("00:00/" + SobotDateUtils.formatCallTimeDurationTwo(callMainCDRInfo.getDuration()));
            viewHolder.iv_voice_pause.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    isPauseRecording = true;
                    viewHolder.iv_voice_play.setVisibility(View.VISIBLE);
                    viewHolder.iv_voice_pause.setVisibility(View.GONE);
                    AudioTools.getInstance().pause();
                }
            });
            viewHolder.iv_voice_play.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    viewHolder.iv_voice_play.setVisibility(View.GONE);
                    viewHolder.iv_voice_pause.setVisibility(View.VISIBLE);
                    au.setVoideIsPlaying(true);

                    if (!isPauseRecording || (!TextUtils.isEmpty(playingRecordingUrl) && !playingRecordingUrl.equals(au.getAudioUrl()))) {
                        //播放
                        clickPlayAudio(au);
                    } else {
                        //继续播放
                        AudioTools.getInstance().start();
                    }
                    voiceRunnable(au.getAudioUrl(), au.getDuration(), viewHolder.iv_voice_play, viewHolder.iv_voice_pause, viewHolder.sb_voice_schedule, viewHolder.tv_voice_time, viewHolder.tv_voice_play_frequency);
                }
            });
            viewHolder.tv_voice_play_frequency.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    List<SobotActionItem> lineStatusActionItems = new ArrayList<>();

                    lineStatusActionItems.add(new SobotActionItem("0.5", false, 0.5f));
                    lineStatusActionItems.add(new SobotActionItem("1.0", false, 1.0f));
                    lineStatusActionItems.add(new SobotActionItem("1.25", false, 1.25f));
                    lineStatusActionItems.add(new SobotActionItem("1.5", false, 1.5f));
                    lineStatusActionItems.add(new SobotActionItem("2.0", false, 2.0f));
                    CallSpeedMenu callfrequencyMenu = new CallSpeedMenu(mContext, lineStatusActionItems, SobotDensityUtil.dp2px(mContext, 100), new CallSpeedMenu.PopItemClick() {
                        @Override
                        public void onPopItemClick(SobotActionItem item, int index) {
                            if (item != null) {
                                mData.get(index).setTmpSpeed((Float) item.obj);
                                au.setSpeed((Float) item.obj);
                                viewHolder.tv_voice_play_frequency.setText("x " + item.mTitle);
                                //倍速播放
                                if (AudioTools.getInstance().isPlaying()) {
                                    if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
                                        AudioTools.getInstance().setPlaybackParams(new PlaybackParams().setSpeed((Float) item.obj));
                                    }
                                }
                            }
                            popupWindow.dismiss();
                        }
                    });
                    popupWindow = callfrequencyMenu.getPopWindow();
                    popupWindow.showAsDropDown(viewHolder.tv_voice_play_frequency, SobotDensityUtil.dp2px(mContext, -50), 0);
                }
            });
            viewHolder.sb_voice_schedule.setOnSeekBarChangeListener(new SeekBar.OnSeekBarChangeListener() {
                @Override
                public void onProgressChanged(SeekBar seekBar, int progress, boolean fromUser) {
                    if (fromUser) {// 注意点
                        try {
//                                                if (!AudioTools.getInstance().isPlaying()) {
//                                                    try {
//                                                        AudioTools.getInstance().reset();
//                                                        AudioTools.getInstance().setDataSource(au.getAudioUrl());
//                                                        AudioTools.getInstance().prepareAsync();
//                                                        // mPlayer.prepare();
//                                                        AudioTools.getInstance().start();
//                                                    } catch (IllegalStateException |
//                                                             IOException e) {
//                                                        e.printStackTrace();
//                                                    }
//                                                }
                            AudioTools.getInstance().seekTo(seekBar.getProgress());
                        } catch (IllegalStateException e) {
                            e.printStackTrace();

                        }
                    }
                }

                @Override
                public void onStartTrackingTouch(SeekBar seekBar) {

                }

                @Override
                public void onStopTrackingTouch(SeekBar seekBar) {

                }
            });
        } else {
            //没有录音
            viewHolder.ll_voice_sound.setVisibility(View.GONE);
        }
    }

    public void voiceRunnable(String audioUrl, long duration, ImageView iv_voice_play, ImageView iv_voice_pause, SeekBar sb_voice_schedule, TextView tv_voice_time, TextView tv_voice_play_frequency) {
        if (!TextUtils.isEmpty(playingRecordingUrl) && !playingRecordingUrl.equals(audioUrl)) {
            if (m_voice_time != null) {
                m_voice_time.setText("00:00/" + SobotDateUtils.formatCallTimeDurationTwo(playingRecordingDuration));
            }
            if (m_voice_play != null) {
                m_voice_play.setVisibility(View.VISIBLE);
            }
            if (m_voice_pause != null) {
                m_voice_pause.setVisibility(View.GONE);
            }
            if (m_voice_schedule != null) {
                m_voice_schedule.setProgress(0);
            }
        }
        //更新成新的播放控件和内容
        m_voice_time = tv_voice_time;
        m_voice_schedule = sb_voice_schedule;
        m_voice_play = iv_voice_play;
        m_voice_play.setVisibility(View.GONE);
        m_voice_pause = iv_voice_pause;
        m_voice_pause.setVisibility(View.VISIBLE);
        playingRecordingUrl = audioUrl;
        playingRecordingDuration = duration;
        if (handler != null && runnable != null) {
            handler.removeCallbacks(runnable);
            runnable = null;
        }
        runnable = new Runnable() {
            @Override
            public void run() {
                handler.postDelayed(this, 200);
                if (AudioTools.getInstance().isPlaying()) {
                    int progress = AudioTools.getInstance().getCurrentPosition();
                    int max = AudioTools.getInstance().getDuration();
                    SobotLogUtils.i("Current position: " + progress + " duration: " + max + "播放进度");
                    m_voice_schedule.setProgress(progress);
                    m_voice_schedule.setMax(max);
                    if (playingRecordingDuration >= 0) {
                        m_voice_time.setText(parseTime(progress) + "/" + SobotDateUtils.formatCallTimeDurationTwo(playingRecordingDuration));
                    } else {
                        m_voice_time.setText(parseTime(progress) + "/" + parseTime(max));
                    }
                } else {
                    m_voice_time.setText("00:00/" + SobotDateUtils.formatCallTimeDurationTwo(playingRecordingDuration));
                    m_voice_schedule.setProgress(0);
//                    SobotLogUtils.i("播放进度" + "100%");
                }
            }
        };
        handler.postDelayed(runnable, 100);
    }

    @Override
    public int getItemCount() {
        return mData.size();
    }


    class CallTaskRecordVH extends RecyclerView.ViewHolder {
        public TextView tv_time;
        //--------音频相关开始--------------
        private LinearLayout ll_voice_sound;
        public ImageView iv_voice_play;
        public ImageView iv_voice_pause;
        public SeekBar sb_voice_schedule;
        private TextView tv_voice_time;
        private TextView tv_voice_play_frequency;
        //----------音频相关结束------------
        public TextView tv_call_type;
        public TextView tv_customer_phone;
        public TextView tv_belonging_place;
        public TextView tv_relay_number;
        public TextView tv_answering_seat;
        public TextView tv_call_duration;
        public TextView tv_satisfaction;
        public TextView tv_call_id;
        public TextView tv_call_result;
        public View v_line;
        public View v_line_end;

        public CallTaskRecordVH(@NonNull View itemView) {
            super(itemView);
            ll_voice_sound = itemView.findViewById(R.id.ll_voice_sound);
            tv_call_type = itemView.findViewById(R.id.tv_call_type);
            tv_time = itemView.findViewById(R.id.tv_time);
            tv_call_duration = itemView.findViewById(R.id.tv_call_duration);
            tv_answering_seat = itemView.findViewById(R.id.tv_answering_seat);
            tv_call_result = itemView.findViewById(R.id.tv_call_result);
            v_line = itemView.findViewById(R.id.v_line);
            v_line_end = itemView.findViewById(R.id.v_line_end);

            iv_voice_play = itemView.findViewById(R.id.iv_voice_play);
            iv_voice_pause = itemView.findViewById(R.id.iv_voice_pause);
            sb_voice_schedule = itemView.findViewById(R.id.sb_voice_schedule);
            tv_voice_time = itemView.findViewById(R.id.tv_voice_time);
            tv_voice_play_frequency = itemView.findViewById(R.id.tv_voice_play_frequency);
            tv_customer_phone = itemView.findViewById(R.id.tv_customer_phone);
            tv_belonging_place = itemView.findViewById(R.id.tv_belonging_place);
            tv_relay_number = itemView.findViewById(R.id.tv_relay_number);
            tv_satisfaction = itemView.findViewById(R.id.tv_satisfaction);
            tv_call_id = itemView.findViewById(R.id.tv_call_id);
        }
    }

    // 点击播放录音
    public void clickPlayAudio(AudioInfoModel audioInfoModel) {
        if (AudioTools.getInstance().isPlaying()) {
            AudioTools.getInstance().stop();
        }
        abandonAudioFocus();
        initAudioManager();
        requestAudioFocus();
        float speed = audioInfoModel.getSpeed();
//        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
//            AudioTools.getInstance().setPlaybackParams(new PlaybackParams().setSpeed(audioInfoModel.getSpeed()));
//        }
        if (mAudioPlayPresenter == null) {
            mAudioPlayPresenter = new AudioPlayPresenter(mContext.getApplicationContext());
        }
        if (mAudioPlayCallBack == null) {
            mAudioPlayCallBack = new AudioPlayCallBack() {
                @Override
                public void onPlayStart(AudioInfoModel audioInfoModel) {
                    if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
                        AudioTools.getInstance().setPlaybackParams(new PlaybackParams().setSpeed(audioInfoModel.getSpeed()));
                    }
                }

                @Override
                public void onPlayEnd(AudioInfoModel audioInfoModel) {
                    isPauseRecording = false;
                    abandonAudioFocus();
                    if (handler != null && runnable != null) {
                        handler.removeCallbacks(runnable);
                        runnable = null;
                    }
                    m_voice_time.setText("00:00/" + SobotDateUtils.formatCallTimeDurationTwo(audioInfoModel.getDuration()));
                    m_voice_schedule.setProgress(0);
                    m_voice_play.setVisibility(View.VISIBLE);
                    m_voice_pause.setVisibility(View.GONE);
                }
            };
        }
        mAudioPlayPresenter.clickAudio(audioInfoModel, mAudioPlayCallBack);
    }

    // 设置听筒模式或者是正常模式的转换
    public void initAudioManager() {
        if (audioManager == null)
            audioManager = (AudioManager) mContext.getSystemService(Context.AUDIO_SERVICE);
        audioFocusChangeListener = new AudioManager.OnAudioFocusChangeListener() {
            @Override
            public void onAudioFocusChange(int focusChange) {
                switch (focusChange) {
                    case AudioManager.AUDIOFOCUS_GAIN:
                        // TBD 继续播放
                        break;
                    case AudioManager.AUDIOFOCUS_LOSS:
                        // TBD 停止播放
//                        if (AudioTools.getInstance().isPlaying()) {
//                            AudioTools.getInstance().stop();
//                        }
                        break;
                    case AudioManager.AUDIOFOCUS_LOSS_TRANSIENT:
                        // TBD 暂停播放
                        if (handler != null && runnable != null) {
                            handler.removeCallbacks(runnable);
                            runnable = null;
                        }
                        break;
                    case AudioManager.AUDIOFOCUS_LOSS_TRANSIENT_CAN_DUCK:
                        // TBD 混音播放
                        break;
                    default:
                        break;
                }

            }
        };
        //android 版本 5.0
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
            mAttribute = new AudioAttributes.Builder()
                    .setUsage(AudioAttributes.USAGE_MEDIA)
                    .setContentType(AudioAttributes.CONTENT_TYPE_MUSIC)
                    .build();
        }
        //android 版本 8.0
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
            mFocusRequest = new AudioFocusRequest.Builder(AudioManager.AUDIOFOCUS_GAIN_TRANSIENT)
                    .setWillPauseWhenDucked(true)
                    .setAcceptsDelayedFocusGain(true)
                    .setOnAudioFocusChangeListener(audioFocusChangeListener, new Handler())
                    .setAudioAttributes(mAttribute)
                    .build();
        }
    }

    //请求音频焦点
    public void requestAudioFocus() {
        if (Build.VERSION.SDK_INT <= Build.VERSION_CODES.ECLAIR_MR1) {
            return;
        }
        if (audioManager == null)
            audioManager = (AudioManager) mContext.getSystemService(Context.AUDIO_SERVICE);
        if (audioManager != null) {
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
                if (mFocusRequest != null)
                    audioManager.requestAudioFocus(mFocusRequest);
            } else {
                if (audioFocusChangeListener != null)
                    //AUDIOFOCUS_GAIN_TRANSIENT 只是短暂获得，一会就释放焦点
                    audioManager.requestAudioFocus(audioFocusChangeListener, AudioManager.STREAM_MUSIC, AudioManager.AUDIOFOCUS_GAIN_TRANSIENT);
            }
        }

    }

    //放弃音频焦点
    public void abandonAudioFocus() {
        if (Build.VERSION.SDK_INT <= Build.VERSION_CODES.ECLAIR_MR1) {
            return;
        }
        if (audioManager != null) {
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
                if (mFocusRequest != null)
                    audioManager.abandonAudioFocusRequest(mFocusRequest);
            } else {
                if (audioFocusChangeListener != null)
                    audioManager.abandonAudioFocus(audioFocusChangeListener);
            }
            audioManager = null;
        }
    }

    private String parseTime(long oldTime) {
        SimpleDateFormat sdf = new SimpleDateFormat("mm:ss");// 时间格式
        String newTime = sdf.format(new Date(oldTime));
        return newTime;
    }

}
