package com.sobot.callsdk.v6.dialog;

import android.app.Activity;
import android.view.View;
import android.widget.LinearLayout;
import android.widget.TextView;

import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.sobot.callbase.model.placename.AreaModel;
import com.sobot.callbase.model.placename.CityModel;
import com.sobot.callbase.model.placename.ProvinceModel;
import com.sobot.callsdk.R;
import com.sobot.callsdk.api.SobotCallServiceFactory;
import com.sobot.callsdk.dialog.SobotBottomDialog;
import com.sobot.callsdk.v6.adapter.CallCommonAdapter;
import com.sobot.network.http.callback.SobotResultCallBack;

import java.util.ArrayList;
import java.util.List;

//选择城市级联
public class SelectCityDialog extends SobotBottomDialog implements View.OnClickListener {
    private LinearLayout coustom_pop_layout, sobot_negativeButton,ll_level;
    private RecyclerView rv_list;
    private String provinceName = "";
    private String cityName = "";
    private String areaName = "";
    private String provinceId = "";
    private String cityId = "";
    private String areaId = "";
    //国家id
    private String countryId = "";
    private CallCommonAdapter adapter;
    private List<String> list;
    private List<ProvinceModel> provinceList;//省
    private List<CityModel> cityList;//市
    private List<AreaModel> areaList;//地区
    private Activity activity;
    private int seletIndex=-1;
    private int level=0;
    private CityListener listener;
    private boolean isRegion=false;

    public SelectCityDialog(Activity context,String countryId ,String provinceId,String provinceName,String cityId, String cityName,String areaId,String areaName,CityListener listener,boolean isRegion) {
        super(context);
        this.isRegion = isRegion;
        activity = context;
        this.countryId = countryId;
        this.provinceId = provinceId;
        this.provinceName = provinceName;
        this.cityId = cityId;
        this.cityName = cityName;
        this.areaId = areaId;
        this.areaName = areaName;
        this.listener = listener;
        provinceList = new ArrayList<>();
        cityList = new ArrayList<>();
        areaList = new ArrayList<>();
        list = new ArrayList<>();
    }

    @Override
    protected int getLayout() {
        return R.layout.call_dialog_select_city;
    }

    @Override
    protected View getDialogContainer() {
        if (coustom_pop_layout == null) {
            coustom_pop_layout = findViewById(R.id.sobot_container);
        }
        return coustom_pop_layout;
    }

    @Override
    protected void initView() {
        sobot_negativeButton = findViewById(R.id.sobot_negativeButton);
        ll_level = findViewById(R.id.ll_level);
        rv_list = findViewById(R.id.rv_list);
        LinearLayoutManager layoutManager = new LinearLayoutManager(activity, LinearLayoutManager.VERTICAL, false);
        // 设置RecyclerView的LayoutManager
        rv_list.setLayoutManager(layoutManager);
        sobot_negativeButton.setOnClickListener(this);
    }

    @Override
    protected void initData() {
        adapter = new CallCommonAdapter(activity, list, seletIndex, new DialogItemOnClick() {
            @Override
            public void selectItem(Object selectObj) {
                int index = (int) selectObj;
                if(isRegion && !"101".equals(countryId)){
                    ProvinceModel provinceModel = provinceList.get(index);
                    provinceId = provinceModel.getProvinceId();
                    provinceName = provinceModel.getProvinceName();
                    listener.selectCity(provinceId, provinceName, cityId, cityName, areaId, areaName);
                    dismiss();
                }else {
                    if (level == 0) {
                        if (index < provinceList.size()) {
                            ProvinceModel provinceModel = provinceList.get(index);
                            provinceId = provinceModel.getProvinceId();
                            provinceName = provinceModel.getProvinceName();
                            addLevelText(provinceName, level);
                            level++;
                            requestDate();
                        }
                    } else if (level == 1) {
                        if (index < cityList.size()) {
                            CityModel cityModel = cityList.get(index);
                            cityId = cityModel.getCityId();
                            cityName = cityModel.getCityName();
                            addLevelText(cityName, level);
                            level++;
                            requestDate();
                        }
                    } else if (level == 2) {
                        if (index < areaList.size()) {
                            AreaModel areaModel = areaList.get(index);
                            areaId = areaModel.getAreaId();
                            areaName = areaModel.getAreaName();
                            listener.selectCity(provinceId, provinceName, cityId, cityName, areaId, areaName);
                            dismiss();
                        }
                    }
                }
            }
        });
        rv_list.setAdapter(adapter);
        requestDate();
    }


    //升级
    private void addLevelText(String text,int levelTemp){
        ll_level.setVisibility(View.VISIBLE);
        TextView view = (TextView) View.inflate(activity,R.layout.sobot_item_select_level,null);
        view.setText(text);
        view.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                level --;
                levelLow();
            }
        });
        ll_level.addView(view);
    }
    //降级
    private void levelLow(){
        if(level>0) {
            ll_level.removeViewAt(level);
        }else{
            level=0;
        }
        if(level==0){
            ll_level.removeAllViews();
            ll_level.setVisibility(View.GONE);
        }
        requestDate();
    }
    private void requestDate(){
        if(level==0){
            //请求省
            if(provinceList.size()==0) {
                SobotCallServiceFactory.createZhiChiApi(activity).getProvinceListByCountryId(activity, countryId, new SobotResultCallBack<List<ProvinceModel>>() {
                    @Override
                    public void onSuccess(List<ProvinceModel> provinceModels) {
                        if (null != provinceModels && provinceModels.size() > 0) {
                            provinceList.addAll(provinceModels);
                            list.clear();
                            seletIndex = -1;
                            for (int i = 0; i < provinceModels.size(); i++) {
                                list.add(provinceModels.get(i).getProvinceName());
                                if (provinceId.equals(provinceModels.get(i).getProvinceId())) {
                                    seletIndex = i;
                                }
                            }
                            adapter.notifyDataSetChanged();
                        } else if(level ==1){
                            listener.selectCity(provinceId,provinceName,cityId,cityName,areaId,areaName);
                            dismiss();
                        } else {
                            level = 0;
                        }
                    }

                    @Override
                    public void onFailure(Exception e, String des) {

                    }
                });
            }else{
                list.clear();
                seletIndex = -1;
                for (int i = 0; i < provinceList.size(); i++) {
                    list.add(provinceList.get(i).getProvinceName());
                    if (provinceId.equals(provinceList.get(i).getProvinceId())) {
                        seletIndex = i;
                    }
                }
                adapter.notifyDataSetChanged();
            }
        }else if(level==1){
            //请求城市
                SobotCallServiceFactory.createZhiChiApi(activity).getCityList(activity, provinceId, new SobotResultCallBack<List<CityModel>>() {
                    @Override
                    public void onSuccess(List<CityModel> cityModels) {
                        if (null != cityModels && cityModels.size() > 0) {
                            cityList.addAll(cityModels);
                            list.clear();
                            seletIndex = -1;
                            for (int i = 0; i < cityModels.size(); i++) {
                                list.add(cityModels.get(i).getCityName());
                                if (cityId.equals(cityModels.get(i).getCityId())) {
                                    seletIndex = i;
                                }
                            }
                            adapter.notifyDataSetChanged();
                        } else {
                            level = 1;
                        }
                    }

                    @Override
                    public void onFailure(Exception e, String des) {

                    }
                });
        }else if(level==2){
            //请求区
                SobotCallServiceFactory.createZhiChiApi(activity).getAreaList(activity, cityId, new SobotResultCallBack<List<AreaModel>>() {
                    @Override
                    public void onSuccess(List<AreaModel> areaModels) {
                        if (null != areaModels && areaModels.size() > 0) {
                            areaList.addAll(areaModels);
                            list.clear();
                            seletIndex = -1;
                            for (int i = 0; i < areaModels.size(); i++) {
                                list.add(areaModels.get(i).getAreaName());
                                if (areaId.equals(areaModels.get(i).getAreaId())) {
                                    seletIndex = i;
                                }
                            }
                            adapter.notifyDataSetChanged();
                        } else {
                            level = 2;
                        }
                    }

                    @Override
                    public void onFailure(Exception e, String des) {

                    }
                });
        }
    }

    @Override
    public void onClick(View v) {
        if (v == sobot_negativeButton) {
            //关闭
            dismiss();
        }
    }

    @Override
    public void dismiss() {
        try {
            if (isShowing()) {
                super.dismiss();
            }
        } catch (Exception e) {
//            e.printStackTrace();
        }
    }

    public interface CityListener {
        void selectCity(String proviceId,String proviceName,String cityId, String cityName,String areaId,String areaName);
    }

}
