package com.sobot.callsdk.v6.dialog;

import android.content.Context;
import android.graphics.Typeface;
import android.graphics.drawable.ColorDrawable;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.PopupWindow;
import android.widget.TextView;

import com.sobot.callbase.dialog.SobotActionItem;
import com.sobot.callsdk.R;

import java.util.List;

/**
 * @author: Sobot
 * 2022/4/12
 */
public class SobotTitileMoreMenuV6 {

    private Context mContext;
    private PopItemClick mPopItemClick;//点击事件
    private List<SobotActionItem> mActionItems;//显示的菜单
    private boolean isShowCheck = false;//是否显示选中
    private int type = TYPE_TOP_TRIANGLE;//
    public static int TYPE_BOTTOM_CIRCULAR = 1;//下边显示圆角
    public static int TYPE_TOP_TRIANGLE = 2;//顶部带三角

    public SobotTitileMoreMenuV6(Context context, List<SobotActionItem> list, PopItemClick popItemClick) {
        this.type = type;
        mActionItems = list;
        mContext = context;
        mPopItemClick = popItemClick;
    }

    public SobotTitileMoreMenuV6(Context context, List<SobotActionItem> list, int type, boolean isShowCheck, PopItemClick popItemClick) {
        this.type = type;
        mActionItems = list;
        mContext = context;
        mPopItemClick = popItemClick;
        this.isShowCheck = isShowCheck;
    }

    public PopupWindow getPopWindow() {

        View mPopView = LayoutInflater.from(mContext).inflate(R.layout.sobot_pop_title_menu_v6, null);
        LinearLayout linearLayout = mPopView.findViewById(R.id.sobot_pop_content);
        View v_black = mPopView.findViewById(R.id.v_black);
        if (null != mActionItems && mActionItems.size() > 0) {
            for (int i = 0; i < mActionItems.size(); i++) {
                final int index = i;
                View view = LayoutInflater.from(mContext).inflate(R.layout.sobot_pop_item_title_menu_v6, null);
                TextView textView = view.findViewById(R.id.sobot_txt_title);
                SobotActionItem actionItem = mActionItems.get(i);
                textView.setText(actionItem.mTitle);
                textView.setTextColor(mContext.getResources().getColor(R.color.sobot_call_wenzi_gray1));
                // 设置文本居中          xaz
                textView.setSingleLine(true);
                //设置左边图片
                if (null != actionItem.mDrawable) {
                    actionItem.mDrawable.setBounds(0, 0, actionItem.mDrawable.getMinimumWidth(), actionItem.mDrawable.getMinimumHeight());
                    textView.setCompoundDrawables(actionItem.mDrawable, null, null, null);
                    textView.setCompoundDrawablePadding(30);
                }
                //设置行间距
                textView.setLineSpacing(0, 1.1f);
                view.setOnClickListener(new View.OnClickListener() {
                    @Override
                    public void onClick(View view) {
                        if (mPopItemClick != null) {
                            mPopItemClick.onPopItemClick(actionItem,index);
                        }
                    }
                });
                ImageView imageView = view.findViewById(R.id.sobot_img_state);
                if (isShowCheck && actionItem.isChecked) {
                    imageView.setVisibility(View.VISIBLE);
                    textView.setSelected(true);
                    view.setSelected(true);
                    textView.setTypeface(null, Typeface.BOLD);
                } else {
                    view.setSelected(false);
                    textView.setSelected(false);
                    imageView.setVisibility(View.GONE);
                    textView.setTypeface(null, Typeface.NORMAL);
                }
                linearLayout.addView(view);
            }
        }

        PopupWindow mPopWindow = new PopupWindow(mPopView,
                ViewGroup.LayoutParams.MATCH_PARENT,
                ViewGroup.LayoutParams.WRAP_CONTENT, true);
        mPopWindow.setBackgroundDrawable(new ColorDrawable(0x00000000));
        v_black.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                mPopWindow.dismiss();
            }
        });
        return mPopWindow;
    }

    public interface PopItemClick {
        void onPopItemClick(SobotActionItem item, int index);
    }
}
