package com.sobot.callsdk.v6.fragment;

import android.content.Context;
import android.content.Intent;
import android.media.AudioAttributes;
import android.media.AudioFocusRequest;
import android.media.AudioManager;
import android.media.PlaybackParams;
import android.os.Build;
import android.os.Bundle;
import android.os.Handler;
import android.text.ClipboardManager;
import android.text.TextUtils;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.PopupWindow;
import android.widget.ScrollView;
import android.widget.SeekBar;
import android.widget.TextView;

import androidx.annotation.Nullable;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.sobot.callbase.CallPermissionManager;
import com.sobot.callbase.dialog.SobotActionItem;
import com.sobot.callbase.model.callinfo.CallDetailEntity;
import com.sobot.callbase.model.callinfo.CallLeaveMessageTrace;
import com.sobot.callbase.model.callinfo.CallMainCDRInfo;
import com.sobot.callbase.model.callinfo.CallSatisfactionModel;
import com.sobot.callbase.utils.CommonUtils;
import com.sobot.callbase.utils.SobotDateUtils;
import com.sobot.callbase.utils.SobotStringUtils;
import com.sobot.callbase.widget.voice.AudioInfoModel;
import com.sobot.callbase.widget.voice.AudioPlayCallBack;
import com.sobot.callbase.widget.voice.AudioPlayPresenter;
import com.sobot.callbase.widget.voice.AudioTools;
import com.sobot.callsdk.R;
import com.sobot.callsdk.dialog.CallTipDialog;
import com.sobot.callsdk.fargment.SobotBaseFragment;
import com.sobot.callsdk.utils.SobotCallConstant;
import com.sobot.callsdk.v6.adapter.CallAgentCallDetailsAdapter;
import com.sobot.callsdk.v6.dialog.CallSpeedMenu;
import com.sobot.common.login.SobotLoginTools;
import com.sobot.common.login.permission.SobotPermissionManager;
import com.sobot.gson.SobotGsonUtil;
import com.sobot.network.http.callback.SobotResultCallBack;
import com.sobot.utils.SobotDensityUtil;
import com.sobot.utils.SobotLogUtils;
import com.sobot.widget.ui.toast.SobotToastUtil;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 通话详情
 */
public class CallInfoFragment extends SobotBaseFragment implements View.OnClickListener {
    private TextView tv_call_record;
    private LinearLayout ll_call_details;
    private TextView tv_agent_call_details;
    private ImageView iv_agent_call_details;
    private TextView tv_associated_records;
    private ScrollView sv_call_record;
    private LinearLayout ll_agent_call_details;
    private LinearLayout ll_associated_records;

    //通话信息
    public CallMainCDRInfo callMainCDRInfo;
    //录音
    private LinearLayout ll_sound_recording;

    private TextView m_voice_play_frequency;
    private TextView m_voice_time;
    private TextView tv_call_type;//通话类型
    private SeekBar m_voice_schedule;
    private ImageView m_voice_play;//播放
    private ImageView m_voice_pause;//暂停
    private boolean isPauseRecording;//是否暂停播放录音
    private long playingRecordingDuration;//正在播放的录音时长
    private String playingRecordingUrl;//正在播放的录音地址
    private Runnable runnable;
    //留言轨迹
    private LinearLayout ll_sound_leavemsg;

    private boolean isPauseLeavemsgRecording;//是否暂停播放留言录音
    private boolean isPlayLeavemsgRecording;//是否正在播放留言录音

    private TextView tv_time_start;
    private TextView tv_customer_no;
    private ImageView iv_customer_no_copy;
    private TextView tv_belonging_place;
    private TextView tv_relay_number;
    private TextView tv_first_queuing_skill;
    private TextView tv_answering_seat;
    private TextView tv_call_duration;
    private TextView tv_call_results;
    private TextView tv_satisfaction;
    private TextView tv_call_id;
    private ImageView iv_call_id_copy;

    //关联记录
    private TextView tv_source_type;
    private TextView tv_source_number;

    //座席通话明细
    private RecyclerView rv_agent_call_details;
    private CallAgentCallDetailsAdapter mAdapter;

    private String callID;

    private PopupWindow popupWindow;

    private String zone = "";

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        zone = CommonUtils.getTimeZone();
    }


    private String parseTime(long oldTime) {
        SimpleDateFormat sdf = new SimpleDateFormat("mm:ss");// 时间格式
        String newTime = sdf.format(new Date(oldTime));
        return newTime;
    }

    Handler handler = new Handler();

    public void voiceRunnable(String audioUrl, long duration, ImageView iv_voice_play, ImageView iv_voice_pause, SeekBar sb_voice_schedule, TextView tv_voice_time, TextView tv_voice_play_frequency) {
        if (!TextUtils.isEmpty(playingRecordingUrl) && !playingRecordingUrl.equals(audioUrl)) {
            if (m_voice_time != null) {
                if (callMainCDRInfo != null) {
                    m_voice_time.setText("00:00/" + SobotDateUtils.formatCallTimeDurationTwo(playingRecordingDuration));
                }
            }
            if (m_voice_play != null) {
                m_voice_play.setVisibility(View.VISIBLE);
            }
            if (m_voice_pause != null) {
                m_voice_pause.setVisibility(View.GONE);
            }
            if (m_voice_schedule != null) {
                m_voice_schedule.setProgress(0);
            }
        }
        //更新成新的播放控件和内容
        m_voice_time = tv_voice_time;
        m_voice_schedule = sb_voice_schedule;
        m_voice_play = iv_voice_play;
        m_voice_play.setVisibility(View.GONE);
        m_voice_pause = iv_voice_pause;
        m_voice_pause.setVisibility(View.VISIBLE);
        playingRecordingUrl = audioUrl;
        playingRecordingDuration = duration;
        if (handler != null && runnable != null) {
            handler.removeCallbacks(runnable);
            runnable = null;
        }
        runnable = new Runnable() {
            @Override
            public void run() {
                handler.postDelayed(this, 200);
                if (AudioTools.getInstance().isPlaying()) {
                    int progress = AudioTools.getInstance().getCurrentPosition();
                    int max = AudioTools.getInstance().getDuration();
                    SobotLogUtils.i("Current position: " + progress + " duration: " + max + "播放进度");
                    m_voice_schedule.setProgress(progress);
                    m_voice_schedule.setMax(max);
                    if (callMainCDRInfo != null) {
                        m_voice_time.setText(parseTime(progress) + "/" + SobotDateUtils.formatCallTimeDurationTwo(playingRecordingDuration));
                    } else {
                        m_voice_time.setText(parseTime(progress) + "/" + parseTime(max));
                    }
                } else {
                    if (callMainCDRInfo != null) {
                        m_voice_time.setText("00:00/" + SobotDateUtils.formatCallTimeDurationTwo(playingRecordingDuration));
                    }
                    m_voice_schedule.setProgress(0);
//                    SobotLogUtils.i("播放进度" + "100%");
                }
            }
        };
        handler.postDelayed(runnable, 100);
    }


    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        View view = inflater.inflate(R.layout.fragment_call_info, container, false);
        initView(view);
        return view;
    }

    @Override
    public void setArguments(@Nullable Bundle bundle) {
        super.setArguments(bundle);
        callID = bundle.getString("callID", "");
    }

    public void initView(View view) {
        tv_call_type = view.findViewById(R.id.tv_call_type);
        tv_call_record = view.findViewById(R.id.tv_call_record);
        tv_agent_call_details = view.findViewById(R.id.tv_agent_call_details);
        ll_call_details = view.findViewById(R.id.ll_call_details);
        iv_agent_call_details = view.findViewById(R.id.iv_agent_call_details);
        tv_associated_records = view.findViewById(R.id.tv_associated_records);
        sv_call_record = view.findViewById(R.id.sv_call_record);
        ll_agent_call_details = view.findViewById(R.id.ll_agent_call_details);
        ll_associated_records = view.findViewById(R.id.ll_associated_records);
        tv_call_record.setOnClickListener(this);
        tv_associated_records.setOnClickListener(this);
        ll_call_details.setOnClickListener(this);
        iv_agent_call_details.setOnClickListener(this);

        ll_agent_call_details.setVisibility(View.GONE);
        ll_associated_records.setVisibility(View.GONE);

        //通话信息
        ll_sound_recording = view.findViewById(R.id.ll_sound_recording);

        ll_sound_leavemsg = view.findViewById(R.id.ll_sound_leavemsg);

        tv_time_start = view.findViewById(R.id.tv_time_start);
        tv_customer_no = view.findViewById(R.id.tv_customer_no);
        iv_customer_no_copy = view.findViewById(R.id.iv_customer_no_copy);
        iv_customer_no_copy.setOnClickListener(this);
        tv_belonging_place = view.findViewById(R.id.tv_belonging_place);
        tv_relay_number = view.findViewById(R.id.tv_relay_number);
        tv_first_queuing_skill = view.findViewById(R.id.tv_first_queuing_skill);
        tv_answering_seat = view.findViewById(R.id.tv_answering_seat);
        tv_call_duration = view.findViewById(R.id.tv_call_duration);
        tv_call_results = view.findViewById(R.id.tv_call_results);
        tv_satisfaction = view.findViewById(R.id.tv_satisfaction);
        tv_call_id = view.findViewById(R.id.tv_call_id);
        iv_call_id_copy = view.findViewById(R.id.iv_call_id_copy);
        iv_call_id_copy.setOnClickListener(this);

        tv_source_type = view.findViewById(R.id.tv_source_type);
        tv_source_number = view.findViewById(R.id.tv_source_number);

        rv_agent_call_details = view.findViewById(R.id.rv_agent_call_details);

        //获取通话信息详情
        zhiChiApi.getCallDetails(CallInfoFragment.this, callID, new SobotResultCallBack<CallDetailEntity>() {
            @Override
            public void onSuccess(CallDetailEntity callDetailEntity) {
                if (callDetailEntity != null) {
                    if (callDetailEntity.getMainCDRInfoList() != null && callDetailEntity.getMainCDRInfoList().size() > 0) {
                        callMainCDRInfo = callDetailEntity.getMainCDRInfoList().get(0);
                        if (!SobotStringUtils.isEmpty(callMainCDRInfo.getRecordUrl()) && CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_THXQ_LYBF)) {
                            TextView tv_voice_play_frequency = view.findViewById(R.id.tv_voice_play_frequency);
                            TextView tv_voice_time = view.findViewById(R.id.tv_voice_time);
                            SeekBar sb_voice_schedule = view.findViewById(R.id.sb_voice_schedule);
                            ImageView iv_voice_play = view.findViewById(R.id.iv_voice_play);//播放
                            ImageView iv_voice_pause = view.findViewById(R.id.iv_voice_pause);//暂停
                            AudioInfoModel au = new AudioInfoModel();
                            au.setAudioUrl(callMainCDRInfo.getRecordUrl() + "?Authorization=" + SobotLoginTools.getInstance().getAccessToken());
                            au.setDuration(callMainCDRInfo.getDuration());
                            ll_sound_recording.setVisibility(View.VISIBLE);
                            tv_voice_time.setText("00:00/" + SobotDateUtils.formatCallTimeDurationTwo(callMainCDRInfo.getDuration()));
                            iv_voice_pause.setOnClickListener(new View.OnClickListener() {
                                @Override
                                public void onClick(View v) {
                                    isPauseRecording = true;
                                    iv_voice_play.setVisibility(View.VISIBLE);
                                    iv_voice_pause.setVisibility(View.GONE);
                                    AudioTools.getInstance().pause();
                                    if (handler != null && runnable != null) {
                                        handler.removeCallbacks(runnable);
                                        runnable = null;
                                    }
                                }
                            });
                            iv_voice_play.setOnClickListener(new View.OnClickListener() {
                                @Override
                                public void onClick(View v) {
                                    iv_voice_play.setVisibility(View.GONE);
                                    iv_voice_pause.setVisibility(View.VISIBLE);
                                    au.setVoideIsPlaying(true);
                                    if (!isPauseRecording || (!TextUtils.isEmpty(playingRecordingUrl) && !playingRecordingUrl.equals(au.getAudioUrl()))) {
                                        //播放
                                        clickPlayAudio(au);
                                    } else {
                                        //继续播放
                                        AudioTools.getInstance().start();
                                    }
                                    voiceRunnable(au.getAudioUrl(), au.getDuration(), iv_voice_play, iv_voice_pause, sb_voice_schedule, tv_voice_time, tv_voice_play_frequency);
                                }
                            });
                            tv_voice_play_frequency.setOnClickListener(new View.OnClickListener() {
                                @Override
                                public void onClick(View v) {
                                    List<SobotActionItem> lineStatusActionItems = new ArrayList<>();
                                    lineStatusActionItems.add(new SobotActionItem("0.5", false, 0.5f));
                                    lineStatusActionItems.add(new SobotActionItem("1.0", false, 1.0f));
                                    lineStatusActionItems.add(new SobotActionItem("1.25", false, 1.25f));
                                    lineStatusActionItems.add(new SobotActionItem("1.5", false, 1.5f));
                                    lineStatusActionItems.add(new SobotActionItem("2.0", false, 2.0f));
                                    CallSpeedMenu callfrequencyMenu = new CallSpeedMenu(getContext(), lineStatusActionItems, SobotDensityUtil.dp2px(getSobotActivity(), 100), new CallSpeedMenu.PopItemClick() {
                                        @Override
                                        public void onPopItemClick(SobotActionItem item, int index) {
                                            if (item != null) {
                                                au.setSpeed((Float) item.obj);
                                                tv_voice_play_frequency.setText("x " + item.mTitle);
                                                //倍速播放
                                                if (AudioTools.getInstance().isPlaying()) {
                                                    if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
                                                        AudioTools.getInstance().setPlaybackParams(new PlaybackParams().setSpeed((Float) item.obj));
                                                    }
                                                }
                                            }
                                            popupWindow.dismiss();
                                        }
                                    });
                                    popupWindow = callfrequencyMenu.getPopWindow();
                                    popupWindow.showAsDropDown(tv_voice_play_frequency, SobotDensityUtil.dp2px(getSobotActivity(), -50), 0);
                                }
                            });
                            sb_voice_schedule.setOnSeekBarChangeListener(new SeekBar.OnSeekBarChangeListener() {
                                @Override
                                public void onProgressChanged(SeekBar seekBar, int progress, boolean fromUser) {
                                    if (fromUser) {// 注意点
                                        try {
//                                                if (!AudioTools.getInstance().isPlaying()) {
//                                                    try {
//                                                        AudioTools.getInstance().reset();
//                                                        AudioTools.getInstance().setDataSource(au.getAudioUrl());
//                                                        AudioTools.getInstance().prepareAsync();
//                                                        // mPlayer.prepare();
//                                                        AudioTools.getInstance().start();
//                                                    } catch (IllegalStateException |
//                                                             IOException e) {
//                                                        e.printStackTrace();
//                                                    }
//                                                }
                                            AudioTools.getInstance().seekTo(seekBar.getProgress());
                                        } catch (IllegalStateException e) {
                                            e.printStackTrace();

                                        }
                                    }
                                }

                                @Override
                                public void onStartTrackingTouch(SeekBar seekBar) {

                                }

                                @Override
                                public void onStopTrackingTouch(SeekBar seekBar) {

                                }
                            });
                        }
                        if (callMainCDRInfo.getLeaveMessageTraces() != null && callMainCDRInfo.getLeaveMessageTraces().size() > 0 && CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_THXQ_LYBF)) {
                            ll_sound_leavemsg.setVisibility(View.VISIBLE);
                            for (int i = 0; i < callMainCDRInfo.getLeaveMessageTraces().size(); i++) {
                                CallLeaveMessageTrace trace = callMainCDRInfo.getLeaveMessageTraces().get(i);
                                if (trace != null) {
                                    AudioInfoModel au = new AudioInfoModel();
                                    au.setAudioUrl(trace.getRecordUrl() + "?Authorization=" + SobotLoginTools.getInstance().getAccessToken());
                                    au.setDuration(trace.getRecordDuration());
                                    LinearLayout ll_leavemsg_item = new LinearLayout(getSobotActivity());
                                    LinearLayout.LayoutParams itemLp = new LinearLayout.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.WRAP_CONTENT);
                                    ll_leavemsg_item.setPadding(SobotDensityUtil.dp2px(getSobotActivity(), 15), SobotDensityUtil.dp2px(getSobotActivity(), 15), SobotDensityUtil.dp2px(getSobotActivity(), 15), SobotDensityUtil.dp2px(getSobotActivity(), 15));
                                    ll_leavemsg_item.setBackground(getResources().getDrawable(R.drawable.draw_call_arrange_ractangle_gray_bg));
                                    ll_leavemsg_item.setOrientation(LinearLayout.HORIZONTAL);
                                    ll_leavemsg_item.setGravity(Gravity.CENTER_VERTICAL);

                                    ImageView iv_leavemsg_voice_play = new ImageView(getSobotActivity());//播放
                                    LinearLayout.LayoutParams playLp = new LinearLayout.LayoutParams(SobotDensityUtil.dp2px(getSobotActivity(), 24), SobotDensityUtil.dp2px(getSobotActivity(), 24));
                                    iv_leavemsg_voice_play.setLayoutParams(playLp);
                                    iv_leavemsg_voice_play.setBackgroundResource(R.drawable.call_icon_play);
                                    ll_leavemsg_item.addView(iv_leavemsg_voice_play);

                                    ImageView iv_leavemsg_voice_pause = new ImageView(getSobotActivity());//暂停
                                    LinearLayout.LayoutParams pauseLp = new LinearLayout.LayoutParams(SobotDensityUtil.dp2px(getSobotActivity(), 24), SobotDensityUtil.dp2px(getSobotActivity(), 24));
                                    iv_leavemsg_voice_pause.setLayoutParams(pauseLp);
                                    iv_leavemsg_voice_pause.setBackgroundResource(R.drawable.call_icon_pause);
                                    iv_leavemsg_voice_pause.setVisibility(View.GONE);
                                    ll_leavemsg_item.addView(iv_leavemsg_voice_pause);

                                    SeekBar sb_leavemsg_voice_schedule = (SeekBar) View.inflate(getSobotActivity(), R.layout.fragment_call_info_leave_track_item, null);
                                    LinearLayout.LayoutParams slp = new LinearLayout.LayoutParams(0, ViewGroup.LayoutParams.WRAP_CONTENT, 1.0f);
                                    sb_leavemsg_voice_schedule.setLayoutParams(slp);
                                    ll_leavemsg_item.addView(sb_leavemsg_voice_schedule);

                                    TextView tv_leavemsg_voice_time = new TextView(getSobotActivity());
                                    tv_leavemsg_voice_time.setTextSize(12);
                                    tv_leavemsg_voice_time.setTextColor(getResources().getColor(R.color.call_wenzi_gray2));
                                    LinearLayout.LayoutParams lp = new LinearLayout.LayoutParams(ViewGroup.LayoutParams.WRAP_CONTENT, ViewGroup.LayoutParams.WRAP_CONTENT);
                                    lp.setMargins(0, 0, SobotDensityUtil.dp2px(getSobotActivity(), 8), 0);
                                    tv_leavemsg_voice_time.setLayoutParams(lp);
                                    ll_leavemsg_item.addView(tv_leavemsg_voice_time);

                                    TextView tv_leavemsg_voice_play_frequency = new TextView(getSobotActivity());
                                    tv_leavemsg_voice_play_frequency.setTextSize(10);
                                    tv_leavemsg_voice_play_frequency.setTextColor(getResources().getColor(R.color.call_wenzi_gray3));
                                    LinearLayout.LayoutParams flp = new LinearLayout.LayoutParams(SobotDensityUtil.dp2px(getSobotActivity(), 40), ViewGroup.LayoutParams.WRAP_CONTENT);
                                    tv_leavemsg_voice_play_frequency.setLayoutParams(flp);
                                    tv_leavemsg_voice_play_frequency.setBackground(getResources().getDrawable(R.drawable.draw_call_ractangle_gray2_bg));
                                    tv_leavemsg_voice_play_frequency.setGravity(Gravity.CENTER);
                                    tv_leavemsg_voice_play_frequency.setPadding(SobotDensityUtil.dp2px(getSobotActivity(), 2), SobotDensityUtil.dp2px(getSobotActivity(), 2), SobotDensityUtil.dp2px(getSobotActivity(), 2), SobotDensityUtil.dp2px(getSobotActivity(), 2));
                                    tv_leavemsg_voice_play_frequency.setText("x 1.0");
                                    ll_leavemsg_item.addView(tv_leavemsg_voice_play_frequency);
                                    ll_sound_leavemsg.addView(ll_leavemsg_item);

                                    TextView tv_associated_work_order = new TextView(getSobotActivity());
                                    tv_associated_work_order.setTextSize(12);
                                    tv_associated_work_order.setTextColor(getResources().getColor(R.color.sobot_call_theme_color));
                                    LinearLayout.LayoutParams woLp = new LinearLayout.LayoutParams(ViewGroup.LayoutParams.WRAP_CONTENT, ViewGroup.LayoutParams.WRAP_CONTENT);

                                    ll_sound_leavemsg.addView(tv_associated_work_order);

                                    tv_leavemsg_voice_time.setText("00:00/" + SobotDateUtils.formatCallTimeDurationTwo(trace.getRecordDuration()));
                                    iv_leavemsg_voice_pause.setOnClickListener(new View.OnClickListener() {
                                        @Override
                                        public void onClick(View v) {
                                            isPauseRecording = true;
                                            iv_leavemsg_voice_play.setVisibility(View.VISIBLE);
                                            iv_leavemsg_voice_pause.setVisibility(View.GONE);
                                            AudioTools.getInstance().pause();
                                            if (handler != null && runnable != null) {
                                                handler.removeCallbacks(runnable);
                                                runnable = null;
                                            }
                                        }
                                    });
                                    iv_leavemsg_voice_play.setOnClickListener(new View.OnClickListener() {
                                        @Override
                                        public void onClick(View v) {
                                            iv_leavemsg_voice_play.setVisibility(View.GONE);
                                            iv_leavemsg_voice_pause.setVisibility(View.VISIBLE);
                                            au.setVoideIsPlaying(true);
                                            if (!isPauseRecording || (!TextUtils.isEmpty(playingRecordingUrl) && !playingRecordingUrl.equals(au.getAudioUrl()))) {
                                                //播放
                                                clickPlayAudio(au);
                                            } else {
                                                //继续播放
                                                AudioTools.getInstance().start();
                                            }
                                            voiceRunnable(au.getAudioUrl(), au.getDuration(), iv_leavemsg_voice_play, iv_leavemsg_voice_pause, sb_leavemsg_voice_schedule, tv_leavemsg_voice_time, tv_leavemsg_voice_play_frequency);
                                        }
                                    });
                                    tv_leavemsg_voice_play_frequency.setOnClickListener(new View.OnClickListener() {
                                        @Override
                                        public void onClick(View v) {
                                            List<SobotActionItem> lineStatusActionItems = new ArrayList<>();
                                            lineStatusActionItems.add(new SobotActionItem("0.5", false, 0.5f));
                                            lineStatusActionItems.add(new SobotActionItem("1.0", false, 1.0f));
                                            lineStatusActionItems.add(new SobotActionItem("1.25", false, 1.25f));
                                            lineStatusActionItems.add(new SobotActionItem("1.5", false, 1.5f));
                                            lineStatusActionItems.add(new SobotActionItem("2.0", false, 2.0f));
                                            CallSpeedMenu callfrequencyMenu = new CallSpeedMenu(getContext(), lineStatusActionItems, SobotDensityUtil.dp2px(getSobotActivity(), 100), new CallSpeedMenu.PopItemClick() {
                                                @Override
                                                public void onPopItemClick(SobotActionItem item, int index) {
                                                    if (item != null) {
                                                        au.setSpeed((Float) item.obj);
                                                        tv_leavemsg_voice_play_frequency.setText("x " + item.mTitle);
                                                        //倍速播放
                                                        if (AudioTools.getInstance().isPlaying()) {
                                                            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
                                                                AudioTools.getInstance().setPlaybackParams(new PlaybackParams().setSpeed((Float) item.obj));
                                                            }
                                                        }
                                                    }
                                                    popupWindow.dismiss();
                                                }
                                            });
                                            popupWindow = callfrequencyMenu.getPopWindow();
                                            popupWindow.showAsDropDown(tv_leavemsg_voice_play_frequency, SobotDensityUtil.dp2px(getSobotActivity(), -50), 0);
                                        }
                                    });
                                    sb_leavemsg_voice_schedule.setOnSeekBarChangeListener(new SeekBar.OnSeekBarChangeListener() {
                                        @Override
                                        public void onProgressChanged(SeekBar seekBar, int progress, boolean fromUser) {
                                            if (fromUser) {// 注意点
                                                try {
//                                                    if (!AudioTools.getInstance().isPlaying()) {
//                                                        try {
//                                                            AudioTools.getInstance().reset();
//                                                            AudioTools.getInstance().setDataSource(au.getAudioUrl());
//                                                            AudioTools.getInstance().prepareAsync();
//                                                            // mPlayer.prepare();
//                                                            AudioTools.getInstance().start();
//                                                        } catch (IllegalStateException |
//                                                                 IOException e) {
//                                                            e.printStackTrace();
//                                                        }
//                                                    }
                                                    AudioTools.getInstance().seekTo(seekBar.getProgress());
                                                } catch (IllegalStateException e) {
                                                    e.printStackTrace();

                                                }
                                            }
                                        }

                                        @Override
                                        public void onStartTrackingTouch(SeekBar seekBar) {

                                        }

                                        @Override
                                        public void onStopTrackingTouch(SeekBar seekBar) {

                                        }
                                    });

                                    if (trace.getDestination() == 1 && !TextUtils.isEmpty(trace.getDestinationResultCode())) {
                                        tv_associated_work_order.setText(getSobotActivity().getResources().getString(R.string.call_str_associated_work_0rder) + " #" + trace.getDestinationResultCode());
                                        tv_associated_work_order.setVisibility(View.VISIBLE);
                                        tv_associated_work_order.setOnClickListener(new View.OnClickListener() {
                                            @Override
                                            public void onClick(View v) {
                                                Intent intent1 = new Intent();
                                                intent1.setAction(SobotCallConstant.CALL_OPEN_WORDORDER);//通话详情 留言录音 点击关联工单 跳转
                                                intent1.putExtra("orderId", SobotStringUtils.checkStringIsNull(trace.getDestinationResultId()));
                                                getSobotActivity().sendBroadcast(intent1);
                                            }
                                        });
                                        if (i < (callMainCDRInfo.getLeaveMessageTraces().size() - 1)) {
                                            woLp.setMargins(0, SobotDensityUtil.dp2px(getSobotActivity(), 5), 0, SobotDensityUtil.dp2px(getSobotActivity(), 20));
                                            tv_associated_work_order.setLayoutParams(woLp);
                                        } else {
                                            woLp.setMargins(0, SobotDensityUtil.dp2px(getSobotActivity(), 5), 0, 0);
                                            tv_associated_work_order.setLayoutParams(woLp);
                                        }
                                        ll_leavemsg_item.setLayoutParams(itemLp);
                                    } else {
                                        if (i < (callMainCDRInfo.getLeaveMessageTraces().size() - 1)) {
                                            itemLp.setMargins(0, 0, 0, SobotDensityUtil.dp2px(getSobotActivity(), 20));
                                        }
                                        ll_leavemsg_item.setLayoutParams(itemLp);
                                        tv_associated_work_order.setVisibility(View.GONE);
                                    }

                                }
                            }
                        } else {
                            ll_sound_leavemsg.setVisibility(View.GONE);
                        }

                        tv_time_start.setText(SobotDateUtils.formatYMDHM(callMainCDRInfo.getStartTime(), zone));
                        tv_customer_no.setText(TextUtils.isEmpty(callMainCDRInfo.getScreenNumber()) ? "- -" : callMainCDRInfo.getScreenNumber());
                        if (TextUtils.isEmpty(callMainCDRInfo.getAreaProvince()) && TextUtils.isEmpty(callMainCDRInfo.getAreaCity())) {
                            tv_belonging_place.setText("- -");
                        } else if (!TextUtils.isEmpty(callMainCDRInfo.getAreaProvince()) && !TextUtils.isEmpty(callMainCDRInfo.getAreaCity())) {
                            tv_belonging_place.setText(callMainCDRInfo.getAreaProvince() + "-" + callMainCDRInfo.getAreaCity());
                        } else if (TextUtils.isEmpty(callMainCDRInfo.getAreaCity())) {
                            tv_belonging_place.setText(callMainCDRInfo.getAreaProvince());
                        } else if (TextUtils.isEmpty(callMainCDRInfo.getAreaProvince())) {
                            tv_belonging_place.setText(callMainCDRInfo.getAreaCity());
                        }
                        String tempGatewayNumberNick = "";
                        if (!SobotStringUtils.isEmpty(callMainCDRInfo.getGatewayNumberNick())) {
                            tempGatewayNumberNick = " (" + callMainCDRInfo.getGatewayNumberNick() + ")";
                        }
                        tv_relay_number.setText(TextUtils.isEmpty(callMainCDRInfo.getGatewayNumber()) ? "- -" : (callMainCDRInfo.getGatewayNumber() + tempGatewayNumberNick));
                        tv_first_queuing_skill.setText(TextUtils.isEmpty(callMainCDRInfo.getFirstDistributedQueueName()) ? "- -" : callMainCDRInfo.getFirstDistributedQueueName());
//                        belongAgentID
                        if (TextUtils.isEmpty(callMainCDRInfo.getBelongAgentName())) {
                            tv_answering_seat.setText("- -");
                        } else {
                            tv_answering_seat.setText(callMainCDRInfo.getBelongAgentName() + (TextUtils.isEmpty(callMainCDRInfo.getBelongAgentID()) ? "" : ("(" + callMainCDRInfo.getBelongAgentID() + ")")));
                        }
                        tv_call_duration.setText(SobotDateUtils.formatCallTimeDuration(callMainCDRInfo.getDuration()));
                        //  通话类型【0.未知；1.内部通话； 2.呼入；3.外呼；4咨询；webcall】
                        if (callMainCDRInfo.getCallType() == 1) {
                            tv_call_type.setText(getResources().getString(R.string.sobot_custom_tnternal_call));
                        } else if (callMainCDRInfo.getCallType() == 2) {
                            tv_call_type.setText(getResources().getString(R.string.sobot_call_record_in));
                        } else if (callMainCDRInfo.getCallType() == 3) {
                            tv_call_type.setText(getResources().getString(R.string.call_pick_type_out));
                        } else {
                            tv_call_type.setText("- -");
                        }

                        /**
                         * 通话结果:1.其他原因无法应答 2.欠费 3.客户号码黑名单 4.未找到座席侧 5.客户速挂6.座席侧未接听 7.客户未接听 8.双方已接听 9.中继号码停用 10.呼入路由未匹配 21.(客户已接听) 22.(系统未应答)
                         */
                        if (callMainCDRInfo.getCallResult() == 1) {
                            tv_call_results.setText(getSobotActivity().getResources().getString(R.string.call_str_other_reasons));
                        } else if (callMainCDRInfo.getCallResult() == 2) {
                            tv_call_results.setText(getSobotActivity().getResources().getString(R.string.call_str_arrears));
                        } else if (callMainCDRInfo.getCallResult() == 3) {
                            tv_call_results.setText(getSobotActivity().getResources().getString(R.string.call_str_customer_number_blacklist));
                        } else if (callMainCDRInfo.getCallResult() == 4) {
                            tv_call_results.setText(getSobotActivity().getResources().getString(R.string.call_str_seat_side_not_found));
                        } else if (callMainCDRInfo.getCallResult() == 5) {
                            tv_call_results.setText(getSobotActivity().getResources().getString(R.string.call_str_customer_quick_hang));
                        } else if (callMainCDRInfo.getCallResult() == 6) {
                            tv_call_results.setText(getSobotActivity().getResources().getString(R.string.call_str_seat_side_not_answering));
                        } else if (callMainCDRInfo.getCallResult() == 7) {
                            tv_call_results.setText(getSobotActivity().getResources().getString(R.string.call_str_customer_not_answering));
                        } else if (callMainCDRInfo.getCallResult() == 8) {
                            tv_call_results.setText(getSobotActivity().getResources().getString(R.string.call_str_both_answered));
                        } else if (callMainCDRInfo.getCallResult() == 9) {
                            tv_call_results.setText(getSobotActivity().getResources().getString(R.string.call_str_relay_number_disabled));
                        } else if (callMainCDRInfo.getCallResult() == 10) {
                            tv_call_results.setText(getSobotActivity().getResources().getString(R.string.call_result_not_assigned));
                        } else if (callMainCDRInfo.getCallResult() == 21) {
                            tv_call_results.setText(getSobotActivity().getResources().getString(R.string.call_result_customer_answered));
                        } else if (callMainCDRInfo.getCallResult() == 22) {
                            tv_call_results.setText(getSobotActivity().getResources().getString(R.string.cal_result_system_unanswered));
                        } else {
                            tv_call_results.setText("- -");
                        }
                        if (!TextUtils.isEmpty(callMainCDRInfo.getSatisfyResult())) {
                            List<CallSatisfactionModel> list = SobotGsonUtil.jsonToList(callMainCDRInfo.getSatisfyResult(), CallSatisfactionModel.class);
                            tv_satisfaction.setText(callMainCDRInfo.getSatisfyResult());
                            StringBuffer tempSB = new StringBuffer();
                            if (list != null && list.size() > 0) {
                                for (int i = 0; i < list.size(); i++) {
                                    CallSatisfactionModel satisfactionModel = list.get(i);
                                    if (!TextUtils.isEmpty(satisfactionModel.getKey())) {
                                        tempSB.append(SobotStringUtils.checkStringIsNull(satisfactionModel.getKey())).append(" ").append(SobotStringUtils.checkStringIsNull(satisfactionModel.getKeyName())).append(";");
                                    }
                                }
                            }
                            tv_satisfaction.setText(tempSB.toString());
                        } else {
                            tv_satisfaction.setText("- -");
                        }
                        tv_call_id.setText(TextUtils.isEmpty(callMainCDRInfo.getCallID()) ? "- -" : callMainCDRInfo.getCallID());

                        //1通话记录   2工单
                        if (callMainCDRInfo.getSourceType() == 1) {
                            tv_source_type.setText(getSobotActivity().getResources().getString(R.string.sobot_call_record));
//                            tv_source_number.setOnClickListener(new View.OnClickListener() {
//                                @Override
//                                public void onClick(View v) {
//                                    //跳转到详情页面
//                                    Intent intent = new Intent(getSobotActivity(), CallDetailsActivity.class);
//                                    intent.putExtra("callID", callMainCDRInfo.getSourceId());
//                                    intent.putExtra("defaultIndex", 0);//默认打开位置
//                                    intent.putExtra("hiddenFlag", "0");
//                                    startActivity(intent);
//                                }
//                            });
                        } else if (callMainCDRInfo.getSourceType() == 2) {
                            tv_source_type.setText(getSobotActivity().getResources().getString(R.string.call_str_order));
                        } else if (callMainCDRInfo.getSourceType() == 3) {
                            tv_source_type.setText(getSobotActivity().getResources().getString(R.string.call_str_session_recording));
                        } else if (callMainCDRInfo.getSourceType() == 4) {
                            tv_source_type.setText(getSobotActivity().getResources().getString(R.string.call_out_task));
                        } else if (callMainCDRInfo.getSourceType() == 5) {
                            tv_source_type.setText(getSobotActivity().getResources().getString(R.string.sobot_call_plan));
                        } else if (callMainCDRInfo.getSourceType() == 6) {
                            tv_source_type.setText(getSobotActivity().getResources().getString(R.string.call_str_call_loss_call));
                        } else if (callMainCDRInfo.getSourceType() == 7) {
                            tv_source_type.setText(getSobotActivity().getResources().getString(R.string.call_str_message_number));
                        } else {
                            tv_source_type.setText("- -");
                        }
                        if (!SobotStringUtils.isEmpty(callMainCDRInfo.getSourceCode())) {
                            tv_source_number.setText(callMainCDRInfo.getSourceCode());
                            tv_source_number.setTextColor(getResources().getColor(R.color.sobot_call_theme_color));
                        } else {
                            tv_source_number.setText("- -");
                        }
                    }
                    if (callDetailEntity.getPartyCDRInfoList() != null && callDetailEntity.getPartyCDRInfoList().size() > 0) {
                        //列表
                        rv_agent_call_details.setLayoutManager(new LinearLayoutManager(getSobotActivity()));
                        mAdapter = new CallAgentCallDetailsAdapter(getSobotActivity(), callDetailEntity.getPartyCDRInfoList(), zone);
                        rv_agent_call_details.setAdapter(mAdapter);
                    }
                }
            }

            @Override
            public void onFailure(Exception e, String des) {

            }
        });
    }

    @Override
    public void onClick(View v) {
        if (v == tv_call_record) {
            sv_call_record.setVisibility(View.VISIBLE);
            ll_agent_call_details.setVisibility(View.GONE);
            ll_associated_records.setVisibility(View.GONE);
            tv_call_record.setTextColor(getResources().getColor(R.color.call_wenzi_white_to_white));
            tv_call_record.setBackgroundResource(R.drawable.draw_call_ractangle_theme_bg);
            tv_agent_call_details.setTextColor(getResources().getColor(R.color.call_wenzi_gray2));
            iv_agent_call_details.setImageResource(R.drawable.call_icon_info);
            ll_call_details.setBackgroundResource(R.color.sobot_call_transparent);
            tv_associated_records.setTextColor(getResources().getColor(R.color.call_wenzi_gray2));
            tv_associated_records.setBackgroundResource(R.color.sobot_call_transparent);
        } else if (v == ll_call_details) {
            sv_call_record.setVisibility(View.GONE);
            ll_agent_call_details.setVisibility(View.VISIBLE);
            ll_associated_records.setVisibility(View.GONE);
            tv_call_record.setTextColor(getResources().getColor(R.color.call_wenzi_gray2));
            tv_call_record.setBackgroundResource(R.color.sobot_call_transparent);
            tv_agent_call_details.setTextColor(getResources().getColor(R.color.call_wenzi_white_to_white));
            ll_call_details.setBackgroundResource(R.drawable.draw_call_ractangle_theme_bg);
            iv_agent_call_details.setImageResource(R.drawable.call_icon_info_white);
            tv_associated_records.setTextColor(getResources().getColor(R.color.call_wenzi_gray2));
            tv_associated_records.setBackgroundResource(R.color.sobot_call_transparent);
        } else if (v == tv_associated_records) {
            sv_call_record.setVisibility(View.GONE);
            ll_agent_call_details.setVisibility(View.GONE);
            ll_associated_records.setVisibility(View.VISIBLE);
            tv_call_record.setTextColor(getResources().getColor(R.color.call_wenzi_gray2));
            tv_call_record.setBackgroundResource(R.color.sobot_call_transparent);
            tv_agent_call_details.setTextColor(getResources().getColor(R.color.call_wenzi_gray2));
            iv_agent_call_details.setImageResource(R.drawable.call_icon_info);
            ll_call_details.setBackgroundResource(R.color.sobot_call_transparent);
            tv_associated_records.setTextColor(getResources().getColor(R.color.call_wenzi_white_to_white));
            tv_associated_records.setBackgroundResource(R.drawable.draw_call_ractangle_theme_bg);
        } else if (v == iv_agent_call_details) {
            CallTipDialog tipDialog = new CallTipDialog(getSobotActivity().getResources().getString(R.string.call_str_agent_call_details_title), getSobotActivity().getResources().getString(R.string.call_str_agent_call_details_tip));
            tipDialog.setCancelable(true);
            tipDialog.show(getFragmentManager(), "tipDialog");
        } else if (v == iv_call_id_copy) {
            if (!TextUtils.isEmpty(tv_call_id.getText().toString())) {
                ClipboardManager cmb = (ClipboardManager) getSobotActivity().getApplicationContext().getSystemService(
                        Context.CLIPBOARD_SERVICE);
                cmb.setText(tv_call_id.getText().toString());
                cmb.getText();
                SobotToastUtil.showCustomToast(getSobotActivity(), getSobotActivity().getResources().getString(R.string.sobot_ctrl_v_success));
            }
        } else if (v == iv_customer_no_copy) {
            if (!TextUtils.isEmpty(tv_customer_no.getText().toString())) {
                ClipboardManager cmb = (ClipboardManager) getSobotActivity().getApplicationContext().getSystemService(
                        Context.CLIPBOARD_SERVICE);
                cmb.setText(tv_customer_no.getText().toString());
                cmb.getText();
                SobotToastUtil.showCustomToast(getSobotActivity(), getSobotActivity().getResources().getString(R.string.sobot_ctrl_v_success));
            }
        }

    }

    @Override
    public void onPause() {
        if (AudioTools.getInstance().isPlaying()) {
            //停止播放
            AudioTools.getInstance().pause();

            if (m_voice_time != null) {
                if (callMainCDRInfo != null) {
                    m_voice_time.setText("00:00/" + SobotDateUtils.formatCallTimeDurationTwo(playingRecordingDuration));
                }
            }
            if (m_voice_play != null) {
                m_voice_play.setVisibility(View.VISIBLE);
            }
            if (m_voice_pause != null) {
                m_voice_pause.setVisibility(View.GONE);
            }
            if (m_voice_schedule != null) {
                m_voice_schedule.setProgress(0);
            }
        }
        //放弃音频焦点
        abandonAudioFocus();
        super.onPause();
    }

    //语音相关
    // 听筒模式转换
    public AudioManager audioManager = null; // 声音管理器
    private AudioFocusRequest mFocusRequest;
    private AudioManager.OnAudioFocusChangeListener audioFocusChangeListener;
    private AudioAttributes mAttribute;
    AudioPlayPresenter mAudioPlayPresenter = null;
    AudioPlayCallBack mAudioPlayCallBack = null;

    // 点击播放录音
    public void clickPlayAudio(AudioInfoModel audioInfoModel) {
        if (AudioTools.getInstance().isPlaying()) {
            AudioTools.getInstance().stop();
        }
        abandonAudioFocus();
        initAudioManager();
        requestAudioFocus();
        if (mAudioPlayPresenter == null) {
            mAudioPlayPresenter = new AudioPlayPresenter(getSobotActivity().getApplicationContext());
        }
        if (mAudioPlayCallBack == null) {
            mAudioPlayCallBack = new AudioPlayCallBack() {
                @Override
                public void onPlayStart(AudioInfoModel mCurrentMsg) {
                    if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
                        AudioTools.getInstance().setPlaybackParams(new PlaybackParams().setSpeed(audioInfoModel.getSpeed()));
                    }
                }

                @Override
                public void onPlayEnd(AudioInfoModel mCurrentMsg) {
                    isPauseRecording = false;
                    abandonAudioFocus();
                    if (handler != null && runnable != null) {
                        handler.removeCallbacks(runnable);
                        runnable = null;
                    }
                    if (callMainCDRInfo != null) {
                        m_voice_time.setText("00:00/" + SobotDateUtils.formatCallTimeDurationTwo(mCurrentMsg.getDuration()));
                    }
                    m_voice_schedule.setProgress(0);
                    m_voice_play.setVisibility(View.VISIBLE);
                    m_voice_pause.setVisibility(View.GONE);
                }
            };
        }
        mAudioPlayPresenter.clickAudio(audioInfoModel, mAudioPlayCallBack);
    }

    // 设置听筒模式或者是正常模式的转换
    public void initAudioManager() {
        if (audioManager == null)
            audioManager = (AudioManager) getSobotActivity().getSystemService(Context.AUDIO_SERVICE);
        audioFocusChangeListener = new AudioManager.OnAudioFocusChangeListener() {
            @Override
            public void onAudioFocusChange(int focusChange) {
                switch (focusChange) {
                    case AudioManager.AUDIOFOCUS_GAIN:
                        // TBD 继续播放
                        break;
                    case AudioManager.AUDIOFOCUS_LOSS:
                        // TBD 停止播放
//                        if (AudioTools.getInstance().isPlaying()) {
//                            AudioTools.getInstance().stop();
//                        }
                        break;
                    case AudioManager.AUDIOFOCUS_LOSS_TRANSIENT:
                        // TBD 暂停播放
                        if (handler != null && runnable != null) {
                            handler.removeCallbacks(runnable);
                            runnable = null;
                        }
                        break;
                    case AudioManager.AUDIOFOCUS_LOSS_TRANSIENT_CAN_DUCK:
                        // TBD 混音播放
                        break;
                    default:
                        break;
                }

            }
        };
        //android 版本 5.0
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
            mAttribute = new AudioAttributes.Builder()
                    .setUsage(AudioAttributes.USAGE_MEDIA)
                    .setContentType(AudioAttributes.CONTENT_TYPE_MUSIC)
                    .build();
        }
        //android 版本 8.0
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
            mFocusRequest = new AudioFocusRequest.Builder(AudioManager.AUDIOFOCUS_GAIN_TRANSIENT)
                    .setWillPauseWhenDucked(true)
                    .setAcceptsDelayedFocusGain(true)
                    .setOnAudioFocusChangeListener(audioFocusChangeListener, new Handler())
                    .setAudioAttributes(mAttribute)
                    .build();
        }
    }

    //请求音频焦点
    public void requestAudioFocus() {
        if (Build.VERSION.SDK_INT <= Build.VERSION_CODES.ECLAIR_MR1) {
            return;
        }
        if (audioManager == null)
            audioManager = (AudioManager) getContext().getSystemService(Context.AUDIO_SERVICE);
        if (audioManager != null) {
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
                if (mFocusRequest != null)
                    audioManager.requestAudioFocus(mFocusRequest);
            } else {
                if (audioFocusChangeListener != null)
                    //AUDIOFOCUS_GAIN_TRANSIENT 只是短暂获得，一会就释放焦点
                    audioManager.requestAudioFocus(audioFocusChangeListener, AudioManager.STREAM_MUSIC, AudioManager.AUDIOFOCUS_GAIN_TRANSIENT);
            }
        }

    }

    //放弃音频焦点
    public void abandonAudioFocus() {
        if (Build.VERSION.SDK_INT <= Build.VERSION_CODES.ECLAIR_MR1) {
            return;
        }
        if (audioManager != null) {
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
                if (mFocusRequest != null)
                    audioManager.abandonAudioFocusRequest(mFocusRequest);
            } else {
                if (audioFocusChangeListener != null)
                    audioManager.abandonAudioFocus(audioFocusChangeListener);
            }
            audioManager = null;
        }
    }


}