package com.sobot.callsdk.v6.fragment;

import android.content.Intent;
import android.os.Bundle;
import android.os.Handler;
import android.text.Editable;
import android.text.TextWatcher;
import android.view.KeyEvent;
import android.view.LayoutInflater;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.view.inputmethod.EditorInfo;
import android.widget.EditText;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.sobot.callbase.widget.CallClassicsFooter;
import com.sobot.callsdk.R;
import com.sobot.callsdk.fargment.SobotBaseFragment;
import com.sobot.callsdk.model.SobotCallTaskEntity;
import com.sobot.callsdk.utils.CustomFieldsUtils;
import com.sobot.callsdk.v6.activity.CallTaskDetailsActivity;
import com.sobot.callsdk.v6.adapter.CallTaskV6Adapter;
import com.sobot.common.login.SobotLoginTools;
import com.sobot.common.login.model.SobotServiceInfoModel;
import com.sobot.network.http.callback.SobotResultCallBack;
import com.sobot.utils.SobotDensityUtil;
import com.sobot.utils.SobotStringUtils;
import com.sobot.widget.loading.SobotLoadingLayout;
import com.sobot.widget.refresh.layout.SobotRefreshLayout;
import com.sobot.widget.refresh.layout.api.RefreshLayout;
import com.sobot.widget.refresh.layout.header.ClassicsHeader;
import com.sobot.widget.refresh.layout.listener.OnLoadMoreListener;
import com.sobot.widget.refresh.layout.listener.OnRefreshListener;
import com.sobot.widget.ui.toast.SobotToastUtil;

import java.util.ArrayList;
import java.util.List;

public class CallTaskListV6Fragment extends SobotBaseFragment implements CallTaskV6Adapter.OnItemClickListener, View.OnClickListener {
    //列表
    private int pageNo = 1;
    private int pageSize = 20;
    private SobotRefreshLayout refreshLayout;
    private RecyclerView recyclerView;
    private SobotLoadingLayout loadingLayout;
    private CallTaskV6Adapter mAdapter;
    private List<SobotCallTaskEntity> mDate;
    private boolean isHasMoreData = false;
    private SobotServiceInfoModel serviceVo;
    private LinearLayout ll_search;
    private EditText et_search_input;
    private ImageView iv_clear;
    private ImageView iv_search;
    //输入后0.5s去搜索
    private long inputTime = 0;

    @Override
    public void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
    }

    @Nullable
    @Override
    public View onCreateView(@NonNull LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {
        View view = inflater.inflate(R.layout.sobot_fragment_v6_call_task, container, false);
        initView(view);
        return view;
    }

    private void initView(View view) {
        initListView(view);
    }

    private void initListView(View view) {
        refreshLayout = view.findViewById(R.id.sobot_srl_call);
        recyclerView = view.findViewById(R.id.sobot_rv_call_task);
        loadingLayout = view.findViewById(R.id.sobot_loading_layout);
        //搜索
        ll_search = view.findViewById(R.id.ll_search);
        et_search_input = view.findViewById(R.id.et_search_input);
        iv_clear = view.findViewById(R.id.iv_clear);
        iv_search = view.findViewById(R.id.iv_search);
        iv_clear.setOnClickListener(this);
        iv_search.setOnClickListener(this);
        et_search_input.setOnFocusChangeListener(new View.OnFocusChangeListener() {
            @Override
            public void onFocusChange(View v, boolean hasFocus) {
                if (hasFocus) {
                    CustomFieldsUtils.showKeyboard(getContext(), et_search_input);
                    ll_search.setBackgroundResource(R.drawable.sobot_call_v6_bg_search_f);
                } else {
                    CustomFieldsUtils.hideKeyboard(getContext(), v);
                    ll_search.setBackgroundResource(R.drawable.sobot_call_v6_bg_search);
                }
            }
        });
        et_search_input.setOnEditorActionListener(new TextView.OnEditorActionListener() {
            @Override
            public boolean onEditorAction(TextView textView, int i, KeyEvent keyEvent) {
                if (i == EditorInfo.IME_ACTION_SEARCH) {
                    //搜索
                    pageNo = 1;
                    requestDate(pageNo);
                    return true;
                }
                return false;
            }
        });
        et_search_input.addTextChangedListener(new TextWatcher() {
            @Override
            public void beforeTextChanged(CharSequence s, int start, int count, int after) {

            }

            @Override
            public void onTextChanged(CharSequence s, int start, int before, int count) {

            }

            @Override
            public void afterTextChanged(Editable s) {
                int inputCount = s.length();
                if (inputCount > 0) {
                    iv_clear.setVisibility(View.VISIBLE);
                } else {
                    iv_clear.setVisibility(View.GONE);
                }
                inputTime = System.currentTimeMillis();
                new Handler().postDelayed(new Runnable() {
                    @Override
                    public void run() {
                        pageNo = 1;
                        requestDate(pageNo);
                    }
                }, 500);
            }
        });

        //列表
        recyclerView.setLayoutManager(new LinearLayoutManager(getContext()));
        mDate = new ArrayList<>();
        mAdapter = new CallTaskV6Adapter(getSobotActivity(), mDate, this);
        recyclerView.setAdapter(mAdapter);

        //下拉刷新控件
        recyclerView.setLayoutManager(new LinearLayoutManager(getContext()));
        refreshLayout.setRefreshHeader(new ClassicsHeader(getSobotActivity()));
        refreshLayout.setRefreshFooter(new CallClassicsFooter(getSobotActivity()), SobotDensityUtil.getScreenWidth(getSobotActivity()), SobotDensityUtil.dp2px(getSobotActivity(), 100));
        refreshLayout.setEnableLoadMore(true);
        refreshLayout.setEnableRefresh(true);
        refreshLayout.setEnableAutoLoadMore(true);
        refreshLayout.setEnableFooterFollowWhenNoMoreData(false);
        recyclerView.setOnTouchListener(new View.OnTouchListener() {
            @Override
            public boolean onTouch(View v, MotionEvent event) {
                if (event.getAction() == MotionEvent.ACTION_MOVE) {
                    et_search_input.clearFocus();
                }
                return false;
            }
        });
        refreshLayout.setOnLoadMoreListener(new OnLoadMoreListener() {
            @Override
            public void onLoadMore(@NonNull RefreshLayout refreshLayout) {
                if (isHasMoreData) {
                    requestDate(pageNo + 1);
                } else {
                    refreshLayout.setNoMoreData(true);
                }
            }
        });
        refreshLayout.setOnRefreshListener(new OnRefreshListener() {
            @Override
            public void onRefresh(@NonNull RefreshLayout refreshLayout) {
                pageNo = 1;
                requestDate(pageNo);
            }
        });
        refreshLayout.setNoMoreData(true);
        //没有内容时显示
        loadingLayout.setEmpty(R.layout.sobot_history_no_data);
        //是否显示无内容
        loadingLayout.setRetryListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                pageNo = 1;
                requestDate(pageNo);
            }
        });
        serviceVo = SobotLoginTools.getInstance().getServiceInfo();
        if (serviceVo != null) {
            pageNo = 1;
            requestDate(pageNo);
        }
    }

    private void requestDate(int pageIndex) {
        serviceVo = SobotLoginTools.getInstance().getServiceInfo();
        if (serviceVo == null) {
            isHasMoreData = false;
            loadingLayout.showEmpty();//显示无内容
            refreshLayout.finishLoadMore();
            return;
        }
        String searchText = et_search_input.getText().toString();
        zhiChiApi.getTaskListV6(getSobotActivity(), getContext(), searchText, pageIndex, pageSize, new SobotResultCallBack<List<SobotCallTaskEntity>>() {
            @Override
            public void onSuccess(List<SobotCallTaskEntity> sobotCallTaskModels) {
                refreshLayout.finishRefresh();//停止刷新
                pageNo = pageIndex;
                if (pageIndex == 1) {
                    mDate.clear();//刷新时清空列表
                    if (sobotCallTaskModels == null || sobotCallTaskModels.size() == 0) {
                        isHasMoreData = false;
                        loadingLayout.showEmpty();//显示无内容
                        refreshLayout.setEnableFooterFollowWhenNoMoreData(false);
                        return;
                    } else {
                        if (sobotCallTaskModels.size() > 3) {
                            refreshLayout.setEnableFooterFollowWhenNoMoreData(true);
                        } else {
                            refreshLayout.setEnableFooterFollowWhenNoMoreData(false);
                        }
                    }
                }
                if (sobotCallTaskModels.size() < pageSize) {
                    //加载完毕
                    isHasMoreData = false;
                    refreshLayout.setNoMoreData(true);
                } else {
                    //有 下一页
                    isHasMoreData = true;
                    refreshLayout.setEnableLoadMore(true);
                    refreshLayout.setNoMoreData(false);
                }

                mDate.addAll(sobotCallTaskModels);
                mAdapter.notifyDataSetChanged();
                loadingLayout.showContent();//显示列表
                refreshLayout.finishLoadMore();
            }

            @Override
            public void onFailure(Exception e, String des) {
                refreshLayout.finishLoadMore();
                refreshLayout.finishRefresh();
                if (pageIndex == 1) {
                    loadingLayout.showEmpty();
                } else {
                    SobotToastUtil.showCustomToast(getContext(), SobotStringUtils.isEmpty(des) ? getResources().getString(R.string.sobot_call_net_error_string) : des, R.drawable.sobot_icon_warning_attention);
                }
            }
        });

    }

    @Override
    public void onItemClick(SobotCallTaskEntity taskEntity) {
        if (getActivity() != null && taskEntity != null) {
            String taskId = "", taskName = "";
            int status = 0;
            taskId = taskEntity.getCampaignId();
            taskName = taskEntity.getCampaignName();
            status = taskEntity.getState();
            Intent intent = new Intent(getActivity(), CallTaskDetailsActivity.class);
            intent.putExtra("taskId", taskId);
            intent.putExtra("taskName", taskName);
            intent.putExtra("status", status);
            getActivity().startActivity(intent);
        }
    }

    @Override
    public void onClick(View v) {
        if (v == iv_clear) {
            et_search_input.setText("");
            pageNo = 1;
            requestDate(1);
        } else if (v == iv_search) {
            et_search_input.clearFocus();
            //搜索
            pageNo = 1;
            iv_search.requestFocus();
            requestDate(pageNo);
        }
    }
}
