package com.sobot.callsdk.v6.fragment;

import android.os.Bundle;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.sobot.callbase.model.callinfo.CallMainCDRInfo;
import com.sobot.callbase.utils.CommonUtils;
import com.sobot.callsdk.R;
import com.sobot.callsdk.fargment.SobotBaseFragment;
import com.sobot.callsdk.v6.adapter.CallTaskRecordAdapter;
import com.sobot.callsdk.v6.listener.CallTaskStatusListener;
import com.sobot.network.http.callback.SobotResultCallBack;
import com.sobot.widget.loading.SobotLoadingLayout;
import com.sobot.widget.refresh.layout.SobotRefreshLayout;
import com.sobot.widget.refresh.layout.api.RefreshLayout;
import com.sobot.widget.refresh.layout.header.ClassicsHeader;
import com.sobot.widget.refresh.layout.listener.OnRefreshListener;

import java.util.ArrayList;
import java.util.List;

/**
 * 任务通话记录
 */
public class CallTaskRocordFragment extends SobotBaseFragment {

    private RecyclerView recyclerView;
    private CallTaskRecordAdapter mAdapter;
    private List<CallMainCDRInfo> data;
    private SobotRefreshLayout refreshLayout;
    private SobotLoadingLayout loadingLayout;
    private String campaignId;//任务id
    private String recordId;//任务明细id
    private View mRootView;
    private String zone="";
    private CallTaskStatusListener statusListener;

    public void setStatusListener(CallTaskStatusListener statusListener) {
        this.statusListener = statusListener;
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        zone = CommonUtils.getTimeZone();
    }

    @Override
    public void setArguments(@Nullable Bundle args) {
        super.setArguments(args);
        if(args!=null) {
            campaignId = args.getString("campaignId");
            recordId = args.getString("recordId");
        }
    }
    private void requestDate(){
        if(!TextUtils.isEmpty(campaignId)&& !TextUtils.isEmpty(recordId)&&zhiChiApi !=null) {
            zhiChiApi.taskRecord(getSobotActivity(), campaignId, recordId, new SobotResultCallBack<List<CallMainCDRInfo>>() {
                @Override
                public void onSuccess(List<CallMainCDRInfo> list) {
                    data.clear();
                    if (null == list || list.size() == 0) {
                        loadingLayout.showEmpty();//显示无内容
                        refreshLayout.setEnableFooterFollowWhenNoMoreData(false);
                        return;
                    }else{
                        refreshLayout.setNoMoreData(true);
                        loadingLayout.showContent();//显示列表
                        refreshLayout.finishLoadMore();
                    }
                    data.addAll(list);
                    mAdapter.notifyDataSetChanged();
                }

                @Override
                public void onFailure(Exception e, String des) {
                    loadingLayout.showEmpty();//显示无内容
                    refreshLayout.setEnableFooterFollowWhenNoMoreData(false);
                }
            });
        }
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        mRootView = inflater.inflate(R.layout.fragment_call_task_rocord, container, false);
        initView();
        return mRootView;
    }
    private void initView(){
        //显示历史记录
        recyclerView = mRootView.findViewById(R.id.sobot_rv_history_list);
        refreshLayout = mRootView.findViewById(R.id.sobot_srl_call_record);
        loadingLayout = mRootView.findViewById(R.id.sobot_loading_layout);
        loadingLayout.setEmpty(R.layout.sobot_history_no_data);
        //列表
        recyclerView.setLayoutManager(new LinearLayoutManager(getContext()));
        refreshLayout.setRefreshHeader(new ClassicsHeader(getSobotActivity()));
        refreshLayout.setEnableLoadMore(false);
        refreshLayout.setEnableRefresh(true);
        refreshLayout.setEnableAutoLoadMore(false);
        refreshLayout.setEnableFooterFollowWhenNoMoreData(false);
        data = new ArrayList<>();
        mAdapter = new CallTaskRecordAdapter(getSobotActivity(), data,zone);
        recyclerView.setAdapter(mAdapter);
        refreshLayout.setOnRefreshListener(new OnRefreshListener() {
            @Override
            public void onRefresh(@NonNull  RefreshLayout refreshLayout) {
                requestDate();
            }
        });
        requestDate();
    }
    public void refreshDate(String cId ,String rId){
//        new Handler().post(new Runnable() {
//            @Override
//            public void run() {
                campaignId = cId;
                recordId = rId;
                requestDate();
//            }});
    }
}