package com.sobot.callsdk.activity;

import android.content.res.Configuration;
import android.content.res.Resources;
import android.os.Build;
import android.os.Bundle;
import android.os.LocaleList;
import android.text.TextUtils;
import android.util.DisplayMetrics;
import android.view.View;
import android.widget.PopupWindow;
import android.widget.TextView;

import androidx.annotation.Nullable;

import com.sobot.callbase.model.SobotExplicitRuleEntity;
import com.sobot.callbase.model.SobotOutboundRoutesEntity;
import com.sobot.callsdk.R;
import com.sobot.callsdk.api.SobotCallService;
import com.sobot.callsdk.api.SobotCallServiceFactory;
import com.sobot.callsdk.dialog.OutboundRulesPopDialog;
import com.sobot.callsdk.utils.CallSharedPreferencesUtils;
import com.sobot.callsdk.v6.constant.SobotCallLiveDataBusV6Key;
import com.sobot.common.login.SobotLoginTools;
import com.sobot.common.login.model.SobotServiceInfoModel;
import com.sobot.common.utils.SobotGlobalContext;
import com.sobot.network.http.SobotOkHttpUtils;
import com.sobot.network.http.callback.SobotResultCallBack;
import com.sobot.widget.livedatabus.SobotLiveEventBus;
import com.sobot.widget.ui.base.SobotBaseActivity;

import java.util.Locale;

public abstract class SobotCallBaseActivity extends SobotBaseActivity {
    public SobotCallService zhiChiApi = null;
    public SobotServiceInfoModel serviceVo;

    //外呼规则
    private SobotOutboundRoutesEntity outboundRoutes;
    private PopupWindow popupWindow;


    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        zhiChiApi = getZhiChiApi();
        changeAppLanguage();
        super.onCreate(savedInstanceState);
        SobotGlobalContext.getInstance().addActivity(this);
        if (SobotLoginTools.getInstance().getServiceInfo()==null){
            SobotGlobalContext.getInstance().finishAllActivity();
        }
    }

    //国际化指定语言，放到setContentView()之前
    public void changeAppLanguage() {
        try {
            Locale locale = (Locale) CallSharedPreferencesUtils.getInstance(SobotCallBaseActivity.this).get("SobotLanguage", Locale.class);
            if (locale != null) {
                Resources resources = getResources();
                DisplayMetrics metrics = resources.getDisplayMetrics();
                Configuration configuration = resources.getConfiguration();
                //Android 7.0以上的方法
                if (Build.VERSION.SDK_INT >= 24) {
                    configuration.setLocale(locale);
                    configuration.setLocales(new LocaleList(locale));
                    createConfigurationContext(configuration);
                    //实测，updateConfiguration这个方法虽然很多博主说是版本不适用
                    //但是我的生产环境androidX+Android Q环境下，必须加上这一句，才可以通过重启App来切换语言
                    resources.updateConfiguration(configuration, metrics);

                } else if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN_MR1) {
                    //Android 4.1 以上方法
                    configuration.setLocale(locale);
                    resources.updateConfiguration(configuration, metrics);
                } else {
                    configuration.locale = locale;
                    resources.updateConfiguration(configuration, metrics);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public SobotCallService getZhiChiApi() {
        if (zhiChiApi == null) {
            synchronized (SobotCallBaseActivity.class) {
                if (zhiChiApi == null) {
                    zhiChiApi = SobotCallServiceFactory.createZhiChiApi(getSobotBaseContext());
                }
            }
        }
        return zhiChiApi;
    }

    public boolean isCallV6() {
        boolean isCallV6 = false;
        SobotServiceInfoModel serviceVoModel = SobotLoginTools.getInstance().getServiceInfo();
        if (serviceVoModel != null && serviceVoModel.getCallV6Flag() == 1) {
            isCallV6 = true;
        }
        return isCallV6;
    }

    public boolean isHidePhone() {
        boolean hideFlag = false;
        SobotServiceInfoModel serviceVoModel = SobotLoginTools.getInstance().getServiceInfo();
        if (serviceVoModel != null && serviceVoModel.isHideFlag()) {
            hideFlag = true;
        }
        return hideFlag;
    }

    @Override
    protected void onLeftMenuClick(View view) {
        finish();
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        SobotOkHttpUtils.getInstance().cancelTag(this);
        SobotGlobalContext.getInstance().removeActivity(this);
    }


    //获取外呼规则
    public void getOutboudRoutesRules(boolean isShowDialog, View ll_waixian, TextView tv_mobile) {
        serviceVo = SobotLoginTools.getInstance().getServiceInfo();
        if (serviceVo == null) return;
        if (tv_mobile == null) return;
        if (ll_waixian == null) return;
        zhiChiApi.queryOutBoudRoutesRules(this, serviceVo.getServiceId(), new SobotResultCallBack<SobotOutboundRoutesEntity>() {
            @Override
            public void onSuccess(SobotOutboundRoutesEntity o) {
                outboundRoutes = o;
                if (outboundRoutes != null) {
                    if (null != outboundRoutes.getExplicitRule() && outboundRoutes.getExplicitRule().size() > 0) {
                        //坐席号码池
                        String text = "";
                        for (int i = 0; i < outboundRoutes.getExplicitRule().size(); i++) {
                            if (outboundRoutes.getExplicitRule().get(i).isHasSet()) {
                                if ("1".equals(outboundRoutes.getExplicitRule().get(i).getCode())) {
                                    text = outboundRoutes.getExplicitRule().get(i).getName();
                                } else if ("2".equals(outboundRoutes.getExplicitRule().get(i).getCode())) {
                                    if (null != outboundRoutes.getExplicitSchema() && outboundRoutes.getExplicitSchema().size() > 0) {
                                        //外显方案
                                        for (int j = 0; j < outboundRoutes.getExplicitSchema().size(); j++) {
                                            if (outboundRoutes.getExplicitSchema().get(j).isHasSet()) {
                                                text = outboundRoutes.getExplicitSchema().get(j).getPlanName();
                                            }
                                        }
                                    }
                                } else if ("3".equals(outboundRoutes.getExplicitRule().get(i).getCode())) {
                                    if (null != outboundRoutes.getExplicitNumbers() && outboundRoutes.getExplicitNumbers().size() > 0) {
                                        //外显号
                                        for (int j = 0; j < outboundRoutes.getExplicitNumbers().size(); j++) {
                                            if (outboundRoutes.getExplicitNumbers().get(j).isHasSet()) {
                                                text = outboundRoutes.getExplicitNumbers().get(j).getNumber();
                                                if (!TextUtils.isEmpty(outboundRoutes.getExplicitNumbers().get(j).getNickName())) {
                                                    text = outboundRoutes.getExplicitNumbers().get(j).getNumber() + "(" + outboundRoutes.getExplicitNumbers().get(j).getNickName() + ")";
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                        tv_mobile.setText(TextUtils.isEmpty(text) ? getResources().getString(R.string.call_select_hint) : text);
                        if (isShowDialog) {
                            showRulesDialog(ll_waixian, tv_mobile);
                        }
                    } else {
                        tv_mobile.setText(getResources().getString(R.string.call_select_hint));
                        if (isShowDialog) {
                            showRulesDialog(ll_waixian, tv_mobile);
                        }
                    }
                } else {
                    tv_mobile.setText(getResources().getString(R.string.call_select_hint));
                    if (isShowDialog) {
                        outboundRoutes = new SobotOutboundRoutesEntity();
                        showRulesDialog(ll_waixian, tv_mobile);
                    }
                }
            }

            @Override
            public void onFailure(Exception e, String des) {
            }
        });
    }

    public void showRulesDialog(View ll_waixian, TextView tv_mobile) {
        if (tv_mobile == null) return;
        if (ll_waixian == null) return;
        if (outboundRoutes != null) {
            OutboundRulesPopDialog dialog = new OutboundRulesPopDialog(SobotCallBaseActivity.this, outboundRoutes, new OutboundRulesPopDialog.PopItemClick() {

                @Override
                public void onPopItemClick(SobotOutboundRoutesEntity item, SobotExplicitRuleEntity leftRule, SobotExplicitRuleEntity rightRule) {
                    outboundRoutes = item;
                    String text = leftRule.getName();
                    if (null != rightRule) {
                        if (!TextUtils.isEmpty(rightRule.getNumber())) {
                            text = rightRule.getNumber();
                        }
                        if (!TextUtils.isEmpty(rightRule.getCode())) {
                            text = rightRule.getPlanName();
                        }
                        if (Integer.parseInt(leftRule.getCode()) > 0) {
                            changeOutboudRoutesRules(leftRule.getCode(), rightRule.getCode(), rightRule.getNumber(), ll_waixian, tv_mobile);
                        }
                    } else {
                        //设置外显号
                        if (Integer.parseInt(leftRule.getCode()) > 0) {
                            changeOutboudRoutesRules(leftRule.getCode(), "", "", ll_waixian, tv_mobile);
                        }
                    }
                    tv_mobile.setText(text);
                    if (popupWindow != null)
                        popupWindow.dismiss();
                }
            });
            popupWindow = dialog.getPopWindow();
            popupWindow.showAsDropDown(ll_waixian, 0, 0);
        }
    }

    /**
     * 切换座席的外呼外显规则
     *
     * @param explicitRule   外显规则:1：企业号码池随机匹配；2：动态外显号码方案匹配；3：座席号码池指定；单选；
     * @param explicitCode   动态外显方案编码: 外显规则为动态外显号码方案时必传
     * @param explicitNumber 外显号码:不使用外显规则，直接指定企业的某外显号码呼叫客户，外显号码和外显规则至少需要传一个
     */
    public void changeOutboudRoutesRules(String explicitRule, String explicitCode, String explicitNumber, View ll_waixian, TextView tv_mobile) {
        if (ll_waixian == null) return;
        serviceVo = SobotLoginTools.getInstance().getServiceInfo();
        if (serviceVo == null) return;
        zhiChiApi.switchOutBoudRoutesRules(SobotCallBaseActivity.this, serviceVo.getServiceId(), explicitRule, explicitCode, explicitNumber, new SobotResultCallBack<SobotOutboundRoutesEntity>() {
            @Override
            public void onSuccess(SobotOutboundRoutesEntity outboundRoutesEntity) {
                getOutboudRoutesRules(false, ll_waixian, tv_mobile);
                SobotLiveEventBus.get(SobotCallLiveDataBusV6Key.SOBOT_CALL_CHANGE_RULES).post(true);
            }

            @Override
            public void onFailure(Exception e, String des) {
            }
        });
    }
}
