package com.sobot.callsdk.api;

import android.content.Context;

import com.sobot.callbase.api.utils.CallBaseSharedPreferencesUtils;
import com.sobot.callbase.constant.SobotCallBaseConstant;
import com.sobot.common.login.SobotLoginTools;
import com.sobot.gson.SobotGsonUtil;
import com.sobot.network.http.SobotOkHttpUtils;
import com.sobot.network.http.callback.StringCallback;
import com.sobot.network.http.log.SobotNetLogUtils;

import org.json.JSONObject;

import java.io.File;
import java.util.Map;

import okhttp3.Call;
import okhttp3.MediaType;

public class SobotCallHttpUtils {
    private static SobotCallHttpUtils client = null;

    String VERSION = "3.0.2";

    String SOBOT_FROM = "2";// 用户来源1.web 2.android 3.ios

    private SobotCallHttpUtils() {
    }

    public static SobotCallHttpUtils getInstance() {
        if (client == null) {
            client = new SobotCallHttpUtils();
        }
        return client;
    }

    private static String getTokenId(Context context) {
        String token = SobotLoginTools.getInstance().getToken();
//        String token = CallSharedPreferencesUtils.getInstance(context).get(SobotCallConstant.SOBOT_KEY_TOKEN, "");
        return token;
    }

    private static String getLanguage(Context context) {
        String languageStr = CallBaseSharedPreferencesUtils.getInstance(context).get("SobotLanguageStr", "");
        return languageStr;
    }

    private static String getAccessToken(Context context) {
        String token = "Bearer " + SobotLoginTools.getInstance().getAccessToken();
        return token;
    }

    public void doPost(Object cancelTag, Context context, String url_str, final Map<String, Object> map,
                       final StringCallBack callback) {
        if (url_str.contains("/basic-set/") || url_str.contains("/call-data/") || url_str.contains("/basic/") || url_str.contains("/call-report/") || url_str.contains("/callservice/")) {
            url_str = url_str.replace("/text", "");
        }
        if (url_str.contains("/basic-set/") || url_str.contains("/call-data/") || url_str.contains("/basic/") || url_str.contains("/call-report/")) {
            url_str = url_str.replace("api-c.", "www.");
        }
        SobotNetLogUtils.i("请求URL: --> " + url_str);
        SobotNetLogUtils.i("请求参数: --> " + map);
        SobotNetLogUtils.i("请求token: --> " + getTokenId(context));
        SobotNetLogUtils.i("请求language: --> " + getLanguage(context));
        SobotNetLogUtils.i("请求accessToken: --> " + getAccessToken(context));
        SobotNetLogUtils.i("请求language: --> " + getLanguage(context));
        String finalUrl_str = url_str;
        SobotOkHttpUtils
                .post()
                .tag(cancelTag)
                .url(url_str)
                .params(map)
                .addHeader(SobotCallBaseConstant.SOBOT_AUTHORIZATION, getAccessToken(context))
                .addHeader(SobotCallBaseConstant.SOBOT_IDEMPOTENCY_KEY, System.currentTimeMillis() + "")
                .addHeader(SobotCallBaseConstant.KEY_TEMP_ID, getTokenId(context))
                .addHeader("language", getLanguage(context))
                .addHeader("from", SOBOT_FROM)
                .addHeader("version", VERSION)
                .build()
                .readTimeOut(8 * 1000)
                .writeTimeOut(8 * 1000)
                .connTimeOut(8 * 1000).execute(new StringCallback() {

                    @Override
                    public void onResponse(String response) {
                        SobotNetLogUtils.i(finalUrl_str + "----请求返回结果: --> " + response);
                        callback.onResponse(response);

                    }

                    @Override
                    public void onError(Call call, Exception e) {
                        SobotNetLogUtils.i(call.toString());
                        e.printStackTrace();
                        callback.onError(e, call.toString(), -1);
                    }
                });
    }

    public void doPut(Object cancelTag, Context context, String url_str, final Map<String, String> map,
                      final StringCallBack callback) {
        if (url_str.contains("/basic-set/") || url_str.contains("/call-data/") || url_str.contains("/basic/") || url_str.contains("/call-report/") || url_str.contains("/callservice/")) {
            url_str = url_str.replace("/text", "");
        }
        if (url_str.contains("/basic-set/") || url_str.contains("/call-data/") || url_str.contains("/basic/") || url_str.contains("/call-report/")) {
            url_str = url_str.replace("api-c.", "www.");
        }
        SobotNetLogUtils.i("请求URL: --> " + url_str);
        SobotNetLogUtils.i("请求token: --> " + getTokenId(context));
        SobotNetLogUtils.i("请求language: --> " + getLanguage(context));
        SobotNetLogUtils.i("请求accessToken: --> " + getAccessToken(context));
        String content = SobotGsonUtil.beanToJson(map);
        SobotNetLogUtils.i("请求参数: --> " + content);
        String finalUrl_str = url_str;
        SobotOkHttpUtils
                .put()
                .tag(cancelTag)
                .url(url_str)
                .requestBody(content)
                .addHeader(SobotCallBaseConstant.SOBOT_AUTHORIZATION, getAccessToken(context))
                .addHeader(SobotCallBaseConstant.SOBOT_IDEMPOTENCY_KEY, System.currentTimeMillis() + "")
                .addHeader(SobotCallBaseConstant.KEY_TEMP_ID, getTokenId(context))
                .addHeader("language", getLanguage(context))
                .addHeader("from", SOBOT_FROM)
                .addHeader("version", VERSION)
                .build()
                .readTimeOut(8 * 1000)
                .writeTimeOut(8 * 1000)
                .connTimeOut(8 * 1000).execute(new StringCallback() {

                    @Override
                    public void onResponse(String response) {
                        SobotNetLogUtils.i(finalUrl_str + "----请求返回结果: --> " + response);
                        callback.onResponse(response);

                    }

                    @Override
                    public void onError(Call call, Exception e) {
                        SobotNetLogUtils.i(call.toString());
                        e.printStackTrace();
                        callback.onError(e, call.toString(), -1);
                    }
                });
    }

    public void doPatch(Object cancelTag, Context context, String url_str, final String content,
                        final StringCallBack callback) {
        if (url_str.contains("/basic-set/") || url_str.contains("/call-data/") || url_str.contains("/basic/") || url_str.contains("/call-report/") || url_str.contains("/callservice/")) {
            url_str = url_str.replace("/text", "");
        }
        if (url_str.contains("/basic-set/") || url_str.contains("/call-data/") || url_str.contains("/basic/") || url_str.contains("/call-report/")) {
            url_str = url_str.replace("api-c.", "www.");
        }
        SobotNetLogUtils.i("请求URL: --> " + url_str);
        SobotNetLogUtils.i("请求token: --> " + getTokenId(context));
        SobotNetLogUtils.i("请求language: --> " + getLanguage(context));
        SobotNetLogUtils.i("请求accessToken: --> " + getAccessToken(context));
//        String content = SobotGsonUtil.beanToJson(map);
        SobotNetLogUtils.i("请求参数: --> " + content);
        String finalUrl_str = url_str;
        SobotOkHttpUtils
                .patch()
                .tag(cancelTag)
                .url(url_str)
                .requestBody(content)
                .addHeader(SobotCallBaseConstant.SOBOT_AUTHORIZATION, getAccessToken(context))
                .addHeader(SobotCallBaseConstant.SOBOT_IDEMPOTENCY_KEY, System.currentTimeMillis() + "")
                .addHeader(SobotCallBaseConstant.KEY_TEMP_ID, getTokenId(context))
                .addHeader("language", getLanguage(context))
                .addHeader("from", SOBOT_FROM)
                .addHeader("version", VERSION)
                .mediaType(MediaType.parse("application/json; charset=utf-8"))
                .build()
                .readTimeOut(8 * 1000)
                .writeTimeOut(8 * 1000)
                .connTimeOut(8 * 1000).execute(new StringCallback() {

                    @Override
                    public void onResponse(String response) {
                        SobotNetLogUtils.i(finalUrl_str + "----请求返回结果: --> " + response);
                        callback.onResponse(response);

                    }

                    @Override
                    public void onError(Call call, Exception e) {
                        SobotNetLogUtils.i(call.toString());
                        e.printStackTrace();
                        callback.onError(e, call.toString(), -1);
                    }
                });
    }

    public void doPostByJson(Object cancelTag, Context context, String url_str, Map<String, Object> paramMap,
                             final StringCallBack callback) {
        if (url_str.contains("/basic-set/") || url_str.contains("/call-data/") || url_str.contains("/basic/") || url_str.contains("/call-report/") || url_str.contains("/callservice/")) {
            url_str = url_str.replace("/text", "");
        }
        if (url_str.contains("/basic-set/") || url_str.contains("/call-data/") || url_str.contains("/basic/") || url_str.contains("/call-report/")) {
            url_str = url_str.replace("api-c.", "www.");
        }
        SobotNetLogUtils.i("请求URL: --> " + url_str);
        SobotNetLogUtils.i("请求参数: --> " + paramMap);
        SobotNetLogUtils.i("请求language: --> " + getLanguage(context));
        SobotNetLogUtils.i("请求temp-id: --> " + getTokenId(context));
        SobotNetLogUtils.i("请求accessToken: --> " + getAccessToken(context));
        String finalUrl_str = url_str;
        SobotOkHttpUtils
                .postString()
                .tag(cancelTag)
                .url(url_str)
                .addHeader(SobotCallBaseConstant.SOBOT_AUTHORIZATION, getAccessToken(context))
                .addHeader(SobotCallBaseConstant.SOBOT_IDEMPOTENCY_KEY, System.currentTimeMillis() + "")
                .addHeader(SobotCallBaseConstant.KEY_TEMP_ID, getTokenId(context))
                .addHeader("language", getLanguage(context))
                .addHeader("from", SOBOT_FROM)
                .addHeader("version", VERSION)
                .mediaType(MediaType.get("application/json"))
                .content(map2Json(paramMap))
                .build()
                .readTimeOut(8 * 1000)
                .writeTimeOut(8 * 1000)
                .connTimeOut(8 * 1000).execute(new StringCallback() {

                    @Override
                    public void onResponse(String response) {
                        SobotNetLogUtils.i(finalUrl_str + "----请求返回结果: --> " + response);
                        callback.onResponse(response);

                    }

                    @Override
                    public void onError(Call call, Exception e) {
                        SobotNetLogUtils.i(call.toString());
                        e.printStackTrace();
                        callback.onError(e, call.toString(), -1);
                    }
                });
    }

    public void doPostWithHeader(Object cancelTag, String url_str, final Map<String, String> headerMap, final Map<String, Object> map,
                                 final StringCallBack callback) {
        if (url_str.contains("/basic-set/") || url_str.contains("/call-data/") || url_str.contains("/basic/") || url_str.contains("/call-report/") || url_str.contains("/callservice/")) {
            url_str = url_str.replace("/text", "");
        }
        if (url_str.contains("/basic-set/") || url_str.contains("/call-data/") || url_str.contains("/basic/") || url_str.contains("/call-report/")) {
            url_str = url_str.replace("api-c.", "www.");
        }
        SobotNetLogUtils.i("请求URL: --> " + url_str);
        SobotNetLogUtils.i("请求参数: --> " + map);
        String finalUrl_str = url_str;
        SobotOkHttpUtils
                .post()
                .tag(cancelTag)
                .url(url_str)
                .params(map)
                .headers(headerMap)
                .addHeader("from", SOBOT_FROM)
                .addHeader("version", VERSION)
                .build()
                .readTimeOut(8 * 1000)
                .writeTimeOut(8 * 1000)
                .connTimeOut(8 * 1000).execute(new StringCallback() {

                    @Override
                    public void onResponse(String response) {
                        SobotNetLogUtils.i(finalUrl_str + "----请求返回结果: --> " + response);
                        callback.onResponse(response);

                    }

                    @Override
                    public void onError(Call call, Exception e) {
                        SobotNetLogUtils.i(call.toString());
                        e.printStackTrace();
                        callback.onError(e, call.toString(), -1);
                    }
                });
    }


    public void doGet(Object cancelTag, Context context, String url_str, final Map<String, Object> map,
                      final StringCallBack callback) {
        if (url_str.contains("/basic-set/") || url_str.contains("/call-data/") || url_str.contains("/basic/") || url_str.contains("/call-report/") || url_str.contains("/callservice/")) {
            url_str = url_str.replace("/text", "");
        }
        if (url_str.contains("/basic-set/") || url_str.contains("/call-data/") || url_str.contains("/basic/") || url_str.contains("/call-report/")) {
            url_str = url_str.replace("api-c.", "www.");
        }
        SobotNetLogUtils.i("请求URL: --> " + url_str);
        SobotNetLogUtils.i("请求参数: --> " + map);
        SobotNetLogUtils.i("请求token: --> " + getTokenId(context));
        SobotNetLogUtils.i("请求language: --> " + getLanguage(context));
        SobotNetLogUtils.i("请求accessToken: --> " + getAccessToken(context));
        String finalUrl_str = url_str;
        SobotOkHttpUtils
                .get()
                .tag(cancelTag)
                .url(url_str)
                .params(map)
                .addHeader(SobotCallBaseConstant.SOBOT_AUTHORIZATION, getAccessToken(context))
                .addHeader(SobotCallBaseConstant.SOBOT_IDEMPOTENCY_KEY, System.currentTimeMillis() + "")
                .addHeader(SobotCallBaseConstant.KEY_TEMP_ID, getTokenId(context))
                .addHeader("language", getLanguage(context))
                .addHeader("from", SOBOT_FROM)
                .addHeader("version", VERSION)
                .build()
                .readTimeOut(20 * 1000)
                .writeTimeOut(20 * 1000)
                .connTimeOut(20 * 1000).execute(new StringCallback() {

                    @Override
                    public void onResponse(String response) {
                        SobotNetLogUtils.i(finalUrl_str + "----请求返回结果: --> " + response);
                        callback.onResponse(response);

                    }

                    @Override
                    public void onError(Call call, Exception e) {
                        SobotNetLogUtils.i(call.toString());
                        e.printStackTrace();
                        callback.onError(e, call.toString(), -1);
                    }


                });
    }

    public void doGetByJson(Object cancelTag, Context context, String url_str, final Map<String, Object> map,
                            final StringCallBack callback) {
        if (url_str.contains("/basic-set/") || url_str.contains("/call-data/") || url_str.contains("/basic/") || url_str.contains("/call-report/") || url_str.contains("/callservice/")) {
            url_str = url_str.replace("/text", "");
        }
        if (url_str.contains("/basic-set/") || url_str.contains("/call-data/") || url_str.contains("/basic/") || url_str.contains("/call-report/")) {
            url_str = url_str.replace("api-c.", "www.");
        }
        SobotNetLogUtils.i("请求URL: --> " + url_str);
        SobotNetLogUtils.i("请求参数: --> " + map);
        SobotNetLogUtils.i("请求language: --> " + getLanguage(context));
        SobotNetLogUtils.i("请求token: --> " + getTokenId(context));
        SobotNetLogUtils.i("请求accessToken: --> " + getAccessToken(context));
        String finalUrl_str = url_str;
        SobotOkHttpUtils
                .get()
                .tag(cancelTag)
                .url(url_str)
                .params(map)
                .addHeader(SobotCallBaseConstant.SOBOT_AUTHORIZATION, getAccessToken(context))
                .addHeader(SobotCallBaseConstant.SOBOT_IDEMPOTENCY_KEY, System.currentTimeMillis() + "")
                .addHeader(SobotCallBaseConstant.KEY_TEMP_ID, getTokenId(context))
                .addHeader("language", getLanguage(context))
                .addHeader("from", SOBOT_FROM)
                .addHeader("version", VERSION)
                .build()
                .readTimeOut(20 * 1000)
                .writeTimeOut(20 * 1000)
                .connTimeOut(20 * 1000).execute(new StringCallback() {

                    @Override
                    public void onResponse(String response) {
                        SobotNetLogUtils.i(finalUrl_str + "----请求返回结果: --> " + response);
                        callback.onResponse(response);

                    }

                    @Override
                    public void onError(Call call, Exception e) {
                        SobotNetLogUtils.i(call.toString());
                        e.printStackTrace();
                        callback.onError(e, call.toString(), -1);
                    }


                });
    }

    public void download(Context context, String url_str, File file, Map<String, String> map,
                         final FileCallBack callback) {
        SobotNetLogUtils.i("下载地址：" + url_str);
        SobotNetLogUtils.i("请求language: --> " + getLanguage(context));
        SobotOkHttpUtils
                .get()
                .url(url_str)
                .addHeader(SobotCallBaseConstant.SOBOT_AUTHORIZATION, getAccessToken(context))
                .addHeader(SobotCallBaseConstant.SOBOT_IDEMPOTENCY_KEY, System.currentTimeMillis() + "")
                .addHeader(SobotCallBaseConstant.KEY_TEMP_ID, getTokenId(context))
                .addHeader("language", getLanguage(context))
                .addHeader("from", SOBOT_FROM)
                .addHeader("version", VERSION)
                .build()
                .connTimeOut(1000 * 30)
                .readTimeOut(1000 * 30)
                .writeTimeOut(1000 * 30)
                .execute(new com.sobot.network.http.callback.FileCallBack(file.getAbsolutePath()) {

                    @Override
                    public void onError(Call call, Exception e) {
                        callback.onError(e, call.toString(), -1);
                    }

                    @Override
                    public void onResponse(File file) {
                        callback.onResponse(file);
                    }

                    @Override
                    public void inProgress(float progress, long total) {
                        callback.inProgress((int) (progress * 100));
                    }
                });

    }


    public interface StringCallBack {
        void onResponse(String result);

        void onError(Exception e, String msg, int responseCode);

        void inProgress(int progress);
    }

    public interface FileCallBack {
        void onResponse(File result);

        void onError(Exception e, String msg, int responseCode);

        void inProgress(int progress);
    }

    public static String map2Json(Map<String, Object> map) {
        if (map != null && map.size() > 0) {
            JSONObject a = new JSONObject(map);
            return a.toString();
        }
        return "";
    }
}
