package com.sobot.callsdk.api;

import static com.sobot.callbase.utils.CommonUtils.getShortToken;
import static com.sobot.callbase.utils.CommonUtils.getShortUrl;

import android.app.Activity;
import android.app.Service;
import android.content.Context;
import android.content.Intent;
import android.text.TextUtils;

import androidx.localbroadcastmanager.content.LocalBroadcastManager;

import com.sobot.callbase.api.SobotCallBaseCode;
import com.sobot.callbase.api.SobotCallBaseCodeFourth;
import com.sobot.callbase.api.SobotCallBaseCodeThird;
import com.sobot.callbase.api.SobotCallBaseListCode;
import com.sobot.callbase.api.SobotCallBaseListCodeSecond;
import com.sobot.callbase.api.SobotCallBaseResult;
import com.sobot.callbase.api.SobotCallBaseUrl;
import com.sobot.callbase.api.SobotStringResultCallBack;
import com.sobot.callbase.model.CallNumberCity;
import com.sobot.callbase.model.CallSipModel;
import com.sobot.callbase.model.CallTaskContactModel;
import com.sobot.callbase.model.CallTaskDetailsModel;
import com.sobot.callbase.model.CanSubmitSummaryModel;
import com.sobot.callbase.model.EnterPriseModel;
import com.sobot.callbase.model.QueueAgentCheckin;
import com.sobot.callbase.model.SobotAgentInfoEntity;
import com.sobot.callbase.model.SobotBusyStatusEntity;
import com.sobot.callbase.model.SobotCallListSecondEntity;
import com.sobot.callbase.model.SobotCallStatusEntity;
import com.sobot.callbase.model.SobotCountryRegion;
import com.sobot.callbase.model.SobotCusFieldEntity;
import com.sobot.callbase.model.SobotExtEntity;
import com.sobot.callbase.model.SobotExtensionEntity;
import com.sobot.callbase.model.SobotLoginBindEntity;
import com.sobot.callbase.model.SobotLoginStatusEntity;
import com.sobot.callbase.model.SobotOutboundRoutesEntity;
import com.sobot.callbase.model.SobotSummaryClassifies;
import com.sobot.callbase.model.SobotSummaryConfig;
import com.sobot.callbase.model.SobotSummaryEntity;
import com.sobot.callbase.model.SobotSummaryProgress;
import com.sobot.callbase.model.SobotSummaryTemplate;
import com.sobot.callbase.model.SobotSummaryTemplateList;
import com.sobot.callbase.model.callinfo.CallDetailEntity;
import com.sobot.callbase.model.callinfo.CallMainCDRInfo;
import com.sobot.callbase.model.placename.AreaModel;
import com.sobot.callbase.model.placename.CityModel;
import com.sobot.callbase.model.placename.CountryModel;
import com.sobot.callbase.model.placename.ProvinceModel;
import com.sobot.callsdk.R;
import com.sobot.callsdk.model.SobotAgentEntity;
import com.sobot.callsdk.model.SobotCall3Response;
import com.sobot.callsdk.model.SobotCallCenterStatus;
import com.sobot.callsdk.model.SobotCallCustomerModel;
import com.sobot.callsdk.model.SobotCallListEntity;
import com.sobot.callsdk.model.SobotCallPageEntity;
import com.sobot.callsdk.model.SobotCallRecordDetailEntity;
import com.sobot.callsdk.model.SobotCallRecordEntity;
import com.sobot.callsdk.model.SobotCallTaskEntity;
import com.sobot.callsdk.utils.CallSharedPreferencesUtils;
import com.sobot.callsdk.utils.SobotCallConstant;
import com.sobot.callsdk.v1.entity.SobotOutCallResult;
import com.sobot.callsdk.v1.entity.v1.SobotCallContactPlan;
import com.sobot.callsdk.v1.entity.v1.SobotCallRecordV1;
import com.sobot.callsdk.v1.entity.v1.SobotCallSeatCurrentStatus;
import com.sobot.callsdk.v1.entity.v1.SobotCallTaskDetailsModel;
import com.sobot.callsdk.v1.entity.v1.SobotCallTaskModel;
import com.sobot.callsdk.v1.entity.v1.SobotWorkOrderUser;
import com.sobot.common.login.SobotLoginTools;
import com.sobot.common.utils.SobotResourceUtils;
import com.sobot.gson.SobotGsonUtil;
import com.sobot.gson.reflect.TypeToken;
import com.sobot.network.apiUtils.SobotHttpGlobalContext;
import com.sobot.network.http.callback.SobotResultCallBack;
import com.sobot.network.http.log.SobotNetLogUtils;
import com.sobot.utils.SobotLogUtils;
import com.sobot.utils.SobotStringUtils;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 接口类实现
 */
public class SobotCallImplService implements SobotCallService {

    private Context mContext;

    private SobotCallImplService() {
    }

    public SobotCallImplService(Context context) {
        this.mContext = context;
    }
    @Override
    public void getAccessToken(Object cancelTag, String token, SobotResultCallBack<Object> resultCallBack) {
        Map<String, String> headerMap = new HashMap<>();
        headerMap.put("temp-id", token);
        String url = (SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_get_access_token).replace("/text/", "/");
        SobotCallHttpUtils.getInstance().doPostWithHeader(cancelTag, url, headerMap, null,
                new SobotCallHttpUtils.StringCallBack() {

                    @Override
                    public void onError(Exception e, String msg, int responseCode) {
                        if (!checkErrorMessage(url, headerMap, e.getMessage())) {
                            SobotNetLogUtils.i(SobotCallUrlApi.api_get_access_token + "  请求异常: " + e.getMessage());
                            resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                        }
                    }

                    @Override
                    public void onResponse(String response) {
                        if (!TextUtils.isEmpty(response))
                            resultCallBack.onSuccess(response);
                    }

                    @Override
                    public void inProgress(int progress) {
                    }
                });
    }

    @Override
    public void getCallServiceStatus(Object tag, Context context, SobotResultCallBack<SobotCall3Response<SobotCallCenterStatus>> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("dictCode", "1028");//taskId
        map.put("modelFlag", "2");
        SobotCallHttpUtils.getInstance().doGet(tag, context, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_get_call_service_status_v1, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(tag, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_get_call_service_status_v1, map, response, resultCallBack)) {
                    SobotCall3Response<SobotCallCenterStatus> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCall3Response<SobotCallCenterStatus>>() {
                    }.getType());
                    resultCallBack.onSuccess(result);
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_get_call_service_status_v1, map, e.getMessage())) {
                    SobotNetLogUtils.i(SobotCallUrlApi.api_get_call_service_status_v1 + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void appGetAgentStatus(Context context, SobotResultCallBack<SobotCallSeatCurrentStatus> resultCallBack) {
        String token = SobotLoginTools.getInstance().getToken();
        //如果token 为空，不请求
        if (TextUtils.isEmpty(token)) {
            return;
        }
        SobotCallHttpUtils.getInstance().doPost(context, context, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_get_agent_status_v1, null, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_get_agent_status_v1, null, response, resultCallBack)) {
                    SobotCallBaseCodeThird<SobotCallSeatCurrentStatus> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCodeThird<SobotCallSeatCurrentStatus>>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        resultCallBack.onSuccess(result.getItem());
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_get_agent_status_v1, null, e.getMessage())) {
                    SobotNetLogUtils.i(SobotCallUrlApi.api_get_agent_status_v1 + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void getAppUserListByCallNum(Object tag, Context context, String tel, SobotResultCallBack<List<SobotWorkOrderUser>> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("tel", tel);
        SobotCallHttpUtils.getInstance().doGet(tag, context, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.getAppUserList, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(tag, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.getAppUserList, map, response, resultCallBack)) {
                    SobotCallBaseCode<SobotCallBaseCodeThird<SobotWorkOrderUser>> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCode<SobotCallBaseCodeThird<SobotWorkOrderUser>>>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getCode()) && SobotCallConstant.RESULT_SUCCESS_CODE2.equals(result.getCode()) && result.getData() != null) {
                        resultCallBack.onSuccess(result.getData().getItems());
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.getAppUserList, map, e.getMessage())) {
                    SobotNetLogUtils.i(SobotCallUrlApi.api_get_agent_status_v1 + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void appSetAgentStatus(Object tag, Context context, String agentStatus, SobotResultCallBack<SobotCallBaseCode> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("agentStatus", agentStatus);//座席状态
        SobotCallHttpUtils.getInstance().doPost("SOBOT_TAG_GET_CALL_STATUS", context, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_app_set_agent_status_v1, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(tag, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_app_set_agent_status_v1, map, response, resultCallBack)) {
                    SobotCallBaseCode result = SobotGsonUtil.jsonToBean(response, SobotCallBaseCode.class);
                    if (result != null) {
                        resultCallBack.onSuccess(result);
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_app_set_agent_status_v1, map, e.getMessage())) {
                    SobotNetLogUtils.i(SobotCallUrlApi.api_app_set_agent_status_v1 + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void appAgentLogout(Object tag, Context context, int model, String number, SobotResultCallBack<SobotCallBaseCode> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("callWay", model + "");
        SobotCallHttpUtils.getInstance().doPost(tag, context, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_app_agent_logout_v1, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(tag, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_app_agent_logout_v1, map, response, resultCallBack)) {
                    SobotCallBaseCode result = SobotGsonUtil.jsonToBean(response, SobotCallBaseCode.class);
                    if (result != null) {
                        resultCallBack.onSuccess(result);
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_app_agent_logout_v1, map, e.getMessage())) {
                    SobotNetLogUtils.i(SobotCallUrlApi.api_app_agent_logout_v1 + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void appAgentLogin(Object tag, Context context, int model, String number, SobotResultCallBack<SobotCallBaseCode> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("callWay", model + "");//手机方式  3
        if (!TextUtils.isEmpty(number)) {
            map.put("agentNumber", number);
        }
        SobotCallHttpUtils.getInstance().doPost(tag, context, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_app_agent_login_v1, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(tag, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_app_agent_login_v1, map, response, resultCallBack)) {
                    SobotCallBaseCode result = SobotGsonUtil.jsonToBean(response, SobotCallBaseCode.class);
                    if (result != null) {
                        resultCallBack.onSuccess(result);
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_app_agent_login_v1, map, e.getMessage())) {
                    SobotNetLogUtils.i(SobotCallUrlApi.api_app_agent_login_v1 + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void appAgentLoginModel(Object tag, Context context, SobotResultCallBack<SobotCallBaseCodeThird> resultCallBack) {
        SobotCallHttpUtils.getInstance().doGet(tag, context, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_phone_types_v1, null, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(tag, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_phone_types_v1, null, response, resultCallBack)) {
                    SobotCallBaseCodeThird result = SobotGsonUtil.jsonToBean(response, SobotCallBaseCodeThird.class);
                    if (result != null) {
                        resultCallBack.onSuccess(result);
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_phone_types_v1, null, e.getMessage())) {
                    SobotNetLogUtils.i(SobotCallUrlApi.api_phone_types_v1 + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void appGetSipMsg(Object tag, Context context, String agentNumber, SobotResultCallBack<CallSipModel> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        if (!TextUtils.isEmpty(agentNumber)) {
            map.put("agentNumber", agentNumber);
        }
        SobotCallHttpUtils.getInstance().doPost(tag, context, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_app_agent_number_v1, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(tag, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_app_agent_number_v1, map, response, resultCallBack)) {
                    SobotCallBaseCodeThird<CallSipModel> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCodeThird<CallSipModel>>() {
                    }.getType());
                    if (result != null) {
                        resultCallBack.onSuccess(result.getItem());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_app_agent_number_v1, map, e.getMessage())) {
                    SobotNetLogUtils.i(SobotCallUrlApi.api_app_agent_number_v1 + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void callOut(Object cancelTag, Context context, int hiddenFlag, String taskDetailId, String taskId, String calleeNumber, String groupId, SobotResultCallBack<SobotCallBaseResult> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("calleeNumber", calleeNumber);
        if (!TextUtils.isEmpty(taskDetailId)) {
            map.put("taskDetailId", taskDetailId);
        }

        if (!TextUtils.isEmpty(taskId)) {
            map.put("taskId", taskId);
        }
        if (!TextUtils.isEmpty(groupId)) {
            map.put("groupId", groupId);
        }

        if (!TextUtils.isEmpty(taskDetailId) && !TextUtils.isEmpty(taskId)) {
            map.put("isTelemarketing", "3");
        }

        map.put("hiddenFlag", hiddenFlag + "");

        SobotCallHttpUtils.getInstance().doPost(cancelTag, context, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_out, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(cancelTag, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_out, map, response, resultCallBack)) {
                    SobotCallBaseResult result = SobotGsonUtil.jsonToBeans(response, SobotCallBaseResult.class);
                    if (result != null) {
                        resultCallBack.onSuccess(result);
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_out, map, e.getMessage())) {
                    SobotNetLogUtils.i(SobotCallUrlApi.api_call_out + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void hungUp(Object cancelTag, Context context, SobotStringResultCallBack<SobotCallBaseResult> resultCallBack) {
        Map<String, Object> planMap = new HashMap<>();
        SobotCallHttpUtils.getInstance().doPostByJson(cancelTag, context, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_hungup, planMap, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String result) {
                if (!TextUtils.isEmpty(result)) {
                    SobotOutCallResult callBaseCode = SobotGsonUtil.jsonToBean(result, SobotOutCallResult.class);
                    if (callBaseCode != null) {
                        resultCallBack.onSuccess(callBaseCode);
                    } else {
                        onFailCallBack(null, callBaseCode.getRetMsg(), resultCallBack);
                    }
                } else {
                    onFailCallBack(null, "", resultCallBack);
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_hungup, planMap, e.getMessage())) {
                    onFailCallBack(e, "", resultCallBack);
                    SobotNetLogUtils.i(SobotCallUrlApi.api_call_hungup + "  请求异常: " + e.getMessage());
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    private void onFailCallBack(Exception e, String errorMsg, SobotStringResultCallBack resultCallBack) {
        if (resultCallBack != null) {
            resultCallBack.onFailure(e == null ? new Exception() : e, TextUtils.isEmpty(errorMsg) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : errorMsg);
        }
    }


    @Override
    public void getLoginStatus(Object cancelTag, SobotResultCallBack<List<SobotLoginStatusEntity>> resultCallBack) {
        SobotCallHttpUtils.getInstance().doGet(cancelTag, mContext, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_login_status_v6, null,
                new SobotCallHttpUtils.StringCallBack() {

                    @Override
                    public void onError(Exception e, String msg, int responseCode) {
                        if (!checkErrorMessage(SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_login_status_v6, null, e.getMessage())) {
                            SobotNetLogUtils.i(SobotCallUrlApi.api_login_status_v6 + "  请求异常: " + e.getMessage());
                            resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                        }
                    }

                    @Override
                    public void onResponse(String response) {
                        if (!checkTokenTimeOut(cancelTag, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_login_status_v6, null, response, resultCallBack)) {
                            SobotCallBaseListCode<SobotLoginStatusEntity> result = SobotGsonUtil.jsonToBeans(response,
                                    new TypeToken<SobotCallBaseListCode<SobotLoginStatusEntity>>() {
                                    }.getType());
                            if (result != null && !TextUtils.isEmpty(result.getCode()) && SobotCallConstant.RESULT_CALL_SUCCESS_CODE.equals(result.getCode())) {
                                resultCallBack.onSuccess(result.getData());
                            } else {
                                resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getMessage())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getMessage());
                            }
                        }
                    }

                    @Override
                    public void inProgress(int progress) {
                    }
                });
    }

    @Override
    public void phoneTypes(Object cancelTag, String agentID, String agentType, SobotResultCallBack<SobotAgentEntity> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("agentID", agentID);
        map.put("agentType", agentType);
        SobotCallHttpUtils.getInstance().doPostByJson(cancelTag, mContext, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_phone_types_v6, map,
                new SobotCallHttpUtils.StringCallBack() {

                    @Override
                    public void onError(Exception e, String msg, int responseCode) {
                        if (!checkErrorMessage(SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_phone_types_v6, map, e.getMessage())) {
                            SobotNetLogUtils.i(SobotCallUrlApi.api_phone_types_v6 + "  请求异常: " + e.getMessage());
                            resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                        }
                    }

                    @Override
                    public void onResponse(String response) {
                        if (!TextUtils.isEmpty(response)) {
                            response = response.replace("\"default\"", "\"isDefault\"");
                        }
                        if (!checkTokenTimeOut(cancelTag, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_phone_types_v6, map, response, resultCallBack)) {
                            SobotCallBaseCode<SobotAgentEntity> result = SobotGsonUtil.jsonToBeans(response,
                                    new TypeToken<SobotCallBaseCode<SobotAgentEntity>>() {
                                    }.getType());
                            if (result != null && !TextUtils.isEmpty(result.getCode()) && SobotCallConstant.RESULT_CALL_SUCCESS_CODE.equals(result.getCode())) {
                                resultCallBack.onSuccess(result.getData());
                            } else {
                                resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getMessage())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getMessage());
                            }
                        }
                    }

                    @Override
                    public void inProgress(int progress) {
                    }
                });
    }

    @Override
    public void getExtensionList(Object cancelTag, String agentID, String agentType, SobotResultCallBack<List<SobotExtensionEntity>> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("agentID", agentID);
        map.put("agentType", agentType);
        map.put("currPage", 1);
        map.put("pageSize", 50);
        SobotCallHttpUtils.getInstance().doPostByJson(cancelTag, mContext, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_get_extension_list, map,
                new SobotCallHttpUtils.StringCallBack() {

                    @Override
                    public void onError(Exception e, String msg, int responseCode) {
                        if (!checkErrorMessage(SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_get_extension_list, map, e.getMessage())) {
                            SobotNetLogUtils.i(SobotCallUrlApi.api_get_extension_list + "  请求异常: " + e.getMessage());
                            resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                        }
                    }

                    @Override
                    public void onResponse(String response) {
                        if (!checkTokenTimeOut(cancelTag, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_get_extension_list, map, response, resultCallBack)) {
                            SobotCallBaseListCode<SobotExtensionEntity> result = SobotGsonUtil.jsonToBeans(response,
                                    new TypeToken<SobotCallBaseListCode<SobotExtensionEntity>>() {
                                    }.getType());
                            if (result != null && !TextUtils.isEmpty(result.getCode()) && SobotCallConstant.RESULT_CALL_SUCCESS_CODE.equals(result.getCode())) {
                                resultCallBack.onSuccess(result.getData());
                            } else {
                                resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getMessage())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getMessage());
                            }
                        }
                    }

                    @Override
                    public void inProgress(int progress) {
                    }
                });
    }

    @Override
    public void getExtensionList(Object cancelTag, String ext, String agentID, String agentType, int currPage, int pageSize, SobotResultCallBack<List<SobotExtensionEntity>> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("agentID", agentID);
        map.put("agentType", agentType);
        map.put("currPage", currPage);
        map.put("pageSize", pageSize);
        map.put("ext", ext);
        SobotCallHttpUtils.getInstance().doPostByJson(cancelTag, mContext, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_get_extension_list_page, map,
                new SobotCallHttpUtils.StringCallBack() {

                    @Override
                    public void onError(Exception e, String msg, int responseCode) {
                        if (!checkErrorMessage(SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_get_extension_list_page, map, e.getMessage())) {
                            SobotNetLogUtils.i(SobotCallUrlApi.api_get_extension_list_page + "  请求异常: " + e.getMessage());
                            resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                        }
                    }

                    @Override
                    public void onResponse(String response) {
                        if (!checkTokenTimeOut(cancelTag, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_get_extension_list_page, map, response, resultCallBack)) {
                            SobotCallBaseListCodeSecond<SobotCallListEntity<SobotExtensionEntity>> result = SobotGsonUtil.jsonToBeans(response,
                                    new TypeToken<SobotCallBaseListCodeSecond<SobotCallListEntity<SobotExtensionEntity>>>() {
                                    }.getType());
                            if (result != null && !TextUtils.isEmpty(result.getCode()) && SobotCallConstant.RESULT_CALL_SUCCESS_CODE.equals(result.getCode())) {
                                resultCallBack.onSuccess(result.getData().getList());
                            } else {
                                resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getMessage())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getMessage());
                            }
                        }
                    }

                    @Override
                    public void inProgress(int progress) {
                    }
                });
    }

    @Override
    public void editExtsLangCode(Object cancelTag, String agentID, String agentType, String ext, String langCodeTxt, SobotResultCallBack<SobotExtensionEntity> resultCallBack) {
        Map<String, String> map = new HashMap<>();
        map.put("agentID", agentID);
        map.put("agentType", agentType);
        map.put("ext", ext);
        map.put("langCodeTxt", langCodeTxt);
        SobotCallHttpUtils.getInstance().doPut(cancelTag, mContext, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_ext_langCode, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String result) {
                if (!checkTokenTimeOut(cancelTag, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_ext_langCode, map, result, resultCallBack)) {
                    SobotCallBaseCode<SobotExtensionEntity> resultEntity = SobotGsonUtil.jsonToBeans(result, new TypeToken<SobotCallBaseCode<SobotExtensionEntity>>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(resultEntity.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(resultEntity.getRetCode())) {
                        resultCallBack.onSuccess(resultEntity.getData());
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(resultEntity.getMessage())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : resultEntity.getMessage());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_ext_langCode, map, e.getMessage())) {
                    SobotNetLogUtils.i(SobotCallUrlApi.api_ext_langCode + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    /**
     * 检查用户session是否超时
     *
     * @return true 超时 ；false 正常
     * @plan response
     */
    private boolean checkTokenTimeOut(Object tag, String url, Map params, String response, SobotResultCallBack resultCallBack) {
        try {
            SobotCallBaseCode baseCode = SobotGsonUtil.jsonToBean(response, SobotCallBaseCode.class);
            if (baseCode != null) {
                if ((!TextUtils.isEmpty(baseCode.getRetCode()) && "999998".equals(baseCode.getRetCode()) || (!TextUtils.isEmpty(baseCode.getCode()) && "999998".equals(baseCode.getCode())))) {
                    //token 失效
                    Intent intent = new Intent();
                    LocalBroadcastManager localBroadcastManager = LocalBroadcastManager.getInstance(mContext);
                    intent.setAction(SobotCallConstant.SOBOT_BROADCAST_SESSION_TIMEOUT);
                    Map map = new HashMap();
                    map.put("url", getShortUrl(url));
                    String token = SobotLoginTools.getInstance().getToken();
                    map.put("token", getShortToken(token));
                    intent.putExtra("httpinfo", "呼叫：" + map.toString());
                    String msg = "";
                    if (!TextUtils.isEmpty(baseCode.getRetMsg())) {
                        msg = baseCode.getRetMsg();
                    } else if (!TextUtils.isEmpty(baseCode.getMsg())) {
                        msg = baseCode.getMsg();
                    }
                    resultCallBack.onFailure(new Exception(), msg);
                    localBroadcastManager.sendBroadcast(intent);
                    return true;
                } else if (!TextUtils.isEmpty(baseCode.getRetCode()) && !SobotCallConstant.RESULT_SUCCESS_CODE.equals(baseCode.getRetCode())) {
                    try {
                        String msg = baseCode.getMessage();
                        if (SobotStringUtils.isEmpty(msg)) {
                            msg = SobotResourceUtils.getResString(mContext, "call_retcode_" + baseCode.getRetCode());
                            if (tag != null) {
                                if (tag instanceof Activity) {
                                    msg = SobotResourceUtils.getResString((Activity) tag, "call_retcode_" + baseCode.getRetCode());
                                } else if (tag instanceof Service) {
                                    msg = SobotResourceUtils.getResString((Service) tag, "call_retcode_" + baseCode.getRetCode());
                                }
                            }
                        }
                        baseCode.setMsg(msg);
                        resultCallBack.onFailure(new Exception(), msg);
                        return true;
                    } catch (Exception e) {
                        resultCallBack.onFailure(new Exception(), !TextUtils.isEmpty(baseCode.getMessage())?baseCode.getMessage():"");
                        e.printStackTrace();
                    }
                }
            } else if (!TextUtils.isEmpty(response) && response.contains("invalided token")) {
                try {
                    Intent intent = new Intent();
                    LocalBroadcastManager localBroadcastManager = LocalBroadcastManager.getInstance(SobotHttpGlobalContext.getAppContext());
                    intent.setAction(SobotCallConstant.SOBOT_BROADCAST_SESSION_TIMEOUT);
                    Map map = new HashMap();
                    map.put("url", getShortUrl(url));
                    String token = SobotLoginTools.getInstance().getToken();
                    map.put("token", getShortToken(token));
                    intent.putExtra("httpinfo", "呼叫：" + map.toString());
                    resultCallBack.onFailure(new Exception(), response);
                    localBroadcastManager.sendBroadcast(intent);
                } catch (Exception e) {
                    e.printStackTrace();
                }
                return true;
            } else {
                return false;
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return false;
    }

    public int getResStrId(Activity context, String name) {
        return SobotResourceUtils.getIdByName(context, "string", name);
    }

    /**
     * 检查http请求失败的信息
     */
    private boolean checkErrorMessage(String url, Map params, String errorMsg) {
        if (!TextUtils.isEmpty(errorMsg) && errorMsg.contains("invalided token")) {
            try {
                //token 失效了
                Intent intent = new Intent();
                LocalBroadcastManager localBroadcastManager = LocalBroadcastManager.getInstance(SobotHttpGlobalContext.getAppContext());
                intent.setAction(SobotCallConstant.SOBOT_BROADCAST_SESSION_TIMEOUT);
                Map map = new HashMap();
                map.put("url", getShortUrl(url));
                String token = SobotLoginTools.getInstance().getToken();
                map.put("token", getShortToken(token));
                intent.putExtra("httpinfo", "呼叫：" + map.toString());
                localBroadcastManager.sendBroadcast(intent);
            } catch (Exception e) {
                e.printStackTrace();
            }
            return false;
        } else {
            return false;
        }
    }


    @Override
    public void getAllTaskDetails(Object cancelTag, Context context, int pageNo, int pageSize, SobotResultCallBack<List<SobotCallTaskModel>> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("pageNo", pageNo + "");
        map.put("pageSize", pageSize + "");
        SobotCallHttpUtils.getInstance().doGet(cancelTag, mContext, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_all_task_v1, map,
                new SobotCallHttpUtils.StringCallBack() {

                    @Override
                    public void onError(Exception e, String msg, int responseCode) {
                        if (!checkErrorMessage(SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_all_task_v1, map, e.getMessage())) {
                            SobotNetLogUtils.i(SobotCallUrlApi.api_all_task_v1 + "  请求异常: " + e.getMessage());
                            resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                        }
                    }

                    @Override
                    public void onResponse(String response) {
                        if (!checkTokenTimeOut(cancelTag, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_all_task_v1, map, response, resultCallBack)) {
                            SobotCallBaseCodeThird<SobotCallTaskModel> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCodeThird<SobotCallTaskModel>>() {
                            }.getType());
                            if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {

                                resultCallBack.onSuccess(result.getItems());
                            } else {
                                resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                            }
                        }
                    }

                    @Override
                    public void inProgress(int progress) {
                    }
                });
    }

    @Override
    public void getOneTaskDetails(Object cancelTag, Context context, String taskId, int pageNo, int pageSize, SobotResultCallBack<List<SobotCallTaskDetailsModel>> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("taskId", taskId);
        map.put("pageNo", pageNo + "");
        map.put("pageSize", pageSize + "");
        SobotCallHttpUtils.getInstance().doGet(cancelTag, mContext, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_task_details_v1, map,
                new SobotCallHttpUtils.StringCallBack() {

                    @Override
                    public void onError(Exception e, String msg, int responseCode) {
                        if (!checkErrorMessage(SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_task_details_v1, map, e.getMessage())) {
                            SobotNetLogUtils.i(SobotCallUrlApi.api_task_details_v1 + "  请求异常: " + e.getMessage());
                            resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                        }
                    }

                    @Override
                    public void onResponse(String response) {
                        if (!checkTokenTimeOut(cancelTag, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_task_details_v1, map, response, resultCallBack)) {
                            SobotCallBaseCodeThird<SobotCallTaskDetailsModel> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCodeThird<SobotCallTaskDetailsModel>>() {
                            }.getType());
                            if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {

                                resultCallBack.onSuccess(result.getItems());
                            } else {
                                resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                            }
                        }
                    }

                    @Override
                    public void inProgress(int progress) {
                    }
                });
    }

    @Override
    public void getCallRecord(Object cancelTag, Context context, int pageNo, int pageSize, SobotResultCallBack<List<SobotCallRecordV1>> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        String token = SobotLoginTools.getInstance().getToken();
        map.put("participateInType", "1");
        map.put("temp-id", token);
        map.put("pageNo", pageNo + "");
        map.put("pageSize", pageSize + "");
        SobotCallHttpUtils.getInstance().doPost(cancelTag, mContext, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_record_v1, map,
                new SobotCallHttpUtils.StringCallBack() {

                    @Override
                    public void onError(Exception e, String msg, int responseCode) {
                        if (!checkErrorMessage(SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_record_v1, map, e.getMessage())) {
                            SobotNetLogUtils.i(SobotCallUrlApi.api_call_record_v1 + "  请求异常: " + e.getMessage());
                            resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                        }
                    }

                    @Override
                    public void onResponse(String response) {
                        if (!checkTokenTimeOut(cancelTag, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_record_v1, map, response, resultCallBack)) {
                            SobotCallBaseCodeFourth<SobotCallRecordV1> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCodeFourth<SobotCallRecordV1>>() {
                            }.getType());
                            if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {

                                resultCallBack.onSuccess(result.getItems());
                            } else {
                                resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                            }
                        }
                    }

                    @Override
                    public void inProgress(int progress) {
                    }
                });
    }

    @Override
    public void getAppServiceCallRecordByPhone(Object cancelTag, Context context, int pageNo, int pageSize, String callee, SobotResultCallBack<SobotCallBaseCodeRecord> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("pageNo", pageNo + "");
        map.put("pageSize", pageSize + "");
        map.put("callee", callee + "");
        SobotCallHttpUtils.getInstance().doPost(cancelTag, mContext, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_record_detail_v1, map,
                new SobotCallHttpUtils.StringCallBack() {

                    @Override
                    public void onError(Exception e, String msg, int responseCode) {
                        if (!checkErrorMessage(SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_record_detail_v1, map, e.getMessage())) {
                            SobotNetLogUtils.i(SobotCallUrlApi.api_call_record_detail_v1 + "  请求异常: " + e.getMessage());
                            resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                        }
                    }

                    @Override
                    public void onResponse(String response) {
                        if (!checkTokenTimeOut(cancelTag, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_record_detail_v1, map, response, resultCallBack)) {
                            SobotCallBaseCodeRecord result1 = SobotGsonUtil.jsonToBeans(response, SobotCallBaseCodeRecord.class);
                            SobotLogUtils.d(String.valueOf("-----" + result1.getItem() == null));
                            resultCallBack.onSuccess(result1);
                        }
                    }

                    @Override
                    public void inProgress(int progress) {
                    }
                });
    }

    @Override
    public void getAllCallContactPlan(Object cancelTag, Context context, int pageNo, int pageSize, SobotResultCallBack<List<SobotCallContactPlan>> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("pageNo", pageNo + "");
        map.put("pageSize", pageSize + "");
        SobotCallHttpUtils.getInstance().doGet(cancelTag, mContext, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_get_call_contact_planList_v1, map,
                new SobotCallHttpUtils.StringCallBack() {

                    @Override
                    public void onError(Exception e, String msg, int responseCode) {
                        if (!checkErrorMessage(SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_get_call_contact_planList_v1, map, e.getMessage())) {
                            SobotNetLogUtils.i(SobotCallUrlApi.api_get_call_contact_planList_v1 + "  请求异常: " + e.getMessage());
                            resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                        }
                    }

                    @Override
                    public void onResponse(String response) {
                        if (!checkTokenTimeOut(cancelTag, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_get_call_contact_planList_v1, map, response, resultCallBack)) {
                            SobotCallBaseCodeThird<SobotCallContactPlan> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCodeThird<SobotCallContactPlan>>() {
                            }.getType());
                            if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {

                                resultCallBack.onSuccess(result.getItems());
                            } else {
                                resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                            }
                        }
                    }

                    @Override
                    public void inProgress(int progress) {
                    }
                });
    }

    @Override
    public void addCallContactPlanInfo(Object cancelTag, Context context, String taskIdName, String taskDetailId, SobotCallContactPlan plan, SobotResultCallBack<SobotCallBaseCode> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        if (!TextUtils.isEmpty(taskIdName)) {
            map.put("taskIdName", taskIdName);
        }
        if (!TextUtils.isEmpty(taskDetailId)) {
            map.put("taskDetailId", taskDetailId);
        }
        map.put("hiddenFlag", plan.getHiddenFlag() + "");
        map.put("taskName", plan.getTaskName());
        map.put("customerPhoneNo", plan.getCustomerPhoneNo());
        map.put("planTime", plan.getPlanTime() + "");
        map.put("remindTime", plan.getRemindTime());
        map.put("remarks", plan.getRemarks());
        SobotCallHttpUtils.getInstance().doPost(cancelTag, mContext, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_add_call_contact_planinfo_v1, map,
                new SobotCallHttpUtils.StringCallBack() {

                    @Override
                    public void onError(Exception e, String msg, int responseCode) {
                        if (!checkErrorMessage(SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_add_call_contact_planinfo_v1, map, e.getMessage())) {
                            SobotNetLogUtils.i(SobotCallUrlApi.api_add_call_contact_planinfo_v1 + "  请求异常: " + e.getMessage());
                            resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                        }
                    }

                    @Override
                    public void onResponse(String response) {
                        if (!checkTokenTimeOut(cancelTag, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_add_call_contact_planinfo_v1, map, response, resultCallBack)) {
                            SobotCallBaseCode result = SobotGsonUtil.jsonToBean(response, SobotCallBaseCode.class);
                            resultCallBack.onSuccess(result);
                        }
                    }

                    @Override
                    public void inProgress(int progress) {
                    }
                });
    }

    @Override
    public void updateCallContactPlanInfo(Object cancelTag, Context context, SobotCallContactPlan plan, SobotResultCallBack<SobotCallBaseCode> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("id", plan.getId());
        map.put("taskName", plan.getTaskName());
        map.put("planTime", plan.getPlanTime() + "");
        map.put("remindTime", plan.getRemindTime());
        map.put("remarks", plan.getRemarks());
        map.put("hiddenFlag", plan.getHiddenFlag() + "");
        SobotCallHttpUtils.getInstance().doPost(cancelTag, mContext, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_update_call_contact_planinfo_v1, map,
                new SobotCallHttpUtils.StringCallBack() {

                    @Override
                    public void onError(Exception e, String msg, int responseCode) {
                        if (!checkErrorMessage(SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_update_call_contact_planinfo_v1, map, e.getMessage())) {
                            SobotNetLogUtils.i(SobotCallUrlApi.api_update_call_contact_planinfo_v1 + "  请求异常: " + e.getMessage());
                            resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                        }
                    }

                    @Override
                    public void onResponse(String response) {
                        if (!checkTokenTimeOut(cancelTag, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_update_call_contact_planinfo_v1, map, response, resultCallBack)) {
                            SobotCallBaseCode result = SobotGsonUtil.jsonToBean(response, SobotCallBaseCode.class);
                            resultCallBack.onSuccess(result);
                        }
                    }

                    @Override
                    public void inProgress(int progress) {
                    }
                });
    }

    @Override
    public void deleteCallContactPlanInfo(Object cancelTag, Context context, String id, SobotResultCallBack<SobotCallBaseResult> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("id", id);
        SobotCallHttpUtils.getInstance().doPost(cancelTag, mContext, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_delete_call_contact_planinfo_v1, map,
                new SobotCallHttpUtils.StringCallBack() {

                    @Override
                    public void onError(Exception e, String msg, int responseCode) {
                        if (!checkErrorMessage(SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_delete_call_contact_planinfo_v1, map, e.getMessage())) {
                            SobotNetLogUtils.i(SobotCallUrlApi.api_delete_call_contact_planinfo_v1 + "  请求异常: " + e.getMessage());
                            resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                        }
                    }

                    @Override
                    public void onResponse(String response) {
                        if (!checkTokenTimeOut(cancelTag, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_delete_call_contact_planinfo_v1, map, response, resultCallBack)) {
                            SobotCallBaseResult baseCode = SobotGsonUtil.jsonToBean(response, SobotCallBaseResult.class);
                            resultCallBack.onSuccess(baseCode);
                        }
                    }

                    @Override
                    public void inProgress(int progress) {
                    }
                });
    }

    public void getCallRecordList(Object cancelTag, long startTime, long endTime, String callType, String callResult, String customerId, String customerNumber, int pageNo, int pageSize, boolean hidePhone, SobotResultCallBack<List<SobotCallRecordEntity>> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("startTime", startTime + "");
        map.put("endTime", endTime + "");
        map.put("hideNumber", hidePhone ? "1" : "0");
        map.put("pageNum", pageNo + "");
        map.put("pageSize", pageSize + "");
        map.put("participateInType", 1);
        if (!TextUtils.isEmpty(callType)) {
            map.put("callType", callType);//呼叫类型 2: 呼入; 3: 外呼;
        }
        if (!TextUtils.isEmpty(callResult)) {
            map.put("callResult", callResult);//通话结果:1.其他原因无法应答 2.欠费 3.客户号码黑名单 4.未找到座席侧 5.客户速挂6.座席侧未接听 7.客户未接听 8.双方已接听 9.中继号码停用
        }
        if (!TextUtils.isEmpty(customerNumber)) {
            map.put("customerNumber", customerNumber);//客户号码
        }
        if (!TextUtils.isEmpty(customerId)) {
            map.put("customerId", customerId);//客户ID
        }
        SobotCallHttpUtils.getInstance().doPostByJson(cancelTag, mContext, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_get_record_list_v6, map,
                new SobotCallHttpUtils.StringCallBack() {

                    @Override
                    public void onError(Exception e, String msg, int responseCode) {
                        if (!checkErrorMessage(SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_get_record_list_v6, map, e.getMessage())) {
                            SobotNetLogUtils.i(SobotCallUrlApi.api_get_record_list_v6 + "  请求异常: " + e.getMessage());
                            resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                        }
                    }

                    @Override
                    public void onResponse(String response) {
                        if (!checkTokenTimeOut(cancelTag, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_get_record_list_v6, map, response, resultCallBack)) {
                            SobotCallBaseListCodeSecond<SobotCallPageEntity<SobotCallRecordEntity>> baseCode = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseListCodeSecond<SobotCallPageEntity<SobotCallRecordEntity>>>() {
                            }.getType());
                            if (baseCode != null && !TextUtils.isEmpty(baseCode.getCode()) && baseCode.getCode().equals(SobotCallConstant.RESULT_CALL_SUCCESS_CODE)) {
                                resultCallBack.onSuccess(baseCode.getData().getPageData());
                            } else {
                                resultCallBack.onFailure(null, response);
                            }
                        }
                    }

                    @Override
                    public void inProgress(int progress) {
                    }
                });
    }

    @Override
    public void getCallDetails(Object cancelTag, String callID, SobotResultCallBack<CallDetailEntity> resultCallBack) {
        String url = SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_details.replace("{callID}", callID);
        Map<String, Object> map = new HashMap<>();
        SobotCallHttpUtils.getInstance().doGet(cancelTag, mContext, url, map,
                new SobotCallHttpUtils.StringCallBack() {

                    @Override
                    public void onError(Exception e, String msg, int responseCode) {
                        if (!checkErrorMessage(url, map, e.getMessage())) {
                            SobotNetLogUtils.i(url + "  请求异常: " + e.getMessage());
                            resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                        }
                    }

                    @Override
                    public void onResponse(String response) {
                        if (!checkTokenTimeOut(cancelTag, url, map, response, resultCallBack)) {
                            SobotCallBaseCode<CallDetailEntity> baseCode = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCode<CallDetailEntity>>() {
                            }.getType());
                            if (baseCode != null && !TextUtils.isEmpty(baseCode.getCode()) && baseCode.getCode().equals(SobotCallConstant.RESULT_CALL_SUCCESS_CODE)) {
                                resultCallBack.onSuccess(baseCode.getData());
                            } else {
                                resultCallBack.onFailure(null, response);
                            }
                        }
                    }

                    @Override
                    public void inProgress(int progress) {
                    }
                });
    }

    @Override
    public void getCallRecordOne(Object cancelTag, String callID, SobotResultCallBack<List<SobotCallRecordDetailEntity>> resultCallBack) {
        String url = SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_get_record_one_v6.replace("{callID}", callID);
        Map<String, Object> map = new HashMap<>();
        SobotCallHttpUtils.getInstance().doGet(cancelTag, mContext, url, map,
                new SobotCallHttpUtils.StringCallBack() {

                    @Override
                    public void onError(Exception e, String msg, int responseCode) {
                        if (!checkErrorMessage(url, map, e.getMessage())) {
                            SobotNetLogUtils.i(url + "  请求异常: " + e.getMessage());
                            resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                        }
                    }

                    @Override
                    public void onResponse(String response) {
                        if (!checkTokenTimeOut(cancelTag, url, map, response, resultCallBack)) {
                            SobotCallBaseListCodeSecond baseCode = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseListCodeSecond>() {
                            }.getType());
                            if (baseCode != null && !TextUtils.isEmpty(baseCode.getCode()) && baseCode.getCode().equals(SobotCallConstant.RESULT_CALL_SUCCESS_CODE)) {
                                try {
                                    JSONObject jsonObject = new JSONObject(response);
                                    JSONObject data = jsonObject.getJSONObject("data");
                                    String listStr = data.getString("list");
                                    List<SobotCallRecordDetailEntity> list = SobotGsonUtil.jsonToList(listStr, SobotCallRecordDetailEntity.class);
                                    resultCallBack.onSuccess(list);
                                } catch (JSONException e) {
                                    e.printStackTrace();
                                    resultCallBack.onFailure(null, response);
                                }
//
                            } else {
                                resultCallBack.onFailure(null, response);
                            }
                        }
                    }

                    @Override
                    public void inProgress(int progress) {
                    }
                });
    }

    @Override
    public void addCustomerInfo(Object tag, SobotCallCustomerModel user, boolean isNew, SobotResultCallBack<SobotCallCustomerModel> resultCallBack) {
        Map<String, Object> map = new HashMap<>();

        map.put("nick", user.getNick());
        map.put("email", user.getEmail());
        map.put("tel", user.getTel());
        if (isNew) {
            map.put("partnerId", user.getPartnerId());
            map.put("uname", user.getUname());
            map.put("visitorIds", user.getVisitorIds());
            map.put("source", user.getSource() + "");
            map.put("isVip", user.getIsVip());
            map.put("vipLevel", user.getVipLevel());
            map.put("enterpriseName", user.getEnterpriseName());
            map.put("enterpriseId", user.getEnterpriseId());
            map.put("countryId", user.getCountryId());
            map.put("countryName", user.getCountryName());
            map.put("proviceId", user.getProviceId());
            map.put("proviceName", user.getProviceName());
            map.put("cityId", user.getCityId());
            map.put("cityName", user.getCityName());
            map.put("areaId", user.getAreaId());
            map.put("areaName", user.getAreaName());
            map.put("qq", user.getQq());
            map.put("wx", user.getWx());
            map.put("sex", user.getSex() + "");
            map.put("remark", user.getRemark());
            map.put("customFields", user.getCustomFields());
        }
        SobotCallHttpUtils.getInstance().doPost(tag, mContext, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_add_customer_info, map,
                new SobotCallHttpUtils.StringCallBack() {

                    @Override
                    public void onError(Exception e, String msg, int responseCode) {
                        if (!checkErrorMessage(SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_add_customer_info, map, e.getMessage())) {
                            SobotNetLogUtils.i(SobotCallUrlApi.api_call_add_customer_info + "  请求异常: " + e.getMessage());
                            resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                        }
                    }

                    @Override
                    public void onResponse(String response) {
                        if (!checkTokenTimeOut(tag, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_add_customer_info, map, response, resultCallBack)) {
                            SobotCallBaseCodeThird<SobotCallCustomerModel> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCodeThird<SobotCallCustomerModel>>() {
                            }.getType());
                            if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                                if (result.getTotalCount() == 0) {
                                    if (result.getItems() != null) {
                                        resultCallBack.onSuccess(result.getItem());
                                    } else {
                                        resultCallBack.onSuccess(null);
                                    }
                                } else {
                                    //统一提示语,跟iOS一致 2022.07.08-gqf
                                    resultCallBack.onFailure(new Exception(), mContext.getResources().getString(R.string.sobot_save_error_result_string));
                                }
                            } else {
                                resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                            }
                        }
                    }

                    @Override
                    public void inProgress(int progress) {
                    }
                });
    }

    @Override
    public void updateCustomerInfo(Object tag, SobotCallCustomerModel user, SobotResultCallBack<SobotCallCustomerModel> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("id", user.getId());
        map.put("nick", user.getNick());
        map.put("email", user.getEmail());
        map.put("tel", user.getTel());
        SobotCallHttpUtils.getInstance().doPost(tag, mContext, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_update_customer_info, map,
                new SobotCallHttpUtils.StringCallBack() {

                    @Override
                    public void onError(Exception e, String msg, int responseCode) {
                        if (!checkErrorMessage(SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_update_customer_info, map, e.getMessage())) {
                            SobotNetLogUtils.i(SobotCallUrlApi.api_call_add_customer_info + "  请求异常: " + e.getMessage());
                            resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                        }
                    }

                    @Override
                    public void onResponse(String response) {
                        if (!checkTokenTimeOut(tag, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_update_customer_info, map, response, resultCallBack)) {
                            SobotCallBaseCodeThird<SobotCallCustomerModel> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCodeThird<SobotCallCustomerModel>>() {
                            }.getType());
                            if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                                if (result.getTotalCount() == 0) {
                                    if (result.getItems() != null && result.getItems().size() > 0) {
                                        resultCallBack.onSuccess(result.getItems().get(0));
                                    } else {
                                        resultCallBack.onSuccess(null);
                                    }
                                } else {
                                    //统一提示语,跟iOS一致 2022.07.08-gqf
                                    resultCallBack.onFailure(new Exception(), mContext.getResources().getString(R.string.sobot_save_error_result_string));
                                }
                            } else {
                                resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                            }
                        }
                    }

                    @Override
                    public void inProgress(int progress) {
                    }
                });
    }

    @Override
    public void getCustomerInfoByPhone(Object tag, String phone, SobotResultCallBack<SobotCallCustomerModel> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("tel", phone);
        SobotCallHttpUtils.getInstance().doGet(tag, mContext, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_get_customer_info, map,
                new SobotCallHttpUtils.StringCallBack() {

                    @Override
                    public void onError(Exception e, String msg, int responseCode) {
                        if (!checkErrorMessage(SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_get_customer_info, map, e.getMessage())) {
                            SobotNetLogUtils.i(SobotCallUrlApi.api_call_get_customer_info + "  请求异常: " + e.getMessage());
                            resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                        }
                    }

                    @Override
                    public void onResponse(String response) {
                        SobotCallBaseCodeThird<SobotCallCustomerModel> baseCode = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCodeThird<SobotCallCustomerModel>>() {
                        }.getType());
                        if (baseCode != null && !TextUtils.isEmpty(baseCode.getRetCode()) && baseCode.getRetCode().equals(SobotCallConstant.RESULT_SUCCESS_CODE)) {
                            resultCallBack.onSuccess(baseCode.getItem());
                        } else {
                            resultCallBack.onFailure(null, response);
                        }
                    }

                    @Override
                    public void inProgress(int progress) {
                    }
                });
    }

    @Override
    public void getTaskListV6(Object cancelTag, Context context, String name, int pageNo, int pageSize, SobotResultCallBack<List<SobotCallTaskEntity>> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("pageSize", pageSize + "");
        map.put("currPage", pageNo + "");
        if (!TextUtils.isEmpty(name)) {
            map.put("name", name);
            // 按那个字段进行搜索：1 名称或编号 2名称,这个字段默认"1",我们传"2",String类型
            map.put("nameType", "2");
        }
        SobotCallHttpUtils.getInstance().doPostByJson(cancelTag, context, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_tasklist_v6, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(cancelTag, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_tasklist_v6, map, response, resultCallBack)) {
                    SobotCallBaseListCodeSecond<SobotCallListEntity<SobotCallTaskEntity>> baseCode = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseListCodeSecond<SobotCallListEntity<SobotCallTaskEntity>>>() {
                    }.getType());
                    if (baseCode != null && !TextUtils.isEmpty(baseCode.getCode()) && baseCode.getCode().equals(SobotCallConstant.RESULT_CALL_SUCCESS_CODE)) {
                        resultCallBack.onSuccess(baseCode.getData().getList());
                    } else {
                        resultCallBack.onFailure(null, response);
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_tasklist_v6, map, e.getMessage())) {
                    SobotNetLogUtils.i(SobotCallUrlApi.api_tasklist_v6 + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void getTaskDetailsV6(Object cancelTag, Context context, String taskId, String type, String value, String name, int pageNo, int pageSize, SobotResultCallBack<SobotCallListSecondEntity<CallTaskDetailsModel>> resultCallBack) {
        String url = SobotCallUrlApi.api_tast_detail_v6.replace("{campaignId}", taskId);
        Map<String, Object> map = new HashMap<>();
        map.put("name", name);
        map.put("type", type);
        map.put("value", value);
        map.put("pageSize", pageSize + "");
        map.put("currPage", pageNo + "");
        SobotCallHttpUtils.getInstance().doPostByJson(cancelTag, context, SobotCallBaseUrl.getCallApiHost() + url, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(cancelTag, SobotCallBaseUrl.getCallApiHost() + url, map, response, resultCallBack)) {
                    SobotCallBaseListCodeSecond<SobotCallListSecondEntity<CallTaskDetailsModel>> baseCode = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseListCodeSecond<SobotCallListSecondEntity<CallTaskDetailsModel>>>() {
                    }.getType());
                    if (baseCode != null && !TextUtils.isEmpty(baseCode.getCode()) && baseCode.getCode().equals(SobotCallConstant.RESULT_CALL_SUCCESS_CODE)) {
                        resultCallBack.onSuccess(baseCode.getData());
                    } else {
                        resultCallBack.onFailure(null, response);
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getCallApiHost() + url, map, e.getMessage())) {
                    SobotNetLogUtils.i(url + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void taskCallV6(Object cancelTag, Context context, String recordId, String campaignId, SobotResultCallBack<String> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("recordId", recordId);
        map.put("campaignId", campaignId);
        SobotCallHttpUtils.getInstance().doPostByJson(cancelTag, context, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_tast_call_v6, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(cancelTag, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_tast_call_v6, map, response, resultCallBack)) {
                    SobotCallBaseCode baseCode = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCode>() {
                    }.getType());
                    if (baseCode != null && !TextUtils.isEmpty(baseCode.getRetCode()) && baseCode.getRetCode().equals(SobotCallConstant.RESULT_SUCCESS_CODE)) {
                        String message = "";
                        int errorCode = 0;
                        if (!SobotStringUtils.isEmpty(baseCode.getReason())) {
                            try {
                                JSONObject object = new JSONObject(baseCode.getReason());
                                if (object.has("errorMessage")) {
                                    message = object.optString("errorMessage");
                                }
                                if (object.has("errorCode")) {
                                    errorCode = object.optInt("errorCode", 0);
                                }
                            } catch (JSONException e) {
                                e.printStackTrace();
                            }
                        }
                        if (errorCode == 6019) {
                            //处理欠费
                            resultCallBack.onFailure(null, message);
                        } else {
                            resultCallBack.onSuccess(message);
                        }
                    } else {
                        String message = "";
                        if (!SobotStringUtils.isEmpty(baseCode.getReason())) {
                            try {
                                JSONObject object = new JSONObject(baseCode.getReason());
                                if (object.has("errorMessage")) {
                                    message = object.optString("errorMessage");
                                }
                            } catch (JSONException e) {
                                e.printStackTrace();
                            }
                        }
                        resultCallBack.onFailure(null, message);
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_tast_call_v6, map, e.getMessage())) {
                    SobotNetLogUtils.i(SobotCallUrlApi.api_tast_call_v6 + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void queryGroupListV1(Object tag, Context context, SobotResultCallBack<SobotCallBaseCodeGroup> resultCallBack) {
        SobotCallHttpUtils.getInstance().doGet(tag, context, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_app_query_group_v1, null, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String result) {
                SobotCallBaseCodeGroup group = SobotGsonUtil.jsonToBean(result, SobotCallBaseCodeGroup.class);
                resultCallBack.onSuccess(group);
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                resultCallBack.onFailure(e, msg);
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void recoverAgentStatus(Object canceTag, Context context, String simpSessionId, String currentInstanceId, SobotResultCallBack<SobotAgentInfoEntity> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("simpSessionId", simpSessionId);
        map.put("currentInstanceId", currentInstanceId);
        SobotCallHttpUtils.getInstance().doGetByJson(canceTag, mContext, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_recover_agent_status_v6, map,
                new SobotCallHttpUtils.StringCallBack() {

                    @Override
                    public void onError(Exception e, String msg, int responseCode) {
                        if (!checkErrorMessage(SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_recover_agent_status_v6, map, e.getMessage())) {
                            SobotNetLogUtils.i(SobotCallUrlApi.api_recover_agent_status_v6 + "  请求异常: " + e.getMessage());
                            resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                        }
                    }

                    @Override
                    public void onResponse(String response) {
                        if (!TextUtils.isEmpty(response)) {
                            response = response.replace("\"default\"", "\"isDefault\"");
                        }
                        if (!checkTokenTimeOut(canceTag, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_recover_agent_status_v6, map, response, resultCallBack)) {
                            SobotCallBaseCode<SobotAgentInfoEntity> result = SobotGsonUtil.jsonToBeans(response,
                                    new TypeToken<SobotCallBaseCode<SobotAgentInfoEntity>>() {
                                    }.getType());
                            if (result != null && !TextUtils.isEmpty(result.getCode()) && SobotCallConstant.RESULT_CALL_SUCCESS_CODE.equals(result.getCode())) {
                                resultCallBack.onSuccess(result.getData());
                            } else {
                                resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getMessage())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getMessage());
                            }
                        }
                    }

                    @Override
                    public void inProgress(int progress) {
                    }
                });
    }

    @Override
    public void recoverAgentCallStatus(Object canceTag, Context context, String simpSessionId, String currentInstanceId, SobotResultCallBack<SobotCallStatusEntity> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("simpSessionId", simpSessionId);
        map.put("currentInstanceId", currentInstanceId);
        SobotCallHttpUtils.getInstance().doGetByJson(canceTag, mContext, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_recover_agent_call_status_v6, map,
                new SobotCallHttpUtils.StringCallBack() {

                    @Override
                    public void onError(Exception e, String msg, int responseCode) {
                        if (!checkErrorMessage(SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_recover_agent_call_status_v6, map, e.getMessage())) {
                            SobotNetLogUtils.i(SobotCallUrlApi.api_recover_agent_call_status_v6 + "  请求异常: " + e.getMessage());
                            resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                        }
                    }

                    @Override
                    public void onResponse(String response) {
                        if (!TextUtils.isEmpty(response)) {
                            response = response.replace("\"default\"", "\"isDefault\"");
                        }
                        if (!checkTokenTimeOut(canceTag, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_recover_agent_call_status_v6, map, response, resultCallBack)) {
                            SobotCallBaseCode<SobotCallStatusEntity> result = SobotGsonUtil.jsonToBeans(response,
                                    new TypeToken<SobotCallBaseCode<SobotCallStatusEntity>>() {
                                    }.getType());
                            if (result != null && !TextUtils.isEmpty(result.getCode()) && SobotCallConstant.RESULT_CALL_SUCCESS_CODE.equals(result.getCode())) {
                                resultCallBack.onSuccess(result.getData());
                            } else {
                                resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getMessage())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getMessage());
                            }
                        }
                    }

                    @Override
                    public void inProgress(int progress) {
                    }
                });
    }

    @Override
    public void queryOutBoudRoutesRules(Context context, String serviceId, SobotResultCallBack<SobotOutboundRoutesEntity> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        String url = String.format(SobotCallUrlApi.api_call_query_outboud_routes_rules, serviceId, "1");
        //旧版接口的
//        String url = SobotCallUrlApi.api_call_query_outboud_routes_rules;
//        map.put("agent", serviceId);
//        map.put("agentType", "1");
        SobotCallHttpUtils.getInstance().doGetByJson(context, context, SobotCallBaseUrl.getCallApiHost() + url, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, SobotCallBaseUrl.getCallApiHost() + url, map, response, resultCallBack)) {
                    SobotCallBaseCode<SobotOutboundRoutesEntity> result = SobotGsonUtil.jsonToBeans(response,
                            new TypeToken<SobotCallBaseCode<SobotOutboundRoutesEntity>>() {
                            }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getCode()) && SobotCallConstant.RESULT_CALL_SUCCESS_CODE.equals(result.getCode())) {
                        resultCallBack.onSuccess(result.getData());
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getMessage())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getMessage());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_query_outboud_routes_rules, map, e.getMessage())) {
                    SobotNetLogUtils.i(SobotCallUrlApi.api_call_query_outboud_routes_rules + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void switchOutBoudRoutesRules(Context context, String serviceId, String explicitRule, String explicitCode, String explicitNumber, SobotResultCallBack<SobotOutboundRoutesEntity> resultCallBack) {
        Map<String, String> map = new HashMap<>();
        map.put("agent", serviceId);
        map.put("agentType", "1");
        map.put("explicitRule", explicitRule);
        if (!TextUtils.isEmpty(explicitNumber)) {
            map.put("explicitNumber", explicitNumber);
        }
        if (!TextUtils.isEmpty(explicitCode)) {
            map.put("explicitCode", explicitCode);
        }
        SobotCallHttpUtils.getInstance().doPut(context, context, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_switch_outboud_routes_rules, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_switch_outboud_routes_rules, map, response, resultCallBack)) {
                    SobotCallBaseCode<SobotOutboundRoutesEntity> result = SobotGsonUtil.jsonToBeans(response,
                            new TypeToken<SobotCallBaseCode<SobotOutboundRoutesEntity>>() {
                            }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getCode()) && SobotCallConstant.RESULT_CALL_SUCCESS_CODE.equals(result.getCode())) {
                        resultCallBack.onSuccess(result.getData());
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getMessage())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getMessage());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_switch_outboud_routes_rules, map, e.getMessage())) {
                    SobotNetLogUtils.i(SobotCallUrlApi.api_call_switch_outboud_routes_rules + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void queryBusyStatuses(Context context, String serviceId, SobotResultCallBack<List<SobotBusyStatusEntity>> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("agent", serviceId);
        map.put("agentType", "1");
        SobotCallHttpUtils.getInstance().doPostByJson(context, context, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_busy_statuses, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_busy_statuses, map, response, resultCallBack)) {
                    SobotCallBaseListCodeSecond<List<SobotBusyStatusEntity>> baseCode = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseListCodeSecond<List<SobotBusyStatusEntity>>>() {
                    }.getType());
                    if (baseCode != null && !TextUtils.isEmpty(baseCode.getCode()) && baseCode.getCode().equals(SobotCallConstant.RESULT_CALL_SUCCESS_CODE)) {
                        resultCallBack.onSuccess(baseCode.getData());
                    } else {
                        resultCallBack.onFailure(null, response);
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_busy_statuses, map, e.getMessage())) {
                    SobotNetLogUtils.i(SobotCallUrlApi.api_call_busy_statuses + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void queryAvailableExts(Context context, String serviceId, SobotResultCallBack<List<SobotExtEntity>> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("agent", serviceId);
        map.put("agentType", "1");
        SobotCallHttpUtils.getInstance().doPostByJson(context, context, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_available_exts, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_available_exts, map, response, resultCallBack)) {
                    SobotCallBaseListCodeSecond<List<SobotExtEntity>> baseCode = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseListCodeSecond<List<SobotExtEntity>>>() {
                    }.getType());
                    if (baseCode != null && !TextUtils.isEmpty(baseCode.getCode()) && baseCode.getCode().equals(SobotCallConstant.RESULT_CALL_SUCCESS_CODE)) {
                        resultCallBack.onSuccess(baseCode.getData());
                    } else {
                        resultCallBack.onFailure(null, response);
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_available_exts, map, e.getMessage())) {
                    SobotNetLogUtils.i(SobotCallUrlApi.api_call_available_exts + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void queryLoginBindingInfo(Context context, String serviceId, SobotResultCallBack<SobotLoginBindEntity> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("agent", serviceId);
        map.put("agentType", "1");
        SobotCallHttpUtils.getInstance().doPostByJson(context, context, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_login_binding_info, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_login_binding_info, map, response, resultCallBack)) {
                    SobotCallBaseCode<SobotLoginBindEntity> result = SobotGsonUtil.jsonToBeans(response,
                            new TypeToken<SobotCallBaseCode<SobotLoginBindEntity>>() {
                            }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getCode()) && SobotCallConstant.RESULT_CALL_SUCCESS_CODE.equals(result.getCode())) {
                        resultCallBack.onSuccess(result.getData());
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getMessage())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getMessage());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_login_binding_info, map, e.getMessage())) {
                    SobotNetLogUtils.i(SobotCallUrlApi.api_call_login_binding_info + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void queryAvailableQueues(Context context, String serviceId, SobotResultCallBack<List<QueueAgentCheckin>> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("agent", serviceId);
        map.put("agentType", "1");
        SobotCallHttpUtils.getInstance().doPostByJson(context, context, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_available_queues, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_available_queues, map, response, resultCallBack)) {
                    SobotCallBaseListCodeSecond<List<QueueAgentCheckin>> baseCode = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseListCodeSecond<List<QueueAgentCheckin>>>() {
                    }.getType());
                    if (baseCode != null && !TextUtils.isEmpty(baseCode.getCode()) && baseCode.getCode().equals(SobotCallConstant.RESULT_CALL_SUCCESS_CODE)) {
                        resultCallBack.onSuccess(baseCode.getData());
                    } else {
                        resultCallBack.onFailure(null, response);
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_available_queues, map, e.getMessage())) {
                    SobotNetLogUtils.i(SobotCallUrlApi.api_call_available_queues + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void searchCallingCodeV6(Context context, SobotResultCallBack<String> block) {
        SobotCallHttpUtils.getInstance().doGet(context, context, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.searchCallingCodeV6, null, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.searchCallingCodeV6, null, response, block)) {
                    SobotCallBaseCode<String> baseCode = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCode<String>>() {
                    }.getType());
                    if (baseCode != null && !TextUtils.isEmpty(baseCode.getCode()) && baseCode.getCode().equals(SobotCallConstant.RESULT_CALL_SUCCESS_CODE)) {
                        block.onSuccess(baseCode.getData());
                    } else {
                        block.onFailure(null, response);
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.searchCallingCodeV6, null, e.getMessage())) {
                    SobotNetLogUtils.i(SobotCallUrlApi.api_call_available_queues + "  请求异常: " + e.getMessage());
                    block.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void searchAreaListV6(Context context, SobotResultCallBack<List<SobotCountryRegion>> block) {
        SobotCallHttpUtils.getInstance().doGet(context, context, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.searchAreaListV6, null, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.searchAreaListV6, null, response, block)) {
                    SobotCallBaseListCodeSecond<List<SobotCountryRegion>> baseCode = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseListCodeSecond<List<SobotCountryRegion>>>() {
                    }.getType());
                    if (baseCode != null && !TextUtils.isEmpty(baseCode.getCode()) && baseCode.getCode().equals(SobotCallConstant.RESULT_CALL_SUCCESS_CODE)) {
                        block.onSuccess(baseCode.getData());
                    } else {
                        block.onFailure(null, response);
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.searchAreaListV6, null, e.getMessage())) {
                    SobotNetLogUtils.i(SobotCallUrlApi.api_call_available_queues + "  请求异常: " + e.getMessage());
                    block.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void updateAreaV6(Context context, String callingCode, SobotResultCallBack block) {
        Map<String, String> map = new HashMap<>();
        map.put("callingCode", callingCode);
        SobotCallHttpUtils.getInstance().doPut(context, context, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.updateAreaV6, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.updateAreaV6, map, response, block)) {
                    SobotCallBaseCode baseCode = SobotGsonUtil.jsonToBean(response, SobotCallBaseCode.class);
                    if (baseCode != null && !TextUtils.isEmpty(baseCode.getCode()) && baseCode.getCode().equals(SobotCallConstant.RESULT_CALL_SUCCESS_CODE)) {
                        block.onSuccess(baseCode.getData());
                    } else {
                        block.onFailure(null, response);
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.updateAreaV6, map, e.getMessage())) {
                    SobotNetLogUtils.i(SobotCallUrlApi.api_call_available_queues + "  请求异常: " + e.getMessage());
                    block.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }


    @Override
    public void getSummaryConfig(Context context, SobotResultCallBack resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        SobotCallHttpUtils.getInstance().doGet(context, context, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_summary_config, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_summary_config, map, response, resultCallBack)) {
                    SobotCallBaseCode<SobotSummaryConfig> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCode<SobotSummaryConfig>>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        CallSharedPreferencesUtils.getInstance(context).put(SobotCallConstant.CALL_SUMMARY_CONFIG, response);
                        resultCallBack.onSuccess(result.getData());
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_summary_config, map, e.getMessage())) {
                    SobotNetLogUtils.i(SobotCallUrlApi.api_call_summary_config + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void getSummaryClassifies(Context context, String planType, String classifyParentId, SobotResultCallBack<List<SobotSummaryClassifies>> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("planType", planType);
        SobotCallHttpUtils.getInstance().doGet(context, context, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_summary_classifies, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_summary_classifies, map, response, resultCallBack)) {

                    SobotCallBaseCode<List<SobotSummaryClassifies>> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCode<List<SobotSummaryClassifies>>>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        resultCallBack.onSuccess(result.getData());
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_summary_classifies, map, e.getMessage())) {
                    SobotNetLogUtils.i(SobotCallUrlApi.api_call_summary_classifies + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void getSummaryTemplates(Context context, int currPage, int pageSize, SobotResultCallBack<List<SobotSummaryTemplate>> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("currPage", currPage + "");
        map.put("pageSize", pageSize + "");
        SobotCallHttpUtils.getInstance().doPostByJson(context, context, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_summary_templates, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_summary_templates, map, response, resultCallBack)) {

                    SobotCallBaseCode<SobotSummaryTemplateList> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCode<SobotSummaryTemplateList>>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        if (result.getData() != null && result.getData().getList() != null) {
                            resultCallBack.onSuccess(result.getData().getList());
                        } else {
                            resultCallBack.onSuccess(new ArrayList<>());
                        }
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_summary_templates, map, e.getMessage())) {
                    SobotNetLogUtils.i(SobotCallUrlApi.api_call_summary_templates + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void getCusFieldInfoList(Context context, int businessType, SobotResultCallBack<List<SobotCusFieldEntity>> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("openFlag", "1");
        map.put("businessType", businessType);
        SobotCallHttpUtils.getInstance().doGet(context, context, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_custom_field, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_custom_field, map, response, resultCallBack)) {
                    SobotCallBaseCodeThird<SobotCusFieldEntity> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCodeThird<SobotCusFieldEntity>>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        resultCallBack.onSuccess(result.getItems());
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_custom_field, map, e.getMessage())) {
                    SobotNetLogUtils.i(SobotCallUrlApi.api_call_custom_field + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void searchSummary(Context context, String callID, SobotResultCallBack<SobotSummaryEntity> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        String url = SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_search_summary;
        String finalUrl = url.replace("#CALLID#", callID);
        SobotCallHttpUtils.getInstance().doGet(context, context, finalUrl, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, finalUrl, map, response, resultCallBack)) {
                    SobotCallBaseCode<SobotSummaryEntity> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCode<SobotSummaryEntity>>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        resultCallBack.onSuccess(result.getData());
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(finalUrl, map, e.getMessage())) {
                    SobotNetLogUtils.i(finalUrl + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void handleProgress(Context context, SobotResultCallBack<List<SobotSummaryProgress>> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        String finalUrl = SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_handleprogress;
        SobotCallHttpUtils.getInstance().doGet(context, context, finalUrl, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, finalUrl, map, response, resultCallBack)) {
                    SobotCallBaseCode<List<SobotSummaryProgress>> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCode<List<SobotSummaryProgress>>>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        resultCallBack.onSuccess(result.getData());
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(finalUrl, map, e.getMessage())) {
                    SobotNetLogUtils.i(finalUrl + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void submitSummary(Context context, SobotSummaryEntity summaryModel, int planType, SobotResultCallBack resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("callID", summaryModel.getCallID());
        map.put("companyId", summaryModel.getCompanyId());
        map.put("departmentId", summaryModel.getDepartmentId());
        map.put("customerId", summaryModel.getCustomerId());
        map.put("planType", planType);
        map.put("remark", summaryModel.getRemark());
        map.put("sourceCode", summaryModel.getSourceCode());
        map.put("sourceId", summaryModel.getSourceId());
        map.put("sourceType", summaryModel.getSourceType());
        map.put("summaryClassifyCodes", summaryModel.getSummaryClassifyCodes());
        map.put("summaryClassifyIds", summaryModel.getSummaryClassifyIds());
        map.put("summaryClassifyNames", summaryModel.getSummaryClassifyNames());
        map.put("summaryHandleProgress", summaryModel.getSummaryHandleProgress());
        map.put("summaryHandleProgressName", summaryModel.getSummaryHandleProgressName());
        map.put("summaryTemplateId", summaryModel.getSummaryTemplateId());
        map.put("summaryTemplateName", summaryModel.getSummaryTemplateName());
        map.put("customerFields", summaryModel.getCustomerFieldStr());
        map.put("clientType", 2);

        map.put("version", TextUtils.isEmpty(summaryModel.getVersion()) ? 1 : (Integer.parseInt(summaryModel.getVersion()) + 1));
        if (null != summaryModel.getCustomerFields()) {
            for (int i = 0; i < summaryModel.getCustomerFields().size(); i++) {
                map.put(summaryModel.getCustomerFields().get(i).getFieldId(), summaryModel.getCustomerFields().get(i).getFieldValue());
            }
        }
        String finalUrl = SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_submit_summary;
        SobotCallHttpUtils.getInstance().doPostByJson(context, context, finalUrl, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, finalUrl, map, response, resultCallBack)) {
                    SobotCallBaseCodeThird<SobotCusFieldEntity> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCodeThird<SobotCusFieldEntity>>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        resultCallBack.onSuccess(result.getItems());
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(finalUrl, map, e.getMessage())) {
                    SobotNetLogUtils.i(finalUrl + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void saveCustom(Context context, SobotCallCustomerModel customer, Map<String, String> cusList, SobotResultCallBack<SobotCallCustomerModel> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("nick", customer.getNick());
        map.put("uname", customer.getUname());
        map.put("sex", customer.getSex());
        map.put("email", customer.getEmail());
        map.put("tel", customer.getEncryptCustomerNumber());
        map.put("countryId", customer.getCountryId());
        map.put("countryName", customer.getCountryName());
        map.put("proviceId", customer.getProviceId());
        map.put("proviceName", customer.getProviceName());
        map.put("cityId", customer.getCityId());
        map.put("cityName", customer.getCityName());
        map.put("areaId", customer.getAreaId());
        map.put("areaName", customer.getAreaName());
        if (!TextUtils.isEmpty(customer.getQq())) {
            map.put("qq", customer.getQq());
        }
        if (!TextUtils.isEmpty(customer.getWx())) {
            map.put("wx", customer.getWx());
        }
        map.put("remark", customer.getRemark());
        map.put("source", customer.getSource() + "");
        map.put("vipLevel", customer.getVipLevel());
        map.put("isVip", customer.getIsVip());
        map.put("exFieldStr", customer.getExFieldStr());
        map.put("enterpriseName", customer.getEnterpriseName());
        map.put("enterpriseId", customer.getEnterpriseId());
        if (null != cusList && cusList.size() > 0) {
            map.putAll(cusList);
        }
        String finalUrl = SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_save_custom;
        SobotCallHttpUtils.getInstance().doPost(context, context, finalUrl, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, finalUrl, map, response, resultCallBack)) {
                    SobotCallBaseCodeThird<SobotCallCustomerModel> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCodeThird<SobotCallCustomerModel>>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        SobotCallCustomerModel customerModel = result.getItem();
                        customerModel.setTotalCount(result.totalCount);
                        resultCallBack.onSuccess(customerModel);
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }

                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(finalUrl, map, e.getMessage())) {
                    SobotNetLogUtils.i(finalUrl + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });

    }

    @Override
    public void updateCustom(Context context, SobotCallCustomerModel customer, Map<String, String> cusList, SobotResultCallBack<SobotCallCustomerModel> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("nick", customer.getNick());
        map.put("uname", customer.getUname());
        map.put("sex", customer.getSex());
        map.put("email", customer.getEmail());
        map.put("tel", customer.getEncryptCustomerNumber());
        map.put("countryId", customer.getCountryId());
        map.put("countryName", customer.getCountryName());
        map.put("proviceId", customer.getProviceId());
        map.put("proviceName", customer.getProviceName());
        map.put("cityId", customer.getCityId());
        map.put("cityName", customer.getCityName());
        map.put("areaId", customer.getAreaId());
        map.put("areaName", customer.getAreaName());
        if (!TextUtils.isEmpty(customer.getQq())) {
            map.put("qq", customer.getQq());
        }
        if (!TextUtils.isEmpty(customer.getWx())) {
            map.put("wx", customer.getWx());
        }
        map.put("remark", customer.getRemark());
        map.put("source", customer.getSource() + "");
        map.put("vipLevel", customer.getVipLevel());
        map.put("isVip", customer.getIsVip());
        map.put("exFieldStr", customer.getExFieldStr());
        map.put("enterpriseName", customer.getEnterpriseName());
        map.put("enterpriseId", customer.getEnterpriseId());
        map.put("id", customer.getId());
        if (null != cusList && cusList.size() > 0) {
            map.putAll(cusList);
        }
        String finalUrl = SobotCallBaseUrl.getOpenApiHost() + String.format(SobotCallUrlApi.api_call_update_custom, customer.getId());
        SobotCallHttpUtils.getInstance().doPost(context, context, finalUrl, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, finalUrl, map, response, resultCallBack)) {
                    SobotCallBaseCodeThird<SobotCallCustomerModel> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCodeThird<SobotCallCustomerModel>>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        SobotCallCustomerModel customerModel = result.getItem();
                        customerModel.setTotalCount(result.totalCount);
                        resultCallBack.onSuccess(customerModel);
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(finalUrl, map, e.getMessage())) {
                    SobotNetLogUtils.i(finalUrl + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void searchCustomById(Context context, String customerId, SobotResultCallBack<SobotCallCustomerModel> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        String finalUrl = SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_search_custom + customerId;
        SobotCallHttpUtils.getInstance().doGet(context, context, finalUrl, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, finalUrl, map, response, resultCallBack)) {
                    SobotCallBaseCodeThird<SobotCallCustomerModel> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCodeThird<SobotCallCustomerModel>>() {
                    }.getType());

                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        SobotCallCustomerModel model = result.getItem();
                        try {
                            JSONObject object = new JSONObject(response);
                            JSONObject items = object.optJSONObject("item");
                            if (items != null) {
                                Map<String, String> curList = SobotGsonUtil.jsonToMaps(items.toString());
                                model.setCusList(curList);
                            }
                        } catch (JSONException e) {
                            throw new RuntimeException(e);
                        }
                        resultCallBack.onSuccess(model);
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(finalUrl, map, e.getMessage())) {
                    SobotNetLogUtils.i(finalUrl + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void mergeCustom(Context context, SobotCallCustomerModel user, SobotResultCallBack<SobotCallCustomerModel> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("nick", user.getNick());
        map.put("uname", user.getUname());
        map.put("sex", user.getSex());
        map.put("email", user.getEmail());
        map.put("tel", user.getTel());
        map.put("countryId", user.getCountryId());
        map.put("countryName", user.getCountryName());
        map.put("proviceId", user.getProviceId());
        map.put("proviceName", user.getProviceName());
        map.put("cityId", user.getCityId());
        map.put("cityName", user.getCityName());
        map.put("areaId", user.getAreaId());
        map.put("areaName", user.getAreaName());
        map.put("qq", user.getQq());
        map.put("wx", user.getWx());
        map.put("remark", user.getRemark());
        map.put("source", user.getSource() + "");
        map.put("vipLevel", user.getVipLevel());
        map.put("isVip", user.getIsVip());
        map.put("exFieldStr", user.getCustomFields());
        map.put("enterpriseName", user.getEnterpriseName());
        map.put("enterpriseId", user.getEnterpriseId());
        map.put("id", user.getPartnerId());
        map.put("mergedUserId", user.getMergedUserId());
        map.put("mergeType", user.getMergeType());

        String finalUrl = SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_merge_custom;
        SobotCallHttpUtils.getInstance().doPost(context, context, finalUrl, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, finalUrl, map, response, resultCallBack)) {
                    SobotCallBaseCodeThird<SobotCallCustomerModel> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCodeThird<SobotCallCustomerModel>>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        resultCallBack.onSuccess(result.getItem());
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(finalUrl, map, e.getMessage())) {
                    SobotNetLogUtils.i(finalUrl + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void associationCustom(Context context, String callId, String customId, SobotResultCallBack resultCallBack) {
        String url = String.format(SobotCallUrlApi.api_call_association_custom, callId, customId);
        String finalUrl = SobotCallBaseUrl.getCallApiHost() + url;
        Map<String, String> map = new HashMap<>();//?callID=%s&customerID=%s
//        map.put("callID",callId);
//        map.put("customerID",customId);
        SobotCallHttpUtils.getInstance().doPut(context, context, finalUrl, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, finalUrl, map, response, resultCallBack)) {
                    SobotCallBaseCode result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCode>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        resultCallBack.onSuccess(result.getData());
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(finalUrl, map, e.getMessage())) {
                    SobotNetLogUtils.i(finalUrl + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void getCountryList(Context context, SobotResultCallBack<List<CountryModel>> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        String finalUrl = SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_country;
        SobotCallHttpUtils.getInstance().doGet(context, context, finalUrl, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, finalUrl, map, response, resultCallBack)) {
                    SobotCallBaseCodeFourth<CountryModel> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCodeFourth<CountryModel>>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        resultCallBack.onSuccess(result.getItems());
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(finalUrl, map, e.getMessage())) {
                    SobotNetLogUtils.i(finalUrl + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void getProvinceListByCountryId(Context context, String countryId, SobotResultCallBack<List<ProvinceModel>> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("countryId", countryId);
        String finalUrl = SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_province;
        SobotCallHttpUtils.getInstance().doGet(context, context, finalUrl, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, finalUrl, map, response, resultCallBack)) {
                    SobotCallBaseCodeFourth<ProvinceModel> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCodeFourth<ProvinceModel>>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        resultCallBack.onSuccess(result.getItems());
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(finalUrl, map, e.getMessage())) {
                    SobotNetLogUtils.i(finalUrl + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void getCityList(Context context, String provinceId, SobotResultCallBack<List<CityModel>> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("provinceId", provinceId);
        String finalUrl = SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_city;
        SobotCallHttpUtils.getInstance().doGet(context, context, finalUrl, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, finalUrl, map, response, resultCallBack)) {
                    SobotCallBaseCodeFourth<CityModel> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCodeFourth<CityModel>>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        resultCallBack.onSuccess(result.getItems());
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(finalUrl, map, e.getMessage())) {
                    SobotNetLogUtils.i(finalUrl + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void getAreaList(Context context, String cityId, SobotResultCallBack<List<AreaModel>> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("cityId", cityId);
        String finalUrl = SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_area;
        SobotCallHttpUtils.getInstance().doGet(context, context, finalUrl, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, finalUrl, map, response, resultCallBack)) {
                    SobotCallBaseCodeFourth<AreaModel> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCodeFourth<AreaModel>>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        resultCallBack.onSuccess(result.getItems());
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(finalUrl, map, e.getMessage())) {
                    SobotNetLogUtils.i(finalUrl + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void getEnterpriseList(Context context, int pageNo, int pageSize, String searchValue, SobotResultCallBack<List<EnterPriseModel>> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("pageNo", pageNo);
        map.put("pageSize", pageSize);
        map.put("searchValue", searchValue);
        map.put("searchType", 3);
        String finalUrl = SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_call_enterprise;
        SobotCallHttpUtils.getInstance().doGet(context, context, finalUrl, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, finalUrl, map, response, resultCallBack)) {
                    SobotCallBaseCodeFourth<EnterPriseModel> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCodeFourth<EnterPriseModel>>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        resultCallBack.onSuccess(result.getItems());
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(finalUrl, map, e.getMessage())) {
                    SobotNetLogUtils.i(finalUrl + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void searchCustom(Context context, String searchType, String searchValue, SobotResultCallBack resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("pageNo", 1);
        map.put("pageSize", 15);
        map.put("isblack", 0);
        map.put("searchType", searchType);
        map.put("searchValue", searchValue);
        map.put("searchFlag", 0);
        String finalUrl = SobotCallBaseUrl.getOpenApiHost() + SobotCallUrlApi.api_get_search_user;
        SobotCallHttpUtils.getInstance().doGet(context, context, finalUrl, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, finalUrl, map, response, resultCallBack)) {
                    SobotCallBaseCodeFourth<SobotCallCustomerModel> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCodeFourth<SobotCallCustomerModel>>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        resultCallBack.onSuccess(result.getItems());
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(finalUrl, map, e.getMessage())) {
                    SobotNetLogUtils.i(finalUrl + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void callbacks(Context context, String fromCallID, String sourceType, String sourceId, String switchCurrentTabs, SobotResultCallBack resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("fromCallID", fromCallID);
        map.put("sourceType", sourceType);
        map.put("sourceId", sourceId);
        map.put("switchCurrentTabs", switchCurrentTabs);
        String finalUrl = SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_callbacks;
        SobotCallHttpUtils.getInstance().doGet(context, context, finalUrl, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, finalUrl, map, response, resultCallBack)) {
                    SobotCallBaseCodeFourth<SobotCallCustomerModel> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCodeFourth<SobotCallCustomerModel>>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        resultCallBack.onSuccess(result.getItems());
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(finalUrl, map, e.getMessage())) {
                    SobotNetLogUtils.i(finalUrl + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void queueCheckin(Context context, SobotResultCallBack resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        String finalUrl = SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_queue_checkin;
        SobotCallHttpUtils.getInstance().doGet(context, context, finalUrl, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, finalUrl, map, response, resultCallBack)) {
                    JSONObject result = null;
                    try {
                        result = new JSONObject(response);
                        String retCode = result.optString("retCode", "");
                        if (!TextUtils.isEmpty(retCode) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(retCode)) {
                            int open = 0;
                            try {
                                if (!result.isNull("data")) {
                                    JSONObject object = result.getJSONObject("data");
                                    open = object.optInt("agentSelectQueueCheckin", 0);
                                }
                            } catch (JSONException e) {
                                throw new RuntimeException(e);
                            }
                            resultCallBack.onSuccess(open);
                        } else {
                            resultCallBack.onFailure(new Exception(), (!TextUtils.isEmpty(result.optString("retMsg", "")) && !TextUtils.isEmpty(retCode)) ? result.optString("retMsg", "") : mContext.getResources().getString(R.string.sobot_call_net_error_string));
                        }
                    } catch (JSONException e) {
                        throw new RuntimeException(e);
                    }

                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(finalUrl, map, e.getMessage())) {
                    SobotNetLogUtils.i(finalUrl + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void queueCanSubmitSummary(Context context, String callId, SobotResultCallBack<CanSubmitSummaryModel> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        String url = SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_can_submit_summary;
        String finalUrl = String.format(url, callId);
        SobotCallHttpUtils.getInstance().doGet(context, context, finalUrl, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, finalUrl, map, response, resultCallBack)) {
                    SobotCallBaseCode<CanSubmitSummaryModel> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCode<CanSubmitSummaryModel>>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        resultCallBack.onSuccess(result.getData());
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(finalUrl, map, e.getMessage())) {
                    SobotNetLogUtils.i(finalUrl + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void queueNumberInfo(Context context, String callId, SobotResultCallBack<CallNumberCity> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        String url = SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_number_info;
        String finalUrl = String.format(url, callId);
        SobotCallHttpUtils.getInstance().doGet(context, context, finalUrl, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, finalUrl, map, response, resultCallBack)) {
                    SobotCallBaseCode<CallNumberCity> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCode<CallNumberCity>>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        resultCallBack.onSuccess(result.getData());
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(finalUrl, map, e.getMessage())) {
                    SobotNetLogUtils.i(finalUrl + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void taskDetail(Context context, String campaignId, String recordId, SobotResultCallBack<CallTaskContactModel> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        String url = SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_task_detail;
        String finalUrl = String.format(url, campaignId, recordId);
        SobotCallHttpUtils.getInstance().doGet(context, context, finalUrl, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, finalUrl, map, response, resultCallBack)) {
                    SobotCallBaseCode<CallTaskContactModel> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCode<CallTaskContactModel>>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        resultCallBack.onSuccess(result.getData());
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(finalUrl, map, e.getMessage())) {
                    SobotNetLogUtils.i(finalUrl + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void editTaskDetail(Context context, String campaignId, String recordId, String dataFields, SobotResultCallBack resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("dataFields", dataFields);
        map.put("clientType", 2);
        String url = SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_task_detail;
        String finalUrl = String.format(url, campaignId, recordId);
        SobotCallHttpUtils.getInstance().doPatch(context, context, finalUrl, dataFields, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, finalUrl, map, response, resultCallBack)) {
                    SobotCallBaseCode result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCode>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        resultCallBack.onSuccess("");
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(finalUrl, map, e.getMessage())) {
                    SobotNetLogUtils.i(finalUrl + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void taskSummary(Context context, String campaignId, String recordId, SobotResultCallBack<CallTaskContactModel> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        String url = SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_task_detail_edit;
        String finalUrl = String.format(url, campaignId, recordId);
        SobotCallHttpUtils.getInstance().doGet(context, context, finalUrl, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, finalUrl, map, response, resultCallBack)) {
                    SobotCallBaseCode<CallTaskContactModel> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCode<CallTaskContactModel>>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        resultCallBack.onSuccess(result.getData());
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(finalUrl, map, e.getMessage())) {
                    SobotNetLogUtils.i(finalUrl + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void updateTaskSummary(Context context, String campaignId, String recordId, String dataFields, SobotResultCallBack resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("dataFields", dataFields);
        map.put("clientType",2);
        String url = SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_task_detail_edit;
        String finalUrl = String.format(url, campaignId, recordId);
        SobotCallHttpUtils.getInstance().doPatch(context, context, finalUrl, dataFields, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, finalUrl, map, response, resultCallBack)) {
                    SobotCallBaseCode<CallNumberCity> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCode<CallNumberCity>>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        resultCallBack.onSuccess("");
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(finalUrl, map, e.getMessage())) {
                    SobotNetLogUtils.i(finalUrl + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }

    @Override
    public void taskRecord(Context context, String campaignId, String campaignRecordId, SobotResultCallBack<List<CallMainCDRInfo>> resultCallBack) {
        Map<String, Object> map = new HashMap<>();
        map.put("campaignId", campaignId);
        map.put("campaignRecordId", campaignRecordId);
        map.put("pageNum", 1);
        map.put("pageSize", 1000);
        String finalUrl = SobotCallBaseUrl.getCallApiHost() + SobotCallUrlApi.api_call_task_record;
        SobotCallHttpUtils.getInstance().doPostByJson(context, context, finalUrl, map, new SobotCallHttpUtils.StringCallBack() {
            @Override
            public void onResponse(String response) {
                if (!checkTokenTimeOut(context, finalUrl, map, response, resultCallBack)) {
                    SobotCallBaseCode<SobotCallListEntity<CallMainCDRInfo>> result = SobotGsonUtil.jsonToBeans(response, new TypeToken<SobotCallBaseCode<SobotCallListEntity<CallMainCDRInfo>>>() {
                    }.getType());
                    if (result != null && !TextUtils.isEmpty(result.getRetCode()) && SobotCallConstant.RESULT_SUCCESS_CODE.equals(result.getRetCode())) {
                        resultCallBack.onSuccess(result.getData().getList());
                    } else {
                        resultCallBack.onFailure(new Exception(), (result == null || TextUtils.isEmpty(result.getRetMsg())) ? mContext.getResources().getString(R.string.sobot_call_net_error_string) : result.getRetMsg());
                    }
                }
            }

            @Override
            public void onError(Exception e, String msg, int responseCode) {
                if (!checkErrorMessage(finalUrl, map, e.getMessage())) {
                    SobotNetLogUtils.i(finalUrl + "  请求异常: " + e.getMessage());
                    resultCallBack.onFailure(e, mContext.getResources().getString(R.string.sobot_call_net_error_string));
                }
            }

            @Override
            public void inProgress(int progress) {

            }
        });
    }
}