package com.sobot.callsdk.dialog;

import android.annotation.SuppressLint;
import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.LinearLayout;
import android.widget.PopupWindow;

import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.sobot.callbase.model.SobotExplicitRuleEntity;
import com.sobot.callbase.model.SobotOutboundRoutesEntity;
import com.sobot.callbase.utils.CommonUtils;
import com.sobot.callsdk.R;
import com.sobot.callsdk.v6.adapter.CallRulesAdapter;

import java.util.ArrayList;
import java.util.List;

/**
 * @author: Sobot
 * 2023/7/18
 */
public class OutboundRulesPopDialog {

    private Context mContext;
    private PopItemClick mPopItemClick;//点击事件
    private List<SobotExplicitRuleEntity> leftList;//显示的菜单
    private List<SobotExplicitRuleEntity> rightList;//显示的菜单
    private CallRulesAdapter leftAdapter;
    private CallRulesAdapter rightAdapter;
    private SobotOutboundRoutesEntity outboundRoutes;
    private SobotExplicitRuleEntity leftEntity;//左侧选中
    private SobotExplicitRuleEntity rightEntity;//右侧选中

    private LinearLayout ll_no_data,ll_show_data;


    public OutboundRulesPopDialog(Context context, SobotOutboundRoutesEntity outboundRoutes, PopItemClick popItemClick) {
        this.outboundRoutes = outboundRoutes;
        mContext = context;
        mPopItemClick = popItemClick;
        leftList = new ArrayList<>();
        rightList = new ArrayList<>();
        //初始化数据
        if(null!=outboundRoutes.getExplicitRule()) {
            leftList.addAll(outboundRoutes.getExplicitRule());
            for (int i = 0; i < leftList.size(); i++) {
                if (leftList.get(i).isHasSet()) {
                    leftEntity = leftList.get(i);
                }
            }
            rightList.clear();
            rightList.addAll(getRightList());
        }
    }

    private List<SobotExplicitRuleEntity> getRightList(){
        List<SobotExplicitRuleEntity> list = new ArrayList<>();
        if(null!=leftEntity) {
            if ("1".equals(leftEntity.getCode())) {
                SobotExplicitRuleEntity explicitRule = new SobotExplicitRuleEntity();
                explicitRule.setCode("");
                explicitRule.setName(mContext.getResources().getString(R.string.call_outboud_rules_num));
                explicitRule.setHasSet(true);
                list.add(explicitRule);
            } else if ("2".equals(leftEntity.getCode())) {
                if (outboundRoutes.getExplicitSchema() != null && outboundRoutes.getExplicitSchema().size() > 0) {
                    return outboundRoutes.getExplicitSchema();
                }
            } else if ("3".equals(leftEntity.getCode())) {
                if (outboundRoutes.getExplicitNumbers() != null && outboundRoutes.getExplicitNumbers().size() > 0) {
                    return outboundRoutes.getExplicitNumbers();
                }
            }
        }
        return list;
    }
    public PopupWindow getPopWindow() {

        View mPopView = LayoutInflater.from(mContext).inflate(R.layout.sobot_pop_outbound_rules, null);
        View v_black = mPopView.findViewById(R.id.v_black);
        ll_show_data = mPopView.findViewById(R.id.ll_show_data);
        ll_no_data = mPopView.findViewById(R.id.ll_no_data);
        RecyclerView leftRecyclerView = mPopView.findViewById(R.id.sobot_pop_left);
        RecyclerView rightRecyclerView = mPopView.findViewById(R.id.sobot_pop_right);
        View v_line = mPopView.findViewById(R.id.v_line);
        if(leftList!=null && leftList.size()>0){
            ll_show_data.setVisibility(View.VISIBLE);
            ll_no_data.setVisibility(View.GONE);
        }else {
            ll_show_data.setVisibility(View.GONE);
            ll_no_data.setVisibility(View.VISIBLE);
        }
        leftAdapter = new CallRulesAdapter(mContext, leftList,true, new CallRulesAdapter.ItemOnclickListener() {
            @SuppressLint("NotifyDataSetChanged")
            @Override
            public void itemClick(SobotExplicitRuleEntity explicitRule) {
                explicitRule.setHasSet(true);
                leftEntity = explicitRule;
                for (int i = 0; i < leftList.size(); i++) {
                    if (explicitRule.getCode().equals(leftList.get(i).getCode())) {
                        leftList.get(i).setHasSet(true);
                    } else {
                        leftList.get(i).setHasSet(false);
                    }
                }
                leftAdapter.notifyDataSetChanged();

                if (explicitRule.getCode().equals("1")) {
                    rightRecyclerView.setVisibility(View.GONE);
                    v_line.setVisibility(View.GONE);
                    ViewGroup.MarginLayoutParams marginLayoutParams =
                            (ViewGroup.MarginLayoutParams) leftRecyclerView.getLayoutParams();
                    marginLayoutParams.width = ViewGroup.MarginLayoutParams.MATCH_PARENT;
                    leftRecyclerView.setLayoutParams(marginLayoutParams);
                    mPopItemClick.onPopItemClick(outboundRoutes, leftEntity,rightEntity);
                } else  {
                    ViewGroup.MarginLayoutParams marginLayoutParams =
                            (ViewGroup.MarginLayoutParams) leftRecyclerView.getLayoutParams();
                    marginLayoutParams.width = CommonUtils.dip2px(mContext,124);
                    leftRecyclerView.setLayoutParams(marginLayoutParams);
                    rightRecyclerView.setVisibility(View.VISIBLE);
                    v_line.setVisibility(View.VISIBLE);
                    rightList.clear();
                    rightList.addAll(getRightList());
                    if (rightAdapter != null) {
                        rightAdapter.notifyDataSetChanged();
                    }
                }
            }
        });
        rightAdapter = new CallRulesAdapter(mContext, rightList,false, new CallRulesAdapter.ItemOnclickListener() {
            @Override
            public void itemClick(SobotExplicitRuleEntity explicitRule) {
                rightEntity = explicitRule;
                mPopItemClick.onPopItemClick(outboundRoutes, leftEntity,rightEntity);
            }
        });
        //没有选的情况下
        boolean flag =false;
        if(leftEntity == null && leftList!=null){
            for (int i = 0; i < leftList.size(); i++) {
                if(leftList.get(i).getCode().equals("1")){
                    flag = true;
                }
            }
        }
        if (flag || leftEntity!=null && leftEntity.getCode().equals("1")) {
            rightRecyclerView.setVisibility(View.GONE);
            v_line.setVisibility(View.GONE);
            ViewGroup.MarginLayoutParams marginLayoutParams =
                    (ViewGroup.MarginLayoutParams) leftRecyclerView.getLayoutParams();
            marginLayoutParams.width = ViewGroup.MarginLayoutParams.MATCH_PARENT;
            leftRecyclerView.setLayoutParams(marginLayoutParams);
        }
        leftRecyclerView.setLayoutManager(new LinearLayoutManager(mContext));
        rightRecyclerView.setLayoutManager(new LinearLayoutManager(mContext));
        leftRecyclerView.setAdapter(leftAdapter);
        rightRecyclerView.setAdapter(rightAdapter);
        PopupWindow mPopWindow = new PopupWindow(mPopView,
                ViewGroup.LayoutParams.MATCH_PARENT,
                ViewGroup.LayoutParams.WRAP_CONTENT, true);
        v_black.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                mPopWindow.dismiss();
            }
        });
        return mPopWindow;
    }

    public interface PopItemClick {
        //        * @param explicitRule   外显规则:1：企业号码池随机匹配；2：动态外显号码方案匹配；3：座席号码池指定；单选；
//     * @param explicitCode   动态外显方案编码: 外显规则为动态外显号码方案时必传,2时必传
//     * @param explicitNumber 外显号码:不使用外显规则，直接指定企业的某外显号码呼叫客户，外显号码和外显规则至少需要传一个，1时传外显号，3时传坐席号
        void onPopItemClick(SobotOutboundRoutesEntity item, SobotExplicitRuleEntity leftRule, SobotExplicitRuleEntity rightRule);
    }
}
