package com.sobot.callsdk.listener;

import android.content.Context;

import com.sobot.callbase.api.SobotCallBaseCode;
import com.sobot.callbase.api.SobotCallBaseUrl;
import com.sobot.callbase.api.utils.CallBaseSharedPreferencesUtils;
import com.sobot.callbase.api.utils.SobotStompEventConstant;
import com.sobot.callbase.listener.SobotCallOption;
import com.sobot.callbase.model.CallSipModel;
import com.sobot.callbase.stomp.SobotStompClient;
import com.sobot.callsdk.R;
import com.sobot.callsdk.api.SobotCallServiceFactory;
import com.sobot.callsdk.janus.SobotJanusSipPhoneUtils;
import com.sobot.callsdk.sip.callback.SobotRegistrationCallback;
import com.sobot.callsdk.utils.CallSharedPreferencesUtils;
import com.sobot.callsdk.utils.CallStatusUtils;
import com.sobot.callsdk.utils.SobotCallConstant;
import com.sobot.callsdk.v1.sipphonelibrary.SobotPhoneUtils;
import com.sobot.common.login.SobotLoginTools;
import com.sobot.common.login.model.SobotServiceInfoModel;
import com.sobot.network.http.callback.SobotResultCallBack;
import com.sobot.utils.SobotLogUtils;
import com.sobot.utils.SobotStringUtils;
import com.sobot.widget.ui.toast.SobotToastUtil;

//话机注册状态监听 单例  内部使用
public class SobotRegistrationListener extends SobotRegistrationCallback {

    //注册成功
    public static final String registrationOK = "registrationOK";
    //注册失败
    public static final String registrationFailed = "registrationFailed";
    //用户注销
    public static final String registrationCleared = "registrationCleared";

    private Context context;
    private CallSipModel sipModel;
    private CallBack callBack;
    private String lineStatus;
    private String lineStatusName;
    private boolean unbindExtOnLogout = false;//座席离线后会将绑定的分机号解绑；true-离线解绑；false-离线不解绑；缺省不解绑
    public volatile boolean isLogin;
    public boolean isRegistrationOk;//是否注册成功

    public boolean isUnbindExtOnLogout() {
        return unbindExtOnLogout;
    }

    public void setUnbindExtOnLogout(boolean unbindExtOnLogout) {
        this.unbindExtOnLogout = unbindExtOnLogout;
    }

    public boolean isRegistrationOk() {
        return isRegistrationOk;
    }

    public void setRegistrationOk(boolean registrationOk) {
        isRegistrationOk = registrationOk;
    }

    private SobotRegistrationListener() {
    }

    private static class SinglenHander {
        private static final SobotRegistrationListener instence = new SobotRegistrationListener();
    }

    public static SobotRegistrationListener getInstance() {
        return SinglenHander.instence;
    }

    @Override
    public void registrationOK() {
        isRegistrationOk = true;
        if (SobotCallOption.voipRegisterListener != null) {
            SobotCallOption.voipRegisterListener.registrationOK();
        }
        SobotServiceInfoModel serviceVo = SobotLoginTools.getInstance().getServiceInfo();
        if (serviceVo != null) {
            if (serviceVo.getCallV6Flag() == 1) {
                String status = CallSharedPreferencesUtils.getInstance(context).get(SobotCallConstant.callLoginStatus, CallStatusUtils.V6_OFFLINE);
                SobotLogUtils.i("注册成功后开始,当前坐席状态登录===" + status);
                if (!SobotStompClient.getInstance(context).isConnected()) {
                    String accesstoken =SobotLoginTools.getInstance().getAccessToken();
                    String languageStr = CallBaseSharedPreferencesUtils.getInstance(context).get("SobotLanguageStr", "zh");
                    //连接stomp
                    SobotStompClient.getInstance(context).over(SobotStompClient.ConnectionProviderType.OKHTTP, SobotCallBaseUrl.getStompSocketUri() + "?authorization=Bearer " + accesstoken + "&language=" + languageStr, null, null);
                    SobotLogUtils.i("stomp 链接地址=====" + SobotCallBaseUrl.getStompSocketUri() + "?authorization=Bearer " + accesstoken);
                    SobotStompClient.getInstance(context).connectStomp(0);
                }
                if (CallStatusUtils.V6_OFFLINE.equals(status)) {
                    if (SobotStompClient.getInstance(context) != null) {
                        try {
                            Thread.sleep(500);
                        } catch (InterruptedException e) {
                            e.printStackTrace();
                        }
//                        CallSharedPreferencesUtils.getInstance(context).get(SobotCallConstant.AgentLoginInput.phoneType);
//                        CallSharedPreferencesUtils.getInstance(context).get(SobotCallConstant.AgentLoginInput.bindExt);
//                        CallSharedPreferencesUtils.getInstance(context).get(SobotCallConstant.AgentLoginInput.bindMobile);
                        SobotLogUtils.d("坐席登录 状态===" + lineStatus);
                        if (SobotStringUtils.isEmpty(lineStatus)) {
                            lineStatus = CallStatusUtils.V6_FREE;
                            SobotLogUtils.d("坐席登录 状态==11==" + lineStatus);
                        } else if (CallStatusUtils.V6_OFFLINE.equals(lineStatus)) {
                            lineStatus = CallStatusUtils.V6_FREE;
                            SobotLogUtils.d("坐席登录 状态==22===" + lineStatus);
                        }
                        String thisQueues = CallSharedPreferencesUtils.getInstance(context).get(SobotCallConstant.AgentLoginInput.thisQueues);
                        String currentTime = System.currentTimeMillis() + "";
                        SobotStompClient.getInstance(context).send("/cc/app/request", "{\n" +
                                "    \"messageID\": \"" + SobotStompEventConstant.RequestAgentLogin + "\",\n" +
                                "    \"referenceID\": " + currentTime + ",\n" +
                                "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                                "    \"agentType\": \"1\",\n" +
                                "    \"agentState\": \"" + lineStatus + "\",\n" +
                                "    \"phoneType\": \"webrtc\",\n" +
                                "    \"bindExt\": \"" + SobotJanusSipPhoneUtils.getmUsername() + "\",\n" +
                                "    \"bindMobile\": \"" + CallSharedPreferencesUtils.getInstance(context).get(SobotCallConstant.AgentLoginInput.bindMobile) + "\",\n" +
                                "    \"unbindExtOnLogout\": " + isUnbindExtOnLogout() + ",\n\"edgeOut\": \"1\"," +
                                "    \"userData\": {\n" +
                                "        \"__fromChannel\": \"SobotMobilePhone\"" +
                                "    },\n" +
                                (SobotStringUtils.isEmpty(thisQueues) ? "" : "    \"thisQueues\": " + thisQueues + " ,\n") +
                                "    \"creationTime\": " + currentTime + "\n" +
                                "}\n").subscribe();
                    }
                }
                //v6
            } else {
                String status = CallSharedPreferencesUtils.getInstance(context).get(SobotCallConstant.callLoginStatus, CallStatusUtils.OFF_LINE);
                SobotLogUtils.i("注册成功后开始,当前坐席状态登录===" + status);
                if (CallStatusUtils.OFF_LINE.equals(status) || CallStatusUtils.ERROR_SIP.equals(status)) {
                    //v1
                    int callWay = CallSharedPreferencesUtils.getInstance(context).get(SobotCallConstant.SP_KEY_CALL_MODEL_TYPE_V1, SobotCallConstant.CALL_MODEL_PHONE);
                    SobotCallServiceFactory.createZhiChiApi(context).appAgentLogin(this, context, callWay, sipModel.getAgentNumber(), new SobotResultCallBack<SobotCallBaseCode>() {
                        @Override
                        public void onSuccess(SobotCallBaseCode sobotCallBaseCode) {
                            if (sobotCallBaseCode != null && SobotCallConstant.RESULT_SUCCESS_CODE.equals(sobotCallBaseCode.getRetCode())) {
                                if (callBack != null)
                                    callBack.callStatus(lineStatus, lineStatusName, false, context.getResources().getString(R.string.sobot_call_login_success));
                            } else {//登录失败
                                if (sobotCallBaseCode != null) {
                                    SobotPhoneUtils.logoutUser();//注销sip;
                                    isLogin = false;
                                    SobotPhoneUtils.stopService(context);
                                    SobotToastUtil.showToast(context, sobotCallBaseCode.getRetMsg());
                                    if (callBack != null)
                                        callBack.callTitle(context.getResources().getString(R.string.sobot_custom_offline), false);
                                }
                            }
                        }

                        @Override
                        public void onFailure(Exception e, String des) {

                        }
                    });
                }
            }
        }
    }


    @Override
    public void registrationFailed() {
        isRegistrationOk = false;
        if (SobotCallOption.voipRegisterListener != null) {
            SobotCallOption.voipRegisterListener.registrationFailed();
        }
    }

    @Override
    public void registrationCleared() {
        isRegistrationOk = false;
        if (SobotCallOption.voipRegisterListener != null) {
            SobotCallOption.voipRegisterListener.registrationCleared();
        }
    }

    public void setSipModel(CallSipModel sipModel) {
        this.sipModel = sipModel;
    }

    public void setContext(Context context) {
        this.context = context.getApplicationContext();
    }

    public void setCallBack(CallBack callBack) {
        this.callBack = callBack;
    }

    public CallBack getCallBack() {
        return callBack;
    }

    public void setLineStatus(String lineStatus) {
        this.lineStatus = lineStatus;
    }

    public String getLineStatusName() {
        return lineStatusName;
    }

    public void setLineStatusName(String lineStatusName) {
        this.lineStatusName = lineStatusName;
    }

    public interface CallBack {
        void callStatus(String lineStatus, String lineStatusName, boolean isShowToast, String toastString);

        void callTitle(String lineStatusText, boolean isShowToast);
    }
}
