package com.sobot.callsdk.sip;

import android.app.Activity;
import android.content.Context;

import com.sobot.callsdk.janus.SobotJanusSipPhoneUtils;
import com.sobot.callsdk.sip.callback.SobotPhoneCallback;
import com.sobot.callsdk.sip.callback.SobotRegistrationCallback;
import com.sobot.callsdk.v1.sipphonelibrary.SobotPhoneUtils;

public class SobotSipUtils {

    /**
     * 开启服务
     *
     * @param context 上下文
     */
    public static void startService(boolean isV6, Context context) {
        if (isV6) {
            SobotJanusSipPhoneUtils.startService(context);
        } else {
            SobotPhoneUtils.startService(context);
        }
    }

    /**
     * 关闭服务
     *
     * @param context 上下文
     */
    public static void stopService(boolean isV6, Context context) {
        if (isV6) {
            SobotJanusSipPhoneUtils.stopService(context);
        } else {
            SobotPhoneUtils.stopService(context);
        }
    }


    /**
     * 添加注册状态、通话状态回调
     *
     * @param phoneCallback        通话回调,可为null
     * @param registrationCallback 注册状态回调,可为null
     */
    public static void addPhoneCallStatesback(boolean isV6, SobotRegistrationCallback registrationCallback, SobotPhoneCallback phoneCallback) {
        if (isV6) {

        } else {
            SobotPhoneUtils.addPhoneCallStatesback(registrationCallback, phoneCallback);
        }
    }


    /**
     * 设置 sip 账户信息
     *
     * @param userName 账号名
     * @param password 密码
     * @param serverIP IP地址：端口号
     */
    public static void setAccount(boolean isV6, String userName, String password, String serverIP) {
        if (isV6) {
            SobotJanusSipPhoneUtils.setAccount(userName, password, serverIP);
        } else {
            SobotPhoneUtils.setAccount(userName, password, serverIP, 1);
        }
    }


    /**
     * 登录到 SIP 服务器
     */
    public static void login(boolean isV6, Activity context) {
        if (isV6) {
            SobotJanusSipPhoneUtils.login(context.getApplicationContext());
        } else {
            SobotPhoneUtils.login();
        }
    }


    /**
     * 注销账户
     */
    public static void logoutUser(boolean isV6) {
        if (isV6) {
            SobotJanusSipPhoneUtils.logoutUser();
        } else {
            SobotPhoneUtils.logoutUser();
        }
    }


    /**
     * 接通电话
     */
    public static void accept(boolean isV6, Context context, String jsep) {
        if (isV6) {
            SobotJanusSipPhoneUtils.accept(context, jsep);
        } else {
            SobotPhoneUtils.accept(context);
        }
    }


    /**
     * 挂断电话
     */
    public static void hangUp(boolean isV6) {
        if (isV6) {
            SobotJanusSipPhoneUtils.hangUp();
        } else {
            SobotPhoneUtils.hangUp();
        }
    }

    /**
     * 切换静音
     *
     * @param isMicMuted 是否静音
     */
    public static void toggleMicro(boolean isV6, boolean isMicMuted) {
        if (isV6) {
            SobotJanusSipPhoneUtils.toggleMicro(isMicMuted);
        } else {
            SobotPhoneUtils.toggleMicro(isMicMuted);
        }
    }


    /**
     * 日志开关
     *
     * @param isOpenLog true 打开 false 关闭 默认打开
     */
    public static void isOpenLog(boolean isOpenLog) {
        SobotJanusSipPhoneUtils.isOpenLog(isOpenLog);
        SobotPhoneUtils.isOpenLog(isOpenLog);
    }


    public static boolean isServiceRun(boolean isV6) {
        if (isV6) {
            return SobotJanusSipPhoneUtils.isServiceRun();
        } else {
            return SobotPhoneUtils.isServiceRun();
        }
    }
}