package com.sobot.callsdk.utils;

import android.app.Activity;
import android.app.Application;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;

import com.sobot.callbase.constant.SobotCallBaseConstant;
import com.sobot.callbase.widget.floatwindow.FloatingWindowPermissionUtil;
import com.sobot.callbase.widget.floatwindow.IFloatWindow;
import com.sobot.callbase.widget.floatwindow.MoveType;
import com.sobot.callbase.widget.floatwindow.Screen;
import com.sobot.callbase.widget.floatwindow.SobotFloatWindow;
import com.sobot.utils.SobotLogUtils;
import com.sobot.utils.SobotStringUtils;
import com.sobot.widget.ui.toast.SobotToastUtil;

import java.lang.ref.WeakReference;

public class MyActivityLifeCycle implements Application.ActivityLifecycleCallbacks {
    private Handler mHandler = new Handler(Looper.getMainLooper());
    private boolean mPaused = true;
    private Runnable mCheckForegroundRunnable;
    private boolean mForeground = false;
    private static MyActivityLifeCycle sInstance;
    //当前Activity的弱引用
    private WeakReference<Activity> mActivityReference;

    protected final String TAG = "MyActivityLifeCycle";

    //打开的Activity数量统计
    private int activityStartCount = 0;


    private MyActivityLifeCycle() {
    }

    public static synchronized MyActivityLifeCycle getInstance() {
        if (sInstance == null) {
            sInstance = new MyActivityLifeCycle();
        }
        return sInstance;
    }

    public Activity getCurrentActivity() {
        if (mActivityReference != null) {
            return mActivityReference.get();
        }
        return null;
    }

    public boolean isForground() {
        return mForeground;
    }

    @Override
    public void onActivityCreated(Activity activity, Bundle savedInstanceState) {
        Log.d(TAG, activity.getLocalClassName() + " " + "onActivityCreated");
        mActivityReference = new WeakReference<Activity>(activity);
    }

    @Override
    public void onActivityStarted(Activity activity) {
        Log.d(TAG, activity.getLocalClassName() + " " + "onActivityStarted");
        activityStartCount++;
        //数值从0变到1说明是从后台切到前台
        if (activityStartCount == 1) {
            mForeground = true;
            //从后台切到前台
            SobotLogUtils.i("从后台切到前台");
            boolean showTipFloat= CallSharedPreferencesUtils.getInstance(activity).get("showTipFloat",false);
            if(showTipFloat){
                //系统锁定
                String mMessageTop = activity.getResources().getString(com.sobot.callbase.R.string.call_str_system_Lock);
                String mMessage = activity.getResources().getString(com.sobot.callbase.R.string.call_str_system_Lock_tip);
                showTipFloat(activity,mMessageTop, mMessage);
                CallSharedPreferencesUtils.getInstance(activity).put("showTipFloat",false);
            }
        }

    }
    private void showTipFloat(Activity activity,String mMessageTop, String mMessage){
        if (FloatingWindowPermissionUtil.hasSuspendedWindowPermission(activity.getApplicationContext())) {
            //提示浮层
            IFloatWindow iFloatWindow = SobotFloatWindow.get(SobotCallBaseConstant.CALL_TIP_FLOAT);

            if (iFloatWindow != null) {
                iFloatWindow.show();
            } else {
                SobotFloatWindow.B floatWindow = SobotFloatWindow
                        .with(activity.getApplicationContext())
                        .setView(com.sobot.callbase.R.layout.call_dialog_common_tip)
                        .setTag(SobotCallBaseConstant.CALL_TIP_FLOAT)
                        .setX(Screen.width, 0.1f)
                        .setY(Screen.height, 0.36f)
                        .setWidth(Screen.width, 0.8f)
                        .setMoveType(MoveType.inactive)
                        .setDesktopShow(true);
                floatWindow.build();
                if (SobotFloatWindow.get(SobotCallBaseConstant.CALL_TIP_FLOAT) != null) {
                    SobotFloatWindow.get(SobotCallBaseConstant.CALL_TIP_FLOAT).show();
                }
            }
            View statusFloatView = SobotFloatWindow.get(SobotCallBaseConstant.CALL_TIP_FLOAT).getView();
            TextView tv_message_top = statusFloatView.findViewById(com.sobot.callbase.R.id.tv_message_top);
            TextView tv_message = statusFloatView.findViewById(com.sobot.callbase.R.id.tv_message);
            tv_message_top.setText(SobotStringUtils.checkStringIsNull(mMessageTop));
            tv_message.setText(SobotStringUtils.checkStringIsNull(mMessage));
            Button btn_cancel = statusFloatView.findViewById(com.sobot.callbase.R.id.btn_cancel);
            btn_cancel.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    if (SobotFloatWindow.get(SobotCallBaseConstant.CALL_TIP_FLOAT) != null) {
                        SobotFloatWindow.destroy(SobotCallBaseConstant.CALL_TIP_FLOAT);
                    }
                }
            });
            statusFloatView.setOnClickListener(null);
        } else {
            if (!SobotStringUtils.isEmpty(mMessageTop) || !SobotStringUtils.isEmpty(mMessage)) {
                String tip = "";
                if (!SobotStringUtils.isEmpty(mMessage)) {
                    tip = tip + SobotStringUtils.checkStringIsNull(mMessage);
                } else {
                    if (!SobotStringUtils.isEmpty(mMessageTop)) {
                        tip = tip + SobotStringUtils.checkStringIsNull(mMessageTop);
                    }
                }
                if (!SobotStringUtils.isEmpty(tip)) {
                    SobotToastUtil.showCustomLongToast(activity, tip);
                }
            }
        }
    }

    @Override
    public void onActivityResumed(Activity activity) {
        String activityName = activity.getClass().getName();
        mPaused = false;
        if (mCheckForegroundRunnable != null) {
            mHandler.removeCallbacks(mCheckForegroundRunnable);
        }
        mActivityReference = new WeakReference<Activity>(activity);
    }

    @Override
    public void onActivityPaused(Activity activity) {//pause事件后是否在前台要分情况判断
        mPaused = true;
        if (mCheckForegroundRunnable != null) {
            mHandler.removeCallbacks(mCheckForegroundRunnable);
        }
    }

    @Override
    public void onActivityStopped(Activity activity) {
        Log.d(TAG, activity.getLocalClassName() + " " + "onActivityStopped");
        activityStartCount--;
        //数值从1到0说明是从前台切到后台
        if (activityStartCount == 0) {
            mForeground = false;
            //从前台切到后台
            SobotLogUtils.i("从前台切到后台");
            if (SobotFloatWindow.get(SobotCallBaseConstant.CALL_TIP_FLOAT) != null) {
                SobotFloatWindow.destroy(SobotCallBaseConstant.CALL_TIP_FLOAT);
            }
        }

    }

    @Override
    public void onActivitySaveInstanceState(Activity activity, Bundle outState) {

    }

    @Override
    public void onActivityDestroyed(Activity activity) {
        Log.d(TAG, activity.getLocalClassName() + " " + "onActivityDestroyed");
    }

    private void BackToFrontChanged() {

    }


}
