package com.sobot.callsdk.utils;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.text.TextUtils;

import com.sobot.callbase.model.SobotLoginStatusEntity;
import com.sobot.callsdk.activity.SobotCallBaseActivity;
import com.sobot.callsdk.api.SobotCallService;
import com.sobot.callsdk.api.SobotCallServiceFactory;
import com.sobot.callsdk.model.SobotCall3Response;
import com.sobot.callsdk.model.SobotCallCenterStatus;
import com.sobot.callsdk.v1.activity.SobotCallStatusActivity;
import com.sobot.callsdk.v1.constant.SobotCallLiveDataBusV1Key;
import com.sobot.callsdk.v1.entity.v1.SobotCallSeatCurrentStatus;
import com.sobot.common.utils.SobotGlobalContext;
import com.sobot.network.http.callback.SobotResultCallBack;
import com.sobot.widget.livedatabus.SobotLiveEventBus;

import java.util.ArrayList;
import java.util.List;

public class SobotCallApiUtils {

    //-------------------------------------------------- V1 start--------------------------
    //获取 当前  呼叫客服之前的状态
    public static void appGetAgentStatus(SobotCallService zhiChiApi, Context context, SobotResultCallBack<SobotCallSeatCurrentStatus> callback) {
        if (zhiChiApi != null) {
            zhiChiApi.appGetAgentStatus(context, new SobotResultCallBack<SobotCallSeatCurrentStatus>() {
                @Override
                public void onSuccess(SobotCallSeatCurrentStatus model) {
                    if (model != null && !TextUtils.isEmpty(model.getAgentStatus())) {
                        if (CallStatusUtils.RINGING.equals(model.getAgentStatus()) && (!"null".equals(model.getDirection()) && !TextUtils.isEmpty(model.getDirection()))) {//有字段
                            if ("1".equals(model.getDirection())) {//拨号中
                                model.setAgentStatus(CallStatusUtils.interior_dialing_a);
                            }
                            if ("0".equals(model.getDirection())) {//振铃中
                                if (!TextUtils.isEmpty(model.getCallWay()) && SobotCallConstant.CALL_MODEL_SIP_STR.equals(model.getCallWay()) && SobotGlobalContext.getAppContext() != null) {
                                    Activity activity = SobotGlobalContext.getInstance().currentActivity();
                                    //跳转到来电界面
                                    if (activity == null) {
                                        Intent intent = SobotCallStatusActivity.initCallMeIntent(context, "", "", "", "", 0, SobotCallConstant.CALL_MODEL_SIP);
                                        intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
                                        context.startActivity(intent);
                                    } else {
                                        if (!(activity instanceof SobotCallStatusActivity)) {
                                            Intent intent = SobotCallStatusActivity.initCallMeIntent(context, "", "", "", "", 0, SobotCallConstant.CALL_MODEL_SIP);
                                            intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
                                            context.startActivity(intent);
                                        }
                                    }
                                }
                                model.setAgentStatus(CallStatusUtils.interior_ringing_b);
                            }
                        }

                        if (CallStatusUtils.CALLING.equals(model.getAgentStatus())) {//通话中
                            if ("0".equals(model.getCallout())) {//拨号中
                                model.setAgentStatus(CallStatusUtils.interior_dialing_a);
                            }
                        }
                        CallSharedPreferencesUtils.getInstance(context).put(SobotCallConstant.callLoginStatus, model.getAgentStatus());
                        CallSharedPreferencesUtils.getInstance(context).put(SobotCallConstant.SP_KEY_CALL_MODEL_TYPE_V1, Integer.parseInt(model.getCallWay()));
                        CallSharedPreferencesUtils.getInstance(context).put(SobotCallConstant.SP_KEY_USER_PHONE, model.getAgentNumber());
                        SobotLiveEventBus.get(SobotCallLiveDataBusV1Key.set_call_seat_status).post(true);
                        if (callback != null) {
                            callback.onSuccess(model);
                        }
                    }
                }

                @Override
                public void onFailure(Exception e, String des) {

                }
            });
        }
    }


    //获取 当前  呼叫客服状态列表v1
    public static void getCallServiceStatusList(SobotCallService zhiChiApi, Object tag, Context context, SobotResultCallBack<SobotCall3Response<SobotCallCenterStatus>> callback) {
        zhiChiApi.getCallServiceStatus(tag, context, new SobotResultCallBack<SobotCall3Response<SobotCallCenterStatus>>() {
            @Override
            public void onSuccess(SobotCall3Response<SobotCallCenterStatus> call3Response) {
                if (call3Response != null && call3Response.item != null && call3Response.item.getData() != null) {
                    ArrayList<SobotCallCenterStatus> data = call3Response.item.getResult();
                    CallSharedPreferencesUtils.getInstance(context).remove(SobotCallConstant.callStatusList_v1);
                    CallSharedPreferencesUtils.getInstance(context).put(SobotCallConstant.callStatusList_v1, data);
                    if (callback != null) {
                        callback.onSuccess(call3Response);
                    }
                }
            }

            @Override
            public void onFailure(Exception e, String des) {

            }
        });
    }
//-------------------------------------------------- V1 start--------------------------


    //-------------------------------------------------- V6 start--------------------------
    //v6 获取 当前  呼叫客服状态列表
    public static void getLoginStatusV6(SobotCallService zhiChiApi, Object tag, Context context, SobotResultCallBack<List<SobotLoginStatusEntity>> callback) {
        zhiChiApi.getLoginStatus(tag, new SobotResultCallBack<List<SobotLoginStatusEntity>>() {
            @Override
            public void onSuccess(List<SobotLoginStatusEntity> sobotLoginStatusEntities) {
                if (sobotLoginStatusEntities != null) {
                    CallSharedPreferencesUtils.getInstance(context).remove(SobotCallConstant.callStatusList_v6);
                    CallSharedPreferencesUtils.getInstance(context).put(SobotCallConstant.callStatusList_v6, sobotLoginStatusEntities);
                    if (callback != null) {
                        callback.onSuccess(sobotLoginStatusEntities);
                    }
                }
            }

            @Override
            public void onFailure(Exception e, String des) {

            }
        });
    }

    //根据code 获取坐席状态名字
    public static String getLoginStatusV6(Context context, String statueCode) {
        String statusName = "";
        List<SobotLoginStatusEntity> sobotLoginStatusEntities = CallSharedPreferencesUtils.getInstance(context).get(SobotCallConstant.callStatusList_v6, ArrayList.class);
        if (sobotLoginStatusEntities != null) {
            for (int i = 0; i < sobotLoginStatusEntities.size(); i++) {
                if (statueCode.equals(sobotLoginStatusEntities.get(i).getCode())) {
                    statusName = sobotLoginStatusEntities.get(i).getName();
                    break;
                }
            }
        }
        return statusName;
    }
    //-------------------------------------------------- V6 end--------------------------

    public static SobotCallService zhiChiApi = null;

    public static SobotCallService getZhiChiApi(Context context) {
        if (zhiChiApi == null) {
            synchronized (SobotCallBaseActivity.class) {
                if (zhiChiApi == null) {
                    zhiChiApi = SobotCallServiceFactory.createZhiChiApi(context);
                }
            }
        }
        return zhiChiApi;
    }
}
