package com.sobot.callsdk.v1.activity;


import android.content.Intent;
import android.graphics.drawable.Drawable;
import android.text.TextUtils;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.sobot.callbase.api.SobotCallBaseResult;
import com.sobot.callbase.api.utils.SobotCallUtils;
import com.sobot.callbase.dialog.SobotCallCommonDialog;
import com.sobot.callsdk.R;
import com.sobot.callsdk.activity.SobotCallBaseActivity;
import com.sobot.callsdk.api.SobotCallBaseCodeGroup;
import com.sobot.callsdk.utils.CallSharedPreferencesUtils;
import com.sobot.callsdk.utils.SobotCallConstant;
import com.sobot.callsdk.v1.adapter.SobotCallPlanAdapter;
import com.sobot.callsdk.v1.entity.v1.SobotCallContactPlan;
import com.sobot.callsdk.v1.viewholder.SwipeItemTouchListener;
import com.sobot.network.http.callback.SobotResultCallBack;
import com.sobot.utils.SobotStringUtils;
import com.sobot.widget.loading.SobotLoadingLayout;
import com.sobot.widget.refresh.layout.SobotRefreshLayout;
import com.sobot.widget.refresh.layout.api.RefreshLayout;
import com.sobot.widget.refresh.layout.footer.ClassicsFooter;
import com.sobot.widget.refresh.layout.header.ClassicsHeader;
import com.sobot.widget.refresh.layout.listener.OnLoadMoreListener;
import com.sobot.widget.refresh.layout.listener.OnRefreshListener;
import com.sobot.widget.ui.toast.SobotToastUtil;

import java.util.ArrayList;
import java.util.List;

/**
 * 联系计划列表页
 */
public class SobotCallPlanActivity extends SobotCallBaseActivity implements SobotCallPlanAdapter.OnItemClickListener {

    private int pageNo = 1;
    private int pageSize = 20;
    private SobotRefreshLayout refreshLayout;
    private RecyclerView recyclerView;
    private SobotLoadingLayout loadingLayout;
    private SobotCallPlanAdapter mAdapter;
    private List<SobotCallContactPlan> mDate;
    private boolean isHasMoreData = false;

    @Override
    protected int getContentViewResId() {
        return R.layout.sobot_activity_call_record;
    }

    @Override
    protected void initView() {
        setTitle(getResources().getString(R.string.sobot_call_plan));
        Drawable drawable = getResources().getDrawable(R.drawable.sobot_call_title_back_selector);
        drawable.setBounds(0, 0, drawable.getMinimumWidth(), drawable.getMinimumHeight());
        getLeftMenu().setCompoundDrawables(drawable, null, null, null);

        refreshLayout = findViewById(getResId("sobot_srl_call_record"));
        recyclerView = findViewById(getResId("sobot_rv_record_list"));
        loadingLayout = findViewById(getResId("sobot_loading_layout"));

        //列表
        recyclerView.setLayoutManager(new LinearLayoutManager(getSobotBaseContext()));
        mDate = new ArrayList<>();
        mAdapter = new SobotCallPlanAdapter(this,mDate,this);
        recyclerView.setAdapter(mAdapter);
        //横向滑动删除
        recyclerView.addOnItemTouchListener(new SwipeItemTouchListener());

        //下拉刷新控件
        refreshLayout.setRefreshHeader(new ClassicsHeader(this));
        refreshLayout.setRefreshFooter(new ClassicsFooter(this));
        refreshLayout.setEnableLoadMore(true);
        refreshLayout.setOnLoadMoreListener(new OnLoadMoreListener() {
            @Override
            public void onLoadMore(@NonNull  RefreshLayout refreshLayout) {
                if (isHasMoreData) {
                    requestDate(pageNo + 1);
                } else {
                    refreshLayout.setNoMoreData(true);
                }
            }
        });
        refreshLayout.setOnRefreshListener(new OnRefreshListener() {
            @Override
            public void onRefresh(@NonNull  RefreshLayout refreshLayout) {
                pageNo = 1;
                requestDate(pageNo);
            }
        });
        refreshLayout.setNoMoreData(true);

        //是否显示无内容
        loadingLayout.setRetryListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                pageNo = 1;
                requestDate(pageNo);
            }
        });
    }

    @Override
    protected void initData() {
        if(isCallV6()){
            refreshLayout.finishLoadMore();
            refreshLayout.finishRefresh();
            loadingLayout.showEmpty();
        }else {
            requestDate(pageNo);
        }
    }
    private void requestDate(int pageIndex){
        zhiChiApi.getAllCallContactPlan(this, this, pageNo, pageSize, new SobotResultCallBack<List<SobotCallContactPlan>>() {
            @Override
            public void onSuccess(List<SobotCallContactPlan> sobotCallContactPlans) {
                refreshLayout.finishRefresh();//停止刷新
                pageNo = pageIndex;
                if(pageIndex==1){
                    mDate.clear();//刷新时清空列表
                    if(sobotCallContactPlans.size() == 0){
                        isHasMoreData = false;
                        loadingLayout.showEmpty();//显示无内容
                        return;
                    }
                }
                if(sobotCallContactPlans.size()<pageSize){
                    //加载完毕
                    isHasMoreData = false;
                    refreshLayout.setNoMoreData(true);
                }else{
                    //有 下一页
                    isHasMoreData = true;
                    refreshLayout.setNoMoreData(false);
                }

                mDate.addAll(sobotCallContactPlans);
                mAdapter.notifyDataSetChanged();
                loadingLayout.showContent();//显示列表
                refreshLayout.finishLoadMore();
            }

            @Override
            public void onFailure(Exception e, String des) {
                refreshLayout.finishLoadMore();
                refreshLayout.finishRefresh();
                if (pageIndex == 1) {
                    loadingLayout.showEmpty();
                } else {
                    SobotToastUtil.showCustomToast(getApplicationContext(), SobotStringUtils.isEmpty(des) ? getResources().getString(R.string.sobot_call_net_error_string) : des, R.drawable.sobot_icon_warning_attention);
                }
            }
        });
    }

    @Override
    public void onItemClick(SobotCallContactPlan data) {
        //呼叫号码
        if (data != null && !TextUtils.isEmpty(data.getCustomerPhoneNo())) {
            String phoneNum = data.getCustomerPhoneNo();
            String screenNum= SobotCallUtils.hidePhone(phoneNum,data.getHiddenFlag());
            SobotCallCommonDialog dialog = new SobotCallCommonDialog(screenNum,
                    getResources().getString(R.string.sobot_call_up), new SobotCallCommonDialog.OnBtnClickListener() {
                @Override
                public void onClick() {
                    //调用呼叫接口打电话
                    if(isCallV6()){
                        Intent intent = SobotCallStatusActivity.initIntent(SobotCallPlanActivity.this, phoneNum,"",screenNum);
                        intent.setFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP | Intent.FLAG_ACTIVITY_CLEAR_TOP |
                                Intent.FLAG_ACTIVITY_NEW_TASK);
                        startActivity(intent);
                    }else {
                        final String groupId = CallSharedPreferencesUtils.getInstance(getApplicationContext()).get(SobotCallConstant.SP_KEY_CALL_GROUP_ID, "");
                        if (TextUtils.isEmpty(groupId)) {
                            zhiChiApi.queryGroupListV1(SobotCallPlanActivity.this, SobotCallPlanActivity.this, new SobotResultCallBack<SobotCallBaseCodeGroup>() {
                                @Override
                                public void onSuccess(SobotCallBaseCodeGroup stringSobotCallBaseCodeThird) {
                                    if (stringSobotCallBaseCodeThird != null && !SobotStringUtils.isEmpty(stringSobotCallBaseCodeThird.item)) {
                                        CallSharedPreferencesUtils.getInstance(getApplicationContext()).put(SobotCallConstant.SP_KEY_CALL_GROUP_ID, stringSobotCallBaseCodeThird.item);
                                        Intent intent = SobotCallStatusActivity.initIntent(SobotCallPlanActivity.this, phoneNum, stringSobotCallBaseCodeThird.item, screenNum);
                                        intent.setFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP | Intent.FLAG_ACTIVITY_CLEAR_TOP |
                                                Intent.FLAG_ACTIVITY_NEW_TASK);
                                        startActivity(intent);
                                    }
                                }

                                @Override
                                public void onFailure(Exception e, String des) {

                                }
                            });
                        } else {
                            Intent intent = SobotCallStatusActivity.initIntent(SobotCallPlanActivity.this, phoneNum, groupId, screenNum);
                            intent.setFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP | Intent.FLAG_ACTIVITY_CLEAR_TOP |
                                    Intent.FLAG_ACTIVITY_NEW_TASK);
                            startActivity(intent);
                        }
                    }
                }
            }, getResources().getString(R.string.sobot_call_cancel), null);
            dialog.setCanceledOnTouchOutside(false);
            dialog.show(getSupportFragmentManager(), "dialog");
        }
    }

    @Override
    public void onItemDetail(SobotCallContactPlan record) {
        //计划详情
        Intent intent = new Intent(SobotCallPlanActivity.this, SobotAddCallPlanActivity.class);
        intent.putExtra("fromFlag", false);
        intent.putExtra("model", record);
        intent.putExtra("userPhone", record.getCustomerPhoneNo());
        startActivityForResult(intent,3000);
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, @Nullable Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        if(requestCode == 3000&&resultCode == SobotCallConstant.ACTIVITY_RESULT_NEED_REFRESH){
            pageNo = 1;
            requestDate(pageNo);
        }
    }

    @Override
    public void onItemDelete(SobotCallContactPlan data,int position) {
        //删除
        if (data != null && !TextUtils.isEmpty(data.getId())) {
            zhiChiApi.deleteCallContactPlanInfo(SobotCallPlanActivity.this, SobotCallPlanActivity.this, data.getId(), new SobotResultCallBack<SobotCallBaseResult>() {
                @Override
                public void onSuccess(SobotCallBaseResult sobotCallBaseResult) {
                    if (sobotCallBaseResult != null &&  SobotCallConstant.RESULT_SUCCESS_CODE.equals(sobotCallBaseResult.getRetCode())) {
                        SobotToastUtil.showCustomToast(SobotCallPlanActivity.this,getResources().getString(R.string.sobot_task_state_deleted),R.drawable.sobot_iv_call_right);
                        mDate.remove(position);
                        mAdapter.notifyDataSetChanged();
                    }
                }

                @Override
                public void onFailure(Exception e, String des) {

                }
            });
        }
    }
}