package com.sobot.callsdk.v1.activity;

import android.annotation.SuppressLint;
import android.content.Intent;
import android.graphics.drawable.Drawable;
import android.text.TextUtils;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.sobot.callbase.api.utils.SobotCallUtils;
import com.sobot.callbase.dialog.SobotCallCommonDialog;
import com.sobot.callsdk.R;
import com.sobot.callsdk.activity.SobotCallBaseActivity;
import com.sobot.callsdk.api.SobotCallBaseCodeGroup;
import com.sobot.callsdk.model.SobotCallRecordEntity;
import com.sobot.callsdk.utils.CallSharedPreferencesUtils;
import com.sobot.callsdk.utils.SobotCallConstant;
import com.sobot.callsdk.v1.adapter.SobotCallRecordAdapter;
import com.sobot.callsdk.v1.entity.v1.SobotCallRecordV1;
import com.sobot.network.http.callback.SobotResultCallBack;
import com.sobot.utils.SobotStringUtils;
import com.sobot.widget.loading.SobotLoadingLayout;
import com.sobot.widget.refresh.layout.SobotRefreshLayout;
import com.sobot.widget.refresh.layout.api.RefreshLayout;
import com.sobot.widget.refresh.layout.footer.ClassicsFooter;
import com.sobot.widget.refresh.layout.header.ClassicsHeader;
import com.sobot.widget.refresh.layout.listener.OnLoadMoreListener;
import com.sobot.widget.refresh.layout.listener.OnRefreshListener;
import com.sobot.widget.ui.toast.SobotToastUtil;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

/**
 * 通话记录
 */
public class SobotCallRecordActivity extends SobotCallBaseActivity implements SobotCallRecordAdapter.OnItemClickListener {

    private int pageNo = 1;
    private int pageSize = 20;
    private SobotRefreshLayout refreshLayout;
    private RecyclerView recyclerView;
    private SobotLoadingLayout loadingLayout;
    private SobotCallRecordAdapter mAdapter;
    private List<Object> mDate;
    private boolean isHasMoreData = false;
    private boolean isCallV6 = false;
    private boolean hidePhone = false;
    long starTime = 0;
    long endTime = 0;

    @Override
    protected int getContentViewResId() {
        return R.layout.sobot_activity_call_record;
    }

    @Override
    protected void initView() {
        isCallV6 = isCallV6();
        hidePhone = isHidePhone();
        if (isCallV6) {
            Calendar calendar = Calendar.getInstance();
            calendar.setTime(new Date());
            calendar.set(Calendar.HOUR_OF_DAY, 23);
            calendar.set(Calendar.MINUTE, 59);
            endTime = calendar.getTimeInMillis();
            calendar.add(Calendar.MONTH, -3);
            starTime = calendar.getTimeInMillis();
        }
        setTitle(getResources().getString(R.string.sobot_call_record));
        Drawable drawable = getResources().getDrawable(getResDrawableId("sobot_call_title_back_selector"));
        drawable.setBounds(0, 0, drawable.getMinimumWidth(), drawable.getMinimumHeight());
        getLeftMenu().setCompoundDrawables(drawable, null, null, null);

        refreshLayout = findViewById(getResId("sobot_srl_call_record"));
        recyclerView = findViewById(getResId("sobot_rv_record_list"));
        loadingLayout = findViewById(getResId("sobot_loading_layout"));

        //列表
        recyclerView.setLayoutManager(new LinearLayoutManager(getSobotBaseContext()));
        mDate = new ArrayList<>();
        mAdapter = new SobotCallRecordAdapter(this, mDate, this);
        recyclerView.setAdapter(mAdapter);

        //下拉刷新控件
        refreshLayout.setRefreshHeader(new ClassicsHeader(this));
        refreshLayout.setRefreshFooter(new ClassicsFooter(this));
        refreshLayout.setEnableLoadMore(true);
        refreshLayout.setOnLoadMoreListener(new OnLoadMoreListener() {
            @Override
            public void onLoadMore(@NonNull RefreshLayout refreshLayout) {
                if (isHasMoreData) {
                    requestDate(pageNo + 1);
                } else {
                    refreshLayout.setNoMoreData(true);
                }
            }
        });
        refreshLayout.setOnRefreshListener(new OnRefreshListener() {
            @Override
            public void onRefresh(@NonNull RefreshLayout refreshLayout) {
                pageNo = 1;
                requestDate(pageNo);
            }
        });
        refreshLayout.setNoMoreData(true);

        //是否显示无内容
        loadingLayout.setRetryListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                pageNo = 1;
                requestDate(pageNo);
            }
        });
    }

    @Override
    protected void initData() {
        requestDate(pageNo);
    }

    private void requestDate(int pageIndex) {
        zhiChiApi.getCallRecord(this, this, pageIndex, pageSize, new SobotResultCallBack<List<SobotCallRecordV1>>() {
            @SuppressLint("NotifyDataSetChanged")
            @Override
            public void onSuccess(List<SobotCallRecordV1> sobotCallRecords) {
                refreshLayout.finishRefresh();//停止刷新
                pageNo = pageIndex;
                if (pageIndex == 1) {
                    mDate.clear();//刷新时清空列表
                    if (sobotCallRecords.size() == 0) {
                        isHasMoreData = false;
                        loadingLayout.showEmpty();//显示无内容
                        return;
                    }
                }
                if (sobotCallRecords.size() < pageSize) {
                    //加载完毕
                    isHasMoreData = false;
                    refreshLayout.setNoMoreData(true);
                } else {
                    //有 下一页
                    isHasMoreData = true;
                    refreshLayout.setNoMoreData(false);
                }

                mDate.addAll(sobotCallRecords);
                mAdapter.notifyDataSetChanged();
                loadingLayout.showContent();//显示列表
                refreshLayout.finishLoadMore();
            }

            @Override
            public void onFailure(Exception e, String des) {
                refreshLayout.finishLoadMore();
                refreshLayout.finishRefresh();
                if (pageIndex == 1) {
                    loadingLayout.showEmpty();
                }
                SobotToastUtil.showCustomToast(getApplicationContext(), SobotStringUtils.isEmpty(des) ? getResources().getString(R.string.sobot_call_net_error_string) : des, R.drawable.sobot_icon_warning_attention);
            }
        });
    }

    @Override
    public void onItemClick(Object obj) {
        String callNum = "", screenNum = "";
        if (obj instanceof SobotCallRecordV1) {
            SobotCallRecordV1 data = (SobotCallRecordV1) obj;
            callNum = data.getDirection() == 1 ? data.getCallee() : data.getCaller();
            screenNum = SobotCallUtils.hidePhone(callNum, data.getHiddenFlag());
        } else if (obj instanceof SobotCallRecordEntity) {
            SobotCallRecordEntity info = (SobotCallRecordEntity) obj;
            callNum = info.getEncryptCustomerNumber();
            screenNum = info.getScreenNumber();
        }
        //弹窗，是否拨打电话
        if (!TextUtils.isEmpty(screenNum)) {
            String finalCallNum = callNum;
            String finalScreenNum = screenNum;
            SobotCallCommonDialog dialog = new SobotCallCommonDialog(screenNum, getResources().getString(R.string.sobot_call_up), new SobotCallCommonDialog.OnBtnClickListener() {
                @Override
                public void onClick() {
                    if (isCallV6()) {
                        Intent intent = SobotCallStatusActivity.initIntent(SobotCallRecordActivity.this, finalCallNum, "", finalScreenNum);
                        intent.setFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP | Intent.FLAG_ACTIVITY_CLEAR_TOP |
                                Intent.FLAG_ACTIVITY_NEW_TASK);
                        startActivity(intent);
                    } else {
                        final String groupId = CallSharedPreferencesUtils.getInstance(getApplicationContext()).get(SobotCallConstant.SP_KEY_CALL_GROUP_ID, "");
                        if (TextUtils.isEmpty(groupId)) {
                            zhiChiApi.queryGroupListV1(SobotCallRecordActivity.this, SobotCallRecordActivity.this, new SobotResultCallBack<SobotCallBaseCodeGroup>() {
                                @Override
                                public void onSuccess(SobotCallBaseCodeGroup stringSobotCallBaseCodeThird) {
                                    if (stringSobotCallBaseCodeThird != null && !SobotStringUtils.isEmpty(stringSobotCallBaseCodeThird.item)) {
                                        CallSharedPreferencesUtils.getInstance(getApplicationContext()).put(SobotCallConstant.SP_KEY_CALL_GROUP_ID, stringSobotCallBaseCodeThird.item);
                                        Intent intent = SobotCallStatusActivity.initIntent(SobotCallRecordActivity.this, finalCallNum, stringSobotCallBaseCodeThird.item, finalScreenNum);
                                        intent.setFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP | Intent.FLAG_ACTIVITY_CLEAR_TOP |
                                                Intent.FLAG_ACTIVITY_NEW_TASK);
                                        startActivity(intent);
                                    }
                                }

                                @Override
                                public void onFailure(Exception e, String des) {

                                }
                            });
                        } else {
                            Intent intent = SobotCallStatusActivity.initIntent(SobotCallRecordActivity.this, finalCallNum, groupId, finalScreenNum);
                            intent.setFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP | Intent.FLAG_ACTIVITY_CLEAR_TOP |
                                    Intent.FLAG_ACTIVITY_NEW_TASK);
                            startActivity(intent);
                        }
                    }

                }
            }, getResources().getString(R.string.sobot_call_cancel), null);
            dialog.setCanceledOnTouchOutside(false);
            dialog.show(getSupportFragmentManager(), "dialog");
        }
    }

    @Override
    public void onItemDetail(Object obj) {
        //跳转到详情
        Intent intent = new Intent(SobotCallRecordActivity.this, SobotCallRecordDetailsActivity.class);
        String callNum = "";
        int hiddenFlag = 0;
        if (obj instanceof SobotCallRecordV1) {
            SobotCallRecordV1 data = (SobotCallRecordV1) obj;
            callNum = data.getDirection() == 1 ? data.getCallee() : data.getCaller();
            hiddenFlag = data.getHiddenFlag();
        } else if (obj instanceof SobotCallRecordEntity) {
            SobotCallRecordEntity info = (SobotCallRecordEntity) obj;
            callNum = info.getScreenNumber();
            intent.putExtra("callID", info.getCallID());
            intent.putExtra("callType", info.getCallType());
        }
        intent.putExtra("callee", callNum);
        intent.putExtra("hiddenFlag", hiddenFlag);
        startActivity(intent);
    }
}