package com.sobot.callsdk.v1.activity;


import android.content.Intent;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.View;
import android.widget.LinearLayout;
import android.widget.TextView;

import androidx.annotation.Nullable;

import com.sobot.callbase.api.SobotCallBaseCodeThird;
import com.sobot.callbase.constant.SobotCallBaseConstant;
import com.sobot.callbase.model.CallSipModel;
import com.sobot.callbase.model.SobotExtensionEntity;
import com.sobot.callsdk.R;
import com.sobot.callsdk.activity.SobotCallBaseActivity;
import com.sobot.callsdk.activity.SobotDialogBaseActivity;
import com.sobot.callsdk.api.SobotCallService;
import com.sobot.callsdk.api.SobotCallServiceFactory;
import com.sobot.callsdk.model.SobotAgentEntity;
import com.sobot.callsdk.model.SobotCall3Response;
import com.sobot.callsdk.model.SobotCallCenterStatus;
import com.sobot.callsdk.utils.CallSharedPreferencesUtils;
import com.sobot.callsdk.utils.SobotCallApiUtils;
import com.sobot.callsdk.utils.SobotCallConstant;
import com.sobot.callsdk.widget.SobotSettingItemView;
import com.sobot.common.login.SobotLoginTools;
import com.sobot.common.login.model.SobotServiceInfoModel;
import com.sobot.network.http.callback.SobotResultCallBack;
import com.sobot.widget.ui.toast.SobotToastUtil;

import java.util.ArrayList;
import java.util.List;

public class SobotLoginChooseActivity extends SobotDialogBaseActivity implements View.OnClickListener {
    private SobotCallService zhiChiApi = null;
    private LinearLayout ll_cancle;//关闭界面返回
    private TextView tv_submit;//确定提交
    private SobotSettingItemView sit_answer_mode, sit_extension_account, sit_login_status, sit_phone_number;
    private View view_split_phone_number, view_split_extension_account;//分割线
    private TextView tv_answer_mode_des;
    private SobotServiceInfoModel serviceVo;

    private int callV6Flag; // 1 : v6账号； 其它 v1账号
    private int callWay = -1; // 1网页电话，2sip话机，3手机
    private String callWayName;//接听方式对应的名称
    private String statusType;//登录状态
    private String statusTypeName;//登录状态名称

    private CallSipModel mSipModel;//v1 sip 账号信息
    private SobotAgentEntity mAgentEntity;//v6 接听方式信息
    private List<SobotExtensionEntity> mExtensionModelList;//v6 分机账号信息


    @Override
    protected int getContentViewResId() {
        return R.layout.sobot_activity_login_choose;
    }

    public SobotCallService getZhiChiApi() {
        if (zhiChiApi == null) {
            synchronized (SobotCallBaseActivity.class) {
                if (zhiChiApi == null) {
                    zhiChiApi = SobotCallServiceFactory.createZhiChiApi(getSobotBaseContext());
                }
            }
        }
        return zhiChiApi;
    }


    @Override
    protected void initView() {
        zhiChiApi = getZhiChiApi();
        ll_cancle = findViewById(R.id.ll_cancle);
        tv_submit = findViewById(R.id.tv_submit);
        sit_answer_mode = findViewById(R.id.sit_answer_mode);
        sit_extension_account = findViewById(R.id.sit_extension_account);
        sit_login_status = findViewById(R.id.sit_login_status);
        tv_answer_mode_des = findViewById(R.id.tv_answer_mode_des);
        sit_phone_number = findViewById(R.id.sit_phone_number);
        view_split_phone_number = findViewById(R.id.view_split_phone_number);
        view_split_extension_account = findViewById(R.id.view_split_extension_account);
        sit_answer_mode.setOnClickListener(this);
        sit_extension_account.setOnClickListener(this);
        sit_login_status.setOnClickListener(this);
        ll_cancle.setOnClickListener(this);
        tv_submit.setOnClickListener(this);
        serviceVo =  SobotLoginTools.getInstance().getServiceInfo();
        if (serviceVo != null) {
            callV6Flag = serviceVo.getCallV6Flag();
        } else {
            serviceVo = new SobotServiceInfoModel();
        }
    }

    @Override
    protected void initData() {
        if (callV6Flag != 1) {
            //v1
            getSipModel();
        }
    }

    @Override
    public void onClick(View v) {
        if (v.getId() == sit_answer_mode.getId()) {
            //只要能点击，就跳转
            Intent answerIntent = new Intent(getSobotBaseActivity(), SobotAnswerModeChooseActivity.class);
            startActivityForResult(answerIntent, SobotCallConstant.SOBOT_REQUEST_ANSWERMODECHOOSE_CODE);
        } else if (v.getId() == sit_extension_account.getId()) {

        } else if (v.getId() == sit_login_status.getId()) {
            if (callV6Flag != 1) {
                //v1
                SobotCallApiUtils.getCallServiceStatusList(zhiChiApi, this, getSobotBaseActivity(), new SobotResultCallBack<SobotCall3Response<SobotCallCenterStatus>>() {
                    @Override
                    public void onSuccess(SobotCall3Response<SobotCallCenterStatus> call3Response) {
                        if (call3Response != null && call3Response.item != null && call3Response.item.getData() != null) {
                            ArrayList<SobotCallCenterStatus> data = call3Response.item.getResult();
                            Intent loginStatusIntent = new Intent(getSobotBaseActivity(), SobotLoginStatusChooseActivity.class);
                            Bundle bundle = new Bundle();
                            bundle.putSerializable("callStatusList", data);
                            loginStatusIntent.putExtras(bundle);
                            startActivityForResult(loginStatusIntent, SobotCallConstant.SOBOT_REQUEST_LOGIN_STATUS_CHOOSE_CODE);
                        }
                    }

                    @Override
                    public void onFailure(Exception e, String des) {
                        Intent loginStatusIntent = new Intent(getSobotBaseActivity(), SobotLoginStatusChooseActivity.class);
                        startActivityForResult(loginStatusIntent, SobotCallConstant.SOBOT_REQUEST_LOGIN_STATUS_CHOOSE_CODE);
                    }
                });
            }
        } else if (v.getId() == ll_cancle.getId()) {
            finish();
        } else if (v.getId() == tv_submit.getId()) {
            if (callWay < 0) {
                SobotToastUtil.showToast(getSobotBaseActivity(), getResources().getString(R.string.sobot_please_choose_answer_mode));
                return;
            }
            if (callWay == SobotCallConstant.CALL_MODEL_PHONE) {
                if (TextUtils.isEmpty(sit_phone_number.getTextByTrim())) {
                    SobotToastUtil.showToast(getSobotBaseActivity(), getResources().getString(R.string.sobot_error_login_no_bind_phone));
                    return;
                }
            } else {
                if (TextUtils.isEmpty(sit_extension_account.getTextByTrim())) {
                    SobotToastUtil.showToast(getSobotBaseActivity(), getResources().getString(R.string.sobot_please_choose_extension_account));
                    return;
                }
            }
            if (TextUtils.isEmpty(statusType)) {
                SobotToastUtil.showToast(getSobotBaseActivity(), getResources().getString(R.string.sobot_please_choose_login_status));
                return;
            }
                Intent resultIntent = new Intent();
                resultIntent.putExtra("callWay", callWay);//接听方式
                resultIntent.putExtra("statusType", statusType);//座席登录状态
                resultIntent.putExtra("statusTypeName", statusTypeName);//登录状态名称
                if (callV6Flag == 1) {
                    resultIntent.putExtra("callPhone", mAgentEntity.getPhone());//手机号
                } else {
                    resultIntent.putExtra("callPhone", serviceVo.getPhoneNo());//手机号
                }
                setResult(RESULT_OK, resultIntent);
                finish();
        }
    }


    /**
     * v1  登陆时判断 动态绑定还是固定绑定
     */
    private void getSipModel() {
        zhiChiApi.appAgentLoginModel(this, getSobotBaseActivity(), new SobotResultCallBack<SobotCallBaseCodeThird>() {
            @Override
            public void onSuccess(SobotCallBaseCodeThird baseCodeThird) {
                if (baseCodeThird != null && SobotCallConstant.RESULT_SUCCESS_CODE.equals(baseCodeThird.getRetCode())) {
                    Double model = (Double) baseCodeThird.getItem();
                    if (SobotCallConstant.CallModelSipFlag.BIND_SIP == model) {
                        //固定绑定 支持sip接听方式
                        zhiChiApi.appGetSipMsg(this, getSobotBaseActivity(), null, new SobotResultCallBack<CallSipModel>() {
                            @Override
                            public void onSuccess(CallSipModel sipModel) {
                                mSipModel = sipModel;
                                if (sipModel != null) {
                                    CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).put(SobotCallBaseConstant.SipModel.SIP_NUMBER, sipModel.getAgentNumber());
                                    CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).put(SobotCallBaseConstant.SipModel.SIP_PWD, sipModel.getAgentPwd());
                                    CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).put(SobotCallBaseConstant.SipModel.SIP_IP, sipModel.getServerIP());
                                    CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).put(SobotCallBaseConstant.SipModel.SIP_SCHEME, sipModel.getServerScheme());
                                    if (SobotCallConstant.ServerScheme.FS.equals(sipModel.getServerScheme())) {
                                        //fs 支持sip
                                        sit_answer_mode.setRightImgShow(true);
                                        sit_answer_mode.setClickable(true);
                                        sit_extension_account.setClickable(false);
                                    } else {
                                        //不是FS 只能电话登陆
                                        CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).put(SobotCallBaseConstant.SipModel.SIP_SCHEME, SobotCallConstant.ServerScheme.openSips);
                                        sit_phone_number.setText(serviceVo.getPhoneNo());
                                        sit_phone_number.setRightImgShow(false);
                                        sit_phone_number.setClickable(false);
                                        sit_phone_number.setVisibility(View.VISIBLE);
                                        view_split_phone_number.setVisibility(View.VISIBLE);

                                        sit_answer_mode.setText(getResources().getString(R.string.sobot_phone));
                                        sit_answer_mode.setRightImgShow(false);
                                        sit_answer_mode.setClickable(false);
                                        tv_answer_mode_des.setText(getResources().getString(R.string.sobot_phone_dec_text));
                                        tv_answer_mode_des.setVisibility(View.VISIBLE);
                                        sit_extension_account.setVisibility(View.GONE);
                                        view_split_extension_account.setVisibility(View.GONE);
                                        callWay = SobotCallConstant.CALL_MODEL_PHONE;
                                    }
                                }
                            }

                            @Override
                            public void onFailure(Exception e, String des) {

                            }
                        });
                    } else {
                        CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).put(SobotCallBaseConstant.SipModel.SIP_SCHEME, SobotCallConstant.ServerScheme.openSips);
                        sit_extension_account.setText(serviceVo.getPhoneNo());

                        sit_extension_account.setVisibility(View.GONE);
                        view_split_extension_account.setVisibility(View.GONE);
                        view_split_phone_number.setVisibility(View.VISIBLE);
                        //手机方式直接显示手机号，分机号不能再点击
                        sit_phone_number.setVisibility(View.VISIBLE);
                        sit_phone_number.setText(serviceVo.getPhoneNo());
                        sit_phone_number.setRightImgShow(false);
                        sit_phone_number.setClickable(false);
                        tv_answer_mode_des.setText(getResources().getString(R.string.sobot_phone_dec_text));
                        tv_answer_mode_des.setVisibility(View.VISIBLE);


                        callWay = SobotCallConstant.CALL_MODEL_PHONE;
                    }
                }
            }

            @Override
            public void onFailure(Exception e, String des) {

            }
        });
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, @Nullable Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        if (resultCode == RESULT_OK) {
            if (requestCode == SobotCallConstant.SOBOT_REQUEST_ANSWERMODECHOOSE_CODE) {
                //接听方式返回
                callWay = data.getIntExtra("type", SobotCallConstant.CALL_MODEL_PHONE);
                callWayName = data.getStringExtra("typeName");
                if (!TextUtils.isEmpty(callWayName)) {
                    sit_answer_mode.setText(callWayName);
                }
                if (callWay == SobotCallConstant.CALL_MODEL_PHONE) {
                    sit_extension_account.setVisibility(View.GONE);
                    view_split_extension_account.setVisibility(View.GONE);
                    sit_phone_number.setVisibility(View.VISIBLE);
                    view_split_phone_number.setVisibility(View.VISIBLE);
                    //手机方式直接显示手机号，分机号不能再点击
                    if (callV6Flag == 1) {
                        sit_phone_number.setText(mAgentEntity != null ? mAgentEntity.getPhone() : "");
                    } else {
                        sit_phone_number.setText(serviceVo.getPhoneNo());
                    }
                    tv_answer_mode_des.setText(getResources().getString(R.string.sobot_phone_dec_text));
                    tv_answer_mode_des.setVisibility(View.VISIBLE);
                } else if (callWay == SobotCallConstant.CALL_MODEL_SIP) {
                    sit_extension_account.setVisibility(View.VISIBLE);
                    view_split_extension_account.setVisibility(View.VISIBLE);
                    sit_phone_number.setVisibility(View.GONE);
                    view_split_phone_number.setVisibility(View.GONE);
                    //sip
                    tv_answer_mode_des.setText(getResources().getString(R.string.sobot_sip_dec_text));
                    tv_answer_mode_des.setVisibility(View.VISIBLE);
                    if (callV6Flag != 1) {
                        //v1 直接显示sip账号
                        if (mSipModel != null) {
                            sit_extension_account.setText(mSipModel.getAgentNumber());
                        }
                        sit_extension_account.setClickable(false);
                    } else {
                        //v6 可以自己选择分机号
                        if (mExtensionModelList != null) {
                            sit_extension_account.setClickable(true);
                            sit_extension_account.setText(mAgentEntity != null ? mAgentEntity.getExt() : "");
                            for (int i = 0; i < mExtensionModelList.size(); i++) {
                                SobotExtensionEntity extensionEntity = mExtensionModelList.get(i);
                                if (callWay == SobotCallConstant.CALL_MODEL_SIP && extensionEntity.getBindStatus() == 1) {
                                    sit_extension_account.setText(extensionEntity.getExt());
                                    CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).put(SobotCallBaseConstant.SipModel.SIP_NUMBER, extensionEntity.getExt());
                                    CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).put(SobotCallBaseConstant.SipModel.SIP_PWD, extensionEntity.getPassword());//sip账号密码先写死
                                    CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).put(SobotCallBaseConstant.SipModel.SIP_IP, extensionEntity.getDomain());
                                    CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).put(SobotCallBaseConstant.SipModel.SIP_SCHEME, SobotCallConstant.ServerScheme.FS);
                                }
                            }
                        }
                    }
                }
            }
            if (requestCode == SobotCallConstant.SOBOT_REQUEST_EXTENSIONCHOOSE_CODE) {
                //分机账号返回
                SobotExtensionEntity extensionEntity = (SobotExtensionEntity) data.getSerializableExtra("extension");
                if (extensionEntity != null) {
                    sit_extension_account.setLeftText(getResources().getString(R.string.sobot_extension_account));
                    sit_extension_account.setText(extensionEntity.getExt());
                    CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).put(SobotCallBaseConstant.SipModel.SIP_NUMBER, extensionEntity.getExt());
                    CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).put(SobotCallBaseConstant.SipModel.SIP_PWD, extensionEntity.getPassword());//sip账号密码先写死
                    CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).put(SobotCallBaseConstant.SipModel.SIP_IP, extensionEntity.getDomain());
                    CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).put(SobotCallBaseConstant.SipModel.SIP_SCHEME, SobotCallConstant.ServerScheme.FS);
                }
            }
            if (requestCode == SobotCallConstant.SOBOT_REQUEST_LOGIN_STATUS_CHOOSE_CODE) {
                //座席登录状态方式返回
                statusType = data.getStringExtra("statusType");
                statusTypeName = data.getStringExtra("statusTypeName");
                sit_login_status.setText(statusTypeName);
            }
        }
    }
}