package com.sobot.callsdk.v1.activity;

import android.content.Intent;
import android.graphics.drawable.Drawable;
import android.text.TextUtils;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.sobot.callbase.api.utils.SobotCallUtils;
import com.sobot.callbase.dialog.SobotCallCommonDialog;
import com.sobot.callsdk.R;
import com.sobot.callsdk.activity.SobotCallBaseActivity;
import com.sobot.callsdk.dialog.SobotCallTaskDialog;
import com.sobot.callsdk.utils.CallSharedPreferencesUtils;
import com.sobot.callsdk.utils.CallStatusUtils;
import com.sobot.callsdk.utils.SobotCallConstant;
import com.sobot.callsdk.v1.adapter.SobotV1CallTaskDetailAdapter;
import com.sobot.callsdk.v1.entity.SobotCallTaskDetailsEntity;
import com.sobot.callsdk.v1.entity.v1.SobotCallTaskDetailsModel;
import com.sobot.network.http.callback.SobotResultCallBack;
import com.sobot.utils.SobotStringUtils;
import com.sobot.widget.loading.SobotLoadingLayout;
import com.sobot.widget.refresh.layout.SobotRefreshLayout;
import com.sobot.widget.refresh.layout.api.RefreshLayout;
import com.sobot.widget.refresh.layout.footer.ClassicsFooter;
import com.sobot.widget.refresh.layout.header.ClassicsHeader;
import com.sobot.widget.refresh.layout.listener.OnLoadMoreListener;
import com.sobot.widget.refresh.layout.listener.OnRefreshListener;
import com.sobot.widget.ui.toast.SobotToastUtil;

import java.util.ArrayList;
import java.util.List;

/**
 * 呼叫中心--呼叫详情
 */
public class SobotV1CallTaskDetailsActivity extends SobotCallBaseActivity implements SobotV1CallTaskDetailAdapter.OnItemClickListener {

    int pageNo = 1;
    int pageSize = 10;

    private String taskId;//任务id
    private String taskName;//任务名称
    private int status;//任务状态

    private SobotRefreshLayout refreshLayout;
    private RecyclerView recyclerView;
    private SobotLoadingLayout loadingLayout;
    private boolean isHasMoreData = false;
    private List<Object> mDate;
    private SobotV1CallTaskDetailAdapter mAdapter;

    @Override
    protected int getContentViewResId() {
        return R.layout.sobot_v1_activity_call_record_desc;
    }

    @Override
    protected void initView() {
        if (getIntent() != null) {
            Intent intent = getIntent();
            taskId = intent.getStringExtra("taskId");
            taskName = intent.getStringExtra("taskName");
            status = intent.getIntExtra("status", 1);
        }
        if (!TextUtils.isEmpty(taskName)) {
            setTitle(taskName);
        }
        Drawable drawable = getResources().getDrawable(getResDrawableId("sobot_call_title_back_selector"));
        drawable.setBounds(0, 0, drawable.getMinimumWidth(), drawable.getMinimumHeight());
        getLeftMenu().setCompoundDrawables(drawable, null, null, null);

        refreshLayout = findViewById(getResId("sobot_srl_call_record"));
        recyclerView = findViewById(getResId("sobot_rv_record_list"));
        loadingLayout = findViewById(getResId("sobot_loading_layout"));

        //列表
        recyclerView.setLayoutManager(new LinearLayoutManager(getSobotBaseContext()));
        mDate = new ArrayList<>();
        mAdapter = new SobotV1CallTaskDetailAdapter(this, mDate, status, this);
        recyclerView.setAdapter(mAdapter);

        //下拉刷新控件
        refreshLayout.setRefreshHeader(new ClassicsHeader(this));
        refreshLayout.setRefreshFooter(new ClassicsFooter(this));
        refreshLayout.setEnableLoadMore(true);
        refreshLayout.setOnLoadMoreListener(new OnLoadMoreListener() {
            @Override
            public void onLoadMore(@NonNull  RefreshLayout refreshLayout) {
                if (isHasMoreData) {
                    requestDate(pageNo + 1);
                } else {
                    refreshLayout.setNoMoreData(true);
                }
            }
        });
        refreshLayout.setOnRefreshListener(new OnRefreshListener() {
            @Override
            public void onRefresh(@NonNull  RefreshLayout refreshLayout) {
                pageNo = 1;
                requestDate(pageNo);
            }
        });
        refreshLayout.setNoMoreData(true);

        //是否显示无内容
        loadingLayout.setRetryListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                pageNo = 1;
                requestDate(pageNo);
            }
        });
    }

    @Override
    protected void initData() {
        requestDate(pageNo);
    }

    private void requestDate(int pageIndex) {

        zhiChiApi.getOneTaskDetails(this, this, taskId, pageIndex, pageSize, new SobotResultCallBack<List<SobotCallTaskDetailsModel>>() {
            @Override
            public void onSuccess(List<SobotCallTaskDetailsModel> sobotCallTaskDetailsModels) {
                refreshLayout.finishRefresh();//停止刷新
                pageNo = pageIndex;
                if (pageIndex == 1) {
                    mDate.clear();//刷新时清空列表
                    if (sobotCallTaskDetailsModels.size() == 0) {
                        isHasMoreData = false;
                        loadingLayout.showEmpty();//显示无内容
                        return;
                    }
                }
                if (sobotCallTaskDetailsModels.size() < pageSize) {
                    //加载完毕
                    isHasMoreData = false;
                    refreshLayout.setNoMoreData(true);
                } else {
                    //有 下一页
                    isHasMoreData = true;
                    refreshLayout.setNoMoreData(false);
                }

                mDate.addAll(sobotCallTaskDetailsModels);
                mAdapter.notifyDataSetChanged();
                loadingLayout.showContent();//显示列表
                refreshLayout.finishLoadMore();
            }

            @Override
            public void onFailure(Exception e, String des) {
                refreshLayout.finishLoadMore();
                refreshLayout.finishRefresh();
                if (pageIndex == 1) {
                    loadingLayout.showEmpty();
                } else {
                    SobotToastUtil.showCustomToast(getApplicationContext(), SobotStringUtils.isEmpty(des) ? getResources().getString(R.string.sobot_call_net_error_string) : des, R.drawable.sobot_icon_warning_attention);
                }
            }
        });
    }

    @Override
    public void onItemClick(Object data) {
        //弹窗，是否拨打电话
        if (null != data) {
            //任务在进行中才能拨打
            if (data instanceof SobotCallTaskDetailsModel) {
                SobotCallTaskDetailsModel detailsModel = (SobotCallTaskDetailsModel) data;
                if (status == 2 && !TextUtils.isEmpty(detailsModel.getCallNO())) {
                    String callNum = detailsModel.getCallNO();
                    String screenNum = SobotCallUtils.hidePhone(detailsModel.getCallNO(), detailsModel.getHiddenFlag());
                    SobotCallCommonDialog dialog = new SobotCallCommonDialog(screenNum, getResources().getString(R.string.sobot_call_up), new SobotCallCommonDialog.OnBtnClickListener() {
                        @Override
                        public void onClick() {
                            //调用呼叫接口打电话
                            Intent intent = SobotCallStatusActivity.initIntent(SobotV1CallTaskDetailsActivity.this, callNum,detailsModel.getServiceGroupId(), screenNum);
                            intent.putExtra("taskId",taskId);
                            intent.putExtra("taskDetailId",detailsModel.getTaskDetailId());
                            intent.putExtra("hiddenFlag",detailsModel.getHiddenFlag());
                            intent.setFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP | Intent.FLAG_ACTIVITY_CLEAR_TOP |
                                    Intent.FLAG_ACTIVITY_NEW_TASK);
                            startActivity(intent);
                        }
                    }, getResources().getString(R.string.sobot_call_cancel), null);
                    dialog.setCanceledOnTouchOutside(false);
                    dialog.show(getSupportFragmentManager(), "dialog");
                }
            } else if(data instanceof SobotCallTaskDetailsEntity){
                //调用拨打电话接口
                SobotCallTaskDetailsEntity detailsEntity = (SobotCallTaskDetailsEntity) data;
                if (status == 2  && !TextUtils.isEmpty(detailsEntity.getScreenNumber())) {
                    SobotCallCommonDialog dialog = new SobotCallCommonDialog(detailsEntity.getScreenNumber(), getResources().getString(R.string.sobot_call_up), new SobotCallCommonDialog.OnBtnClickListener() {
                        @Override
                        public void onClick() {
                            //判断是否登录
                            String call_loingStatus = CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).get(SobotCallConstant.callLoginStatus, CallStatusUtils.OFF_LINE);
                            if (call_loingStatus.equals(CallStatusUtils.V6_FINISHING)) {
                                //判断是否正在整理中
                                SobotToastUtil.showToast(getSobotBaseActivity(), getResources().getString(R.string.sobot_error_switch_status));
                            } else if (call_loingStatus.equals(CallStatusUtils.OFF_LINE)||call_loingStatus.equals(CallStatusUtils.BUSY)) {
                                SobotToastUtil.showToast(getSobotBaseActivity(), getResources().getString(R.string.sobot_call_error_hint));
                            } else {
                                //调用呼叫接口打电话
                                Intent intent = SobotCallStatusActivity.initIntent(SobotV1CallTaskDetailsActivity.this,detailsEntity.getEncryptCustomerNumber(),"", detailsEntity.getScreenNumber());
                                intent.putExtra("recordId",detailsEntity.getRecordId());
                                intent.putExtra("campaignId",detailsEntity.getCampaignId());
                                intent.setFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP | Intent.FLAG_ACTIVITY_CLEAR_TOP |
                                        Intent.FLAG_ACTIVITY_NEW_TASK);
                                startActivity(intent);
                            }
                        }
                    }, getResources().getString(R.string.sobot_call_cancel), null);
                    dialog.setCanceledOnTouchOutside(false);
                    dialog.show(getSupportFragmentManager(), "dialog");
                }
            }
        }
    }

    protected SobotCallTaskDialog menuWindow;

    @Override
    public void onItemDetail(Object model) {
        //底部弹窗
        if (model != null) {

            menuWindow = new SobotCallTaskDialog(SobotV1CallTaskDetailsActivity.this, new ViewClickListener(model), model);
            menuWindow.show();
        }
    }

    class ViewClickListener implements View.OnClickListener {

        private Object model;

        public ViewClickListener(Object model) {
            this.model = model;
        }

        @Override
        public void onClick(View v) {
            menuWindow.dismiss();
            if (v.getId() == getResId("sobot_btn_plan")) {
                //新建计划
                if(model instanceof SobotCallTaskDetailsModel){
                    SobotCallTaskDetailsModel data = (SobotCallTaskDetailsModel) model;
                    Intent intent = new Intent(SobotV1CallTaskDetailsActivity.this, SobotAddCallPlanActivity.class);
                    intent.putExtra("fromFlag", true);
                    intent.putExtra("model", data);
                    intent.putExtra("userPhone", data.getCallNO());
                    intent.putExtra("taskIdName", data.getTaskName());
                    intent.putExtra("taskDetailId", data.getTaskDetailId());
                    intent.putExtra("hiddenFlag", data.getHiddenFlag());
                    startActivity(intent);
                }
            } else if (v.getId() == getResId("sobot_btn_custom")) {
                //编辑/新建客户信息
                Intent intent = new Intent(SobotV1CallTaskDetailsActivity.this, SobotCallCustomerActivity.class);

                if(model instanceof SobotCallTaskDetailsModel){
                    SobotCallTaskDetailsModel data = (SobotCallTaskDetailsModel) model;
                    intent.putExtra("userPhone", data.getCallNO());
                    intent.putExtra("hiddenFlag", data.getHiddenFlag());
                }else if(model instanceof SobotCallTaskDetailsEntity){
                    SobotCallTaskDetailsEntity data = (SobotCallTaskDetailsEntity) model;
                    intent.putExtra("userPhone", data.getScreenNumber());
                    intent.putExtra("EncryptUserPhone", data.getEncryptCustomerNumber());
                }
                startActivityForResult(intent,SobotCallConstant.ACTIVITY_RESULT_NEED_REFRESH);
            }
        }
    }
}