package com.sobot.callsdk.v1.adapter;

import android.content.Context;
import android.graphics.Color;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.RelativeLayout;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.sobot.callbase.api.utils.SobotCallUtils;
import com.sobot.callsdk.R;
import com.sobot.callsdk.model.SobotCallRecordEntity;
import com.sobot.callsdk.v1.entity.v1.SobotCallRecordV1;
import com.sobot.utils.SobotStringUtils;

import java.util.List;

/**
 * @author: Sobot
 * 通话记录
 * 2022/7/12
 */
public class SobotCallRecordAdapter extends RecyclerView.Adapter{
    private Context mContext;
    private List<Object> mData;
    private OnItemClickListener itemListener;

    public SobotCallRecordAdapter(Context mContext, List<Object> mData, OnItemClickListener itemListener) {
        this.mContext = mContext;
        this.mData = mData;
        this.itemListener = itemListener;
    }

    @NonNull
    @Override
    public RecyclerView.ViewHolder onCreateViewHolder(@NonNull ViewGroup viewGroup, int i) {
        View v = LayoutInflater.from(mContext).inflate(R.layout.sobot_item_call_record, viewGroup, false);
        RecyclerView.ViewHolder vh = new ViewHolder(v);
        return vh;
    }

    @Override
    public void onBindViewHolder(@NonNull RecyclerView.ViewHolder vh, int i) {
        ViewHolder viewHolder = (ViewHolder)vh;
        Object obj = mData.get(i);
        if(obj instanceof SobotCallRecordV1) {
            SobotCallRecordV1 data = (SobotCallRecordV1) obj;
            viewHolder.tv_icon.setVisibility(data.getDirection() == 1 ? View.VISIBLE : View.INVISIBLE);
            if (!"10".equals(data.getCallResult()) && data.getDirection() == 0) {
                viewHolder.tv_content.setTextColor(Color.RED);
            } else {
                viewHolder.tv_content.setTextColor(mContext.getResources().getColor(R.color.sobot_call_wenzi_gray1));
            }
            viewHolder.tv_time.setText(SobotCallUtils.formatCallRecordTime(mContext,data.getStartTime()));

            String calleeStr = TextUtils.isEmpty(data.getCalleeName()) ? data.getCallee() : data.getCalleeName();
            String callerStr = TextUtils.isEmpty(data.getCallerName()) ? data.getCaller() : data.getCallerName();

            if (data.getDirection() == 1) {
                calleeStr= SobotCallUtils.hidePhone(calleeStr,data.getHiddenFlag());
                viewHolder.tv_content.setText(calleeStr);
            } else {
                callerStr= SobotCallUtils.hidePhone(callerStr,data.getHiddenFlag());
                viewHolder.tv_content.setText(callerStr);
            }
        }
        if(obj instanceof SobotCallRecordEntity){
            SobotCallRecordEntity info = (SobotCallRecordEntity) obj;
            viewHolder.tv_icon.setVisibility(info.getCallType() == 3 ? View.VISIBLE : View.INVISIBLE);
            if (8 !=info.getCallResult() ) {
                viewHolder.tv_content.setTextColor(Color.RED);
            } else {
                viewHolder.tv_content.setTextColor(mContext.getResources().getColor(R.color.sobot_call_wenzi_gray1));
            }
            viewHolder.tv_time.setText(SobotCallUtils.formatCallRecordTime(mContext,info.getStartTime()));
            if(!SobotStringUtils.isEmpty(info.getCustomerNick())){
                viewHolder.tv_content.setText(info.getCustomerNick());
            }else{
                viewHolder.tv_content.setText(info.getScreenNumber());
            }
        }

        viewHolder.tv_detail.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                //跳转到详情
                if(itemListener!=null){
                    itemListener.onItemDetail(obj);
                }
            }
        });
        viewHolder.itemView.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                //拨号
                if(itemListener!=null){
                    itemListener.onItemClick(obj);
                }
            }
        });
    }

    @Override
    public int getItemCount() {
        return mData.size();
    }

    class ViewHolder extends RecyclerView.ViewHolder{
        TextView tv_icon;
        TextView tv_content;
        TextView tv_time;
        RelativeLayout tv_detail;
        public ViewHolder(@NonNull View itemView) {
            super(itemView);
            tv_icon =itemView.findViewById(R.id.tv_icon);
            tv_content =itemView.findViewById(R.id.tv_content);
            tv_time = itemView.findViewById(R.id.tv_time);
            tv_detail = itemView.findViewById(R.id.call_record_tv_detail);
        }
    }
    public interface OnItemClickListener {
        void onItemClick(Object record);
        void onItemDetail(Object record);
    }

}
