package com.sobot.callsdk.v1.adapter;

import android.content.Context;
import android.graphics.Color;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.sobot.callbase.api.utils.SobotCallUtils;
import com.sobot.callsdk.R;
import com.sobot.callsdk.model.SobotCallCustomerModel;
import com.sobot.callsdk.model.SobotCallDetailInfo;
import com.sobot.callsdk.model.SobotCallRecordDetailEntity;
import com.sobot.pictureframe.SobotBitmapUtil;
import com.sobot.widget.ui.image.SobotRCImageView;

import java.util.List;

/**
 * @author: Sobot
 * 通话记录--详情
 * 2022/7/12
 */
public class SobotCallRecordDetailAdapter extends RecyclerView.Adapter{
    private Context mContext;
    private List<Object> mData;
    private static final int TYPE_CALL_HEAD = 0;
    private static final int TYPE_CALL_DETAIL = 1;
    private OnCreatePlanClickListener onCreatePlanClickListener;

    public SobotCallRecordDetailAdapter(Context mContext, List<Object> mData,OnCreatePlanClickListener onCreatePlanClickListener) {
        this.mContext = mContext;
        this.mData = mData;
        this.onCreatePlanClickListener = onCreatePlanClickListener;
    }

    @NonNull
    @Override
    public RecyclerView.ViewHolder onCreateViewHolder(@NonNull ViewGroup viewGroup, int viewType) {
        if(viewType == TYPE_CALL_HEAD){
            View v = LayoutInflater.from(mContext).inflate(R.layout.sobot_item_call_record_head, viewGroup, false);
            RecyclerView.ViewHolder vh = new HeadViewHolder(v);
            return vh;
        }else{
            View v = LayoutInflater.from(mContext).inflate(R.layout.sobot_item_call_record_detail, viewGroup, false);
            RecyclerView.ViewHolder vh = new ViewHolder(v);
            return vh;
        }
    }

    @Override
    public void onBindViewHolder(@NonNull RecyclerView.ViewHolder vh, int position) {
        if(mData.get(position) instanceof SobotCallCustomerModel){
            SobotCallCustomerModel user = (SobotCallCustomerModel) mData.get(position);
            HeadViewHolder headViewHolder = (HeadViewHolder) vh;
            String callNum = user.getEncryptCustomerNumber();
            callNum= SobotCallUtils.hidePhone(callNum,user.getHiddenFlag());
            headViewHolder.iv_head.setRoundAsCircle(true);
            SobotBitmapUtil.display(mContext, user.getImg(), headViewHolder.iv_head
                    , R.drawable.sobot_default_head, R.drawable.sobot_default_head);
            if (!TextUtils.isEmpty(user.getNick())) {
                headViewHolder.tv_title_tel.setText(user.getNick());
            } else {
                headViewHolder.tv_title_tel.setText(callNum);
            }
            headViewHolder.tv_tel.setText(callNum);
            if(user.isV6()){
                headViewHolder.tv_create.setVisibility(View.GONE);
            }else{
                headViewHolder.tv_create.setVisibility(View.VISIBLE);
            }
            headViewHolder.tv_create.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    //创建联系计划
                    if(onCreatePlanClickListener!=null){
                        onCreatePlanClickListener.onCreatePlanClick(user.getTel());
                    }
                }
            });
        }else{
            ViewHolder viewHolder = (ViewHolder)vh;
            if(mData.get(position) instanceof SobotCallDetailInfo){
                SobotCallDetailInfo data = (SobotCallDetailInfo) mData.get(position);
                viewHolder.tv_time.setText(SobotCallUtils.formatCallRecordTimeWithSecend(mContext,data.getStartTime()));
                if (!"10".equals(data.getCallResult()) && data.getDirection() == 0) {
                    viewHolder.tv_time.setTextColor(Color.RED);
                } else {
                    viewHolder.tv_time.setTextColor(mContext.getResources().getColor(R.color.sobot_call_wenzi_gray1));
                }
                viewHolder.tv_type.setText(data.getDirection() == 1 ? mContext.getResources().getString(R.string.sobot_call_record_out) : mContext.getResources().getString(R.string.sobot_call_record_in));
                String resultStr;
                if (data.getCallDuration() > 60) {
                    resultStr = data.getCallDuration() / 60 + mContext.getResources().getString(R.string.sobot_call_minute) + data.getCallDuration() % 60 + mContext.getResources().getString(R.string.sobot_call_second);
                } else if (data.getCallDuration() > 0) {
                    resultStr = data.getCallDuration() + mContext.getResources().getString(R.string.sobot_call_second);
                } else {
                    resultStr = data.getCallResultStr();
                }
                viewHolder.tv_duration.setText(resultStr);
            }else if(mData.get(position) instanceof SobotCallRecordDetailEntity){
                SobotCallRecordDetailEntity data = (SobotCallRecordDetailEntity) mData.get(position);
                viewHolder.tv_time.setText(SobotCallUtils.formatCallRecordTimeWithSecend(mContext,data.getStartTime()));
                if (3!=data.getCallResult() && data.getDuration() == 0) {
                    viewHolder.tv_time.setTextColor(Color.RED);
                } else {
                    viewHolder.tv_time.setTextColor(mContext.getResources().getColor(R.color.sobot_call_wenzi_gray1));
                }

                viewHolder.tv_type.setText(data.getCallType() == 3 ? mContext.getResources().getString(R.string.sobot_call_record_out) : mContext.getResources().getString(R.string.sobot_call_record_in));

                String resultStr;
                if (data.getDuration() > 60) {
                    resultStr = data.getDuration() / 60 + mContext.getResources().getString(R.string.sobot_call_minute) + data.getDuration() % 60 + mContext.getResources().getString(R.string.sobot_call_second);
                } else if (data.getDuration() >= 0) {
                    resultStr = data.getDuration() + mContext.getResources().getString(R.string.sobot_call_second);
                } else {
                    resultStr = data.getDuration()+"";
                }
                viewHolder.tv_duration.setText(resultStr);
            }
        }
    }

    @Override
    public int getItemViewType(int position) {
        if(mData.get(position) instanceof SobotCallCustomerModel){
            return TYPE_CALL_HEAD;
        }
        return TYPE_CALL_DETAIL;
    }

    @Override
    public int getItemCount() {
        return mData.size();
    }

    class ViewHolder extends RecyclerView.ViewHolder{
        private TextView tv_time;
        private TextView tv_type;
        private TextView tv_duration;
        public ViewHolder(@NonNull View itemView) {
            super(itemView);
            tv_time = itemView.findViewById(R.id.tv_time);
            tv_type =itemView.findViewById(R.id.tv_type);
            tv_duration =itemView.findViewById(R.id.tv_duration);
        }
    }
    class HeadViewHolder extends RecyclerView.ViewHolder{
        private SobotRCImageView iv_head;
        private TextView tv_title_tel;
        private TextView tv_create;
        private TextView tv_tel;
        public HeadViewHolder(@NonNull View itemView) {
            super(itemView);
            iv_head =itemView.findViewById(R.id.iv_head);
            tv_title_tel =itemView.findViewById(R.id.tv_title_tel);
            tv_create = itemView.findViewById(R.id.tv_create);
            tv_tel = itemView.findViewById(R.id.tv_tel);
        }
    }
    public interface OnCreatePlanClickListener {
        void onCreatePlanClick(String telPhone);
    }

}
