package com.sobot.callsdk.v1.adapter;

import android.annotation.SuppressLint;
import android.content.Context;
import android.graphics.Color;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.sobot.callsdk.R;
import com.sobot.callsdk.model.SobotCallTaskEntity;
import com.sobot.callsdk.v1.entity.v1.SobotCallTaskModel;
import com.sobot.callsdk.v1.viewholder.SobotCallTaskVH;
import com.sobot.utils.SobotDateUtil;

import java.util.List;

/**
 * @author: Sobot
 * 呼叫中心/通话任务
 * 2022/7/12
 */
public class SobotV1CallCenterAdapter extends RecyclerView.Adapter{
    private List<Object> mDate;
    private Context mContext;
    private OnItemClickListener mListener;

    public SobotV1CallCenterAdapter(Context mContext, List<Object> mDate, OnItemClickListener listener){
        this.mContext = mContext;
        this.mDate = mDate;
        this.mListener = listener;
    }
    @NonNull
    @Override
    public RecyclerView.ViewHolder onCreateViewHolder(@NonNull ViewGroup viewGroup, int i) {
        View v = LayoutInflater.from(mContext).inflate(R.layout.sobot_v1_item_call_center, viewGroup, false);
        RecyclerView.ViewHolder vh = new SobotCallTaskVH(v);
        return vh;
    }

    @Override
    public void onBindViewHolder(@NonNull RecyclerView.ViewHolder viewHolder, @SuppressLint("RecyclerView") int i) {
        SobotCallTaskVH vh = (SobotCallTaskVH)viewHolder;
        if(mDate.get(i) instanceof SobotCallTaskModel) {
            SobotCallTaskModel data = (SobotCallTaskModel) mDate.get(i);
            if (data != null) {
                vh.call_task_name.setText(data.getTaskName());
                vh.call_task_btn.setBackgroundResource(0);
                if (0 == data.getStatus()) {
                    vh.call_task_btn.setText(R.string.sobot_task_state_not_started);
                    vh.call_task_btn.setBackgroundColor(Color.parseColor("#EEB049"));
                } else if (2 == data.getStatus()) {
                    vh.call_task_btn.setText(R.string.sobot_task_state_executing);
                    vh.call_task_btn.setBackgroundColor(Color.parseColor("#21CFA6"));
                } else {
                    vh.call_task_btn.setText(R.string.sobot_task_state_expired);
                    vh.call_task_btn.setBackgroundColor(Color.parseColor("#CFCFCF"));
                }

                if (data.getTaskStartTime() == 0) {
                    vh.call_task_time.setText(R.string.sobot_task_state_forever);
                } else {
                    vh.call_task_time.setText(SobotDateUtil.toDate(data.getTaskStartTime(), SobotDateUtil.DATE_FORMAT2) +
                            " - " + SobotDateUtil.toDate(data.getTaskEndTime(), SobotDateUtil.DATE_FORMAT2));
                }
            }
        }else{
            SobotCallTaskEntity data = (SobotCallTaskEntity) mDate.get(i);
            if (data != null) {
                vh.call_task_name.setText(data.getCampaignName());
                vh.call_task_btn.setBackgroundResource(0);
                if (1 == data.getState()) {
                    vh.call_task_btn.setText(R.string.sobot_task_state_not_started);
                    vh.call_task_btn.setBackgroundColor(Color.parseColor("#EEB049"));
                } else if (2 == data.getState()) {
                    vh.call_task_btn.setText(R.string.sobot_task_state_executing);
                    vh.call_task_btn.setBackgroundColor(Color.parseColor("#21CFA6"));
                } else {
                    if(3==data.getState()) {
                        vh.call_task_btn.setText(R.string.sobot_task_state_suspended);
                    }else if(4==data.getState()){
                        vh.call_task_btn.setText(R.string.sobot_task_state_closed);
                    }else if(5==data.getState()){
                        vh.call_task_btn.setText(R.string.sobot_task_state_completed);
                    }else if(6==data.getState()){
                        vh.call_task_btn.setText(R.string.sobot_task_state_archived);
                    }else {
                        vh.call_task_btn.setText(R.string.sobot_task_state_deleted);
                    }
                    vh.call_task_btn.setBackgroundColor(Color.parseColor("#CFCFCF"));
                }
//                vh.call_task_time_hint.setText("定时时间：");
                if (data.getTimed() == 0) {
                    vh.call_task_time.setText("--");
//                    vh.call_task_time.setText(R.string.sobot_task_state_forever);
                } else {
                    vh.call_task_time.setText(SobotDateUtil.toDate(data.getScheduleStartTime(), SobotDateUtil.DATE_FORMAT2) +
                            " - " + SobotDateUtil.toDate(data.getScheduleEndTime(), SobotDateUtil.DATE_FORMAT2));
                }
            }
        }
        vh.call_layout.setVisibility(View.VISIBLE);
        vh.desc_layout.setVisibility(View.GONE);
        vh.itemView.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (mListener != null) {
                    mListener.onItemClick(mDate.get(i));
                }
            }
        });
    }

    @Override
    public int getItemCount() {
        return mDate.size();
    }

    public interface OnItemClickListener {
        void onItemClick(Object info);
    }

}
