package com.sobot.callsdk.v1.adapter;

import android.annotation.SuppressLint;
import android.content.Context;
import android.graphics.Color;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.sobot.callbase.api.utils.SobotCallUtils;
import com.sobot.callsdk.R;
import com.sobot.callsdk.v1.entity.SobotCallTaskDetailsEntity;
import com.sobot.callsdk.v1.entity.v1.SobotCallTaskDetailsModel;
import com.sobot.callsdk.v1.viewholder.SobotCallTaskVH;

import java.util.List;

/**
 * @author: Sobot
 * 通话任务-任务详情
 * 2022/7/12
 */
public class SobotV1CallTaskDetailAdapter extends RecyclerView.Adapter{
    private Context mContext;
    private List<Object> mData;
    private int status;
    private OnItemClickListener clickListener ;

    public SobotV1CallTaskDetailAdapter(Context mContext, List<Object> mData, int status, OnItemClickListener clickListener) {
        this.mContext = mContext;
        this.mData = mData;
        this.status = status;
        this.clickListener = clickListener;
    }

    public void setStatus(int status) {
        this.status = status;
    }

    @NonNull
    @Override
    public RecyclerView.ViewHolder onCreateViewHolder(@NonNull ViewGroup viewGroup, int i) {
        View v = LayoutInflater.from(mContext).inflate(R.layout.sobot_v1_item_call_center, viewGroup, false);
        RecyclerView.ViewHolder vh = new SobotCallTaskVH(v);
        return vh;
    }

    @Override
    public void onBindViewHolder(@NonNull RecyclerView.ViewHolder vh, @SuppressLint("RecyclerView") int i) {
        SobotCallTaskVH viewHolder = (SobotCallTaskVH) vh;
        if(mData.get(i) instanceof SobotCallTaskDetailsModel) {
            SobotCallTaskDetailsModel data = (SobotCallTaskDetailsModel) mData.get(i);
            if (data != null && !TextUtils.isEmpty(data.getCallNO())) {
                viewHolder.call_task_name.setTextSize(18);
                String phoneNum = data.getCallNO();
                phoneNum = SobotCallUtils.hidePhone(phoneNum, data.getHiddenFlag());
                viewHolder.call_task_name.setText(phoneNum);

                viewHolder.call_task_details_times.setText(data.getContactTimes() + "");
                viewHolder.call_task_details_times.setTextColor(Color.parseColor("#BDC3D1"));
                viewHolder.call_task_details_times_lable.setTextColor(Color.parseColor("#BDC3D1"));
                if (2 == status) {
                    viewHolder.call_task_btn.setVisibility(View.VISIBLE);
                    viewHolder.call_task_btn.setBackgroundResource(R.drawable.sobot_call_up_task_detail);
                } else {
                    viewHolder.call_task_name.setTextColor(Color.parseColor("#BDC3D1"));
                    viewHolder.call_task_btn.setVisibility(View.GONE);
                }

            }
        }else if(mData.get(i) instanceof SobotCallTaskDetailsEntity){
            SobotCallTaskDetailsEntity data = (SobotCallTaskDetailsEntity) mData.get(i);
            if (data != null && !TextUtils.isEmpty(data.getScreenNumber())) {
                viewHolder.call_task_name.setTextSize(18);
                viewHolder.call_task_name.setText(data.getScreenNumber());

                viewHolder.call_task_details_times.setText(data.getDialCount() + "");
                viewHolder.call_task_details_times.setTextColor(Color.parseColor("#BDC3D1"));
                viewHolder.call_task_details_times_lable.setTextColor(Color.parseColor("#BDC3D1"));
                if (2 == status) {
                    viewHolder.call_task_btn.setVisibility(View.VISIBLE);
                    viewHolder.call_task_btn.setBackgroundResource(R.drawable.sobot_call_up_task_detail);
                } else {
                    viewHolder.call_task_name.setTextColor(Color.parseColor("#BDC3D1"));
                    viewHolder.call_task_btn.setVisibility(View.GONE);
                }

            }
        }
        viewHolder.desc_layout.setVisibility(View.VISIBLE);
        viewHolder.call_layout.setVisibility(View.GONE);

        viewHolder.call_task_btn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                //功能弹窗
                if (clickListener != null) {
                    clickListener.onItemDetail(mData.get(i));
                }
            }
        });
        viewHolder.itemView.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                //拨号
                if (clickListener != null) {
                    clickListener.onItemClick(mData.get(i));
                }
            }
        });
    }

    @Override
    public int getItemCount() {
        return mData.size();
    }
    public interface OnItemClickListener {
        void onItemClick(Object info);
        void onItemDetail(Object info);
    }
}
