package com.sobot.callsdk.v1.fragment;

import static android.app.Activity.RESULT_OK;

import android.Manifest;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.graphics.drawable.Drawable;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.os.Build;
import android.os.Bundle;
import android.os.Handler;
import android.text.TextUtils;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.WindowManager;
import android.widget.ImageView;
import android.widget.PopupWindow;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.lifecycle.Observer;
import androidx.localbroadcastmanager.content.LocalBroadcastManager;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.sobot.callbase.api.SobotCallBaseCode;
import com.sobot.callbase.api.SobotCallBaseCodeThird;
import com.sobot.callbase.constant.SobotCallBaseConstant;
import com.sobot.callbase.dialog.SobotActionItem;
import com.sobot.callbase.model.CallSipModel;
import com.sobot.callbase.websocket.util.PermissionUtil;
import com.sobot.callsdk.R;
import com.sobot.callsdk.ZCSobotCallApi;
import com.sobot.callsdk.dialog.SobotTitileMoreMenu;
import com.sobot.callsdk.fargment.SobotBaseFragment;
import com.sobot.callsdk.listener.SobotPhoneStatusListener;
import com.sobot.callsdk.listener.SobotRegistrationListener;
import com.sobot.callsdk.model.SobotCallCenterStatus;
import com.sobot.callsdk.model.SobotCallTaskEntity;
import com.sobot.callsdk.sip.SobotSipUtils;
import com.sobot.callsdk.utils.CallSharedPreferencesUtils;
import com.sobot.callsdk.utils.CallStatusUtils;
import com.sobot.callsdk.utils.SobotCallApiUtils;
import com.sobot.callsdk.utils.SobotCallConstant;
import com.sobot.callsdk.v1.activity.SobotCallNumberActivity;
import com.sobot.callsdk.v1.activity.SobotCallPlanActivity;
import com.sobot.callsdk.v1.activity.SobotCallRecordActivity;
import com.sobot.callsdk.v1.activity.SobotCallTaskDetailsActivity;
import com.sobot.callsdk.v1.activity.SobotLoginChooseActivity;
import com.sobot.callsdk.v1.activity.SobotV1CallTaskDetailsActivity;
import com.sobot.callsdk.v1.adapter.SobotCallCenterAdapter;
import com.sobot.callsdk.v1.constant.SobotCallLiveDataBusV1Key;
import com.sobot.callsdk.v1.entity.v1.SobotCallSeatCurrentStatus;
import com.sobot.callsdk.v1.entity.v1.SobotCallTaskModel;
import com.sobot.common.login.SobotLoginTools;
import com.sobot.common.login.model.SobotServiceInfoModel;
import com.sobot.network.http.callback.SobotResultCallBack;
import com.sobot.utils.SobotLogUtils;
import com.sobot.utils.SobotStringUtils;
import com.sobot.widget.livedatabus.SobotLiveEventBus;
import com.sobot.widget.loading.SobotLoadingLayout;
import com.sobot.widget.refresh.layout.SobotRefreshLayout;
import com.sobot.widget.refresh.layout.api.RefreshLayout;
import com.sobot.widget.refresh.layout.footer.ClassicsFooter;
import com.sobot.widget.refresh.layout.header.ClassicsHeader;
import com.sobot.widget.refresh.layout.listener.OnLoadMoreListener;
import com.sobot.widget.refresh.layout.listener.OnRefreshListener;
import com.sobot.widget.ui.permission.SobotPermissionListenerImpl;
import com.sobot.widget.ui.toast.SobotToastUtil;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.List;

import io.reactivex.functions.Consumer;
import io.reactivex.plugins.RxJavaPlugins;

/**
 * 呼叫中心首页
 */
public class SobotCallFragment extends SobotBaseFragment implements View.OnClickListener, SobotTitileMoreMenu.PopItemClick, SobotCallCenterAdapter.OnItemClickListener {

    private static final String TAG = "SobotCallFragment";
    //title部分
    private TextView statusMenu, moreMenu, callNotifyTip;
    private ImageView backMenu;

    //登录方式
    private int startupMode = 0;
    //左上角弹窗展示数据 在线座席状态
    private List<SobotActionItem> lineStatusActionItems;
    //右上角弹窗展示数据
    private List<SobotActionItem> moreActionItems, moreActionItemsV6;
    private PopupWindow popupWindow;

    //列表
    private int pageNo = 1;
    private int pageSize = 20;
    private SobotRefreshLayout refreshLayout;
    private RecyclerView recyclerView;
    private SobotLoadingLayout loadingLayout;
    private SobotCallCenterAdapter mAdapter;
    private List<Object> mDate;
    private boolean isHasMoreData = false;
    //座席信息
    private SobotServiceInfoModel serviceVo;

    //v1 座席当前状态
    private String call_loingStatus = CallStatusUtils.OFF_LINE;

    private String nowStatus;
    private String callModel;

    //本地广播数据类型实例。
    private LocalBroadcastManager localBroadcastManager;
    private LocalReceiver localReceiver;
    private NetWorkChangeReceiver receiverNet;

    //收到 网络变化广播connectivity_action的次数，0的时候不重启janus websocket 的连接
    public int connectivity_action_count = 0;
    private boolean isRequestReleaseBlueGreen, isCalling;//isRequestReleaseBlueGreen:是否需要切换路由，isCalling：是否正在通话中

    public SobotCallFragment() {
    }

    /**
     * @param startupMode 启动方式: 8888 activity启动，其他fragment启动
     * @return
     */
    public static SobotCallFragment newInstance(int startupMode) {
        SobotCallFragment fragment = new SobotCallFragment();
        Bundle bundle = new Bundle();
        bundle.putInt("StartupMode", startupMode);
        fragment.setArguments(bundle);
        return fragment;
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        if (getArguments() != null) {
            startupMode = getArguments().getInt("StartupMode", 0);
        }
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        View view = inflater.inflate(R.layout.sobot_fragment_call_main, container, false);
        initView(view);
        return view;
    }

    private void initBrocastReceiver() {
        if (localReceiver == null) {
            localReceiver = new LocalReceiver();
        }
        localBroadcastManager = LocalBroadcastManager.getInstance(getSobotActivity());
        // 创建过滤器，并指定action，使之用于接收同action的广播
        IntentFilter localFilter = new IntentFilter();
        localFilter.addAction(SobotCallConstant.SOBOT_BROADCAST_SESSION_TIMEOUT);//广播超时
        localFilter.addAction(SobotCallConstant.SOBOT_CALL_CURRENT_VERSION);//切换版本广播
        // 注册广播接收器
        localBroadcastManager.registerReceiver(localReceiver, localFilter);
        IntentFilter filter = new IntentFilter();
        filter.addAction(SobotCallConstant.SOBOT_ACTION_CALL_CHANGE_VERSION); // 呼叫版本是否更改
        // 注册广播接收器
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
            getSobotActivity().registerReceiver(receiver, filter, Context.RECEIVER_NOT_EXPORTED);
        } else {
            getSobotActivity().registerReceiver(receiver, filter);
        }
        if (receiverNet == null) {
            receiverNet = new NetWorkChangeReceiver();
        }
        IntentFilter netFilter = new IntentFilter();
        netFilter.addAction(ConnectivityManager.CONNECTIVITY_ACTION);
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
            getSobotActivity().registerReceiver(receiverNet, netFilter, Context.RECEIVER_EXPORTED);
        } else {
            getSobotActivity().registerReceiver(receiverNet, netFilter);
        }
    }

    @Override
    public void onDestroyView() {
        try {
            if (receiverNet != null) {
                getSobotActivity().unregisterReceiver(receiverNet);
                receiverNet = null;
            }
        } catch (Exception e) {
        }
        try {
            // 取消广播接受者
            if (localBroadcastManager != null && localReceiver != null) {
                localBroadcastManager.unregisterReceiver(localReceiver);
            }
            if (receiver != null) {
                getSobotActivity().unregisterReceiver(receiver);
                receiver = null;
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        super.onDestroyView();
    }

    class LocalReceiver extends BroadcastReceiver {
        @Override
        public void onReceive(Context context, Intent intent) {
        }
    }

    private BroadcastReceiver receiver = new BroadcastReceiver() {
        @Override
        public void onReceive(Context context, Intent intent) {
            serviceVo = SobotLoginTools.getInstance().getServiceInfo();
            SobotLogUtils.d("=====SOBOT_CALL_CURRENT_VERSION==" + ZCSobotCallApi.getCallVersion(context, serviceVo.getServiceId()));
            if (intent.getAction().equals(SobotCallConstant.SOBOT_ACTION_CALL_CHANGE_VERSION)) {
                //停止获取V1状态
                stopPollingAgentSuatus();
                if (ZCSobotCallApi.getCallVersion(context, serviceVo.getServiceId()) == 6) {
                    //v6 获取到当前公司设置的呼叫客服状态列表
                    SobotCallApiUtils.getLoginStatusV6(zhiChiApi, this, context, null);
                } else {
                    //获取到当前公司设置的呼叫客服状态列表v1
                    SobotCallApiUtils.getCallServiceStatusList(zhiChiApi, this, context, null);
                    appGetAgentStatus();
                }
                //开启现场刷新页面
                getActivity().runOnUiThread(new Runnable() {
                    @Override
                    public void run() {
                        try {
                            if (serviceVo != null) {
                                if (serviceVo.getCallV6Flag() != 1) {
                                    getCallSeatLoginStatus();
                                } else {
                                    getV6CallSeatLoginStatus();
                                }
                                if (mDate != null) {
                                    mDate.clear();
                                }
                                requestDate(1);
                            }
                        } catch (Exception e) {
                        }
                    }
                });

            }
        }
    };

    @Override
    public void onResume() {
        super.onResume();
        serviceVo = SobotLoginTools.getInstance().getServiceInfo();
        if (serviceVo != null) {

        }
        try {
            RxJavaPlugins.setErrorHandler(new Consumer<Throwable>() {
                @Override
                public void accept(Throwable throwable) throws Exception {
                    // 这里打印log trace也要注意，太频繁会损耗性能，
                    // 不能过分依靠这个全局的异常处理，
                    // 尽量在自己的业务代码逻辑中处理完善
                    Log.d(TAG, "RxJava error handler accept: " + Log.getStackTraceString(throwable));
                }
            });
        } catch (Exception e) {
        }
    }

    private void initView(View view) {
        serviceVo = SobotLoginTools.getInstance().getServiceInfo();
        initBrocastReceiver();
        moreActionItems = new ArrayList<>();
        moreActionItems.add(new SobotActionItem(getResources().getString(R.string.sobot_call_record), "sobot_call_record", getResources().getDrawable(R.drawable.sobot_call_up_task_record_icon)));
        moreActionItems.add(new SobotActionItem(getResources().getString(R.string.sobot_call_plan), "sobot_call_plan", getResources().getDrawable(R.drawable.sobot_call_up_task_plan_icon)));
        moreActionItems.add(new SobotActionItem(getResources().getString(R.string.sobot_call_teke), "sobot_call_teke", getResources().getDrawable(R.drawable.sobot_call_up_task_take_icon)));
        moreActionItemsV6 = new ArrayList<>();
        moreActionItemsV6.add(new SobotActionItem(getResources().getString(R.string.sobot_call_record), "sobot_call_record", getResources().getDrawable(R.drawable.sobot_call_up_task_record_icon)));
        moreActionItemsV6.add(new SobotActionItem(getResources().getString(R.string.sobot_call_teke), "sobot_call_teke", getResources().getDrawable(R.drawable.sobot_call_up_task_take_icon)));
        lineStatusActionItems = new ArrayList<>();
        backMenu = view.findViewById(R.id.sobot_call_title_back);
        statusMenu = view.findViewById(R.id.sobot_call_title_status);
        moreMenu = view.findViewById(R.id.sobot_call_title_more);
        callNotifyTip = view.findViewById(R.id.sobot_call_task_notify_tip);
        statusMenu.setOnClickListener(this);
        moreMenu.setOnClickListener(this);
        backMenu.setOnClickListener(this);
        if (startupMode == SobotCallConstant.STARTUP_MODE_ACTIVITY) {
            backMenu.setVisibility(View.VISIBLE);
        } else {
            backMenu.setVisibility(View.GONE);
        }
        //列表view
        initListView(view);
        loadingLayout.showLoading();
        new Handler().postDelayed(new Runnable() {
            @Override
            public void run() {
                serviceVo = SobotLoginTools.getInstance().getServiceInfo();
                if (serviceVo != null) {
                    if (serviceVo.getCallV6Flag() == 1) {

                    } else {
                        //v1账号
                        appGetAgentStatus();
                    }
                    requestDate(pageNo);
                }
            }
        }, 1500);
        SobotLiveEventBus.get(SobotCallLiveDataBusV1Key.set_call_seat_status, Boolean.class)
                .observe(this, new Observer<Boolean>() {
                    @Override
                    public void onChanged(Boolean aBoolean) {
                        getCallSeatLoginStatus();
                    }
                });
    }

    /**
     * 获取电话状态轮询
     */
    private void pollingAgentSuatus() {
        serviceVo = SobotLoginTools.getInstance().getServiceInfo();
        if (serviceVo != null) {
            if (serviceVo.getCallV6Flag() == 1) {
                //只支持v1的轮询座席状态
                return;
            }
        } else {
            return;
        }
        if (mHandler == null) {
            mHandler = new Handler();
        }
        if (mAgentRunnable == null) {
            mAgentRunnable = new Runnable() {
                @Override
                public void run() {
                    appGetAgentStatus();
                }
            };
        }
        if (mHandler != null && mAgentRunnable != null) {
            mHandler.removeCallbacks(mAgentRunnable);
            mHandler.postDelayed(mAgentRunnable, 5 * 1000);
        }
    }

    /**
     * 获取电话状态轮询
     */
    private void stopPollingAgentSuatus() {
        if (mHandler != null && mAgentRunnable != null) {
            mHandler.removeCallbacks(mAgentRunnable);
        }
    }

    Handler mHandler = new Handler();
    private Runnable mAgentRunnable = new Runnable() {
        @Override
        public void run() {
            appGetAgentStatus();
        }
    };

    private void appGetAgentStatus() {
        if (serviceVo != null) {
            if (serviceVo.getCallV6Flag() != 1) {
                //请求成功或者失败，轮训继续
                SobotCallApiUtils.appGetAgentStatus(zhiChiApi, getSobotActivity(), new SobotResultCallBack<SobotCallSeatCurrentStatus>() {
                    @Override
                    public void onSuccess(SobotCallSeatCurrentStatus model) {
                        if (model != null) {
                            CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallConstant.callLoginStatus, model.getAgentStatus());
                            if (TextUtils.isEmpty(callModel) || !callModel.equals(model.getCallWay())) {//改变登录方式状态
                                if (callNotifyTip != null) {
                                    callNotifyTip.setVisibility(View.GONE);
                                }
                                callModel = model.getCallWay();
                                if (SobotCallConstant.CALL_MODEL_SIP == Integer.valueOf(callModel) && "1".equals(model.getAgentStatus())) {//话机 空闲 登录
                                    sipLoginModel(model.getAgentStatus(), SobotCallConstant.CALL_MODEL_SIP);
                                } else if (CallStatusUtils.OFF_LINE.equals(model.getAgentStatus())) {//话机 空闲 登录
                                    stopPollingAgentSuatus();
                                } else {//切换为其他方式
                                    if (SobotSipUtils.isServiceRun(serviceVo.getCallV6Flag() == 1 ? true : false)) {
                                        SobotSipUtils.logoutUser(serviceVo.getCallV6Flag() == 1 ? true : false);
                                        SobotRegistrationListener.getInstance().isLogin = false;
                                        SobotSipUtils.stopService(serviceVo.getCallV6Flag() == 1 ? true : false, getActivity());
                                    }
                                }
                            }
                        }

                        pollingAgentSuatus();
                    }

                    @Override
                    public void onFailure(Exception e, String des) {
                        pollingAgentSuatus();
                    }
                });
            } else {
                stopPollingAgentSuatus();
            }
        } else {
            stopPollingAgentSuatus();
        }
    }

    @Override
    public void onClick(View v) {
        if (v == statusMenu) {
            //权限判断
            permissionListener = new SobotPermissionListenerImpl() {
                @Override
                public void onPermissionSuccessListener() {
                    onStatusClike();
                }
            };
            //判断是否有权限
            if (checkIsShowPermissionPop(getResources().getString(R.string.sobot_microphone), getResources().getString(R.string.sobot_microphone_yongtu))) {
                return;
            }
            if (!checkAudioPermission()) {
                return;
            }
            onStatusClike();
        } else if (v == moreMenu) {
            //其他菜单
            //弹窗
            List<SobotActionItem> list = new ArrayList<>();
            if (serviceVo != null && serviceVo.getCallV6Flag() == 1) {
                list.addAll(moreActionItemsV6);
            } else {
                list.addAll(moreActionItems);
            }
            SobotTitileMoreMenu sobotSelectSearchTypePop = new SobotTitileMoreMenu(getContext(), list, SobotTitileMoreMenu.TYPE_BOTTOM_CIRCULAR, true, SobotCallFragment.this);
            popupWindow = sobotSelectSearchTypePop.getPopWindow();
            //弹窗出现外部为阴影
            WindowManager.LayoutParams attributes = getActivity().getWindow().getAttributes();
            attributes.alpha = 0.5f;
            getActivity().getWindow().setAttributes(attributes);
            //弹窗取消监听 取消之后恢复阴影
            popupWindow.setOnDismissListener(new PopupWindow.OnDismissListener() {
                @Override
                public void onDismiss() {
                    WindowManager.LayoutParams attributes = getActivity().getWindow().getAttributes();
                    attributes.alpha = 1;
                    getActivity().getWindow().setAttributes(attributes);
                }
            });
            popupWindow.showAsDropDown(moreMenu, 0, 0);
        } else if (v == backMenu) {
            //返回
            getActivity().onBackPressed();
        }
    }

    private void onStatusClike() {
        if (serviceVo != null && serviceVo.getCallV6Flag() == 1) {
            call_loingStatus = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.callLoginStatus, CallStatusUtils.V6_OFFLINE);
        } else {
            call_loingStatus = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.callLoginStatus, CallStatusUtils.OFF_LINE);
        }
        boolean isOFF = true;
        if (CallStatusUtils.OFF_LINE.equals(call_loingStatus) || CallStatusUtils.ERROR_SIP.equals(call_loingStatus)) {
            isOFF = true;
        } else {
            isOFF = false;
        }

        if (isOFF) {
            if (serviceVo != null && serviceVo.getCallV6Flag() == 1) {

            }
            //离线状态弹出座席登录弹窗
            Intent intent = new Intent(getContext(), SobotLoginChooseActivity.class);
            Bundle bundle = new Bundle();
            bundle.putString("sip", "");
            intent.putExtras(bundle);
            startActivityForResult(intent, SobotCallConstant.SOBOT_REQUEST_LOGIN_CODE);
        } else {

            lineStatusActionItems.clear();
            if (CallStatusUtils.V6_FINISHING.equals(call_loingStatus)) {
                SobotToastUtil.showToast(getSobotActivity(), getResources().getString(R.string.sobot_error_switch_status));
                return;
            }
            SobotServiceInfoModel serviceVo = SobotLoginTools.getInstance().getServiceInfo();
            if (serviceVo != null && serviceVo.getCallV6Flag() == 1) {
            } else {
                lineStatusActionItems.add(new SobotActionItem(getResources().getString(R.string.sobot_custom_free), getSobotActivity().getDrawable(R
                        .drawable.custom_service_online), call_loingStatus.equals(CallStatusUtils.FREE), CallStatusUtils.FREE));
                lineStatusActionItems.add(new SobotActionItem(getResources().getString(R.string.sobot_custom_busy),
                        getSobotActivity().getDrawable(R.drawable.custom_service_busy), call_loingStatus.equals(CallStatusUtils.BUSY), CallStatusUtils.BUSY));
                ArrayList<SobotCallCenterStatus> data = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.callStatusList_v1, ArrayList.class);
                if (data != null) {
                    for (int i = 0; i < data.size(); i++) {
                        if (!"115".equals(data.get(i).getDictId())) {
                            lineStatusActionItems.add(new SobotActionItem(data.get(i).getDictName(),
                                    getSobotActivity().getDrawable(R.drawable.custom_service_other), call_loingStatus.equals(data.get(i).getDictId()), data.get(i).getDictId()));
                        }
                    }
                }
                lineStatusActionItems.add(new SobotActionItem(getResources().getString(R.string.sobot_custom_offline),
                        getSobotActivity().getDrawable(R.drawable.custom_service_offline), call_loingStatus.equals(CallStatusUtils.OFF_LINE), CallStatusUtils.OFF_LINE));
                //座席状态切换点击事件
                SobotTitileMoreMenu.PopItemClick mPopItemClick = new SobotTitileMoreMenu.PopItemClick() {
                    @Override
                    public void onPopItemClick(SobotActionItem item, int index) {
                        call_loingStatus = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.callLoginStatus, CallStatusUtils.BUSY);
                        if (CallStatusUtils.OFF_LINE.equals(call_loingStatus) || CallStatusUtils.ERROR_SIP.equals(call_loingStatus)) {
                            //登录 选择模式，选择状态后 登录
                            sipLoginModel(item.getDicId(), SobotCallConstant.CALL_MODEL_SIP);
                        } else {
                            switchTitle(item.mTitle, true);
                        }
                        if (popupWindow != null)
                            popupWindow.dismiss();
                    }
                };
                //非离线状态弹出切换座席弹窗
                SobotTitileMoreMenu sobotSelectSearchTypePop = new SobotTitileMoreMenu(getContext(), lineStatusActionItems, SobotTitileMoreMenu.TYPE_BOTTOM_CIRCULAR, true, mPopItemClick);
                popupWindow = sobotSelectSearchTypePop.getPopWindow();
                //弹窗出现外部为阴影
                WindowManager.LayoutParams attributes = getActivity().getWindow().getAttributes();
                attributes.alpha = 0.5f;
                getActivity().getWindow().setAttributes(attributes);
                //弹窗取消监听 取消之后恢复阴影
                popupWindow.setOnDismissListener(new PopupWindow.OnDismissListener() {
                    @Override
                    public void onDismiss() {
                        WindowManager.LayoutParams attributes = getActivity().getWindow().getAttributes();
                        attributes.alpha = 1;
                        getActivity().getWindow().setAttributes(attributes);
                    }
                });
                popupWindow.showAsDropDown(statusMenu, 0, 0);
            }
        }
    }

    @Override
    public void onPopItemClick(SobotActionItem item, int index) {
        if (item.getType().equals("sobot_call_record")) {
            //通话记录
            startActivity(new Intent(getSobotActivity(), SobotCallRecordActivity.class));
        } else if (item.getType().equals("sobot_call_plan")) {
            //通话计划
            startActivity(new Intent(getSobotActivity(), SobotCallPlanActivity.class));
        } else if (item.getType().equals("sobot_call_teke")) {
            //拨号
            startActivity(new Intent(getSobotActivity(), SobotCallNumberActivity.class));
        }
        if (popupWindow != null)
            popupWindow.dismiss();
    }

    private void getV6CallSeatLoginStatus() {
        call_loingStatus = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.callLoginStatus, CallStatusUtils.OFF_LINE);
        Drawable dra;
        switch (call_loingStatus) {
            case CallStatusUtils.V6_FREE://1：空闲
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_online);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                statusMenu.setText(getHeadText(getResources().getString(R.string.sobot_custom_v6_free)));
                break;
            case CallStatusUtils.V6_FINISHING://4 //整理中（话务总结）
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_busy);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                statusMenu.setText(getHeadText(getResources().getString(R.string.sobot_call_finishing)));
                break;
            case CallStatusUtils.V6_DO_NOT_DISTURB://2：勿扰
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_busy);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                statusMenu.setText(getHeadText(getResources().getString(R.string.sobot_custom_do_not_disturb)));
                break;
            case CallStatusUtils.V6_LITTLE_HUGH:// 11：小休
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_other);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                statusMenu.setText(getHeadText(getResources().getString(R.string.sobot_custom_little_rest)));
                break;
            case CallStatusUtils.V6_TRAIN:// 12：培训
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_other);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                statusMenu.setText(getHeadText(getResources().getString(R.string.sobot_custom_peixun)));
                break;
            case CallStatusUtils.V6_MEETING:// 13：会议
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_other);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                statusMenu.setText(getHeadText(getResources().getString(R.string.sobot_custom_huiyi)));
                break;
            case CallStatusUtils.V6_HAVE_MEALS:// 14：用餐
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_other);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                statusMenu.setText(getHeadText(getResources().getString(R.string.sobot_custom_yongcan)));
                break;
            case CallStatusUtils.V6_ACTIVITY:// 活动
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_other);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                statusMenu.setText(getHeadText(getResources().getString(R.string.sobot_custom_huodong)));
                break;
            case CallStatusUtils.OFF_LINE:
            case CallStatusUtils.ERROR_SIP:
                statusMenu.setText(call_loingStatus.equals(CallStatusUtils.OFF_LINE) ? getResources().getString(R.string.sobot_custom_offline_and_click_login) : getHeadText(getResources().getString(R.string.sobot_custom_offline)));
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_offline);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                break;
            default:
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_other);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                statusMenu.setText(getHeadText(TextUtils.isEmpty(SobotRegistrationListener.getInstance().getLineStatusName()) ? getResources().getString(R.string.sobot_custom_do_not_disturb) : SobotRegistrationListener.getInstance().getLineStatusName()));
                break;
        }

    }

    private void getCallSeatLoginStatus() {
        call_loingStatus = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.callLoginStatus, CallStatusUtils.OFF_LINE);
        Drawable dra;
        switch (call_loingStatus) {
            case CallStatusUtils.FREE:
                statusMenu.setText(getHeadText(getResources().getString(R.string.sobot_custom_free)));
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_online);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                break;
            case CallStatusUtils.BUSY:
                statusMenu.setText(getHeadText(getResources().getString(R.string.sobot_custom_busy)));
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_busy);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                break;
            case CallStatusUtils.LITTLE_HUGH:
                statusMenu.setText(getHeadText(getResources().getString(R.string.sobot_custom_little_rest)));
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_other);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                break;
            case CallStatusUtils.LITTLE_HUGH_:
                statusMenu.setText(getHeadText(getResources().getString(R.string.sobot_custom_houchuli)));
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_other);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                break;
            case CallStatusUtils.TRAIN:
                statusMenu.setText(getHeadText(getResources().getString(R.string.sobot_custom_peixun)));
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_other);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                break;
            case CallStatusUtils.MEETING:
                statusMenu.setText(getHeadText(getResources().getString(R.string.sobot_custom_huiyi)));
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_other);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                break;
            case CallStatusUtils.HAVE_MEALS:
                statusMenu.setText(getHeadText(getResources().getString(R.string.sobot_custom_yongcan)));
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_other);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                break;
            case CallStatusUtils.ACTIVITY:
                statusMenu.setText(getHeadText(getResources().getString(R.string.sobot_custom_huodong)));
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_other);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                break;
            case CallStatusUtils.OFF_LINE:
            case CallStatusUtils.ERROR_SIP:
                statusMenu.setText(getResources().getString(R.string.sobot_custom_offline_and_click_login));
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_offline);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                getHeadText(getResources().getString(R.string.sobot_custom_offline));
                break;
            case CallStatusUtils.CALLING:// 通话中
                statusMenu.setText(getHeadText(getResources().getString(R.string.sobot_custom_tonghuazhong)));
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_other);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                break;
            default:
                statusMenu.setText(getHeadText(CallStatusUtils.getCallStatusString(getSobotActivity(), call_loingStatus)));
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_other);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                break;
        }
    }

    //v1 修改左上角的座席状态
    public void switchTitle(String title, boolean isShowSuccess) {
        if (getResources().getString(R.string.sobot_custom_free).equals(title)) {// 空闲
            if (!CallStatusUtils.FREE.equals(call_loingStatus)) {
                appSetAgentStatus(CallStatusUtils.FREE, isShowSuccess);
                statusMenu.setText(getHeadText(getResources().getString(R.string.sobot_custom_free)));
            }
        } else if (getResources().getString(R.string.sobot_custom_busy).equals(title)) {// 忙碌
            if (!CallStatusUtils.BUSY.equals(call_loingStatus)) {
                appSetAgentStatus(CallStatusUtils.BUSY, isShowSuccess);
                statusMenu.setText(getHeadText(getResources().getString(R.string.sobot_custom_busy)));
            }
        } else if (getResources().getString(R.string.sobot_custom_little_rest).equals(title)) {// 小休
            if (!CallStatusUtils.LITTLE_HUGH.equals(call_loingStatus)) {
                appSetAgentStatus(CallStatusUtils.LITTLE_HUGH, isShowSuccess);
                statusMenu.setText(getHeadText(getResources().getString(R.string.sobot_custom_little_rest)));
            }
        } else if (getResources().getString(R.string.sobot_custom_houchuli).equals(title)) {// 后处理
            if (!CallStatusUtils.LITTLE_HUGH_.equals(call_loingStatus)) {
                appSetAgentStatus(CallStatusUtils.LITTLE_HUGH_, isShowSuccess);
                statusMenu.setText(getHeadText(getResources().getString(R.string.sobot_custom_houchuli)));
            }
        } else if (getResources().getString(R.string.sobot_custom_peixun).equals(title)) {// 培训
            if (!CallStatusUtils.TRAIN.equals(call_loingStatus)) {
                appSetAgentStatus(CallStatusUtils.TRAIN, isShowSuccess);
                statusMenu.setText(getHeadText(getResources().getString(R.string.sobot_custom_peixun)));
            }
        } else if (getResources().getString(R.string.sobot_custom_huiyi).equals(title)) {// 会议
            if (!CallStatusUtils.MEETING.equals(call_loingStatus)) {
                appSetAgentStatus(CallStatusUtils.MEETING, isShowSuccess);
                statusMenu.setText(getHeadText(getResources().getString(R.string.sobot_custom_huiyi)));
            }
        } else if (getResources().getString(R.string.sobot_custom_yongcan).equals(title)) {// 用餐
            if (!CallStatusUtils.HAVE_MEALS.equals(call_loingStatus)) {
                appSetAgentStatus(CallStatusUtils.HAVE_MEALS, isShowSuccess);
                statusMenu.setText(getHeadText(getResources().getString(R.string.sobot_custom_yongcan)));
            }
        } else if (getResources().getString(R.string.sobot_custom_huodong).equals(title)) {// 活动
            if (!CallStatusUtils.ACTIVITY.equals(call_loingStatus)) {
                appSetAgentStatus(CallStatusUtils.ACTIVITY, isShowSuccess);
                statusMenu.setText(getHeadText(getResources().getString(R.string.sobot_custom_huodong)));
            }
        } else if (getResources().getString(R.string.sobot_custom_tonghuazhong).equals(title)) {// 通话中
            if (!CallStatusUtils.CALLING.equals(call_loingStatus)) {
                statusMenu.setText(getHeadText(getResources().getString(R.string.sobot_custom_tonghuazhong)));
            }
        } else if (getResources().getString(R.string.sobot_custom_offline).equals(title)) {// 离线
            if (!CallStatusUtils.OFF_LINE.equals(call_loingStatus)) {
                appSetAgentStatus(CallStatusUtils.OFF_LINE, isShowSuccess);
                getHeadText(getResources().getString(R.string.sobot_custom_offline));
                SobotSipUtils.stopService(serviceVo.getCallV6Flag() == 1 ? true : false, getSobotActivity());
                statusMenu.setText(getResources().getString(R.string.sobot_custom_offline_and_click_login));

            }
        }

    }

    private String getHeadText(String text) {
        String lineStatus = text;
        SobotServiceInfoModel serviceVo = SobotLoginTools.getInstance().getServiceInfo();
        if (serviceVo != null) {
            int callWay;
            if (serviceVo.getCallV6Flag() == 1) {
                callWay = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.SP_KEY_CALL_MODEL_TYPE_V6, SobotCallConstant.CALL_MODEL_PHONE);
            } else {
                callWay = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.SP_KEY_CALL_MODEL_TYPE_V1, SobotCallConstant.CALL_MODEL_PHONE);
            }
            if (getResources().getString(R.string.sobot_custom_free).equals(lineStatus) && (!getResources().getString(R.string.sobot_custom_free).equals(nowStatus)) && SobotCallConstant.CALL_MODEL_SIP == callWay) {//原状态不是空闲，sip 话机，状态改变为 空闲

                if (!SobotRegistrationListener.getInstance().isLogin) {//没有登录

                    if (serviceVo.getCallV6Flag() != 1) {
                        loginNotifyUpdata();
                    }
                }
            }
            nowStatus = lineStatus;
            if (getResources().getString(R.string.sobot_custom_offline).equals(lineStatus)) {
                if (callNotifyTip != null) {
                    callNotifyTip.setVisibility(View.GONE);
                    if (SobotCallConstant.CALL_MODEL_SIP == callWay) {
                        if (SobotSipUtils.isServiceRun(serviceVo.getCallV6Flag() == 1 ? true : false)) {
                            SobotSipUtils.logoutUser(serviceVo.getCallV6Flag() == 1 ? true : false);
                            SobotRegistrationListener.getInstance().isLogin = false;
                            SobotSipUtils.stopService(serviceVo.getCallV6Flag() == 1 ? true : false, getActivity());
                        }
                    }
                }
            }
            if (SobotCallConstant.CALL_MODEL_NETWORK == callWay/*||SobotCallConstant.CALL_MODEL_SIP==callWay*/) {
                notifyTipChange(callWay);
            }

            if (SobotCallConstant.CALL_MODEL_PHONE == callWay) {
                return text + getResources().getString(R.string.sobot_call_mode_phone);
            }
            if (SobotCallConstant.CALL_MODEL_SIP == callWay) {
                return text + getResources().getString(R.string.sobot_call_mode_sip);
            }
            if (SobotCallConstant.CALL_MODEL_NETWORK == callWay) {
                return text + getResources().getString(R.string.sobot_call_mode_net);
            }
        }
        return text;

    }


    /**
     * 登录更新数据
     */
    private void loginNotifyUpdata() {
        if (serviceVo != null) {
            if (serviceVo.getCallV6Flag() != 1) {
                SobotCallApiUtils.appGetAgentStatus(zhiChiApi, getSobotActivity(), new SobotResultCallBack<SobotCallSeatCurrentStatus>() {
                    @Override
                    public void onSuccess(SobotCallSeatCurrentStatus sobotCallSeatCurrentStatus) {

                        final String status = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.callLoginStatus, CallStatusUtils.OFF_LINE);
                        if (!CallStatusUtils.OFF_LINE.equals(status) && !CallStatusUtils.ERROR_SIP.equals(status)) {//非离线状态
                            final int callWay = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.SP_KEY_CALL_MODEL_TYPE_V1, SobotCallConstant.CALL_MODEL_PHONE);
                            if (SobotCallConstant.CALL_MODEL_PHONE == callWay) {//电话
                                if (callNotifyTip != null) {
                                    //隐藏网络提示
                                    callNotifyTip.setVisibility(View.GONE);
                                }
                                if (getActivity() != null) {
                                    setAgentStatus(status, false, "");
                                }
                                return;
                            }
                            if (SobotCallConstant.CALL_MODEL_SIP == callWay) {//sip
                                sipLoginModel(status, callWay);
                                return;
                            }
                            if (SobotCallConstant.CALL_MODEL_NETWORK == callWay) {//网络
                                //显示网络提示
                                notifyTipChange(callWay);
                                return;
                            }
                        }
                    }

                    @Override
                    public void onFailure(Exception e, String des) {

                    }
                });
            } else {
                stopPollingAgentSuatus();
            }
        }
    }

    /**
     * 登陆时判断 动态绑定还是 固定绑定
     *
     * @param status
     * @param callWay
     */
    private void sipLoginModel(String status, int callWay) {
        zhiChiApi.appAgentLoginModel(this, getSobotActivity(), new SobotResultCallBack<SobotCallBaseCodeThird>() {
            @Override
            public void onSuccess(SobotCallBaseCodeThird baseCodeThird) {
                if (baseCodeThird != null && SobotCallConstant.RESULT_SUCCESS_CODE.equals(baseCodeThird.getRetCode())) {
                    Double model = (Double) baseCodeThird.getItem();
                    if (SobotCallConstant.CallModelSipFlag.BIND_SIP == model) {//固定绑定
                        zhiChiApi.appGetSipMsg(this, getSobotActivity(), null, new SobotResultCallBack<CallSipModel>() {
                            @Override
                            public void onSuccess(CallSipModel sipModel) {
                                if (sipModel != null) {
                                    CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallBaseConstant.SipModel.SIP_NUMBER, sipModel.getAgentNumber());
                                    CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallBaseConstant.SipModel.SIP_PWD, sipModel.getAgentPwd());
                                    CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallBaseConstant.SipModel.SIP_IP, sipModel.getServerIP());
                                    CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallBaseConstant.SipModel.SIP_SCHEME, sipModel.getServerScheme());

                                    //显示sip话机提示
                                    notifyTipChange(callWay);
                                    if (!SobotCallConstant.ServerScheme.FS.equals(sipModel.getServerScheme())) {//不是FS 只能电话登陆
                                        return;
                                    }
                                    if (TextUtils.isEmpty(status)) {
                                        return;
                                    }
                                    if (getActivity() != null) {
                                        registerSipLongin(sipModel, status, "");
                                    }

                                }
                            }

                            @Override
                            public void onFailure(Exception e, String des) {

                            }
                        });
                    } else {

                        CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallBaseConstant.SipModel.SIP_SCHEME, SobotCallConstant.ServerScheme.openSips);
                        //显示sip话机提示
                        notifyTipChange(callWay);
                        return;

                    }
                }
            }

            @Override
            public void onFailure(Exception e, String des) {
                SobotLogUtils.d("===V1登录失败====" + des);
            }
        });
    }

    /**
     * 改变提示信息
     */
    private void notifyTipChange(final int callWay) {
        if (SobotCallConstant.CALL_MODEL_SIP == callWay) {
            String serverScheme = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallBaseConstant.SipModel.SIP_SCHEME, SobotCallConstant.ServerScheme.vos);
            if (SobotCallConstant.ServerScheme.FS.equals(serverScheme)) {
                if (callNotifyTip != null) {
                    callNotifyTip.setVisibility(View.GONE);
                }
                return;
            }
        }
        if (callNotifyTip != null) {
            callNotifyTip.setVisibility(View.VISIBLE);
        }
        String tipString = String.format(getString(R.string.sobot_call_tip_app_no_support), SobotCallConstant.CALL_MODEL_NETWORK == callWay ? "网络电话" : SobotCallConstant.CALL_MODEL_SIP == callWay ? "SIP电话" : "手机电话");
        //tipString = tipString + "\t 详情";

        callNotifyTip.setText(tipString);
//        HtmlTools.setTextClickContext(callNotifyTip, tipString, "详情", Color.parseColor("#E67F17"), new View.OnClickListener() {
//            @Override
//            public void onClick(View v) {
//                TipDialog dialog = new TipDialog(getActivity());
//                dialog.show();
//                String text = String.format(getString(R.string.sobot_call_tip_call_model), SobotCallConstant.CALL_MODEL_NETWORK == callWay ? "网络" : SobotCallConstant.CALL_MODEL_SIP == callWay ? "SIP" : "手机");
//                String text2 = String.format(getString(R.string.sobot_call_tip_app_no_support), SobotCallConstant.CALL_MODEL_NETWORK == callWay ? "网络电话" : SobotCallConstant.CALL_MODEL_SIP == callWay ? "SIP软电话" : "手机电话");
//
//                SpannableStringBuilder spannableStringBuilder = new SpannableStringBuilder(text + text2);
//                StyleSpan styleSpan_B = new StyleSpan(Typeface.BOLD);
//
//                spannableStringBuilder.setSpan(styleSpan_B, text.length(), spannableStringBuilder.length(), Spanned.SPAN_INCLUSIVE_EXCLUSIVE);
//
//                dialog.setOneTextView(spannableStringBuilder);
//            }
//        });
    }

    /**
     * 手机登录
     *
     * @param type
     * @param lineStatus
     */
    private void loginPhone(int type, final String lineStatus, String phone) {
        SobotServiceInfoModel serviceVo = SobotLoginTools.getInstance().getServiceInfo();
        if (serviceVo != null) {
            if (serviceVo.getCallV6Flag() == 1) {
            } else {
                zhiChiApi.appAgentLogin(this, getSobotActivity(), type, null, new SobotResultCallBack<SobotCallBaseCode>() {
                    @Override
                    public void onSuccess(SobotCallBaseCode sobotCallBaseCode) {
                        if (sobotCallBaseCode != null && SobotCallConstant.RESULT_SUCCESS_CODE.equals(sobotCallBaseCode.getRetCode())) {
                            setAgentStatus(lineStatus, true, getResources().getString(R.string.sobot_call_login_success));
//                            if() {
                            pollingAgentSuatus();
//                            }
                        } else {
                            //登录失败
                            if (sobotCallBaseCode != null) {
                                switchTitle(getResources().getString(R.string.sobot_custom_offline), false);
                                SobotToastUtil.showToast(getSobotActivity(), sobotCallBaseCode.getRetMsg());
                            }
                        }
                    }

                    @Override
                    public void onFailure(Exception e, String des) {

                    }
                });
            }
        }
    }

    /**
     * 设置话机状态
     *
     * @param agentStatus
     * @param isShowSuccess
     */
    private void appSetAgentStatus(final String agentStatus, final boolean isShowSuccess) {
        if (CallStatusUtils.OFF_LINE.equals(agentStatus) || CallStatusUtils.ERROR_SIP.equals(agentStatus)) {
            int callWay;
            if (serviceVo.getCallV6Flag() == 1) {
                callWay = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.SP_KEY_CALL_MODEL_TYPE_V6, SobotCallConstant.CALL_MODEL_PHONE);
            } else {
                callWay = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.SP_KEY_CALL_MODEL_TYPE_V1, SobotCallConstant.CALL_MODEL_PHONE);
            }
            zhiChiApi.appAgentLogout(SobotCallFragment.this, getSobotActivity(), callWay, null, new SobotResultCallBack<SobotCallBaseCode>() {
                @Override
                public void onSuccess(SobotCallBaseCode sobotCallBaseCode) {
                    if (SobotSipUtils.isServiceRun(serviceVo.getCallV6Flag() == 1 ? true : false)) {
                        SobotSipUtils.logoutUser(serviceVo.getCallV6Flag() == 1 ? true : false);
                        SobotRegistrationListener.getInstance().isLogin = false;
                        SobotSipUtils.stopService(serviceVo.getCallV6Flag() == 1 ? true : false, getActivity());
                    }
                    if (sobotCallBaseCode != null && SobotCallConstant.RESULT_SUCCESS_CODE.equals(sobotCallBaseCode.getRetCode())) {
                        Drawable dra = getSobotActivity().getDrawable(R.drawable.custom_service_offline);
                        dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                        statusMenu.setCompoundDrawables(dra, null, null, null);
                        CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallConstant.callLoginStatus, agentStatus);
                        if (isShowSuccess) {
                            // SobotToastUtil.showToast(getSobotActivity(), getResources().getString(R.string.sobot_call_exit_success));
                        }
                    }
                    //停止座席状态轮询
                    stopPollingAgentSuatus();
                }

                @Override
                public void onFailure(Exception e, String des) {

                }
            });
        } else {
            setAgentStatus(agentStatus, isShowSuccess, getResources().getString(R.string.sobot_call_edit_success));
        }
    }

    /**
     * 设置话机状态 非离线
     *
     * @param agentStatus
     * @param isShowSuccess
     * @param toastString
     */
    public void setAgentStatus(final String agentStatus, final boolean isShowSuccess,
                               final String toastString) {
        if (!"3".equals(agentStatus) && !"115".equals(agentStatus) && CallStatusUtils.canChange(agentStatus)) {//非通话中并且非后处理并且可改变状态
            zhiChiApi.appSetAgentStatus(SobotCallFragment.this, getSobotActivity(), agentStatus, new SobotResultCallBack<SobotCallBaseCode>() {
                @Override
                public void onSuccess(SobotCallBaseCode response) {
                    if (response != null) {
                        if (SobotCallConstant.RESULT_SUCCESS_CODE.equals(response.getRetCode())) {
                            Drawable dra;
                            switch (agentStatus) {
                                case CallStatusUtils.FREE:
                                    dra = getSobotActivity().getDrawable(R.drawable.custom_service_online);
                                    dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                                    statusMenu.setCompoundDrawables(dra, null, null, null);
                                    break;
                                case CallStatusUtils.BUSY:
                                    dra = getSobotActivity().getDrawable(R.drawable.custom_service_busy);
                                    dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                                    statusMenu.setCompoundDrawables(dra, null, null, null);
                                    break;
                                default:
                                    dra = getSobotActivity().getDrawable(R.drawable.custom_service_other);
                                    dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                                    statusMenu.setCompoundDrawables(dra, null, null, null);
                                    break;
                            }
                            CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallConstant.callLoginStatus, agentStatus);
                            if (isShowSuccess) {
                                SobotToastUtil.showToast(getSobotActivity(), toastString);
                            }
                            getCallSeatLoginStatus();
                        } else if ("200011".equals(response.getRetCode())) {//座席已经登出
                            if (isShowSuccess) {
                                SobotToastUtil.showToast(getSobotActivity(), response.getRetMsg());
                            }
                            switchTitle(getResources().getString(R.string.sobot_custom_offline), false);
                        }

                    }
                }

                @Override
                public void onFailure(Exception e, String des) {

                }
            });
        } else {
            Drawable dra;
            dra = getSobotActivity().getDrawable(R.drawable.custom_service_other);
            dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
            statusMenu.setCompoundDrawables(dra, null, null, null);
            CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallConstant.callLoginStatus, agentStatus);
            if (isShowSuccess) {
                SobotToastUtil.showToast(getSobotActivity(), toastString);
            }
            getCallSeatLoginStatus();
        }
    }

    /**
     * 注册登录sip
     *
     * @param sipModel
     * @param lineStatus
     */
    public void registerSipLongin(final CallSipModel sipModel, String lineStatus, String
            lineStatusName) {
        SobotLogUtils.i("registerSipLongin");
        if (sipModel == null || TextUtils.isEmpty(sipModel.getAgentNumber())) {
            return;
        }
//        SharedPreferencesUtil.saveStringData(getApplicationContext(), ConstantUtils.callLoginStatus, lineStatus);
        try {
            SobotServiceInfoModel serviceVo = SobotLoginTools.getInstance().getServiceInfo();
            SobotSipUtils.startService(serviceVo.getCallV6Flag() == 1 ? true : false, getSobotActivity());

            new Handler().postDelayed(new Runnable() {
                @Override
                public void run() {
                    SobotRegistrationListener registerListener = SobotRegistrationListener.getInstance();
                    registerListener.setContext(getSobotActivity().getApplicationContext());
                    registerListener.setLineStatus(lineStatus);
                    registerListener.setLineStatusName(lineStatusName);
                    registerListener.setSipModel(sipModel);
                    registerListener.setCallBack(new SobotRegistrationListener.CallBack() {
                        @Override
                        public void callStatus(String lineStatus, String lineStatusName, boolean isShowToast, String toastString) {
                            SobotServiceInfoModel serviceVo = SobotLoginTools.getInstance().getServiceInfo();
                            if (serviceVo != null) {
                                if (serviceVo.getCallV6Flag() != 1) {
                                    setAgentStatus(lineStatus, isShowToast, toastString);
                                }
                            }
                        }

                        @Override
                        public void callTitle(String lineStatusText, boolean isShowToast) {
                            SobotServiceInfoModel serviceVo = SobotLoginTools.getInstance().getServiceInfo();
                            if (serviceVo != null) {
                                if (serviceVo.getCallV6Flag() != 1) {
                                    //v1
                                    switchTitle(lineStatusText, isShowToast);
                                }
                            }
                        }
                    });
                    SobotServiceInfoModel serviceVo = SobotLoginTools.getInstance().getServiceInfo();
                    SobotPhoneStatusListener phoneStatusListener = SobotPhoneStatusListener.getInstance();
                    phoneStatusListener.setContext(getSobotActivity());
                    if (serviceVo != null) {
                        SobotSipUtils.addPhoneCallStatesback(serviceVo.getCallV6Flag() == 1 ? true : false, registerListener, phoneStatusListener);
                        SobotSipUtils.setAccount(serviceVo.getCallV6Flag() == 1 ? true : false, sipModel.getAgentNumber(), sipModel.getAgentPwd(), sipModel.getServerIP());
                        SobotSipUtils.login(serviceVo.getCallV6Flag() == 1 ? true : false, getSobotActivity());
                    }
                }
            }, 1500);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @Override
    public void onActivityResult(int requestCode, int resultCode, @Nullable Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        if (resultCode == RESULT_OK) {
            if (requestCode == SobotCallConstant.SOBOT_REQUEST_LOGIN_CODE) {
                int callWay = data.getIntExtra("callWay", SobotCallConstant.CALL_MODEL_PHONE);//接听方式
                if (serviceVo != null && serviceVo.getCallV6Flag() == 1) {
                    CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallConstant.SP_KEY_CALL_MODEL_TYPE_V6, callWay);
                } else {
                    CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallConstant.SP_KEY_CALL_MODEL_TYPE_V1, callWay);
                }
                String statusType = data.getStringExtra("statusType");//座席登录状态
                String statusTypeName = data.getStringExtra("statusTypeName");//座席登录状态名称
                String phone = data.getStringExtra("callPhone");//座席手机号
                if (callWay == SobotCallConstant.CALL_MODEL_SIP) {
                    //登陆注册sip并修改状态
                    String agentNumber = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallBaseConstant.SipModel.SIP_NUMBER);
                    String agentPwd = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallBaseConstant.SipModel.SIP_PWD);
                    String serverIP = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallBaseConstant.SipModel.SIP_IP);
                    CallSipModel sipModel = new CallSipModel();
                    sipModel.setAgentNumber(agentNumber);
                    sipModel.setAgentPwd(agentPwd);
                    sipModel.setServerIP(serverIP);
                    registerSipLongin(sipModel, statusType, statusTypeName);
                } else if (SobotCallConstant.CALL_MODEL_PHONE == callWay) {
                    loginPhone(callWay, statusType, phone);
                } else {
                    SobotToastUtil.showToast(getSobotActivity(), getResources().getString(R.string.sobot_call_network_no_call_tip));
                }
            }
        }
    }

    private void initListView(View view) {
        refreshLayout = view.findViewById(R.id.sobot_srl_call);
        recyclerView = view.findViewById(R.id.sobot_rv_call_list);
        loadingLayout = view.findViewById(R.id.sobot_loading_layout);

        //列表
        recyclerView.setLayoutManager(new LinearLayoutManager(getContext()));
        mDate = new ArrayList<>();
        mAdapter = new SobotCallCenterAdapter(getSobotActivity(), mDate, this);
        recyclerView.setAdapter(mAdapter);

        //下拉刷新控件
        refreshLayout.setRefreshHeader(new ClassicsHeader(getSobotActivity()));
        refreshLayout.setRefreshFooter(new ClassicsFooter(getSobotActivity()));
        refreshLayout.setEnableLoadMore(false);
        refreshLayout.setOnLoadMoreListener(new OnLoadMoreListener() {
            @Override
            public void onLoadMore(@NonNull RefreshLayout refreshLayout) {
                if (isHasMoreData) {
                    requestDate(pageNo + 1);
                } else {
                    refreshLayout.setNoMoreData(true);
                }
            }
        });
        refreshLayout.setOnRefreshListener(new OnRefreshListener() {
            @Override
            public void onRefresh(@NonNull RefreshLayout refreshLayout) {
                pageNo = 1;
                requestDate(pageNo);
            }
        });
        refreshLayout.setNoMoreData(true);

        //是否显示无内容
        loadingLayout.setRetryListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                pageNo = 1;
                requestDate(pageNo);
            }
        });
    }

    private void requestDate(int pageIndex) {
        serviceVo = SobotLoginTools.getInstance().getServiceInfo();
        if (serviceVo == null) {
            isHasMoreData = false;
            loadingLayout.showEmpty();//显示无内容
            refreshLayout.finishLoadMore();
            return;
        }
        if (serviceVo.getCallV6Flag() == 1) {
            zhiChiApi.getTaskListV6(getSobotActivity(), getContext(), "", pageIndex, pageSize, new SobotResultCallBack<List<SobotCallTaskEntity>>() {
                @Override
                public void onSuccess(List<SobotCallTaskEntity> sobotCallTaskModels) {
                    refreshLayout.finishRefresh();//停止刷新
                    pageNo = pageIndex;
                    if (pageIndex == 1) {
                        mDate.clear();//刷新时清空列表
                        if (sobotCallTaskModels.size() == 0) {
                            isHasMoreData = false;
                            loadingLayout.showEmpty();//显示无内容
                            return;
                        }
                    }
                    if (sobotCallTaskModels.size() < pageSize) {
                        //加载完毕
                        isHasMoreData = false;
                        refreshLayout.setNoMoreData(true);
                        refreshLayout.setEnableLoadMore(false);
                    } else {
                        //有 下一页
                        isHasMoreData = true;
                        refreshLayout.setEnableLoadMore(true);
                        refreshLayout.setNoMoreData(false);
                    }

                    mDate.addAll(sobotCallTaskModels);
                    mAdapter.notifyDataSetChanged();
                    loadingLayout.showContent();//显示列表
                    refreshLayout.finishLoadMore();
                }

                @Override
                public void onFailure(Exception e, String des) {
                    refreshLayout.finishLoadMore();
                    refreshLayout.finishRefresh();
                    if (pageIndex == 1) {
                        loadingLayout.showEmpty();
                    } else {
                        SobotToastUtil.showCustomToast(getContext(), SobotStringUtils.isEmpty(des) ? getResources().getString(R.string.sobot_call_net_error_string) : des, R.drawable.sobot_icon_warning_attention);
                    }
                }
            });
        } else {
            zhiChiApi.getAllTaskDetails(getSobotActivity(), getContext(), pageIndex, pageSize, new SobotResultCallBack<List<SobotCallTaskModel>>() {
                @Override
                public void onSuccess(List<SobotCallTaskModel> sobotCallTaskModels) {
                    refreshLayout.finishRefresh();//停止刷新
                    pageNo = pageIndex;
                    if (pageIndex == 1) {
                        mDate.clear();//刷新时清空列表
                        if (sobotCallTaskModels.size() == 0) {
                            isHasMoreData = false;
                            loadingLayout.showEmpty();//显示无内容
                            return;
                        }
                    }
                    if (sobotCallTaskModels.size() < pageSize) {
                        //加载完毕
                        isHasMoreData = false;
                        refreshLayout.setNoMoreData(true);
                        refreshLayout.setEnableLoadMore(false);
                    } else {
                        //有 下一页
                        isHasMoreData = true;
                        refreshLayout.setEnableLoadMore(true);
                        refreshLayout.setNoMoreData(false);
                    }

                    mDate.addAll(sobotCallTaskModels);
                    mAdapter.notifyDataSetChanged();
                    loadingLayout.showContent();//显示列表
                    refreshLayout.finishLoadMore();
                }

                @Override
                public void onFailure(Exception e, String des) {
                    refreshLayout.finishLoadMore();
                    refreshLayout.finishRefresh();
                    if (pageIndex == 1) {
                        loadingLayout.showEmpty();
                    } else {
                        SobotToastUtil.showCustomToast(getContext(), SobotStringUtils.isEmpty(des) ? getResources().getString(R.string.sobot_call_net_error_string) : des, R.drawable.sobot_icon_warning_attention);
                    }
                }
            });
        }
    }

    @Override
    public void onItemClick(Object info) {
        if (getActivity() != null && info != null) {
            String taskId = "", taskName = "";
            int status = 0;
            if (info instanceof SobotCallTaskModel) {
                SobotCallTaskModel taskModel = (SobotCallTaskModel) info;
                taskId = taskModel.getTaskId();
                taskName = taskModel.getTaskName();
                status = taskModel.getStatus();
                Intent intent = new Intent(getActivity(), SobotV1CallTaskDetailsActivity.class);
                intent.putExtra("taskId", taskId);
                intent.putExtra("taskName", taskName);
                intent.putExtra("status", status);
                getActivity().startActivity(intent);
            } else if (info instanceof SobotCallTaskEntity) {
                SobotCallTaskEntity taskEntity = (SobotCallTaskEntity) info;
                taskId = taskEntity.getCampaignId();
                taskName = taskEntity.getCampaignName();
                status = taskEntity.getState();
                Intent intent = new Intent(getActivity(), SobotCallTaskDetailsActivity.class);
                intent.putExtra("taskId", taskId);
                intent.putExtra("taskName", taskName);
                intent.putExtra("status", status);
                getActivity().startActivity(intent);
            }
        }
    }

    //默认或者离线后的列表显示
    private void showEmptyList() {
        refreshLayout.finishLoadMore();
        refreshLayout.finishRefresh();
        loadingLayout.showEmpty();
        refreshLayout.setEnableLoadMore(false);
    }

    //上次网络变化时间
    private long lastConnectivitytime = 0;

    /**
     * 检测网络状态的广播
     */
    public class NetWorkChangeReceiver extends BroadcastReceiver {

        @Override
        public void onReceive(Context context, Intent intent) {
            if (ConnectivityManager.CONNECTIVITY_ACTION.equals(intent.getAction())) {
                //CONNECTIVITY_ACTION 粘性广播，一注册就会收到这个广播，第一次不处理
                if (connectivity_action_count > 0) {
                    long currentTime = Calendar.getInstance().getTimeInMillis();
                    if (currentTime - lastConnectivitytime > 2000) {
                        //两次收到网络变化广播时间超过2s 才执行逻辑
                        lastConnectivitytime = currentTime;
                        ConnectivityManager manager = (ConnectivityManager) context
                                .getSystemService(Context.CONNECTIVITY_SERVICE);
                        if (manager == null) return;
                        try {
                            if (PermissionUtil.checkPermission(context, Manifest.permission.ACCESS_NETWORK_STATE)) {
                                NetworkInfo activeNetwork = manager.getActiveNetworkInfo();
                                if (activeNetwork != null) {
                                    if (activeNetwork.isConnected()) {
                                        SobotServiceInfoModel serviceVo = SobotLoginTools.getInstance().getServiceInfo();
                                        if (serviceVo.getCallV6Flag() == 1) {

                                        }
                                    } else {
                                        SobotLogUtils.i(TAG + " 当前没有可用网络");
                                    }
                                }
                            }
                        } catch (Exception e) {
                            SobotLogUtils.e(TAG + " 网络状态获取错误", e);
                        }
                    }
                }
                connectivity_action_count++;
            }
        }
    }

}