package com.sobot.callsdk.v1.sipphonelibrary;

import static android.view.View.GONE;
import static android.view.View.VISIBLE;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.Context;
import android.content.Intent;
import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.net.Uri;
import android.telephony.TelephonyManager;
import android.util.TypedValue;
import android.view.KeyEvent;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;

import org.linphone.core.DialPlan;
import org.linphone.core.LinphoneAddress;
import org.linphone.core.LinphoneCall;
import org.linphone.core.LinphoneCall.State;
import org.linphone.core.LinphoneCore;
import org.linphone.core.LinphoneCoreException;
import org.linphone.core.LinphoneCoreFactory;
import org.linphone.core.LinphoneProxyConfig;
import org.linphone.mediastream.Log;

import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Calendar;
import java.util.Collection;
import java.util.List;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;

public final class phoneUtils {

    private phoneUtils() {
    }

    //private static final String sipAddressRegExp = "^(sip:)?(\\+)?[a-z0-9]+([_\\.-][a-z0-9]+)*@([a-z0-9]+([\\.-][a-z0-9]+)*)+\\.[a-z]{2,}(:[0-9]{2,5})?$";
    //private static final String strictSipAddressRegExp = "^sip:(\\+)?[a-z0-9]+([_\\.-][a-z0-9]+)*@([a-z0-9]+([\\.-][a-z0-9]+)*)+\\.[a-z]{2,}$";

    public static boolean isSipAddress(String numberOrAddress) {
        try {
            LinphoneCoreFactory.instance().createLinphoneAddress(numberOrAddress);
            return true;
        } catch (LinphoneCoreException e) {
            return false;
        }
    }

    public static boolean isNumberAddress(String numberOrAddress) {
        LinphoneProxyConfig proxy = SobotPhoneManager.getLc().createProxyConfig();
        return proxy.normalizePhoneNumber(numberOrAddress) != null;
    }

    public static boolean isStrictSipAddress(String numberOrAddress) {
        return isSipAddress(numberOrAddress) && numberOrAddress.startsWith("sip:");
    }

    public static String getAddressDisplayName(String uri) {
        LinphoneAddress lAddress;
        try {
            lAddress = LinphoneCoreFactory.instance().createLinphoneAddress(uri);
            return getAddressDisplayName(lAddress);
        } catch (LinphoneCoreException e) {
            return null;
        }
    }

    public static String getAddressDisplayName(LinphoneAddress address) {
        if (address.getDisplayName() != null) {
            return address.getDisplayName();
        } else {
            if (address.getUserName() != null) {
                return address.getUserName();
            } else {
                return address.asStringUriOnly();
            }
        }
    }

    public static String getUsernameFromAddress(String address) {
        if (address.contains("sip:"))
            address = address.replace("sip:", "");

        if (address.contains("@"))
            address = address.split("@")[0];

        return address;
    }

    public static boolean onKeyBackGoHome(Activity activity, int keyCode, KeyEvent event) {
        if (!(keyCode == KeyEvent.KEYCODE_BACK && event.getRepeatCount() == 0)) {
            return false; // continue
        }

        activity.startActivity(new Intent()
                .setAction(Intent.ACTION_MAIN)
                .addCategory(Intent.CATEGORY_HOME));
        return true;
    }


    static boolean isToday(Calendar cal) {
        return isSameDay(cal, Calendar.getInstance());
    }

    static boolean isSameDay(Calendar cal1, Calendar cal2) {
        if (cal1 == null || cal2 == null) {
            return false;
        }

        return (cal1.get(Calendar.ERA) == cal2.get(Calendar.ERA) &&
                cal1.get(Calendar.YEAR) == cal2.get(Calendar.YEAR) &&
                cal1.get(Calendar.DAY_OF_YEAR) == cal2.get(Calendar.DAY_OF_YEAR));
    }


    public static Bitmap downloadBitmap(Uri uri) {
        URL url;
        InputStream is = null;
        try {
            url = new URL(uri.toString());
            is = url.openStream();
            return BitmapFactory.decodeStream(is);
        } catch (MalformedURLException e) {
            Log.e(e, e.getMessage());
        } catch (IOException e) {
            Log.e(e, e.getMessage());
        } finally {
            try {
                is.close();
            } catch (IOException x) {
            }
        }
        return null;
    }


    public static final List<LinphoneCall> getLinphoneCallsNotInConf(LinphoneCore lc) {
        List<LinphoneCall> l = new ArrayList<LinphoneCall>();
        for (LinphoneCall c : lc.getCalls()) {
            if (!c.isInConference()) {
                l.add(c);
            }
        }
        return l;
    }

    public static final List<LinphoneCall> getLinphoneCallsInConf(LinphoneCore lc) {
        List<LinphoneCall> l = new ArrayList<LinphoneCall>();
        for (LinphoneCall c : lc.getCalls()) {
            if (c.isInConference()) {
                l.add(c);
            }
        }
        return l;
    }

    public static final List<LinphoneCall> getLinphoneCalls(LinphoneCore lc) {
        // return a modifiable list
        return new ArrayList<LinphoneCall>(Arrays.asList(lc.getCalls()));
    }

    public static final boolean hasExistingResumeableCall(LinphoneCore lc) {
        for (LinphoneCall c : getLinphoneCalls(lc)) {
            if (c.getState() == State.Paused) {
                return true;
            }
        }
        return false;
    }

    public static final List<LinphoneCall> getCallsInState(LinphoneCore lc, Collection<State> states) {
        List<LinphoneCall> foundCalls = new ArrayList<LinphoneCall>();
        for (LinphoneCall call : getLinphoneCalls(lc)) {
            if (states.contains(call.getState())) {
                foundCalls.add(call);
            }
        }
        return foundCalls;
    }

    public static final List<LinphoneCall> getRunningOrPausedCalls(LinphoneCore lc) {
        return getCallsInState(lc, Arrays.asList(
                State.Paused,
                State.PausedByRemote,
                State.StreamsRunning));
    }

    public static final int countConferenceCalls(LinphoneCore lc) {
        int count = lc.getConferenceSize();
        if (lc.isInConference()) count--;
        return count;
    }

    public static int countVirtualCalls(LinphoneCore lc) {
        return lc.getCallsNb() - countConferenceCalls(lc);
    }

    public static int countNonConferenceCalls(LinphoneCore lc) {
        return lc.getCallsNb() - countConferenceCalls(lc);
    }

    public static void setVisibility(View v, int id, boolean visible) {
        v.findViewById(id).setVisibility(visible ? VISIBLE : GONE);
    }

    public static void setVisibility(View v, boolean visible) {
        v.setVisibility(visible ? VISIBLE : GONE);
    }

    public static void enableView(View root, int id, OnClickListener l, boolean enable) {
        View v = root.findViewById(id);
        v.setVisibility(enable ? VISIBLE : GONE);
        v.setOnClickListener(l);
    }

    public static int pixelsToDpi(Resources res, int pixels) {
        return (int) TypedValue.applyDimension(TypedValue.COMPLEX_UNIT_DIP, (float) pixels, res.getDisplayMetrics());
    }

    public static boolean isCallRunning(LinphoneCall call) {
        if (call == null) {
            return false;
        }

        State state = call.getState();

        return state == State.Connected ||
                state == State.CallUpdating ||
                state == State.CallUpdatedByRemote ||
                state == State.StreamsRunning ||
                state == State.Resuming;
    }

    public static boolean isCallEstablished(LinphoneCall call) {
        if (call == null) {
            return false;
        }

        State state = call.getState();

        return isCallRunning(call) ||
                state == State.Paused ||
                state == State.PausedByRemote ||
                state == State.Pausing;
    }

    public static boolean isHighBandwidthConnection(Context context) {
        ConnectivityManager cm = (ConnectivityManager) context.getSystemService(Context.CONNECTIVITY_SERVICE);
        NetworkInfo info = cm.getActiveNetworkInfo();
        return (info != null && info.isConnected() && isConnectionFast(info.getType(), info.getSubtype()));
    }

    private static boolean isConnectionFast(int type, int subType) {
        if (type == ConnectivityManager.TYPE_MOBILE) {
            switch (subType) {
                case TelephonyManager.NETWORK_TYPE_EDGE:
                case TelephonyManager.NETWORK_TYPE_GPRS:
                case TelephonyManager.NETWORK_TYPE_IDEN:
                    return false;
            }
        }
        //in doubt, assume connection is good.
        return true;
    }

    public static void clearLogs() {
        try {
            Runtime.getRuntime().exec(new String[]{"logcat", "-c"});
        } catch (IOException e) {
            Log.e(e);
        }
    }

    public static boolean zipLogs(StringBuilder sb, String toZipFile) {
        boolean success = false;
        try {
            FileOutputStream zip = new FileOutputStream(toZipFile);

            ZipOutputStream out = new ZipOutputStream(new BufferedOutputStream(zip));
            ZipEntry entry = new ZipEntry("logs.txt");
            out.putNextEntry(entry);

            out.write(sb.toString().getBytes());

            out.close();
            success = true;

        } catch (Exception e) {
            Log.e("Exception when trying to zip the logs: " + e.getMessage());
        }

        return success;
    }

    public static String getExtensionFromFileName(String fileName) {
        String extension = null;
        int i = fileName.lastIndexOf('.');
        if (i > 0) {
            extension = fileName.substring(i + 1);
        }
        return extension;
    }

    public static void recursiveFileRemoval(File root) {
        if (!root.delete()) {
            if (root.isDirectory()) {
                File[] files = root.listFiles();
                if (files != null) {
                    for (File f : files) {
                        recursiveFileRemoval(f);
                    }
                }
            }
        }
    }


    public static void displayError(boolean isOk, TextView error, String errorText) {
        if (isOk) {
            error.setVisibility(View.INVISIBLE);
            error.setText("");
        } else {
            error.setVisibility(View.VISIBLE);
            error.setText(errorText);
        }
    }


    public static String getCountryCode(EditText dialCode) {
        if (dialCode != null) {
            String code = dialCode.getText().toString();
            if (code != null && code.startsWith("+")) {
                code = code.substring(1);
            }
            return code;
        }
        return null;
    }

    public static void setCountry(DialPlan c, EditText dialCode, Button selectCountry, int countryCode) {
        if (c != null && dialCode != null && selectCountry != null) {
            dialCode.setText(c.getCountryCode());
            selectCountry.setText(c.getCountryName());
        } else {
            if (countryCode != -1) {
                dialCode.setText("+" + countryCode);
            } else {
                dialCode.setText("+");
            }
        }
    }

    public static void displayErrorAlert(String msg, Context ctxt) {
        if (ctxt != null) {
            AlertDialog.Builder builder = new AlertDialog.Builder(ctxt);
            builder.setMessage(msg)
                    .setCancelable(false)
                    .setNeutralButton("Ok", null)
                    .show();
        }
    }
}

