package com.sobot.callsdk.v6.activity;

import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.View;
import android.view.inputmethod.InputMethodManager;
import android.widget.TextView;

import androidx.viewpager.widget.ViewPager;

import com.sobot.callbase.CallPermissionManager;
import com.sobot.callbase.model.SobotSummaryConfig;
import com.sobot.callbase.utils.CommonUtils;
import com.sobot.callbase.widget.tab.SobotCallSlidingTab;
import com.sobot.callsdk.R;
import com.sobot.callsdk.activity.SobotCallBaseActivity;
import com.sobot.callsdk.fargment.SobotBaseFragment;
import com.sobot.callsdk.utils.CallSharedPreferencesUtils;
import com.sobot.callsdk.utils.CallStatusUtils;
import com.sobot.callsdk.utils.SobotCallConstant;
import com.sobot.callsdk.v6.fragment.CallInfoFragment;
import com.sobot.callsdk.v6.fragment.CustomInfoFragment;
import com.sobot.callsdk.v6.fragment.ServiceSummaryFragment;
import com.sobot.callsdk.widget.SobotViewPagerAdapter;
import com.sobot.common.login.permission.SobotPermissionManager;
import com.sobot.network.http.callback.SobotResultCallBack;
import com.sobot.utils.SobotLogUtils;
import com.sobot.widget.ui.toast.SobotToastUtil;

import java.util.ArrayList;
import java.util.List;

/**
 * 通话详情
 */
public class CallDetailsActivity extends SobotCallBaseActivity implements View.OnClickListener {
    private TextView sobot_text_title;
    private SobotCallSlidingTab sobot_call_tab;
    private ViewPager vp_call_viewpager;
    private SobotViewPagerAdapter adapter;

    private CallInfoFragment callInfoFragment;
    private CustomInfoFragment customInfoFragment;
    private ServiceSummaryFragment summaryFragment;
    private int defaultIndex = 0;//默认打开fragment的位置
    private String callID;//通话id
    private String callNumber;//客户号码
    private String encryptCustomerNumber;//客户号码加密后的
    private boolean editType;//是否是编辑状态
    private int userInfoType = -1;//客户详情页显示类型

    private String fromPage;//来源 父界面 是否从通话界面跳转的，如果是 隐藏回拨按钮

    private String customerId;
    private String customerNick;

    private SobotSummaryConfig config;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        if (null != getIntent()) {
            callID = getIntent().getStringExtra("callID");
            callNumber = getIntent().getStringExtra("callNumber");
            encryptCustomerNumber = getIntent().getStringExtra("encryptCustomerNumber");
            defaultIndex = getIntent().getIntExtra("defaultIndex", 0);
            editType = getIntent().getBooleanExtra("editType", false);
            customerId = getIntent().getStringExtra("customerId");
            customerNick = getIntent().getStringExtra("customerNick");
            fromPage = getIntent().getStringExtra("fromPage");
            userInfoType = getIntent().getIntExtra("userInfoType", -1);
            SobotLogUtils.d("====callNumber==" + callNumber);
        }
        super.onCreate(savedInstanceState);
    }

    @Override
    protected void onNewIntent(Intent intent) {
        super.onNewIntent(intent);
        defaultIndex = intent.getIntExtra("defaultIndex", 0);
        if (vp_call_viewpager != null) {
            vp_call_viewpager.setCurrentItem(defaultIndex, false);
        }
    }

    private void requestConfig() {
        zhiChiApi.getSummaryConfig(CallDetailsActivity.this, new SobotResultCallBack<SobotSummaryConfig>() {

            @Override
            public void onSuccess(SobotSummaryConfig sobotSummaryConfig) {
                if (sobotSummaryConfig != null) {
                    config = sobotSummaryConfig;
                    if (sobotSummaryConfig.getSummaryFlag() == 1) {
                        //服务总结开着
                        CallSharedPreferencesUtils.getInstance(getApplication()).put(SobotCallConstant.CALL_SERVICE_SUMMARY_FLAG, true);
                    } else {
                        //关闭服务总结
                        CallSharedPreferencesUtils.getInstance(getApplication()).put(SobotCallConstant.CALL_SERVICE_SUMMARY_FLAG, false);
                    }
                }
                initTab();
            }

            @Override
            public void onFailure(Exception e, String des) {
                initTab();
            }
        });
    }

    @Override
    protected int getContentViewResId() {
        return R.layout.activity_call_details;
    }

    @Override
    protected void initView() throws InterruptedException {
        if (CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_THXQ_DHHB)) {
            String call_loingStatus = CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).get(SobotCallConstant.callLoginStatus, CallStatusUtils.V6_OFFLINE);
            //如果是从通话界面跳转的，不显示回拨按钮 电话条是登录状态
            getRightMenu().setVisibility(View.VISIBLE);
            getRightMenu().setText(R.string.call_call_back);
            getRightMenu().setTextSize(14);
            getRightMenu().setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    if (!CommonUtils.isNetWorkConnected(getSobotBaseActivity())) {
                        SobotToastUtil.showToast(getSobotBaseActivity(), getString(R.string.sobot_call_net_error_string));
                    } else {
                        //判断是否登录
                        String call_loingStatus = CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).get(SobotCallConstant.callLoginStatus, CallStatusUtils.V6_OFFLINE);
//                            if (!TextUtils.isEmpty(callID) && "callStatus".equals(fromPage) ) {
//                                SobotToastUtil.showToast(getSobotBaseActivity(), getString(R.string.sobot_call_net_error_string));
//                            } else
                        if (call_loingStatus.equals(CallStatusUtils.V6_FINISHING)) {
                            //判断是否正在整理中
                            SobotToastUtil.showToast(getSobotBaseActivity(), getResources().getString(R.string.sobot_error_switch_status));
                        } else if (call_loingStatus.equals(CallStatusUtils.V6_SYSYTEM_BUSY)) {
                            SobotToastUtil.showToast(getSobotBaseActivity(), getResources().getString(R.string.call_str_system_Lock_toast));
                        } else if (call_loingStatus.equals(CallStatusUtils.V6_OFFLINE)) {
                            SobotToastUtil.showToast(getSobotBaseActivity(), getResources().getString(R.string.sobot_call_error_hint));
                        } else {
                            if (!TextUtils.isEmpty(callID)) {
                                //回拨
                                zhiChiApi.callbacks(getSobotBaseActivity(), callID, "CDR", callID, "AutoJump", new SobotResultCallBack() {
                                    @Override
                                    public void onSuccess(Object o) {
                                        //先结束当前界面再启动通话界面，防止点击客户信息时 通话详情页面展示的不对
                                        finish();
                                        Intent intent = CallStatusActivity.initCallMeIntent(CallDetailsActivity.this, "");
                                        intent.setFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP | Intent.FLAG_ACTIVITY_CLEAR_TOP |
                                                Intent.FLAG_ACTIVITY_NEW_TASK);
                                        startActivity(intent);
                                    }

                                    @Override
                                    public void onFailure(Exception e, String des) {
                                        SobotToastUtil.showCustomToast(getSobotBaseActivity(), des);
                                    }
                                });
                            }
                        }
                    }
                }
            });

        } else {
            getRightMenu().setVisibility(View.GONE);
        }

        sobot_text_title = findViewById(R.id.sobot_text_title);
        sobot_text_title.setVisibility(View.VISIBLE);
        sobot_text_title.setText(R.string.sobot_call_details);
        sobot_call_tab = findViewById(R.id.call_fragment_tab);
        vp_call_viewpager = findViewById(R.id.vp_call_viewpager);

    }

    @Override
    protected void initData() {
        Bundle bundle = new Bundle();
        bundle.putString("callID", callID);
        bundle.putString("callNumber", callNumber);
        bundle.putString("encryptCustomerNumber", encryptCustomerNumber);
        bundle.putBoolean("editType", editType);
        bundle.putString("customerNick", customerNick);
        bundle.putString("customerId", customerId);
        bundle.putBoolean("editType", editType);
        bundle.putString("customerNick", customerNick);
        bundle.putString("fromPage", fromPage);
        bundle.putInt("userInfoType", userInfoType);//用于客户信息详情
        callInfoFragment = new CallInfoFragment();
        customInfoFragment = new CustomInfoFragment();
        summaryFragment = new ServiceSummaryFragment();
        customInfoFragment.setArguments(bundle);
        callInfoFragment.setArguments(bundle);
        summaryFragment.setArguments(bundle);
        requestConfig();
    }

    private void initTab() {
        List<SobotBaseFragment> fragments = new ArrayList<>();
        List<String> titleList = new ArrayList<>();
        if (CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_THXQ_THXX)) {
            titleList.add(getString(R.string.call_call_info));
            fragments.add(callInfoFragment);
        }
        if (CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_THXQ_FWZJ)) {
            if (config != null ? config.getSummaryFlag() == 1 : CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).get(SobotCallConstant.CALL_SERVICE_SUMMARY_FLAG, false)) {
                titleList.add(getString(R.string.call_str_service_summary));
                fragments.add(summaryFragment);
            }
        }
        if (CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_THXQ_KHXX)) {
            titleList.add(getString(R.string.call_custom_info));
            fragments.add(customInfoFragment);
        }
        String[] titleStr = new String[titleList.size()];
        for (int i = 0; i < titleList.size(); i++) {
            titleStr[i] = titleList.get(i);
        }
        adapter = new SobotViewPagerAdapter(this, getSupportFragmentManager(), titleStr, fragments);
        vp_call_viewpager.setAdapter(adapter);
        sobot_call_tab.setViewPager(vp_call_viewpager);
        vp_call_viewpager.setCurrentItem(defaultIndex, false);
    }

    @Override
    public void onClick(View v) {
    }

    @Override
    public void onBackPressed() {
        hideKeyboard();
        super.onBackPressed();
    }

    public void hideKeyboard() {
        InputMethodManager imm =
                (InputMethodManager) getSystemService(Context.INPUT_METHOD_SERVICE);
        if (imm != null && getCurrentFocus() != null && null != getCurrentFocus().getWindowToken()) {
            imm.hideSoftInputFromWindow(getCurrentFocus().getWindowToken(), 0);
        }
    }
}