package com.sobot.callsdk.v6.activity;

import android.content.Intent;
import android.os.Bundle;
import android.os.Handler;
import android.text.TextUtils;
import android.view.View;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

import androidx.annotation.Nullable;
import androidx.lifecycle.Observer;
import androidx.viewpager.widget.ViewPager;

import com.sobot.callbase.model.CallTaskDetailsModel;
import com.sobot.callbase.widget.SobotShadowLayout;
import com.sobot.callbase.widget.floatwindow.SobotFloatWindow;
import com.sobot.callbase.widget.tab.SobotCallSlidingTab;
import com.sobot.callsdk.R;
import com.sobot.callsdk.activity.SobotCallBaseActivity;
import com.sobot.callsdk.fargment.SobotBaseFragment;
import com.sobot.callsdk.utils.CallSharedPreferencesUtils;
import com.sobot.callsdk.utils.CallStatusUtils;
import com.sobot.callsdk.utils.SobotCallConstant;
import com.sobot.callsdk.v6.constant.SobotCallLiveDataBusV6Key;
import com.sobot.callsdk.v6.fragment.CallTaskDetailsAllFragment;
import com.sobot.callsdk.v6.fragment.CallTaskDetailsExecutedFragment;
import com.sobot.callsdk.v6.fragment.CallTaskDetailsUnexecutedFragment;
import com.sobot.callsdk.v6.listener.CallTaskDetailsCountListener;
import com.sobot.callsdk.widget.SobotViewPagerAdapter;
import com.sobot.common.login.SobotLoginTools;
import com.sobot.utils.SobotStringUtils;
import com.sobot.widget.livedatabus.SobotLiveEventBus;
import com.sobot.widget.ui.toast.SobotToastUtil;

import java.util.ArrayList;
import java.util.List;

/**
 * 呼叫任务详情
 */
public class CallTaskDetailsActivity extends SobotCallBaseActivity implements View.OnClickListener, CallTaskDetailsCountListener {

    private Handler handler;
    private String taskId;//任务id
    private String taskName;//任务名称
    private int status;//任务状态

    private LinearLayout ll_logined;
    private LinearLayout ll_waixian;//登录后如果有切换外显号权限,则显示,否则只显示标题
    private TextView tv_mobile;//登录后手机号码
    private TextView tv_task_title;//任务名称

    private SobotCallSlidingTab sobot_call_tab;
    private ViewPager vp_call_viewpager;
    private SobotViewPagerAdapter adapter;
    private int defaultIndex = 1;//默认打开fragment的位置
    private CallTaskDetailsAllFragment allFragment;
    private CallTaskDetailsUnexecutedFragment unexecutedFragment;
    private CallTaskDetailsExecutedFragment executedFragment;

    //上次拨打
    private SobotShadowLayout ssl_last_call;
    private TextView tv_customer_nick;
    private TextView tv_customer_no;
    private ImageView iv_cancel;
    private TextView tv_btn_recall;
    private TextView tv_btn_details;

    private CallTaskDetailsModel lastDetailsModel;


    @Override
    protected int getContentViewResId() {
        return R.layout.activity_call_record_desc;
    }

    @Override
    protected void initView() {
        if (getIntent() != null) {
            Intent intent = getIntent();
            taskId = intent.getStringExtra("taskId");
            taskName = intent.getStringExtra("taskName");
            status = intent.getIntExtra("status", 1);
        }

        if (getLeftMenu() != null) {
            getLeftMenu().setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    finish();
                }
            });
        }
        ll_logined = findViewById(R.id.ll_logined);
        ll_waixian = findViewById(R.id.ll_waixian);
        tv_mobile = findViewById(R.id.tv_mobile);
        tv_task_title = findViewById(R.id.tv_task_title);
        ll_waixian.setOnClickListener(this);
        if (!TextUtils.isEmpty(taskName)) {
            tv_task_title.setText(taskName);
        }
        serviceVo = SobotLoginTools.getInstance().getServiceInfo();
        if (serviceVo != null) {
            //请求外显规则
            getOutboudRoutesRules(false, ll_waixian, tv_mobile);
        }

        ssl_last_call = findViewById(R.id.ssl_last_call);
        tv_customer_nick = findViewById(R.id.tv_customer_nick);
        tv_customer_no = findViewById(R.id.tv_customer_no);
        iv_cancel = findViewById(R.id.iv_cacle);
        tv_btn_recall = findViewById(R.id.tv_btn_recall);
        tv_btn_details = findViewById(R.id.tv_btn_details);
        tv_btn_recall.setOnClickListener(this);
        tv_btn_details.setOnClickListener(this);
        iv_cancel.setOnClickListener(this);

        sobot_call_tab = findViewById(R.id.call_fragment_tab);
        vp_call_viewpager = findViewById(R.id.vp_call_viewpager);
        initTab();
        //判断是否登录
        String call_loingStatus = CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).get(SobotCallConstant.callLoginStatus, CallStatusUtils.V6_OFFLINE);

        if (call_loingStatus.equals(CallStatusUtils.V6_OFFLINE)) {
            //座席未登录
            ll_waixian.setVisibility(View.GONE);
        } else {
            ll_waixian.setVisibility(View.VISIBLE);
        }
        showLastCall();
    }

    //判断上次拨打区域是否显示
    private void showLastCall() {
        if (lastDetailsModel != null) {
            ssl_last_call.setVisibility(View.VISIBLE);
            tv_customer_nick.setText(SobotStringUtils.checkStringIsNull(lastDetailsModel.getContactName()));
            tv_customer_no.setText(SobotStringUtils.checkStringIsNull(lastDetailsModel.getScreenNumber()));
        } else {
            ssl_last_call.setVisibility(View.GONE);
            tv_customer_nick.setText("");
            tv_customer_no.setText("");
        }
    }

    private Observer<CallTaskDetailsModel> refreshLastObserver;
    private Observer<Long> callObserver;
    @Override
    protected void initData() {
        handler = new Handler();
        Runnable runnable = new Runnable() {
            @Override
            public void run() {
                ssl_last_call.setVisibility(View.GONE);
                tv_customer_nick.setText("");
                tv_customer_no.setText("");
            }
        };
        refreshLastObserver = new Observer<CallTaskDetailsModel>() {
            @Override
            public void onChanged(@Nullable CallTaskDetailsModel callTaskDetailsModel) {
                lastDetailsModel = callTaskDetailsModel;
            }
        };
        callObserver = new Observer<Long>() {
            @Override
            public void onChanged(@Nullable Long time) {
                showLastCall();
                if (handler != null && runnable != null) {
                    handler.removeCallbacks(runnable);
                    handler.postDelayed(runnable, 5000);
                }
            }
        };
        SobotLiveEventBus.get(SobotCallLiveDataBusV6Key.SOBOT_ACTION_REFRESH_LAST_CALL, CallTaskDetailsModel.class).observeForever(refreshLastObserver);
        SobotLiveEventBus.get(SobotCallLiveDataBusV6Key.SOBOT_ACTION_CALL_RELEASED, Long.class).observeForever(callObserver);
    }


    @Override
    public void onDestroy() {
        super.onDestroy();
        if (handler != null) {
            handler.removeCallbacksAndMessages(null);
            handler = null;
        }
        SobotLiveEventBus.get(SobotCallLiveDataBusV6Key.SOBOT_ACTION_REFRESH_LAST_CALL, CallTaskDetailsModel.class).removeObserver(refreshLastObserver);
        SobotLiveEventBus.get(SobotCallLiveDataBusV6Key.SOBOT_ACTION_CALL_RELEASED, Long.class).removeObserver(callObserver);
    }

    String tab1 = "";
    String tab2 = "";
    String tab3 = "";

    String unexecutedCount = "";
    String executedCount = "";

    private void initTab() {
        tab1 = getResources().getString(R.string.call_all_string);
        tab2 = getResources().getString(R.string.call_str_unexecuted);
        tab3 = getResources().getString(R.string.call_str_executed);
        Bundle bundle = new Bundle();
        bundle.putString("taskId", taskId);
        bundle.putString("taskName", taskName);
        bundle.putInt("status", status);
        allFragment = new CallTaskDetailsAllFragment();
        allFragment.setArguments(bundle);
        unexecutedFragment = new CallTaskDetailsUnexecutedFragment();
        unexecutedFragment.setArguments(bundle);
        executedFragment = new CallTaskDetailsExecutedFragment();
        executedFragment.setArguments(bundle);
        List<SobotBaseFragment> fragments = new ArrayList<>();
        List<String> titleList = new ArrayList<>();
        titleList.add(tab1);
        fragments.add(allFragment);
        titleList.add(tab2);
        fragments.add(unexecutedFragment);
        titleList.add(tab3);
        fragments.add(executedFragment);
        String[] titleStr = new String[titleList.size()];
        for (int i = 0; i < titleList.size(); i++) {
            titleStr[i] = titleList.get(i);
        }
        adapter = new SobotViewPagerAdapter(this, getSupportFragmentManager(), titleStr, fragments);
        vp_call_viewpager.setAdapter(adapter);
        sobot_call_tab.setViewPager(vp_call_viewpager);
        vp_call_viewpager.setCurrentItem(defaultIndex, false);
        sobot_call_tab.scrollToChild(defaultIndex, 0);
        sobot_call_tab.setOnPageChangeListener(new ViewPager.OnPageChangeListener() {
            @Override
            public void onPageScrolled(int i, float v, int i1) {
            }

            @Override
            public void onPageSelected(int i) {
                defaultIndex = i;

            }

            @Override
            public void onPageScrollStateChanged(int i) {
                if (allFragment != null) {
                    allFragment.edClearFocus();
                } else if (unexecutedFragment != null) {
                    unexecutedFragment.edClearFocus();
                } else if (executedFragment != null) {
                    executedFragment.edClearFocus();
                }
            }
        });
    }


    @Override
    public void onClick(View v) {
        if (ll_waixian.equals(v)) {
            //弹窗,打开切换外显号
            getOutboudRoutesRules(true, ll_waixian, tv_mobile);
        } else if (v == iv_cancel) {
            ssl_last_call.setVisibility(View.GONE);
        } else if (v == tv_btn_details) {
            if (lastDetailsModel != null) {
                Intent intent = new Intent(CallTaskDetailsActivity.this, CallTaskContactDetailActivity.class);
                intent.putExtra("recordId", lastDetailsModel.getRecordId());//任务明细id
                intent.putExtra("campaignId", lastDetailsModel.getCampaignId());//公司id
                intent.putExtra("dialCount", lastDetailsModel.getDialCount());//外出次数 判断是否执行过
                intent.putExtra("status", status);//任务状态（未开始、进行中..）
                intent.putExtra("taskFromType", sobot_call_tab.getCurrentPosition() + 1);//1 全部 2 未执行 3 已执行
                Bundle bundle = new Bundle();
                ArrayList arrayList = new ArrayList();
                arrayList.add(lastDetailsModel);
                bundle.putSerializable("taskRecordList", arrayList);
                intent.putExtras(bundle);
                startActivity(intent);
            }
        } else if (v == tv_btn_recall) {
            if (lastDetailsModel != null) {
                call(lastDetailsModel);
            }
        }
    }

    private void call(CallTaskDetailsModel detailsEntity) {
        if (detailsEntity != null) {
            //调用拨打电话接口
            if (status == 2 && !TextUtils.isEmpty(detailsEntity.getScreenNumber())) {
                //判断是否登录
                String call_loingStatus = CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).get(SobotCallConstant.callLoginStatus, CallStatusUtils.V6_OFFLINE);
                if (call_loingStatus.equals(CallStatusUtils.V6_FINISHING)) {
                    //判断是否正在整理中
                    SobotToastUtil.showToast(getSobotBaseActivity(), getResources().getString(R.string.sobot_error_switch_status));
                } else if (call_loingStatus.equals(CallStatusUtils.V6_SYSYTEM_BUSY)) {
                    SobotToastUtil.showToast(getSobotBaseActivity(), getResources().getString(R.string.call_str_system_Lock_toast));
                } else if (call_loingStatus.equals(CallStatusUtils.V6_OFFLINE)) {
                    SobotToastUtil.showToast(getSobotBaseActivity(), getResources().getString(R.string.sobot_call_error_hint));
                } else if (SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT) != null && SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT).isShowing()) {
                    //通话没结束，不能切换坐席状态
                    SobotToastUtil.showCustomToast(getSobotBaseActivity(), getString(R.string.call_retcode_330035));
                    return;
                } else {
                    //调用呼叫接口打电话
                    Intent intent = CallStatusActivity.initIntent(getSobotBaseActivity(), detailsEntity.getEncryptCustomerNumber(), detailsEntity.getScreenNumber());
                    intent.putExtra("recordId", detailsEntity.getRecordId());//任务明细id
                    intent.putExtra("campaignId", detailsEntity.getCampaignId());//公司id
                    intent.putExtra("dialCount", detailsEntity.getDialCount());//外出次数 判断是否执行过
                    intent.putExtra("status", status);//任务状态（未开始、进行中..）
                    intent.putExtra("contactName", detailsEntity.getContactName());//联系人姓名
                    intent.putExtra("taskFromType", 2);//1 全部 2 未执行 3 已执行
                    intent.setFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP | Intent.FLAG_ACTIVITY_CLEAR_TOP |
                            Intent.FLAG_ACTIVITY_NEW_TASK);
                    lastDetailsModel = detailsEntity;
                    startActivity(intent);
                    SobotLiveEventBus.get(SobotCallLiveDataBusV6Key.SOBOT_ACTION_REFRESH_EXECUTED_TASK_TAG).post(true);
                    SobotLiveEventBus.get(SobotCallLiveDataBusV6Key.SOBOT_ACTION_REFRESH_ALL_TASK_TAG).post(true);

                }
            }
        }
    }


    @Override
    public void onUpdateTaskUnexecutedCount(int count) {
        if (count > 0) {
            unexecutedCount = count + "";
        } else {
            unexecutedCount = "";
        }
        List<String> titleList = new ArrayList<>();
        titleList.add(tab1);
        titleList.add(tab2 + " " + unexecutedCount);
        titleList.add(tab3 + " " + executedCount);
        String[] titleStr = new String[titleList.size()];
        for (int i = 0; i < titleList.size(); i++) {
            titleStr[i] = titleList.get(i);
        }
        adapter.updateTabs(titleStr);
        sobot_call_tab.updateTabText();
    }

    @Override
    public void onUpdateTaskExecutedCount(int count) {
        if (count > 0) {
            executedCount = count + "";
        } else {
            executedCount = "";
        }
        List<String> titleList = new ArrayList<>();
        titleList.add(tab1);
        titleList.add(tab2 + " " + unexecutedCount);
        titleList.add(tab3 + " " + executedCount);
        String[] titleStr = new String[titleList.size()];
        for (int i = 0; i < titleList.size(); i++) {
            titleStr[i] = titleList.get(i);
        }
        adapter.updateTabs(titleStr);
        sobot_call_tab.updateTabText();
    }
}