package com.sobot.callsdk.v6.activity;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.graphics.drawable.Drawable;
import android.os.Build;
import android.os.Bundle;
import android.os.Handler;
import android.text.TextUtils;
import android.view.View;
import android.widget.CheckBox;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

import androidx.lifecycle.Observer;

import com.sobot.callbase.CallPermissionManager;
import com.sobot.callbase.api.SobotCallBaseUrl;
import com.sobot.callbase.api.utils.CallBaseSharedPreferencesUtils;
import com.sobot.callbase.api.utils.SobotStompEventConstant;
import com.sobot.callbase.constant.SobotCallBaseConstant;
import com.sobot.callbase.constant.SobotCallLiveDataBusKey;
import com.sobot.callbase.janus.SobotJanusClient;
import com.sobot.callbase.model.CallSipModel;
import com.sobot.callbase.model.CallStompMsgModel;
import com.sobot.callbase.model.QueueAgentCheckin;
import com.sobot.callbase.model.SobotExtensionEntity;
import com.sobot.callbase.model.SobotLoginStatusEntity;
import com.sobot.callbase.stomp.SobotStompClient;
import com.sobot.callbase.utils.CallFastClickUtils;
import com.sobot.callbase.utils.CommonUtils;
import com.sobot.callsdk.R;
import com.sobot.callsdk.SobotCallOpenApi;
import com.sobot.callsdk.activity.SobotCallBaseActivity;
import com.sobot.callsdk.dialog.CallTipDialog;
import com.sobot.callsdk.dialog.InputPhoneDialog;
import com.sobot.callsdk.dialog.SelectGroupDialog;
import com.sobot.callsdk.dialog.SelectLoginStatusDialog;
import com.sobot.callsdk.dialog.SelectLoginTypeDialog;
import com.sobot.callsdk.dialog.SobotCallDialogUtils;
import com.sobot.callsdk.listener.SobotPhoneStatusListener;
import com.sobot.callsdk.listener.SobotRegistrationListener;
import com.sobot.callsdk.model.SobotAgentEntity;
import com.sobot.callsdk.model.SobotPhoneTypesEntity;
import com.sobot.callsdk.service.SobotJanusService;
import com.sobot.callsdk.sip.SobotSipUtils;
import com.sobot.callsdk.utils.CallSharedPreferencesUtils;
import com.sobot.callsdk.utils.CallStatusUtils;
import com.sobot.callsdk.utils.SobotCallConstant;
import com.sobot.callsdk.v6.dialog.SelectExtDialog;
import com.sobot.common.login.SobotLoginTools;
import com.sobot.common.login.callback.SobotResultBlock;
import com.sobot.common.login.callback.SobotResultCode;
import com.sobot.common.login.model.SobotServiceInfoModel;
import com.sobot.common.login.permission.SobotPermissionManager;
import com.sobot.gson.SobotGsonUtil;
import com.sobot.network.http.callback.SobotResultCallBack;
import com.sobot.utils.SobotLogUtils;
import com.sobot.utils.SobotStringUtils;
import com.sobot.widget.livedatabus.SobotLiveEventBus;
import com.sobot.widget.ui.permission.SobotPermissionTipDialog;
import com.sobot.widget.ui.toast.SobotToastUtil;

import java.util.ArrayList;
import java.util.List;

/**
 * 签入
 */
public class SignInActivity extends SobotCallBaseActivity implements View.OnClickListener {

    private TextView tv_state;
    private TextView tv_type;
    private TextView tv_mobile;
    private TextView tv_ext_num;
    private TextView tv_group;
    private TextView tv_can_group;
    private ImageView iv_mobile;
    private ImageView iv_group;
    private ImageView iv_can_group;
    private LinearLayout ll_aoto_unbind;
    private CheckBox cb_offline_unbind;
    private TextView btn_login_call;

    private SobotServiceInfoModel serviceVo;
    private SelectExtDialog extsDialog;//选分机号的对话框
    private SobotExtensionEntity mExtensionModel;//分机号
    private List<SobotExtensionEntity> mExtensionModelList;//分机号
    private SelectGroupDialog groupDialog;
    private List<QueueAgentCheckin> groupList;//全部技能组
    private List<QueueAgentCheckin> canGroupList;//可选技能组
    private SobotAgentEntity mAgentEntity;//查询出坐席
    private String curStatus;
    private String statusTypeName;

    private List<SobotPhoneTypesEntity> phoneTypesList;//登录方式
    private int curType;
    private InputPhoneDialog inputPhoneDialog;//编辑手机号

    private LinearLayout ll_phone;
    private TextView tv_mobile_must, tv_ext_must;
    private LinearLayout ll_queueCheckin;

    //状态
    private List<SobotLoginStatusEntity> data;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        receiveStompMsg();
    }

    @Override
    protected int getContentViewResId() {
        return R.layout.activity_sign_in;
    }

    @Override
    protected void initView() throws InterruptedException {
        setTitle(getResources().getString(R.string.call_login_call));
        tv_state = findViewById(R.id.tv_state);
        ll_aoto_unbind = findViewById(R.id.ll_aoto_unbind);
        ll_queueCheckin = findViewById(R.id.ll_queueCheckin);
        tv_type = findViewById(R.id.tv_type);
        tv_mobile = findViewById(R.id.tv_mobile);
        tv_ext_num = findViewById(R.id.tv_ext_num);
        tv_group = findViewById(R.id.tv_group);
        tv_can_group = findViewById(R.id.tv_can_group);
        iv_mobile = findViewById(R.id.iv_mobile);
        iv_group = findViewById(R.id.iv_group);
        iv_can_group = findViewById(R.id.iv_can_group);
        cb_offline_unbind = findViewById(R.id.cb_offline_unbind);
        btn_login_call = findViewById(R.id.btn_login_call);
        tv_ext_must = findViewById(R.id.tv_ext_must);
        tv_mobile_must = findViewById(R.id.tv_mobile_must);
        ll_phone = findViewById(R.id.ll_phone);
        tv_state.setOnClickListener(this);
        tv_type.setOnClickListener(this);
        //修改绑定手机号
        if (CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_DHT_XGBDDHHM)) {
            tv_mobile.setOnClickListener(this);
        } else {
            tv_mobile.setCompoundDrawables(null, null, null, null);
        }
        //修改分机账号
        if (CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_DHT_XGFJZH)) {
            tv_ext_num.setOnClickListener(this);
        } else {
            tv_ext_num.setCompoundDrawables(null, null, null, null);
        }
        if (CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_DHT_LXHZDJB)) {
            ll_aoto_unbind.setVisibility(View.VISIBLE);
            cb_offline_unbind.setClickable(true);
            cb_offline_unbind.setEnabled(true);
        } else {
            ll_aoto_unbind.setVisibility(View.GONE);
            cb_offline_unbind.setClickable(false);
            cb_offline_unbind.setEnabled(false);
        }

        tv_can_group.setOnClickListener(this);
        iv_mobile.setOnClickListener(this);
        iv_group.setOnClickListener(this);
        iv_can_group.setOnClickListener(this);
        btn_login_call.setOnClickListener(this);
        data = CallSharedPreferencesUtils.getInstance(this).get(SobotCallConstant.callStatusList_v6, ArrayList.class);
        if (data == null) {
            data = new ArrayList<>();
        }
    }

    @Override
    protected void initData() {
        if (!SobotStompClient.getInstance(getSobotBaseActivity()).isConnected()) {
            String accesstoken = SobotLoginTools.getInstance().getAccessToken();
            String languageStr = CallBaseSharedPreferencesUtils.getInstance(this).get("SobotLanguageStr", "zh");
            SobotStompClient.getInstance(getSobotBaseActivity()).over(SobotStompClient.ConnectionProviderType.OKHTTP, SobotCallBaseUrl.getStompSocketUri() + "?authorization=Bearer " + accesstoken + "&language=" + languageStr, null, null);
            SobotStompClient.getInstance(getSobotBaseActivity()).connectStomp(0);
            SobotLogUtils.i("stomp 再次链接");
        }
        serviceVo = SobotLoginTools.getInstance().getServiceInfo();
        if (serviceVo == null) {
            finish();
        }
        phoneTypesList = new ArrayList<>();
        groupList = new ArrayList<>();
        canGroupList = new ArrayList<>();
        mExtensionModelList = new ArrayList<>();
        //获取分机号
        getExtensionList();
        //获取登录方式
        phoneTypes();
        //获取可签入技能组
        SobotCallOpenApi.queryAvailableQueues(getSobotBaseActivity(), new SobotResultBlock() {
            @Override
            public void resultBolok(SobotResultCode code, String msg, Object obj) {
                if (code == SobotResultCode.CODE_SUCCEEDED) {
                    groupList = (List<QueueAgentCheckin>) obj;
                    StringBuilder sb = new StringBuilder();
                    for (int i = 0; i < groupList.size(); i++) {
                        if (groupList.get(i).getCheckin() == 0) {
                            //默认签入技能组
                            sb.append(groupList.get(i).getQueueName());
                            if (i != groupList.size() - 1) {
                                sb.append(",");
                            }
                        } else if (groupList.get(i).getCheckin() == 1) {
                            //可选技能组
                            canGroupList.add(groupList.get(i));
                        }
                    }
                    String group = sb.toString();
                    if (group.endsWith(",")) {
                        group = group.substring(0, group.length() - 1);
                    }
                    tv_group.setText(TextUtils.isEmpty(group) ? "--" : group);
                }
            }
        });

        curStatus = CallStatusUtils.V6_FREE;
        for (int i = 0; i < data.size(); i++) {
            if (data.get(i).getCode().equals(curStatus)) {
                statusTypeName = data.get(i).getName();
            }
        }
        tv_state.setText(statusTypeName);
        Drawable dra = getResources().getDrawable(R.drawable.custom_service_online);
        dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
        Drawable draright = getResources().getDrawable(R.drawable.call_item_arrow);
        draright.setBounds(0, 0, draright.getIntrinsicWidth(), draright.getIntrinsicHeight());
        tv_state.setCompoundDrawables(dra, null, draright, null);
        queueCheckin();
    }

    @Override
    public void onClick(View v) {
        if (v == tv_state) {
            //状态
            SelectLoginStatusDialog statusDialog = new SelectLoginStatusDialog(SignInActivity.this, new SelectLoginStatusDialog.StatusListener() {
                @Override
                public void setStatus(String status) {
                    curStatus = status;
                    for (int i = 0; i < data.size(); i++) {
                        if (data.get(i).getCode().equals(status)) {
                            statusTypeName = data.get(i).getName();
                        }
                    }
                    Drawable draright = getResources().getDrawable(R.drawable.call_item_arrow);
                    draright.setBounds(0, 0, draright.getIntrinsicWidth(), draright.getIntrinsicHeight());
                    if (curStatus.equals(CallStatusUtils.V6_FREE)) {
                        Drawable dra = getResources().getDrawable(R.drawable.custom_service_online);
                        dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                        tv_state.setCompoundDrawables(dra, null, draright, null);
                    } else {
                        Drawable dra = getResources().getDrawable(R.drawable.custom_service_busy);
                        dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                        tv_state.setCompoundDrawables(dra, null, draright, null);
                    }
                    tv_state.setText(statusTypeName);
                }
            }, curStatus, data);
            statusDialog.show();
        } else if (v == tv_mobile) {
            //编辑手机号
            if (inputPhoneDialog == null) {
                inputPhoneDialog = new InputPhoneDialog(SignInActivity.this, new InputPhoneDialog.PhoneListener() {
                    @Override
                    public void setPhone(String phone) {
                        tv_mobile.setText(phone);
                    }
                }, tv_mobile.getText().toString());
            }
            inputPhoneDialog.setPhone(tv_mobile.getText().toString());
            inputPhoneDialog.show();
        } else if (v == tv_type) {
            if (phoneTypesList == null || phoneTypesList.size() == 0) {
                SobotToastUtil.showToast(getApplication(), "无可选的登录方式");
                return;
            }
            //类型
            if (phoneTypesList == null || phoneTypesList.size() == 0) {
                SobotToastUtil.showToast(getApplication(), "无可选的登录方式");
                return;
            }
            //类型
            SelectLoginTypeDialog typeDialog = new SelectLoginTypeDialog(SignInActivity.this, new SelectLoginTypeDialog.TypeListener() {
                @Override
                public void setType(int type) {
                    curType = type;
                    tv_type.setText(curType == SobotCallConstant.CALL_MODEL_PHONE ? getResources().getString(R.string.sobot_phone) : getString(R.string.call_source_app));
                    if (SobotCallConstant.CALL_MODEL_PHONE == curType) {
                        //显示手机，而且手机必填
                        tv_ext_must.setVisibility(View.GONE);
                        ll_phone.setVisibility(View.VISIBLE);
                    } else {
                        //分机号必填
                        tv_ext_must.setVisibility(View.VISIBLE);
                        ll_phone.setVisibility(View.GONE);
                    }
                }
            }, curType, phoneTypesList);
            typeDialog.show();
        } else if (v == tv_ext_num) {
            //分机号
            extsDialog = new SelectExtDialog(SignInActivity.this, new SelectExtDialog.ExtsListener() {
                @Override
                public void selectExts(SobotExtensionEntity extNum) {
                    extsDialog.dismiss();
                    if (null != extNum) {
                        mExtensionModel = extNum;
                        tv_ext_num.setText(extNum.getExt());
                        CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).put(SobotCallBaseConstant.SipModel.SIP_NUMBER, extNum.getExt());
                        CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).put(SobotCallBaseConstant.SipModel.SIP_LANGCODE, extNum.getLangCodeTxt());
                        CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).put(SobotCallBaseConstant.SipModel.SIP_PWD, extNum.getPassword());//sip账号密码先写死
                        CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).put(SobotCallBaseConstant.SipModel.SIP_IP, extNum.getDomain());
                        CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).put(SobotCallBaseConstant.SipModel.SIP_SCHEME, SobotCallConstant.ServerScheme.FS);
                    } else {
                        mExtensionModel = null;
                    }
                }
            }, mExtensionModel);
            extsDialog.show();
        } else if (v == tv_can_group) {
            //可选签入组
            if (groupDialog == null) {
                groupDialog = new SelectGroupDialog(SignInActivity.this, new SelectGroupDialog.GruopListener() {
                    @Override
                    public void selectGroup(List<QueueAgentCheckin> groups) {
                        canGroupList = groups;
                        StringBuilder sb = new StringBuilder();
                        for (int i = 0; i < groups.size(); i++) {
                            if (groups.get(i).isSelected()) {
                                sb.append(groups.get(i).getQueueName());
                                if (i != groups.size() - 1) {
                                    sb.append(",");
                                }
                            }
                        }
                        String group = sb.toString();
                        if (group.endsWith(",")) {
                            group = group.substring(0, group.length() - 1);
                        }
                        tv_can_group.setText(group);
                    }
                }, canGroupList);
            } else {
                groupDialog.setData(canGroupList);
            }
            groupDialog.show();
        } else if (v == btn_login_call) {
            //判断是否有网络
            if (CommonUtils.isNetWorkConnected(SignInActivity.this)) {
                if (CallFastClickUtils.isCanClick(1000)) {
                    clickLogin();
                } else {
                    SobotToastUtil.showToast(SignInActivity.this, getResources().getString(R.string.call_retcode_330067));
                }
            } else {
                SobotToastUtil.showToast(SignInActivity.this, getResources().getString(R.string.sobot_call_net_error_string2));
            }
        } else if (v == iv_can_group) {
            //
            CallTipDialog tipDialog = new CallTipDialog(getString(R.string.call_sign_can_group_tip_top), getString(R.string.call_sign_can_group_tip));
            tipDialog.setCancelable(true);
            tipDialog.show(getSupportFragmentManager(), "tipDialog");
        } else if (v == iv_group) {
            //
            CallTipDialog tipDialog = new CallTipDialog(getString(R.string.call_sign_group_tip_top), getString(R.string.call_sign_group_tip));
            tipDialog.setCancelable(true);
            tipDialog.show(getSupportFragmentManager(), "tipDialog");
        } else if (v == iv_mobile) {
            //
            CallTipDialog tipDialog = new CallTipDialog(getString(R.string.call_sign_phone_tip_top), getString(R.string.call_sign_phone_tip));
            tipDialog.setCancelable(true);
            tipDialog.show(getSupportFragmentManager(), "tipDialog");
        }
    }

    //点击登录按钮
    private void clickLogin() {
        //是否有麦克风权限
        if (curType != SobotCallConstant.CALL_MODEL_PHONE && curType != SobotCallConstant.CALL_MODEL_SIP) {
            SobotToastUtil.showToast(getApplication(), getBaseContext().getResources().getString(R.string.sobot_please_choose_answer_mode));
            return;
        }
        if (SobotCallConstant.CALL_MODEL_PHONE == curType) {
            if (SobotStringUtils.isEmpty(tv_mobile.getText().toString().trim())) {
                //手机号不能为空
                SobotToastUtil.showToast(getApplication(), getBaseContext().getResources().getString(R.string.sobot_please_input_phone_number));
                return;
            }
        } else if (curType == SobotCallConstant.CALL_MODEL_SIP) {
            if (checkIsShowPermissionPop(getResources().getString(R.string.sobot_microphone), getResources().getString(R.string.sobot_microphone_yongtu))) {
                return;
            }
            if (!checkAudioPermission()) {
                return;
            }
            //分机号必填
            if (SobotStringUtils.isEmpty(tv_ext_num.getText().toString().trim())) {
                //分机号不能为空
                SobotToastUtil.showToast(getApplication(), getBaseContext().getResources().getString(R.string.sobot_please_choose_extension_account));
                return;
            }
        }
        StringBuilder sb = new StringBuilder();
        List<String> queuesList = new ArrayList<>();
        for (int i = 0; i < groupList.size(); i++) {
            if (groupList.get(i).getCheckin() == 0) {
                queuesList.add(groupList.get(i).getQueueID());
                sb.append(groupList.get(i).getQueueName());
            }
        }
        for (int i = 0; i < canGroupList.size(); i++) {
            if (canGroupList.get(i).isSelected()) {
                queuesList.add(canGroupList.get(i).getQueueID());
                if (sb.length() > 0) {
                    sb.append(",");
                }
                sb.append(canGroupList.get(i).getQueueName());
            }
        }
        String group = sb.toString();
        if (group.endsWith(",")) {
            group = group.substring(0, group.length() - 1);
        }
        SobotSipUtils.startService(true, SignInActivity.this);
        //v6 需要连接stomp
        if (!SobotStompClient.getInstance(getSobotBaseActivity()).isConnected()) {
            String accesstoken = SobotLoginTools.getInstance().getAccessToken();
            String languageStr = CallBaseSharedPreferencesUtils.getInstance(this).get("SobotLanguageStr", "zh");
            SobotStompClient.getInstance(getSobotBaseActivity()).over(SobotStompClient.ConnectionProviderType.OKHTTP, SobotCallBaseUrl.getStompSocketUri() + "?authorization=Bearer " + accesstoken + "&language=" + languageStr, null, null);
            SobotStompClient.getInstance(getSobotBaseActivity()).connectStomp(0);
            SobotLogUtils.i("SobotStompClient 再次链接");
        }
        String thisQueuesStr = (queuesList.size() > 0) ? SobotGsonUtil.beanToJson(queuesList) : "";
        String status = CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).get(SobotCallConstant.callLoginStatus, CallStatusUtils.V6_OFFLINE);
        //签入保存信息
        CallSharedPreferencesUtils.getInstance(SignInActivity.this).put(SobotCallConstant.AgentLoginInput.phoneType, curType);
        CallSharedPreferencesUtils.getInstance(SignInActivity.this).put(SobotCallConstant.AgentLoginInput.bindExt, tv_ext_num.getText().toString());
        CallSharedPreferencesUtils.getInstance(SignInActivity.this).put(SobotCallConstant.AgentLoginInput.bindMobile, tv_mobile.getText().toString().trim());
        CallSharedPreferencesUtils.getInstance(SignInActivity.this).put(SobotCallConstant.AgentLoginInput.thisQueues, thisQueuesStr);
        CallSharedPreferencesUtils.getInstance(SignInActivity.this).put(SobotCallConstant.AgentLoginInput.groupName, group);
        CallSharedPreferencesUtils.getInstance(SignInActivity.this).put(SobotCallConstant.SP_KEY_CALL_MODEL_TYPE_V6, curType);
        new Handler().postDelayed(new Runnable() {
            @Override
            public void run() {
                if (curType == SobotCallConstant.CALL_MODEL_SIP) {
                    //登陆注册sip并修改状态
                    String agentNumber = CallSharedPreferencesUtils.getInstance(SignInActivity.this).get(SobotCallBaseConstant.SipModel.SIP_NUMBER);
                    String agentPwd = CallSharedPreferencesUtils.getInstance(SignInActivity.this).get(SobotCallBaseConstant.SipModel.SIP_PWD);
                    String serverIP = CallSharedPreferencesUtils.getInstance(SignInActivity.this).get(SobotCallBaseConstant.SipModel.SIP_IP);
                    CallSipModel sipModel = new CallSipModel();
                    sipModel.setAgentNumber(agentNumber);
                    sipModel.setAgentPwd(agentPwd);
                    sipModel.setServerIP(serverIP);
                    if (!TextUtils.isEmpty(status) && !CallStatusUtils.V6_OFFLINE.equals(status) && SobotSipUtils.isServiceRun(true)) {
                        //如果当前坐席状态不是离线， 直接关闭
                        finish();
                        return;
                    }
                    registerSipLongin(sipModel, curStatus + "", statusTypeName);
                } else if (SobotCallConstant.CALL_MODEL_PHONE == curType) {
                    if (!TextUtils.isEmpty(status) && !CallStatusUtils.V6_OFFLINE.equals(status)) {
                        //如果当前坐席状态不是离线，直接关闭
                        finish();
                        return;
                    }
                    loginPhone(curStatus + "", tv_mobile.getText().toString(), tv_ext_num.getText().toString());
                } else {
                    SobotToastUtil.showToast(SignInActivity.this, getResources().getString(R.string.sobot_call_network_no_call_tip));
                }
            }
        }, 300);

    }


    @Override
    protected void onDestroy() {
        if (groupDialog != null && groupDialog.isShowing()) {
            groupDialog.dismiss();
        }
        if (inputPhoneDialog != null && inputPhoneDialog.isShowing()) {
            inputPhoneDialog.dismiss();
        }
        if (extsDialog != null && extsDialog.isShowing()) {
            extsDialog.dismiss();
        }
        super.onDestroy();
    }

    /**
     * 查询技能组开关权限
     */
    private void queueCheckin() {
        zhiChiApi.queueCheckin(this, new SobotResultCallBack<Integer>() {
            @Override
            public void onSuccess(Integer agentSelectQueueCheckin) {
                if (agentSelectQueueCheckin == 1) {
                    ll_queueCheckin.setVisibility(View.VISIBLE);
                } else {
                    ll_queueCheckin.setVisibility(View.GONE);
                }
            }

            @Override
            public void onFailure(Exception e, String des) {

            }
        });
    }


    //v6 获取接听方式列表
    private void phoneTypes() {
        zhiChiApi.phoneTypes(getSobotBaseActivity(), serviceVo.getServiceId(), "1", new SobotResultCallBack<SobotAgentEntity>() {
            @Override
            public void onSuccess(SobotAgentEntity sobotAgentEntity) {
                if (sobotAgentEntity != null) {
                    mAgentEntity = sobotAgentEntity;
                    if (!SobotStringUtils.isEmpty(mAgentEntity.getPhone())) {
                        tv_mobile.setText(mAgentEntity.getPhone());
                    }
                    tv_ext_num.setText(mAgentEntity.getExt());
                    CallSharedPreferencesUtils.getInstance(SignInActivity.this).put(SobotCallBaseConstant.SipModel.SIP_NUMBER, mAgentEntity.getExt());

//                    tv_type.setText(mAgentEntity.getCurrentPhoneType());
                    if (sobotAgentEntity.getPhoneTypes() != null) {
                        for (int i = 0; i < sobotAgentEntity.getPhoneTypes().size(); i++) {
                            if ("sip".equals(sobotAgentEntity.getPhoneTypes().get(i).getPhoneType()) || "webrtc".equals(sobotAgentEntity.getPhoneTypes().get(i).getPhoneType())) {
                                phoneTypesList.add(sobotAgentEntity.getPhoneTypes().get(i));
                                //app
                                if (sobotAgentEntity.getPhoneTypes().get(i).isDefaultPhoneType()) {
                                    //默认sip接听方式,app
                                    tv_type.setText(R.string.call_source_app);
                                    curType = SobotCallConstant.CALL_MODEL_SIP;
                                }
                            } else if ("pstn".equals(sobotAgentEntity.getPhoneTypes().get(i).getPhoneType())) {
                                phoneTypesList.add(sobotAgentEntity.getPhoneTypes().get(i));
                                //手机
                                if (sobotAgentEntity.getPhoneTypes().get(i).isDefaultPhoneType()) {
                                    //默认手机接听方式
                                    tv_type.setText(R.string.sobot_phone);
                                    curType = SobotCallConstant.CALL_MODEL_PHONE;
                                }
                            }
                        }
                    }
                    if (SobotCallConstant.CALL_MODEL_PHONE == curType) {
                        //显示手机，而且手机必填
                        tv_ext_must.setVisibility(View.GONE);
                        ll_phone.setVisibility(View.VISIBLE);
                    } else {
                        //分机号必填
                        tv_ext_must.setVisibility(View.VISIBLE);
                        ll_phone.setVisibility(View.GONE);
                    }
                }
            }

            @Override
            public void onFailure(Exception e, String des) {

            }
        });
    }

    //v6 获取分机账号列表
    private void getExtensionList() {
        if (serviceVo == null) {
            return;
        }
        zhiChiApi.getExtensionList(this, serviceVo.getServiceId(), "1", new SobotResultCallBack<List<SobotExtensionEntity>>() {
            @Override
            public void onSuccess(List<SobotExtensionEntity> extensionModelList) {
                if (extensionModelList != null) {
                    mExtensionModelList = extensionModelList;
                    for (int i = 0; i < mExtensionModelList.size(); i++) {
                        SobotExtensionEntity extensionEntity = mExtensionModelList.get(i);

                        if (extensionEntity.getBindStatus() == 1) {
                            extensionEntity.setSelect(true);
                            tv_ext_num.setText(extensionEntity.getExt());
                            CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).put(SobotCallBaseConstant.SipModel.SIP_NUMBER, extensionEntity.getExt());
                            CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).put(SobotCallBaseConstant.SipModel.SIP_LANGCODE, extensionEntity.getLangCodeTxt());
                            CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).put(SobotCallBaseConstant.SipModel.SIP_PWD, extensionEntity.getPassword());//sip账号密码先写死
                            CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).put(SobotCallBaseConstant.SipModel.SIP_IP, extensionEntity.getDomain());
                            CallSharedPreferencesUtils.getInstance(getSobotBaseActivity()).put(SobotCallBaseConstant.SipModel.SIP_SCHEME, SobotCallConstant.ServerScheme.FS);
                        }
                    }

                }
            }

            @Override
            public void onFailure(Exception e, String des) {

            }
        });
    }

    /**
     * 注册登录sip
     *
     * @param sipModel
     * @param lineStatus
     */
    public void registerSipLongin(CallSipModel sipModel, String lineStatus, String
            lineStatusName) {
        SobotLogUtils.i("registerSipLongin");
        if (sipModel == null || TextUtils.isEmpty(sipModel.getAgentNumber())) {
            return;
        }
        try {
            new Handler().postDelayed(new Runnable() {
                @Override
                public void run() {
                    if (!SobotJanusClient.getInstance().isConnected()) {
                        SobotLogUtils.i("SobotJanusClient 再次链接");
                        SobotJanusClient.getInstance().connect(getApplicationContext(), SobotCallBaseUrl.getJanusSocketUri());
                    }
                }
            }, 500);
            new Handler().
                    postDelayed(new Runnable() {
                        @Override
                        public void run() {
                            SobotRegistrationListener registerListener = SobotRegistrationListener.getInstance();
                            registerListener.setContext(getApplicationContext());
                            registerListener.setLineStatus(lineStatus);
                            registerListener.setLineStatusName(lineStatusName);
                            registerListener.setSipModel(sipModel);
                            registerListener.setUnbindExtOnLogout(cb_offline_unbind.isChecked());
                            SobotServiceInfoModel serviceVo = SobotLoginTools.getInstance().getServiceInfo();
                            SobotPhoneStatusListener phoneStatusListener = SobotPhoneStatusListener.getInstance();
                            phoneStatusListener.setContext(SignInActivity.this);
                            if (serviceVo != null) {
                                if (!SobotJanusClient.getInstance().isConnected()) {
                                    SobotLogUtils.i("SobotJanusClient 没有连上 需要再次链接");
                                    SobotJanusClient.getInstance().connect(getApplicationContext(), SobotCallBaseUrl.getJanusSocketUri());
                                    SobotCallDialogUtils.stopProgressDialog(SignInActivity.this);
                                    return;
                                }
                                SobotSipUtils.addPhoneCallStatesback(serviceVo.getCallV6Flag() == 1 ? true : false, registerListener, phoneStatusListener);
                                SobotSipUtils.setAccount(serviceVo.getCallV6Flag() == 1 ? true : false, sipModel.getAgentNumber(), sipModel.getAgentPwd(), sipModel.getServerIP());
                                SobotSipUtils.login(serviceVo.getCallV6Flag() == 1 ? true : false, SignInActivity.this);
                            }
                        }
                    }, 1500);
        } catch (Exception e) {
            e.printStackTrace();
        }
        showProgress();
    }

    /**
     * 手机登录
     *
     * @param lineStatus
     */
    private void loginPhone(String lineStatus, String phone, String extsNumber) {
        SobotServiceInfoModel serviceVo = SobotLoginTools.getInstance().getServiceInfo();
        if (serviceVo != null) {
            try {
                Intent baresipServiceIntent = new Intent(Intent.ACTION_MAIN);
                baresipServiceIntent.setClass(getSobotBaseActivity(), SobotJanusService.class);
                baresipServiceIntent.putExtra("callType", 1);//手机号方式
                if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
                    startForegroundService(baresipServiceIntent);
                } else {
                    startService(baresipServiceIntent);
                }
                new Handler().postDelayed(new Runnable() {
                    @Override
                    public void run() {
                        String currentTime = System.currentTimeMillis() + "";
                        List<String> queuesList = new ArrayList<>();
                        for (int i = 0; i < groupList.size(); i++) {
                            if (groupList.get(i).getCheckin() == 0) {
                                queuesList.add(groupList.get(i).getQueueID());
                            }
                        }
                        for (int i = 0; i < canGroupList.size(); i++) {
                            if (canGroupList.get(i).isSelected()) {
                                queuesList.add(canGroupList.get(i).getQueueID());
                            }
                        }
                        String thisQueuesStr = (queuesList.size() > 0) ? SobotGsonUtil.beanToJson(queuesList) : "";
                        //分机号
                        SobotStompClient.getInstance(getSobotBaseActivity()).send("/cc/app/request", "{\n" +
                                "    \"messageID\": \"" + SobotStompEventConstant.RequestAgentLogin + "\",\n" +
                                "    \"referenceID\": " + currentTime + ",\n" +
                                "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                                "    \"agentType\": \"1\",\n" +
                                "    \"agentState\": \"" + lineStatus + "\",\n" +
                                "    \"phoneType\": \"pstn\",\n" +
                                //手机登录需要必须传正确的分机号
                                "    \"bindExt\": \"" + extsNumber + "\",\n" +
                                "    \"bindMobile\": \"" + phone + "\",\n" +
                                (SobotStringUtils.isEmpty(thisQueuesStr) ? "" : "    \"thisQueues\": " + thisQueuesStr + " ,\n") +
                                "    \"unbindExtOnLogout\": \"" + cb_offline_unbind.isChecked() + "\",\n\"edgeOut\": \"1\"," +
                                "    \"userData\": {\n" +
                                "        \"__fromChannel\": \"SobotMobilePhone\"" +
                                "    },\n" +
                                "    \"creationTime\": " + currentTime + "\n" +
                                "}\n").subscribe();
                    }
                }, 500);
            } catch (Exception e) {
                e.printStackTrace();
            }

        }
        showProgress();
    }


    private void showProgress() {
        SobotCallDialogUtils.startProgressDialog(SignInActivity.this);
    }

    private void receiveStompMsg() {
        //收到 stomp 消息
        SobotLiveEventBus.get(SobotCallLiveDataBusKey.RECEIVE_STOMP_MSG, CallStompMsgModel.class)
                .observe(this, new Observer<CallStompMsgModel>() {
                    @Override
                    public void onChanged(CallStompMsgModel stompMsgModel) {
                        if (stompMsgModel != null) {
                            SobotLogUtils.i("签入页面 SigninActivity 收到stomp 消息:" + SobotStringUtils.checkStringIsNull(stompMsgModel.getStompMessageID()));
                            String stompMessageID = SobotStringUtils.checkStringIsNull(stompMsgModel.getStompMessageID());
                            String stompMessageContent = SobotStringUtils.checkStringIsNull(stompMsgModel.getStompMessageContent());
                            SobotCallDialogUtils.stopProgressDialog(SignInActivity.this);
                            if (!TextUtils.isEmpty(stompMessageContent) && !TextUtils.isEmpty(stompMessageID)) {
                                if (SobotStompEventConstant.EventAgentLogin.equals(stompMessageID)) {
                                    finish();
                                } else if (SobotStompEventConstant.EventAgentReady.equals(stompMessageID)) {
                                    finish();
                                } else if (SobotStompEventConstant.EventAgentNotReady.equals(stompMessageID)) {
                                    finish();
                                } else if (stompMessageID.toLowerCase().contains("error")) {
                                    //返回异常事件,在callfragment中提示
                                }
                            }
                        }

                    }
                });
    }

    class LocalReceiver extends BroadcastReceiver {
        @Override
        public void onReceive(Context context, Intent intent) {

        }
    }

    public boolean checkIsShowPermissionPop(String title, String content) {
        if (!isHasAudioPermission()) {
            SobotPermissionTipDialog dialog = new SobotPermissionTipDialog(SignInActivity.this, title, content, new SobotPermissionTipDialog.ClickViewListener() {
                @Override
                public void clickRightView(Context context, SobotPermissionTipDialog dialog) {
                    dialog.dismiss();
                    if (!checkAudioPermission()) {
                        return;
                    }
                }

                @Override
                public void clickLeftView(Context context, SobotPermissionTipDialog dialog) {
                    dialog.dismiss();
                }
            });
            dialog.show();
            return true;
        }
        return false;
    }

}