package com.sobot.callsdk.v6.adapter;

import android.content.Context;
import android.graphics.Color;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.sobot.callbase.model.callinfo.CallPartyCDRInfo;
import com.sobot.callbase.utils.SobotDateUtils;
import com.sobot.callbase.utils.SobotStringUtils;
import com.sobot.callsdk.R;

import java.util.List;

/**
 * 座席通话明细 Adapter
 */
public class CallAgentCallDetailsAdapter extends RecyclerView.Adapter {
    private Context mContext;
    private List<CallPartyCDRInfo> mData;
    private String zone;

    public CallAgentCallDetailsAdapter(Context mContext, List<CallPartyCDRInfo> mData,String zone) {
        this.mContext = mContext;
        this.mData = mData;
        this.zone = zone;
    }

    @NonNull
    @Override
    public RecyclerView.ViewHolder onCreateViewHolder(@NonNull ViewGroup viewGroup, int i) {
        View v = LayoutInflater.from(mContext).inflate(R.layout.call_item_agent_call_details, viewGroup, false);
        RecyclerView.ViewHolder vh = new CallPartyCDRInfoVH(v);
        return vh;
    }

    @Override
    public void onBindViewHolder(@NonNull RecyclerView.ViewHolder vh, int i) {
        CallPartyCDRInfo partyCDRInfo = mData.get(i);
        CallPartyCDRInfoVH viewHolder = (CallPartyCDRInfoVH) vh;
        if (partyCDRInfo != null) {
            if (i == (getItemCount() - 1)) {
                viewHolder.v_line_end.setVisibility(View.GONE);
            } else {
                viewHolder.v_line_end.setVisibility(View.VISIBLE);
            }
            if (i == 0) {
                viewHolder.v_line.setBackgroundColor(Color.TRANSPARENT);
            } else {
                viewHolder.v_line.setBackgroundColor(mContext.getResources().getColor(R.color.call_line_second));
            }
            //  呼叫类型 1.呼叫 2.转移 3.咨询 4.监听 5.抢接 6.强插
            if (partyCDRInfo.getDialType() == 1) {
                viewHolder.tv_call_type.setText(mContext.getResources().getString(R.string.sobot_call_up));
            } else if (partyCDRInfo.getDialType() == 2) {
                viewHolder.tv_call_type.setText(mContext.getResources().getString(R.string.call_str_type_transfer));
            } else if (partyCDRInfo.getDialType() == 3) {
                viewHolder.tv_call_type.setText(mContext.getResources().getString(R.string.call_consult));
            } else if (partyCDRInfo.getDialType() == 4) {
                viewHolder.tv_call_type.setText(mContext.getResources().getString(R.string.call_str_type_monitoring));
            } else if (partyCDRInfo.getDialType() == 5) {
                viewHolder.tv_call_type.setText(mContext.getResources().getString(R.string.call_str_type_snatch_up));
            } else if (partyCDRInfo.getDialType() == 6) {
                viewHolder.tv_call_type.setText(mContext.getResources().getString(R.string.call_str_type_strong_insertion));
            } else {
                viewHolder.tv_call_type.setText("- -");
            }
            viewHolder.tv_time.setText(SobotDateUtils.formatYMDHM(partyCDRInfo.getStartTime(),zone));
            viewHolder.tv_agent_name.setText(SobotStringUtils.isEmpty(partyCDRInfo.getAgentName()) ? "- -" : partyCDRInfo.getAgentName());
            viewHolder.tv_call_duration.setText(SobotDateUtils.formatCallTimeDuration(partyCDRInfo.getDuration()));

            //  呼叫结果 1.呼叫失败 2.呼叫成功-座席未接听 3.呼叫成功-座席已接听
            if (partyCDRInfo.getCallResult() == 1) {
                viewHolder.tv_call_result.setText(mContext.getResources().getString(R.string.call_result_call_fail));
            } else if (partyCDRInfo.getCallResult() == 2) {
                viewHolder.tv_call_result.setText(mContext.getResources().getString(R.string.call_str_seat_not_answering));
            } else if (partyCDRInfo.getCallResult() == 3) {
                viewHolder.tv_call_result.setText(mContext.getResources().getString(R.string.call_str_seat_answered));
            } else {
                viewHolder.tv_call_result.setText("- -");
            }
        }
    }

    @Override
    public int getItemCount() {
        return mData.size();
    }

    class CallPartyCDRInfoVH extends RecyclerView.ViewHolder {
        public TextView tv_time;
        public TextView tv_call_type;
        public TextView tv_call_duration;
        public TextView tv_agent_name;
        public TextView tv_call_result;
        public View v_line;
        public View v_line_end;

        public CallPartyCDRInfoVH(@NonNull View itemView) {
            super(itemView);
            tv_call_type = itemView.findViewById(R.id.tv_call_type);
            tv_time = itemView.findViewById(R.id.tv_time);
            tv_call_duration = itemView.findViewById(R.id.tv_call_duration);
            tv_agent_name = itemView.findViewById(R.id.tv_agent_name);
            tv_call_result = itemView.findViewById(R.id.tv_call_result);
            v_line = itemView.findViewById(R.id.v_line);
            v_line_end = itemView.findViewById(R.id.v_line_end);
        }
    }
}
