package com.sobot.callsdk.v6.adapter;

import android.annotation.SuppressLint;
import android.content.Context;
import android.graphics.Color;
import android.text.Spannable;
import android.text.SpannableString;
import android.text.TextUtils;
import android.text.style.ForegroundColorSpan;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.sobot.callbase.model.CallTaskDetailsModel;
import com.sobot.callsdk.R;

import java.util.List;

/**
 * 任务详细列表-(全部、已执行、未执行)
 */
public class CallTaskExecutedTypeAdapter extends RecyclerView.Adapter {
    private Context mContext;
    private List<CallTaskDetailsModel> mData;
    private int mStatus; //1："未开始", 2："进行中",3:"暂停中", (4:"已过期"),(5："已完成"),(6:"已归档"),(7:"已删除") 只有进行中 才能打电话
    private CallTaskExecutedTypeAdapter.OnItemClickListener clickListener;

    private String select = "";

    public CallTaskExecutedTypeAdapter(Context mContext, List<CallTaskDetailsModel> mData, int status, CallTaskExecutedTypeAdapter.OnItemClickListener clickListener) {
        this.mContext = mContext;
        this.mData = mData;
        this.clickListener = clickListener;
        this.mStatus = status;
    }


    @NonNull
    @Override
    public RecyclerView.ViewHolder onCreateViewHolder(@NonNull ViewGroup viewGroup, int i) {
        View v = LayoutInflater.from(mContext).inflate(R.layout.item_call_task_executed_type, viewGroup, false);
        RecyclerView.ViewHolder vh = new CallTaskExecutedTypeAdapter.MyViewHolder(v);
        return vh;
    }

    @Override
    public void onBindViewHolder(@NonNull RecyclerView.ViewHolder vh, @SuppressLint("RecyclerView") int i) {
        CallTaskExecutedTypeAdapter.MyViewHolder viewHolder = (CallTaskExecutedTypeAdapter.MyViewHolder) vh;
        if (mData.get(i) instanceof CallTaskDetailsModel) {
            CallTaskDetailsModel data = (CallTaskDetailsModel) mData.get(i);
            if (data != null && !TextUtils.isEmpty(data.getScreenNumber())) {
                if (!com.sobot.callbase.utils.SobotStringUtils.isEmpty(data.getContactName())) {
                    String customerNick = data.getContactName();
                    viewHolder.tv_call_custom_name.setText(customerNick);
                    if (data.getDialCount() > 0 && data.getState() != 2) {
                        //通话数量大于0 state 不等于2  代表未接听
                        viewHolder.tv_call_custom_name.setTextColor(mContext.getResources().getColor(R.color.call_task_no_start_wenzi));
                    } else {
                        viewHolder.tv_call_custom_name.setTextColor(mContext.getResources().getColor(R.color.call_wenzi_gray1));
                    }
                } else {
                    viewHolder.tv_call_custom_name.setText("--");
                }
                String from = "";
                if (!TextUtils.isEmpty(data.getArea())) {
                    from = data.getArea();
                }
                String screenNumber = data.getScreenNumber() + "   " + from;
                SpannableString spannableString = new SpannableString(screenNumber);
                if (screenNumber.contains(select)) {
                    spannableString.setSpan(new ForegroundColorSpan(Color.parseColor("#09AEB0")), screenNumber.indexOf(select), screenNumber.indexOf(select) + select.length(), Spannable.SPAN_EXCLUSIVE_EXCLUSIVE);
                }
                viewHolder.tv_call_custom_phone.setText(spannableString);
                if (data.getDialCount() > 0) {
                    viewHolder.tv_call_out_name.setVisibility(View.VISIBLE);
                    viewHolder.tv_call_out_count.setVisibility(View.VISIBLE);
                    viewHolder.tv_call_out_count.setText(data.getDialCount() + "");
                } else {
                    viewHolder.tv_call_out_name.setVisibility(View.GONE);
                    viewHolder.tv_call_out_count.setVisibility(View.GONE);
                    viewHolder.tv_call_out_count.setText("");
                }
            }
            if (mStatus == 2) {
                viewHolder.ll_call.setVisibility(View.VISIBLE);
                viewHolder.iv_call_out.setVisibility(View.VISIBLE);
                viewHolder.iv_call_out.setOnClickListener(new View.OnClickListener() {
                    @Override
                    public void onClick(View v) {
                        //拨号
                        if (clickListener != null && i < mData.size()) {
                            clickListener.onItemClickCall(mData.get(i), i);
                        }
                    }
                });
            } else {
                viewHolder.ll_call.setVisibility(View.GONE);
                viewHolder.iv_call_out.setVisibility(View.GONE);
                viewHolder.iv_call_out.setOnClickListener(null);
            }
            viewHolder.itemView.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    //拨号
                    if (clickListener != null) {
                        clickListener.onItemClick(mData.get(i), i);
                    }
                }
            });
        }
    }

    public void setDate(String select) {
        this.select = select;
        notifyDataSetChanged();
    }

    @Override
    public int getItemCount() {
        return mData.size();
    }

    public interface OnItemClickListener {
        void onItemClick(CallTaskDetailsModel info, int postion);

        void onItemClickCall(CallTaskDetailsModel info, int postion);
    }

    class MyViewHolder extends RecyclerView.ViewHolder {
        ImageView iv_call_out;
        TextView tv_call_custom_phone;
        TextView tv_call_custom_name;
        TextView tv_call_out_name;
        TextView tv_call_out_count;
        LinearLayout ll_call;

        public MyViewHolder(@NonNull View itemView) {
            super(itemView);
            ll_call = itemView.findViewById(R.id.ll_call);
            iv_call_out = itemView.findViewById(R.id.iv_call_out);
            tv_call_custom_name = itemView.findViewById(R.id.tv_call_custom_name);
            tv_call_custom_phone = itemView.findViewById(R.id.tv_call_custom_phone);
            tv_call_out_name = itemView.findViewById(R.id.tv_call_out_name);
            tv_call_out_count = itemView.findViewById(R.id.tv_call_out_count);
        }
    }
}
