package com.sobot.callsdk.v6.adapter;

import android.annotation.SuppressLint;
import android.content.Context;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.sobot.callbase.api.utils.SobotCallUtils;
import com.sobot.callsdk.R;
import com.sobot.callsdk.model.SobotCallTaskEntity;

import java.util.List;

/**
 * @author: Sobot
 * 呼叫中心/通话任务
 * 2022/7/12
 */
public class CallTaskV6Adapter extends RecyclerView.Adapter {
    private List<SobotCallTaskEntity> mDate;
    private Context mContext;
    private OnItemClickListener mListener;

    public CallTaskV6Adapter(Context mContext, List<SobotCallTaskEntity> mDate, OnItemClickListener listener) {
        this.mContext = mContext;
        this.mDate = mDate;
        this.mListener = listener;
    }

    @NonNull
    @Override
    public RecyclerView.ViewHolder onCreateViewHolder(@NonNull ViewGroup viewGroup, int i) {
        View v = LayoutInflater.from(mContext).inflate(R.layout.item_call_v6_task, viewGroup, false);
        RecyclerView.ViewHolder vh = new SobotCallTaskVH(v);
        return vh;
    }

    @Override
    public void onBindViewHolder(@NonNull RecyclerView.ViewHolder viewHolder, @SuppressLint("RecyclerView") int i) {
        SobotCallTaskVH vh = (SobotCallTaskVH) viewHolder;

        //v6
        SobotCallTaskEntity data = (SobotCallTaskEntity) mDate.get(i);
        if (data != null) {
            vh.call_task_name.setText(data.getCampaignName());
            vh.call_task_status.setBackgroundResource(0);
            if (1 == data.getState()) {
                vh.call_task_status.setText(R.string.sobot_task_state_not_started);
                vh.call_task_status.setTextColor(mContext.getResources().getColor(R.color.call_task_no_start_wenzi));
                vh.call_task_status.setBackground(mContext.getResources().getDrawable(R.drawable.call_task_no_start_bg));
            } else if (2 == data.getState()) {
                vh.call_task_status.setText(R.string.sobot_task_state_executing);
                vh.call_task_status.setTextColor(mContext.getResources().getColor(R.color.call_task_doing_wenzi));
                vh.call_task_status.setBackground(mContext.getResources().getDrawable(R.drawable.call_task_doing_bg));
            } else if (3 == data.getState()) {
                vh.call_task_status.setText(R.string.sobot_task_state_suspended);
                vh.call_task_status.setTextColor(mContext.getResources().getColor(R.color.call_task_pause_wenzi));
                vh.call_task_status.setBackground(mContext.getResources().getDrawable(R.drawable.call_task_pause_bg));
            } else {
                if (4 == data.getState()) {
                    vh.call_task_status.setText(R.string.sobot_task_state_closed);
                } else if (5 == data.getState()) {
                    vh.call_task_status.setText(R.string.sobot_task_state_completed);
                } else if (6 == data.getState()) {
                    vh.call_task_status.setText(R.string.sobot_task_state_archived);
                } else {
                    vh.call_task_status.setText(R.string.sobot_task_state_deleted);
                }
                vh.call_task_status.setTextColor(mContext.getResources().getColor(R.color.call_task_close_wenzi));
                vh.call_task_status.setBackground(mContext.getResources().getDrawable(R.drawable.call_task_close_bg));
            }
            if (data.getTimed() == 0) {
                vh.call_task_time.setText(R.string.call_task_no_limit);
            } else if (data.getScheduleStartTime() > 0 && data.getScheduleEndTime() > 0) {
                vh.call_task_time.setText(SobotCallUtils.formatCallTaskTime(mContext,data.getScheduleStartTime()) +
                        " ~ " + SobotCallUtils.formatCallTaskTime(mContext,data.getScheduleEndTime()));
            } else {
                vh.call_task_time.setText("--");
            }
            //号码数
            vh.call_tast_num.setText("" + data.getContactRecordCount());
            //执行号码数
            vh.call_tast_exexuted_num.setText("" + data.getContactRecordExecuteCount());
            if (!TextUtils.isEmpty(data.getContactExecuteRate())) {
                vh.call_tast_exexuted.setText(data.getContactExecuteRate());
            }
        }
        vh.itemView.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (mListener != null) {
                    mListener.onItemClick(mDate.get(i));
                }
            }
        });
    }

    class SobotCallTaskVH extends RecyclerView.ViewHolder {
        public TextView call_task_name;
        public TextView call_task_time;
        public TextView call_task_status;
        public TextView call_tast_num;
        public TextView call_tast_exexuted_num;
        public TextView call_tast_exexuted;


        public SobotCallTaskVH(@NonNull View itemView) {
            super(itemView);
            call_task_name = itemView.findViewById(R.id.call_task_name);
            call_task_time = itemView.findViewById(R.id.call_task_time);
            call_task_status = itemView.findViewById(R.id.call_task_status);
            call_tast_num = itemView.findViewById(R.id.call_tast_num);
            call_tast_exexuted_num = itemView.findViewById(R.id.call_tast_exexuted_num);
            call_tast_exexuted = itemView.findViewById(R.id.call_tast_exexuted);
        }
    }

    @Override
    public int getItemCount() {
        return mDate.size();
    }

    public interface OnItemClickListener {
        void onItemClick(SobotCallTaskEntity taskEntity);
    }

}
