package com.sobot.callsdk.v6.dialog;

import android.app.Activity;
import android.text.Editable;
import android.text.TextWatcher;
import android.view.MotionEvent;
import android.view.View;
import android.widget.EditText;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.sobot.callbase.model.EnterPriseModel;
import com.sobot.callsdk.R;
import com.sobot.callsdk.api.SobotCallServiceFactory;
import com.sobot.callsdk.dialog.SobotBottomDialog;
import com.sobot.callsdk.utils.CustomFieldsUtils;
import com.sobot.callsdk.v6.adapter.CallCompanyAdapter;
import com.sobot.network.http.callback.SobotResultCallBack;

import java.util.ArrayList;
import java.util.List;

public class SelectCompanyDialog extends SobotBottomDialog implements View.OnClickListener {
    private LinearLayout coustom_pop_layout, sobot_negativeButton;
    private RecyclerView rv_list;
    private LinearLayout ll_search;
    private DialogItemOnClick listener;
    private CallCompanyAdapter adapter;
    private List<EnterPriseModel> data;
    private int pageNo = 1, pageSize = 50;
    private Activity activity;
    private EditText et_ext;
    private ImageView iv_ext_search;
    private ImageView iv_clear;
    private TextView sobot_tv_title, tv_nodata;
    private EnterPriseModel selectCompany;

    public SelectCompanyDialog(Activity context, EnterPriseModel selectCompany, DialogItemOnClick listener) {
        super(context);
        activity = context;
        this.listener = listener;
        this.data = new ArrayList<>();
        this.selectCompany = selectCompany;
    }

    @Override
    protected int getLayout() {
        return R.layout.call_common_dialog_select;
    }

    @Override
    protected View getDialogContainer() {
        if (coustom_pop_layout == null) {
            coustom_pop_layout = findViewById(R.id.sobot_container);
        }
        return coustom_pop_layout;
    }

    @Override
    protected void initData() {
        data = new ArrayList<>();
        adapter = new CallCompanyAdapter(activity, data, selectCompany, listener);
        rv_list.setAdapter(adapter);
        requestComany();
    }

    private void requestComany() {
        String searchText = et_ext.getText().toString();
        SobotCallServiceFactory.createZhiChiApi(activity).getEnterpriseList(activity, pageNo, pageSize, searchText, new SobotResultCallBack<List<EnterPriseModel>>() {
            @Override
            public void onSuccess(List<EnterPriseModel> enterPriseModels) {
                if (pageNo == 1) {
                    data.clear();
                }
                if (enterPriseModels != null && enterPriseModels.size() > 0) {
                    tv_nodata.setVisibility(View.GONE);
                    rv_list.setVisibility(View.VISIBLE);
                    data.addAll(enterPriseModels);
                    adapter.setDate(searchText);
                    adapter.notifyDataSetChanged();

                    if (enterPriseModels.size() == pageSize) {
                        pageNo++;
                    }
                } else {
                    tv_nodata.setVisibility(View.VISIBLE);
                    rv_list.setVisibility(View.GONE);
                }
            }

            @Override
            public void onFailure(Exception e, String des) {

            }
        });
    }

    @Override
    protected void initView() {
        et_ext = findViewById(R.id.et_ext);
        iv_clear = findViewById(R.id.iv_clear);
        et_ext.setHint(R.string.call_search_hint);
        sobot_tv_title = findViewById(R.id.sobot_tv_title);
        sobot_tv_title.setText(R.string.call_custom_company);
        iv_ext_search = findViewById(R.id.iv_ext_search);
        sobot_negativeButton = findViewById(R.id.sobot_negativeButton);
        rv_list = findViewById(R.id.rv_list);
        tv_nodata = findViewById(R.id.tv_nodata);
        ll_search = findViewById(R.id.ll_search);
        iv_clear.setOnClickListener(this);
        rv_list.setOnTouchListener(new View.OnTouchListener() {
            @Override
            public boolean onTouch(View v, MotionEvent event) {
                if (event.getAction() == MotionEvent.ACTION_MOVE) {
                    et_ext.clearFocus();
                }
                return false;
            }
        });
        et_ext.setOnFocusChangeListener(new View.OnFocusChangeListener() {
            @Override
            public void onFocusChange(View v, boolean hasFocus) {
                if (hasFocus) {
                    CustomFieldsUtils.showKeyboard(getContext(), et_ext);
                    ll_search.setBackgroundResource(R.drawable.sobot_call_v6_bg_search_f);
                } else {
                    CustomFieldsUtils.hideKeyboard(getContext(), v);
                    ll_search.setBackgroundResource(R.drawable.sobot_call_v6_bg_search);
                }
            }
        });
        et_ext.addTextChangedListener(new TextWatcher() {
            @Override
            public void beforeTextChanged(CharSequence s, int start, int count, int after) {

            }

            @Override
            public void onTextChanged(CharSequence s, int start, int before, int count) {

            }

            @Override
            public void afterTextChanged(Editable s) {
                int inputCount = s.length();
                if (inputCount > 0) {
                    iv_clear.setVisibility(View.VISIBLE);
                } else {
                    iv_clear.setVisibility(View.GONE);
                }
                pageNo = 1;
                requestComany();
            }
        });
        LinearLayoutManager layoutManager = new LinearLayoutManager(activity, LinearLayoutManager.VERTICAL, false);
        // 设置RecyclerView的LayoutManager
        rv_list.setLayoutManager(layoutManager);
        sobot_negativeButton.setOnClickListener(this);
        iv_ext_search.setOnClickListener(this);
    }


    @Override
    public void onClick(View v) {
        if (v == iv_clear) {
            et_ext.setText("");
            requestComany();
        }else if (v == sobot_negativeButton) {
            //关闭
            dismiss();
        } else if (v == iv_ext_search) {
            et_ext.clearFocus();
            pageNo = 1;
            requestComany();
        }
    }

    @Override
    public void dismiss() {
        et_ext.clearFocus();
        try {
            if (isShowing()) {
                super.dismiss();
            }
        } catch (Exception e) {
//            e.printStackTrace();
        }
    }
}
