package com.sobot.callsdk.v6.dialog;

import android.app.Activity;
import android.text.Editable;
import android.text.TextUtils;
import android.text.TextWatcher;
import android.view.KeyEvent;
import android.view.MotionEvent;
import android.view.View;
import android.view.inputmethod.EditorInfo;
import android.widget.EditText;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.sobot.callbase.model.SobotCountryRegion;
import com.sobot.callsdk.R;
import com.sobot.callsdk.dialog.SobotBottomDialog;
import com.sobot.callsdk.utils.CustomFieldsUtils;
import com.sobot.callsdk.v6.adapter.CallCountryRegionAdapter;

import java.util.ArrayList;
import java.util.List;

//选择国家编码弹窗
public class SelectCountryDialog extends SobotBottomDialog implements View.OnClickListener {
    private LinearLayout coustom_pop_layout, sobot_negativeButton;
    private LinearLayout ll_search;
    private RecyclerView rv_list;
    private EditText et_search_content;//搜索内容
    private ImageView iv_ext_search,iv_clear;
    private CountryRegionListener listener;
    private CallCountryRegionAdapter adapter;
    private List<SobotCountryRegion> data;
    private List<SobotCountryRegion> oldData;//初始数据
    private List<SobotCountryRegion> tempData;//搜索临时数据
    private Activity activity;
    private TextView sobot_tv_title,tv_nodata;

    public SelectCountryDialog(Activity context, CountryRegionListener listener, List<SobotCountryRegion> list) {
        super(context);
        activity = context;
        this.listener = listener;
        this.data = new ArrayList<>();
        this.oldData = new ArrayList<>();
        data.addAll(list);
        oldData.addAll(list);
        tempData = new ArrayList<>();
    }

    @Override
    protected int getLayout() {
        return R.layout.call_dialog_select_country_region;
    }

    @Override
    protected View getDialogContainer() {
        if (coustom_pop_layout == null) {
            coustom_pop_layout = findViewById(R.id.sobot_container);
        }
        return coustom_pop_layout;
    }

    @Override
    protected void initData() {
        adapter = new CallCountryRegionAdapter(activity, data, listener);
        rv_list.setAdapter(adapter);
    }

    @Override
    protected void initView() {
        sobot_negativeButton = findViewById(R.id.sobot_negativeButton);
        rv_list = findViewById(R.id.rv_list);
        ll_search = findViewById(R.id.ll_search);
        iv_ext_search = findViewById(R.id.iv_ext_search);
        sobot_tv_title = findViewById(R.id.sobot_tv_title);
        sobot_tv_title.setText(R.string.sobot_country_region);
        tv_nodata = findViewById(R.id.tv_nodata);
        iv_clear = findViewById(R.id.iv_clear);
        iv_clear.setOnClickListener(this);
        et_search_content = findViewById(R.id.et_search_content);
        rv_list.setOnTouchListener(new View.OnTouchListener() {
            @Override
            public boolean onTouch(View v, MotionEvent event) {
                if (event.getAction() == MotionEvent.ACTION_MOVE) {
                    et_search_content.clearFocus();
                }
                return false;
            }
        });
        et_search_content.setOnFocusChangeListener(new View.OnFocusChangeListener() {
            @Override
            public void onFocusChange(View v, boolean hasFocus) {
                if (hasFocus) {
                    CustomFieldsUtils.showKeyboard(getContext(), et_search_content);
                    ll_search.setBackgroundResource(R.drawable.sobot_call_v6_bg_search_f);
                } else {
                    CustomFieldsUtils.hideKeyboard(getContext(), v);
                    ll_search.setBackgroundResource(R.drawable.sobot_call_v6_bg_search);
                }
            }
        });
        et_search_content.addTextChangedListener(new TextWatcher() {
            @Override
            public void beforeTextChanged(CharSequence s, int start, int count, int after) {

            }

            @Override
            public void onTextChanged(CharSequence s, int start, int before, int count) {

            }

            @Override
            public void afterTextChanged(Editable s) {
                int inputCount = s.length();
                if (inputCount > 0) {
                    iv_clear.setVisibility(View.VISIBLE);
                } else {
                    iv_clear.setVisibility(View.GONE);
                }
                search();
            }
        });
        et_search_content.setOnEditorActionListener(new TextView.OnEditorActionListener() {
            @Override
            public boolean onEditorAction(TextView textView, int i, KeyEvent keyEvent) {
                if (i == EditorInfo.IME_ACTION_SEARCH) {
                    //搜索
                    search();
                    return true;
                }
                return false;
            }
        });
        LinearLayoutManager layoutManager = new LinearLayoutManager(activity, LinearLayoutManager.VERTICAL, false);
        // 设置RecyclerView的LayoutManager
        rv_list.setLayoutManager(layoutManager);

        sobot_negativeButton.setOnClickListener(this);
        iv_ext_search.setOnClickListener(this);
    }

    private void search(){
        String s = et_search_content.getText().toString();
        if (oldData != null && oldData.size() > 0) {
            tempData.clear();
            for (int i = 0; i < oldData.size(); i++) {
                if ((oldData.get(i).getName() + oldData.get(i).getCallingCode()).contains(s)) {
                    tempData.add(oldData.get(i));
                }
            }
            data.clear();
            if (TextUtils.isEmpty(s)) {
                data.addAll(oldData);
            } else {
                data.addAll(tempData);
            }
            adapter.notifyDataSetChanged();
            if(data.size()>0) {
                tv_nodata.setVisibility(View.GONE);
                rv_list.setVisibility(View.VISIBLE);
            }else{
                tv_nodata.setVisibility(View.VISIBLE);
                rv_list.setVisibility(View.GONE);
            }
        }
    }
    public void setData(List<SobotCountryRegion> list) {
        if (data == null) {
            data = new ArrayList<>();
        } else {
            data.clear();
            data.addAll(list);
        }
        if (oldData == null) {
            oldData = new ArrayList<>();
        } else {
            oldData.clear();
            oldData.addAll(list);
        }
        et_search_content.setText("");
        if (tempData == null) {
            tempData = new ArrayList<>();
        } else {
            tempData.clear();
        }
        if (adapter != null) {
            adapter.notifyDataSetChanged();
        }
    }

    @Override
    public void onClick(View v) {
        if (v == sobot_negativeButton) {
            //关闭
            dismiss();
        }else if(iv_clear ==v){
            et_search_content.setText("");
            search();
        }else if(iv_ext_search ==v){
            //搜索
            et_search_content.clearFocus();
            search();
        }
    }

    @Override
    public void dismiss() {
        et_search_content.clearFocus();
        try {
            if (isShowing()) {
                super.dismiss();
            }
        } catch (Exception e) {
//            e.printStackTrace();
        }
    }

    public interface CountryRegionListener {
        void selectCountryRegion(SobotCountryRegion checkin);
    }
}
