package com.sobot.callsdk.v6.dialog;

import android.app.Activity;
import android.text.Editable;
import android.text.TextWatcher;
import android.view.KeyEvent;
import android.view.MotionEvent;
import android.view.View;
import android.view.inputmethod.EditorInfo;
import android.widget.EditText;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.sobot.callbase.model.SobotExtensionEntity;
import com.sobot.callbase.widget.CallClassicsFooter;
import com.sobot.callsdk.R;
import com.sobot.callsdk.api.SobotCallServiceFactory;
import com.sobot.callsdk.dialog.SobotBottomDialog;
import com.sobot.callsdk.utils.CustomFieldsUtils;
import com.sobot.callsdk.v6.adapter.CallExtsAdapter;
import com.sobot.common.login.SobotLoginTools;
import com.sobot.common.login.model.SobotServiceInfoModel;
import com.sobot.network.http.callback.SobotResultCallBack;
import com.sobot.utils.SobotDensityUtil;
import com.sobot.widget.loading.SobotLoadingLayout;
import com.sobot.widget.refresh.layout.SobotRefreshLayout;
import com.sobot.widget.refresh.layout.api.RefreshLayout;
import com.sobot.widget.refresh.layout.header.ClassicsHeader;
import com.sobot.widget.refresh.layout.listener.OnLoadMoreListener;
import com.sobot.widget.refresh.layout.listener.OnRefreshListener;

import java.util.ArrayList;
import java.util.List;

public class SelectExtDialog extends SobotBottomDialog implements View.OnClickListener {
    private LinearLayout coustom_pop_layout, sobot_negativeButton;
    private LinearLayout ll_search;
    private RecyclerView rv_list;
    private EditText et_ext;
    private ImageView iv_ext_search, iv_clear;
    private ExtsListener listener;
    private CallExtsAdapter adapter;
    private List<SobotExtensionEntity> data;
    private List<SobotExtensionEntity> oldData;//初始数据
    private List<SobotExtensionEntity> tempData;//搜索临时数据
    private Activity activity;
    private SobotServiceInfoModel serviceVo;
    private TextView sobot_tv_title, tv_nodata;
    private SobotExtensionEntity selectData;
    private int curPage = 1;
    private int pageSize = 50;
    private SobotRefreshLayout refreshLayout;
    private SobotLoadingLayout loadingLayout;
    private boolean isHasMoreData = false;

    public SelectExtDialog(Activity context, ExtsListener listener, SobotExtensionEntity selectData) {
        super(context);
        activity = context;
        this.selectData = selectData;
        this.listener = listener;
        this.data = new ArrayList<>();
        this.oldData = new ArrayList<>();
        tempData = new ArrayList<>();
        serviceVo = SobotLoginTools.getInstance().getServiceInfo();
    }

    @Override
    protected int getLayout() {
        return R.layout.call_dialog_select_ext;
    }

    @Override
    protected View getDialogContainer() {
        if (coustom_pop_layout == null) {
            coustom_pop_layout = findViewById(R.id.sobot_container);
        }
        return coustom_pop_layout;
    }

    @Override
    protected void initData() {
        adapter = new CallExtsAdapter(activity, data, listener);
        rv_list.setAdapter(adapter);
        if (data == null || data.size() == 0) {
            curPage = 1;
            getExtensionList("", curPage);
        }
    }

    //v6 获取分机账号列表
    private void getExtensionList(String s, int page) {
        if (serviceVo == null) {
            dismiss();
        }
        //旧接口请求
//        SobotCallServiceFactory.createZhiChiApi(activity).getExtensionList(this, serviceVo.getServiceId(), "1", new SobotResultCallBack<List<SobotExtensionEntity>>() {
        //新接口请求
        SobotCallServiceFactory.createZhiChiApi(activity).getExtensionList(this, s, serviceVo.getServiceId(), "1", page, pageSize, new SobotResultCallBack<List<SobotExtensionEntity>>() {
            @Override
            public void onSuccess(List<SobotExtensionEntity> extensionModelList) {
                refreshLayout.finishRefresh();//停止刷新
                curPage = page;
                if (page == 1) {
                    data.clear();//刷新时清空列表
                    if (null == extensionModelList || extensionModelList.size() == 0) {
                        isHasMoreData = false;
                        loadingLayout.showEmpty();//显示无内容
                        return;
                    }
                }
                if (extensionModelList != null) {
                    if (extensionModelList.size() < pageSize) {
                        //加载完毕
                        isHasMoreData = false;
                        refreshLayout.setNoMoreData(true);
                        refreshLayout.setEnableFooterFollowWhenNoMoreData(true);
                    } else {
                        //有 下一页
                        isHasMoreData = true;
                        refreshLayout.setNoMoreData(false);
                        refreshLayout.setEnableLoadMore(true);
                        refreshLayout.setEnableFooterFollowWhenNoMoreData(false);
                    }
                    data.addAll(extensionModelList);
                    if (selectData != null) {
                        for (int i = 0; i < data.size(); i++) {
                            SobotExtensionEntity extensionEntity = data.get(i);
                            if (extensionEntity.getExt().equals(selectData.getExt())) {
                                extensionEntity.setSelect(true);
                            }
                        }
                    } else {
                        for (int i = 0; i < data.size(); i++) {
                            SobotExtensionEntity extensionEntity = data.get(i);
                            if (extensionEntity.getBindStatus() == 1) {
                                extensionEntity.setSelect(true);
                            }
                        }
                    }
                    adapter.notifyDataSetChanged();
                    loadingLayout.showContent();//显示列表
                    refreshLayout.finishLoadMore();

                }
            }

            @Override
            public void onFailure(Exception e, String des) {
            }
        });
    }

    @Override
    protected void initView() {
        refreshLayout = findViewById(R.id.sobot_srl_call_record);
        loadingLayout = findViewById(R.id.sobot_loading_layout);
        sobot_negativeButton = findViewById(R.id.sobot_negativeButton);
        sobot_tv_title = findViewById(R.id.sobot_tv_title);
        ll_search = findViewById(R.id.ll_search);
        sobot_tv_title.setText(R.string.sobot_extension_account);
        rv_list = findViewById(R.id.rv_list);
        et_ext = findViewById(R.id.et_ext);
        tv_nodata = findViewById(R.id.tv_nodata);
        et_ext.setHint(R.string.call_search_ext);
        iv_ext_search = findViewById(R.id.iv_ext_search);
        iv_clear = findViewById(R.id.iv_clear);
        iv_clear.setOnClickListener(this);
        rv_list.setOnTouchListener(new View.OnTouchListener() {
            @Override
            public boolean onTouch(View v, MotionEvent event) {
                if (event.getAction() == MotionEvent.ACTION_MOVE) {
                    et_ext.clearFocus();
                }
                return false;
            }
        });
        et_ext.setOnFocusChangeListener(new View.OnFocusChangeListener() {
            @Override
            public void onFocusChange(View v, boolean hasFocus) {
                if (hasFocus) {
                    CustomFieldsUtils.showKeyboard(getContext(), et_ext);
                    ll_search.setBackgroundResource(R.drawable.sobot_call_v6_bg_search_f);
                } else {
                    CustomFieldsUtils.hideKeyboard(getContext(), v);
                    ll_search.setBackgroundResource(R.drawable.sobot_call_v6_bg_search);
                }
            }
        });
        et_ext.addTextChangedListener(new TextWatcher() {
            @Override
            public void beforeTextChanged(CharSequence s, int start, int count, int after) {

            }

            @Override
            public void onTextChanged(CharSequence s, int start, int before, int count) {
                if (s.toString().contains(" ")) {
                    String[] str = s.toString().split(" ");
                    String str1 = "";
                    for (int i = 0; i < str.length; i++) {
                        str1 += str[i];
                    }
                    et_ext.setText(str1);
                    et_ext.setSelection(start);
                }
            }

            @Override
            public void afterTextChanged(Editable s) {
                int inputCount = s.length();
                if (inputCount > 0) {
                    iv_clear.setVisibility(View.VISIBLE);
                } else {
                    iv_clear.setVisibility(View.GONE);
                }
                search();
            }
        });
        et_ext.setOnEditorActionListener(new TextView.OnEditorActionListener() {
            @Override
            public boolean onEditorAction(TextView textView, int i, KeyEvent keyEvent) {
                if (i == EditorInfo.IME_ACTION_SEARCH) {
                    //搜索
                    search();
                    return true;
                }
                return false;
            }
        });

        refreshLayout.setRefreshHeader(new ClassicsHeader(activity));
        refreshLayout.setRefreshFooter(new CallClassicsFooter(activity), SobotDensityUtil.getScreenWidth(activity), SobotDensityUtil.dp2px(activity, 145));
        refreshLayout.setEnableLoadMore(true);
        refreshLayout.setEnableRefresh(true);
        refreshLayout.setEnableAutoLoadMore(true);
        refreshLayout.setEnableFooterFollowWhenNoMoreData(false);

        refreshLayout.setOnLoadMoreListener(new OnLoadMoreListener() {
            @Override
            public void onLoadMore(@NonNull  RefreshLayout refreshLayout) {
                if (isHasMoreData) {
                    String s = et_ext.getText().toString();
                    getExtensionList(s, curPage + 1);
                } else {
                    refreshLayout.setNoMoreData(true);
                }
            }
        });
        refreshLayout.setOnRefreshListener(new OnRefreshListener() {
            @Override
            public void onRefresh(@NonNull  RefreshLayout refreshLayout) {
                curPage = 1;
                String s = et_ext.getText().toString();
                getExtensionList(s, curPage);
            }
        });

        LinearLayoutManager layoutManager = new LinearLayoutManager(activity, LinearLayoutManager.VERTICAL, false);
        // 设置RecyclerView的LayoutManager
        rv_list.setLayoutManager(layoutManager);

        sobot_negativeButton.setOnClickListener(this);
        iv_ext_search.setOnClickListener(this);
    }

    public void setData(List<SobotExtensionEntity> list) {
        if (data == null) {
            data = new ArrayList<>();
        } else {
            data.clear();
            data.addAll(list);
        }
        if (oldData == null) {
            oldData = new ArrayList<>();
        } else {
            oldData.clear();
            oldData.addAll(list);
        }
        et_ext.setText("");
        if (tempData == null) {
            tempData = new ArrayList<>();
        } else {
            tempData.clear();
        }
        if (adapter != null) {
            adapter.notifyDataSetChanged();
        }
    }

    @Override
    public void onClick(View v) {
        if (v == sobot_negativeButton) {
            //关闭
            et_ext.clearFocus();
            dismiss();
        } else if (iv_clear == v) {
            et_ext.setText("");
            search();
        } else if (iv_ext_search == v) {
            //搜索
            et_ext.clearFocus();
            search();
        }
    }

    private void search() {
        String s = et_ext.getText().toString();
        curPage = 1;
        getExtensionList(s, curPage);
        /*
            //旧接口本地搜索
            if (oldData != null && oldData.size() > 0) {
                tempData.clear();
                for (int i = 0; i < oldData.size(); i++) {
                    if ((oldData.get(i).getExt()).contains(s)) {
                        tempData.add(oldData.get(i));
                    }
                }
                data.clear();
                if (TextUtils.isEmpty(s)) {
                    data.addAll(oldData);
                } else {
                    data.addAll(tempData);
                }
                adapter.notifyDataSetChanged();
                if (data.size() > 0) {
                    tv_nodata.setVisibility(View.GONE);
                    rv_list.setVisibility(View.VISIBLE);
                } else {
                    tv_nodata.setVisibility(View.VISIBLE);
                    rv_list.setVisibility(View.GONE);
                }

            }
        */
    }

    @Override
    public void dismiss() {
        et_ext.clearFocus();
        try {
            if (isShowing()) {
                super.dismiss();
            }
        } catch (Exception e) {
//            e.printStackTrace();
        }
    }

    public interface ExtsListener {
        void selectExts(SobotExtensionEntity checkin);
    }
}
