package com.sobot.callsdk.v6.fragment;

import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.os.Handler;
import android.text.Editable;
import android.text.TextUtils;
import android.text.TextWatcher;
import android.view.KeyEvent;
import android.view.LayoutInflater;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.view.WindowManager;
import android.view.inputmethod.EditorInfo;
import android.widget.EditText;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.PopupWindow;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.lifecycle.Observer;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.sobot.callbase.dialog.SobotActionItem;
import com.sobot.callbase.model.CallTaskDetailsModel;
import com.sobot.callbase.model.SobotCallListSecondEntity;
import com.sobot.callbase.widget.CallClassicsFooter;
import com.sobot.callbase.widget.floatwindow.SobotFloatWindow;
import com.sobot.callsdk.R;
import com.sobot.callsdk.fargment.SobotBaseFragment;
import com.sobot.callsdk.utils.CallSharedPreferencesUtils;
import com.sobot.callsdk.utils.CallStatusUtils;
import com.sobot.callsdk.utils.CustomFieldsUtils;
import com.sobot.callsdk.utils.SobotCallConstant;
import com.sobot.callsdk.v6.activity.CallStatusActivity;
import com.sobot.callsdk.v6.activity.CallTaskContactDetailActivity;
import com.sobot.callsdk.v6.adapter.CallTaskExecutedTypeAdapter;
import com.sobot.callsdk.v6.constant.SobotCallLiveDataBusV6Key;
import com.sobot.callsdk.v6.dialog.SobotMoreMenuPop;
import com.sobot.callsdk.v6.listener.CallTaskDetailsCountListener;
import com.sobot.network.http.callback.SobotResultCallBack;
import com.sobot.utils.SobotDensityUtil;
import com.sobot.utils.SobotLogUtils;
import com.sobot.utils.SobotStringUtils;
import com.sobot.widget.livedatabus.SobotLiveEventBus;
import com.sobot.widget.loading.SobotLoadingLayout;
import com.sobot.widget.refresh.layout.SobotRefreshLayout;
import com.sobot.widget.refresh.layout.api.RefreshLayout;
import com.sobot.widget.refresh.layout.header.ClassicsHeader;
import com.sobot.widget.refresh.layout.listener.OnLoadMoreListener;
import com.sobot.widget.refresh.layout.listener.OnRefreshListener;
import com.sobot.widget.ui.toast.SobotToastUtil;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

/**
 * 任务详情列表 全部
 */
public class CallTaskDetailsAllFragment extends SobotBaseFragment implements CallTaskExecutedTypeAdapter.OnItemClickListener, View.OnClickListener {
    private String taskId;//任务id
    private int status;//任务状态
    private int pageNo = 1;
    private int pageSize = 20;
    private SobotRefreshLayout refreshLayout;
    private RecyclerView recyclerView;
    private SobotLoadingLayout loadingLayout;
    private boolean isHasMoreData = false;
    private ArrayList<CallTaskDetailsModel> mDate;
    private CallTaskExecutedTypeAdapter mAdapter;

    private LinearLayout ll_search;
    private LinearLayout ll_search_status;
    //    private Spinner sp_search_type;
    private TextView tv_search_type;//搜索类型
    private TextView tv_search_answer_status;//接听状态
    private EditText et_search_input;
    private ImageView iv_search;
    private ImageView iv_clear;
    private PopupWindow popupWindow;
    //输入后0.5s去搜索
    private long inputTime = 0;
    private List<SobotActionItem> searchItems;
    private List<SobotActionItem> searchStatusItems;
    //是否自动填充的文字
    private boolean isautoText = false;

    private int searchType = 0;///0:号码，1：姓名

    private String type = "ALL";//已执行 ALL_ENTALK，ENEXECUTE_ENTALK

    private CallTaskDetailsCountListener mListener;
    private boolean isRefresh = false;// 缓存 用于通话结束后从第一页刷新
    //消息监听
    private Observer allTaskObserverTag,allTaskObserver,callReleasedObserver;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
    }

    @Override
    public void onAttach(Context context) {
        super.onAttach(context);
        if (context instanceof CallTaskDetailsCountListener) {
            mListener = (CallTaskDetailsCountListener) context;
        } else {
            throw new RuntimeException(context.toString()
                    + " must implement OnFragmentInteractionListener");
        }
    }

    @Override
    public void onDetach() {
        super.onDetach();
        mListener = null;
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        View view = inflater.inflate(R.layout.fragment_task_details_all, container, false);
        try {
            initView(view);
        } catch (Exception e) {
        }
        return view;
    }

    @Override
    public void setArguments(@Nullable Bundle bundle) {
        super.setArguments(bundle);
        taskId = bundle.getString("taskId", "");
        status = bundle.getInt("status");
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        SobotLiveEventBus.get(SobotCallLiveDataBusV6Key.SOBOT_ACTION_REFRESH_ALL_TASK_TAG).removeObserver(allTaskObserverTag);
        SobotLiveEventBus.get(SobotCallLiveDataBusV6Key.SOBOT_ACTION_REFRESH_ALL_TASK).removeObserver(allTaskObserver);
        SobotLiveEventBus.get(SobotCallLiveDataBusV6Key.SOBOT_ACTION_CALL_RELEASED).removeObserver(callReleasedObserver);
    }


    public void initView(View view) {
        ll_search = view.findViewById(R.id.ll_search);
        iv_clear = view.findViewById(R.id.iv_clear);
        tv_search_type = view.findViewById(R.id.tv_search_type);
        ll_search_status = view.findViewById(R.id.ll_search_status);
        tv_search_answer_status = view.findViewById(R.id.tv_search_answer_status);
//        sp_search_type = view.findViewById(R.id.sp_search_type);
        et_search_input = view.findViewById(R.id.et_search_input_all);
        iv_search = view.findViewById(R.id.iv_search);

        iv_search.setOnClickListener(this);
        iv_clear.setOnClickListener(this);
        //添加监听事件
        liveDateObserver();

        et_search_input.setOnFocusChangeListener(new View.OnFocusChangeListener() {
            @Override
            public void onFocusChange(View v, boolean hasFocus) {
                if (hasFocus) {
                    CustomFieldsUtils.showKeyboard(getContext(), et_search_input);
                    ll_search.setBackgroundResource(R.drawable.sobot_call_v6_bg_search_f);
                } else {
                    CustomFieldsUtils.hideKeyboard(getContext(), v);
                    ll_search.setBackgroundResource(R.drawable.sobot_call_v6_bg_search);
                }
            }
        });
        et_search_input.setOnEditorActionListener(new TextView.OnEditorActionListener() {
            @Override
            public boolean onEditorAction(TextView textView, int i, KeyEvent keyEvent) {
                if (i == EditorInfo.IME_ACTION_SEARCH) {
                    //搜索
                    search();
                    return true;
                }
                return false;
            }
        });
        et_search_input.addTextChangedListener(new TextWatcher() {
            @Override
            public void beforeTextChanged(CharSequence s, int start, int count, int after) {

            }

            @Override
            public void onTextChanged(CharSequence s, int start, int before, int count) {

            }

            @Override
            public void afterTextChanged(Editable s) {
                if (isautoText) {
                    isautoText = false;
                } else {
                    int inputCount = s.length();
                    if (inputCount > 0) {
                        iv_clear.setVisibility(View.VISIBLE);
                    } else {
                        iv_clear.setVisibility(View.GONE);
                        if (searchType == 0) {
                            //搜索历史记录
                            et_search_input.setHint(getString(R.string.sobot_call_search_tip));
                        } else {
                            //搜索客户
                            et_search_input.setHint(getString(R.string.sobot_nickname_hide_string));
                        }
                    }
                    inputTime = System.currentTimeMillis();
                    new Handler().postDelayed(new Runnable() {
                        @Override
                        public void run() {
                            search();
                        }
                    }, 500);
                }
            }
        });

        SobotActionItem sobot_call_search_number = new SobotActionItem(getResources().getString(R.string.sobot_call_search_number), false);
        SobotActionItem sobot_nickname_string = new SobotActionItem(getResources().getString(R.string.call_name), false);
        searchItems = new ArrayList<>();
        searchItems.add(sobot_call_search_number);
        searchItems.add(sobot_nickname_string);
        tv_search_type.setOnClickListener(this);
        SobotActionItem all = new SobotActionItem(getResources().getString(R.string.call_all_string), false);
        SobotActionItem answered = new SobotActionItem(getResources().getString(R.string.call_result_answered), false);
        SobotActionItem unanswered = new SobotActionItem(getResources().getString(R.string.call_result_unanswered), false);
        searchStatusItems = new ArrayList<>();
        searchStatusItems.add(all);
        searchStatusItems.add(unanswered);
        searchStatusItems.add(answered);
        tv_search_answer_status.setOnClickListener(this);

        refreshLayout = view.findViewById(R.id.sobot_srl_call_record);
        recyclerView = view.findViewById(R.id.sobot_rv_record_list);
        loadingLayout = view.findViewById(R.id.sobot_loading_layout);

        //列表
        recyclerView.setLayoutManager(new LinearLayoutManager(getSobotActivity()));
        mDate = new ArrayList<>();
        mAdapter = new CallTaskExecutedTypeAdapter(getSobotActivity(), mDate, status, this);
        recyclerView.setAdapter(mAdapter);

        //下拉刷新控件
        recyclerView.setLayoutManager(new LinearLayoutManager(getContext()));
        refreshLayout.setRefreshHeader(new ClassicsHeader(getSobotActivity()));
        refreshLayout.setRefreshFooter(new CallClassicsFooter(getSobotActivity()), SobotDensityUtil.getScreenWidth(getSobotActivity()), SobotDensityUtil.dp2px(getSobotActivity(), 94));
        refreshLayout.setEnableLoadMore(true);
        refreshLayout.setEnableRefresh(true);
        refreshLayout.setEnableAutoLoadMore(true);
        refreshLayout.setEnableFooterFollowWhenNoMoreData(false);
        recyclerView.setOnTouchListener(new View.OnTouchListener() {
            @Override
            public boolean onTouch(View v, MotionEvent event) {
                if (event.getAction() == MotionEvent.ACTION_MOVE) {
                    et_search_input.clearFocus();
                }
                return false;
            }
        });
        refreshLayout.setOnLoadMoreListener(new OnLoadMoreListener() {
            @Override
            public void onLoadMore(@NonNull  RefreshLayout refreshLayout) {
                if (isHasMoreData) {
                    requestDate(pageNo + 1, searchType, type);
                } else {
                    refreshLayout.setNoMoreData(true);
                }
            }
        });
        refreshLayout.setOnRefreshListener(new OnRefreshListener() {
            @Override
            public void onRefresh(@NonNull  RefreshLayout refreshLayout) {
                pageNo = 1;
                requestDate(pageNo, searchType, type);
            }
        });

        //是否显示无内容
        loadingLayout.setRetryListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                search();
            }
        });
        search();
    }

    private void liveDateObserver() {
        allTaskObserverTag = new Observer<Boolean>() {
            @Override
            public void onChanged(@Nullable Boolean aBoolean) {
                isRefresh = true;//从第一页刷新
            }
        };
        allTaskObserver = new Observer<Boolean>() {
            @Override
            public void onChanged(@Nullable Boolean aBoolean) {
                if (refreshLayout != null) {
                    refreshLayout.autoRefresh();
                }
            }
        };

        callReleasedObserver = new Observer<HashMap<String,Object>>() {
            @Override
            public void onChanged(@Nullable HashMap<String, Object> stringObjectHashMap) {
                String campaignRecordId = (String) stringObjectHashMap.get("campaignRecordId");
                long bridgeUepoch = (Long) stringObjectHashMap.get("bridgeUepoch");
                if (!SobotStringUtils.isEmpty(campaignRecordId) && mDate != null && mAdapter != null) {
                    for (int i = 0; i < mDate.size(); i++) {
                        CallTaskDetailsModel taskDetailsModel = mDate.get(i);
                        if (campaignRecordId.equals(taskDetailsModel.getRecordId())) {
                            mDate.get(i).setDialCount(mDate.get(i).getDialCount() + 1);
                            if (bridgeUepoch > 0) {
                                //已接通
                                mDate.get(i).setState(2);
                            }
                            mAdapter.notifyItemChanged(i);
                            break;
                        }
                    }
                }
                if (isRefresh) {
                    pageNo = 1;
                    new Handler().postDelayed(new Runnable() {
                        @Override
                        public void run() {
                            refreshLayout.autoRefresh();
                            isRefresh = false;
                        }
                    }, 1000);
                }
            }
        };


        SobotLiveEventBus.get(SobotCallLiveDataBusV6Key.SOBOT_ACTION_REFRESH_ALL_TASK_TAG).observeForever(allTaskObserverTag);
        SobotLiveEventBus.get(SobotCallLiveDataBusV6Key.SOBOT_ACTION_REFRESH_ALL_TASK).observeForever(allTaskObserver);
        SobotLiveEventBus.get(SobotCallLiveDataBusV6Key.SOBOT_ACTION_CALL_RELEASED).observeForever(callReleasedObserver);
    }

    public void edClearFocus() {
        if (et_search_input != null) {
            CustomFieldsUtils.hideKeyboard(getContext(), et_search_input);
            et_search_input.clearFocus();
        }
    }

    private void search() {
        if (System.currentTimeMillis() - inputTime < 500) {
            return;
        }
        loadingLayout.showLoading();
        refreshLayout.setVisibility(View.VISIBLE);
        pageNo = 1;
        refreshLayout.setEnableLoadMore(true);
        requestDate(pageNo, searchType, type);
    }

    @Override
    public void onClick(View v) {
        if (v == iv_clear) {
            et_search_input.setText("");
            pageNo = 1;
            search();
        } else if (v == iv_search) {
            et_search_input.clearFocus();
            //搜索
            pageNo = 1;
            iv_search.requestFocus();
            search();
        } else if (v == tv_search_type) {
            et_search_input.clearFocus();
            if (searchType == 0) {
                searchItems.get(0).setChecked(true);
                searchItems.get(1).setChecked(false);
            } else {
                searchItems.get(0).setChecked(false);
                searchItems.get(1).setChecked(true);
            }
            SobotMoreMenuPop pop = new SobotMoreMenuPop(getSobotActivity(), searchItems, false, true, new SobotMoreMenuPop.PopItemClick() {
                @Override
                public void onPopItemClick(SobotActionItem item, int index) {
                    popupWindow.dismiss();
                    searchType = index;
                    pageNo = 1;
                    if (searchType == 1) {
                        et_search_input.setHint(getResources().getString(R.string.call_name_hide_string));
                        tv_search_type.setText(getResources().getString(R.string.call_name));
                    } else {
                        tv_search_type.setText(getResources().getString(R.string.sobot_call_search_number));
                        et_search_input.setHint(getResources().getString(R.string.sobot_call_search_tip));
                    }
                    search();
                }
            });

            popupWindow = pop.getPopWindow();
            //弹窗出现外部为阴影
            WindowManager.LayoutParams attributes = getActivity().getWindow().getAttributes();
            attributes.alpha = 1f;
            getActivity().getWindow().setAttributes(attributes);
            //弹窗取消监听 取消之后恢复阴影
            popupWindow.setOnDismissListener(new PopupWindow.OnDismissListener() {
                @Override
                public void onDismiss() {
                    WindowManager.LayoutParams attributes = getActivity().getWindow().getAttributes();
                    attributes.alpha = 1;
                    getActivity().getWindow().setAttributes(attributes);
                }
            });
            popupWindow.showAsDropDown(ll_search, 0, 0);
        } else if (v == tv_search_answer_status) {
            et_search_input.clearFocus();
            if (type.equals("ALL")) {
                searchStatusItems.get(0).setChecked(true);
                searchStatusItems.get(1).setChecked(false);
                searchStatusItems.get(2).setChecked(false);
            } else if (type.equals("ALL_UNTALK")) {
                searchStatusItems.get(0).setChecked(false);
                searchStatusItems.get(1).setChecked(true);
                searchStatusItems.get(2).setChecked(false);
            } else {
                searchStatusItems.get(0).setChecked(false);
                searchStatusItems.get(1).setChecked(false);
                searchStatusItems.get(2).setChecked(true);
            }
            SobotMoreMenuPop pop = new SobotMoreMenuPop(getSobotActivity(), searchStatusItems, false, true, new SobotMoreMenuPop.PopItemClick() {
                @Override
                public void onPopItemClick(SobotActionItem item, int index) {
                    popupWindow.dismiss();
                    pageNo = 1;
                    if (index == 0) {
                        type = "ALL";
                        tv_search_answer_status.setText(getResources().getString(R.string.call_all_string));
                    } else if (index == 1) {
                        type = "ALL_UNTALK";
                        tv_search_answer_status.setText(getResources().getString(R.string.call_result_unanswered));
                    } else {
                        type = "ALL_ENTALK";
                        tv_search_answer_status.setText(getResources().getString(R.string.call_result_answered));
                    }
                    search();
                }
            });

            popupWindow = pop.getPopWindow();
            //弹窗出现外部为阴影
            WindowManager.LayoutParams attributes = getActivity().getWindow().getAttributes();
            attributes.alpha = 1f;
            getActivity().getWindow().setAttributes(attributes);
            //弹窗取消监听 取消之后恢复阴影
            popupWindow.setOnDismissListener(new PopupWindow.OnDismissListener() {
                @Override
                public void onDismiss() {
                    WindowManager.LayoutParams attributes = getActivity().getWindow().getAttributes();
                    attributes.alpha = 1;
                    getActivity().getWindow().setAttributes(attributes);
                }
            });
            popupWindow.showAsDropDown(ll_search_status, 0, 0);
        }
    }


    /**
     * @param pageIndex
     * @param type      查询条件 1.姓名 2.号码
     * @param name      执行状态名称，ALL，ALL_UNTALK，ALL_ENTALK 分别对应全部,全部未接听，全部已接听
     */
    private void requestDate(int pageIndex, int type, String name) {
        SobotLogUtils.i(" 任务明细 全部 刷新");
        //模糊查询的文本框内容，姓名，号码
        String searchText = et_search_input.getText().toString();
        // searchType = 0;//0:号码，1：姓名
        if (type == 0) {
            //真正类型
            type = 2;
        } else {
            type = 1;
        }
        zhiChiApi.getTaskDetailsV6(this, getSobotActivity(), taskId, type + "", searchText, name, pageIndex, pageSize, new SobotResultCallBack<SobotCallListSecondEntity<CallTaskDetailsModel>>() {
            @Override
            public void onSuccess(SobotCallListSecondEntity<CallTaskDetailsModel> callListSecondEntity) {
                List<CallTaskDetailsModel> callTaskDetailsModels = null;
                if (callListSecondEntity != null && callListSecondEntity.getContacts() != null) {
                    callTaskDetailsModels = callListSecondEntity.getContacts();
                }
                refreshLayout.finishRefresh();//停止刷新
                refreshLayout.finishLoadMore();
                pageNo = pageIndex;
                if (pageIndex == 1) {
                    mDate.clear();//刷新时清空列表
                    if (callTaskDetailsModels == null || callTaskDetailsModels.size() == 0) {
                        isHasMoreData = false;
                        loadingLayout.showEmpty();//显示无内容
                        refreshLayout.setEnableLoadMore(false);
                        return;
                    } else {
                        if (callTaskDetailsModels.size() > 8) {
                            refreshLayout.setEnableFooterFollowWhenNoMoreData(true);
                        } else {
                            refreshLayout.setEnableFooterFollowWhenNoMoreData(false);
                        }
                    }
                }
                if (callTaskDetailsModels == null || callTaskDetailsModels.size() < pageSize) {
                    //加载完毕
                    isHasMoreData = false;
                    refreshLayout.setNoMoreData(true);
                } else {
                    //有 下一页
                    isHasMoreData = true;
                    refreshLayout.setNoMoreData(false);
                }
                if (callTaskDetailsModels != null) {
                    mDate.addAll(callTaskDetailsModels);
                    mAdapter.notifyDataSetChanged();
                }
                loadingLayout.showContent();//显示列表
                if (pageNo == 1 && mDate.size() > 0) {
                    recyclerView.scrollToPosition(0);
                }
            }

            @Override
            public void onFailure(Exception e, String des) {
                refreshLayout.finishLoadMore();
                refreshLayout.finishRefresh();
                if (pageIndex == 1) {
                    loadingLayout.showEmpty();
                } else {
                    SobotToastUtil.showCustomToast(getSobotActivity(), SobotStringUtils.isEmpty(des) ? getResources().getString(R.string.sobot_call_net_error_string) : des, R.drawable.sobot_icon_warning_attention);
                }
            }
        });
    }

    @Override
    public void onItemClick(CallTaskDetailsModel detailsModel, int postion) {
        if (detailsModel != null) {
            Intent intent = new Intent(getSobotActivity(), CallTaskContactDetailActivity.class);
            intent.putExtra("recordId", detailsModel.getRecordId());//任务明细id
            intent.putExtra("campaignId", detailsModel.getCampaignId());//公司id
            intent.putExtra("dialCount", detailsModel.getDialCount());//外出次数 判断是否执行过
            intent.putExtra("status", status);//任务状态（未开始、进行中..）
            intent.putExtra("taskFromType", 1);//1 全部 2 未执行 3 已执行
            Bundle bundle = new Bundle();
            bundle.putSerializable("taskRecordList", mDate);
            intent.putExtras(bundle);
            startActivity(intent);
        }
    }

    @Override
    public void onItemClickCall(CallTaskDetailsModel detailsModel, int postion) {
        if (null != detailsModel) {
            //任务在进行中才能拨打
            //调用拨打电话接口
            if (status == 2 && !TextUtils.isEmpty(detailsModel.getScreenNumber())) {
                //判断是否登录
                String call_loingStatus = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.callLoginStatus, CallStatusUtils.V6_OFFLINE);
                if (call_loingStatus.equals(CallStatusUtils.V6_FINISHING)) {
                    //判断是否正在整理中
                    SobotToastUtil.showToast(getSobotActivity(), getResources().getString(R.string.sobot_error_switch_status));
                } else if (call_loingStatus.equals(CallStatusUtils.V6_SYSYTEM_BUSY)) {
                    SobotToastUtil.showToast(getSobotActivity(), getResources().getString(R.string.call_str_system_Lock_toast));
                } else if (call_loingStatus.equals(CallStatusUtils.V6_OFFLINE)) {
                    SobotToastUtil.showToast(getSobotActivity(), getResources().getString(R.string.sobot_call_error_hint));
                } else if (SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT) != null && SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT).isShowing()) {
                    //通话没结束，不能切换坐席状态
                    SobotToastUtil.showCustomToast(getSobotActivity(), getString(R.string.call_retcode_330035));
                    return;
                } else {
                    //调用呼叫接口打电话
                    Intent intent = CallStatusActivity.initIntent(getSobotActivity(), detailsModel.getEncryptCustomerNumber(), detailsModel.getScreenNumber());
                    intent.putExtra("recordId", detailsModel.getRecordId());//任务明细id
                    intent.putExtra("campaignId", detailsModel.getCampaignId());//公司id
                    intent.putExtra("dialCount", detailsModel.getDialCount());//外出次数 判断是否执行过
                    intent.putExtra("status", status);//任务状态（未开始、进行中..）
                    intent.putExtra("contactName", SobotStringUtils.isEmpty(detailsModel.getContactName())?"--":detailsModel.getContactName());//联系人姓名
                    intent.putExtra("taskFromType", 1);//1 全部 2 未执行 3 已执行
                    Bundle bundle = new Bundle();
                    bundle.putSerializable("taskRecordList", mDate);
                    intent.putExtras(bundle);
                    intent.setFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP | Intent.FLAG_ACTIVITY_CLEAR_TOP |
                            Intent.FLAG_ACTIVITY_NEW_TASK);
                    startActivity(intent);
                    if (detailsModel.getDialCount() == 0) {
                        SobotLiveEventBus.get(SobotCallLiveDataBusV6Key.SOBOT_ACTION_REFRESH_UNEXECUTED_TASK_TAG).post(true);
                    }
                    SobotLiveEventBus.get(SobotCallLiveDataBusV6Key.SOBOT_ACTION_REFRESH_EXECUTED_TASK_TAG).post(System.currentTimeMillis());

                    SobotLiveEventBus.get(SobotCallLiveDataBusV6Key.SOBOT_ACTION_REFRESH_LAST_CALL).post(detailsModel);
                }
            }
        }
    }
}