package com.sobot.callsdk.v6.fragment;

import static android.app.Activity.RESULT_OK;

import android.Manifest;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.content.res.Resources;
import android.graphics.drawable.Drawable;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.os.Handler;
import android.provider.Settings;
import android.text.TextUtils;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.animation.BounceInterpolator;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.PopupWindow;
import android.widget.TextView;
import android.widget.Toast;

import androidx.annotation.Nullable;
import androidx.lifecycle.Observer;
import androidx.localbroadcastmanager.content.LocalBroadcastManager;
import androidx.viewpager.widget.ViewPager;

import com.sobot.callbase.CallPermissionManager;
import com.sobot.callbase.api.SobotCallBaseUrl;
import com.sobot.callbase.api.utils.CallBaseSharedPreferencesUtils;
import com.sobot.callbase.api.utils.SobotStompEventConstant;
import com.sobot.callbase.constant.SobotCallBaseConstant;
import com.sobot.callbase.constant.SobotCallLiveDataBusKey;
import com.sobot.callbase.dialog.SobotActionItem;
import com.sobot.callbase.model.CallSipModel;
import com.sobot.callbase.model.CallStompMsgModel;
import com.sobot.callbase.model.SobotAgentStatusInfo;
import com.sobot.callbase.model.SobotCallEvent;
import com.sobot.callbase.model.SobotCallStatusEntity;
import com.sobot.callbase.model.SobotEventAgentLogin;
import com.sobot.callbase.model.SobotExplicitRuleEntity;
import com.sobot.callbase.model.SobotExtensionEntity;
import com.sobot.callbase.model.SobotLoginStatusEntity;
import com.sobot.callbase.model.SobotOutboundRoutesEntity;
import com.sobot.callbase.stomp.SobotStompClient;
import com.sobot.callbase.utils.CommonUtils;
import com.sobot.callbase.websocket.util.PermissionUtil;
import com.sobot.callbase.widget.floatwindow.FloatingWindowPermissionUtil;
import com.sobot.callbase.widget.floatwindow.IFloatWindow;
import com.sobot.callbase.widget.floatwindow.MoveType;
import com.sobot.callbase.widget.floatwindow.Screen;
import com.sobot.callbase.widget.floatwindow.SobotFloatWindow;
import com.sobot.callbase.widget.tab.SobotCallSlidingTab;
import com.sobot.callsdk.R;
import com.sobot.callsdk.SobotCallOpenApi;
import com.sobot.callsdk.ZCSobotCallApi;
import com.sobot.callsdk.dialog.OutboundRulesPopDialog;
import com.sobot.callsdk.fargment.SobotBaseFragment;
import com.sobot.callsdk.listener.SobotPhoneStatusListener;
import com.sobot.callsdk.listener.SobotRegistrationListener;
import com.sobot.callsdk.service.SobotJanusService;
import com.sobot.callsdk.sip.SobotSipUtils;
import com.sobot.callsdk.utils.CallSharedPreferencesUtils;
import com.sobot.callsdk.utils.CallStatusUtils;
import com.sobot.callsdk.utils.SobotCallApiUtils;
import com.sobot.callsdk.utils.SobotCallConstant;
import com.sobot.callsdk.v6.activity.CallNumberActivity;
import com.sobot.callsdk.v6.activity.CallStatusActivity;
import com.sobot.callsdk.v6.activity.SignInActivity;
import com.sobot.callsdk.v6.activity.SignInInfoActivity;
import com.sobot.callsdk.v6.constant.SobotCallLiveDataBusV6Key;
import com.sobot.callsdk.v6.dialog.SobotTitileMoreMenuV6;
import com.sobot.callsdk.widget.SobotViewPagerAdapter;
import com.sobot.common.login.SobotLoginTools;
import com.sobot.common.login.callback.SobotResultBlock;
import com.sobot.common.login.callback.SobotResultCode;
import com.sobot.common.login.model.SobotServiceInfoModel;
import com.sobot.common.login.permission.SobotPermissionManager;
import com.sobot.common.utils.SobotGlobalContext;
import com.sobot.common.utils.SobotResourceUtils;
import com.sobot.gson.SobotGsonUtil;
import com.sobot.network.http.callback.SobotResultCallBack;
import com.sobot.utils.SobotLogUtils;
import com.sobot.utils.SobotStringUtils;
import com.sobot.widget.livedatabus.SobotLiveEventBus;
import com.sobot.widget.ui.permission.SobotPermissionListenerImpl;
import com.sobot.widget.ui.permission.SobotPermissionTipDialog;
import com.sobot.widget.ui.toast.SobotToastUtil;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.List;
import java.util.Map;

import io.reactivex.functions.Consumer;
import io.reactivex.plugins.RxJavaPlugins;

/**
 * v6 呼叫中心首页
 */
public class SobotCallV6Fragment extends SobotBaseFragment implements View.OnClickListener {

    private static final String TAG = "SobotCallV6Fragment";
    //title部分
    private TextView loginMenu;//登录按钮
    private TextView statusMenu;//状态按钮
    private TextView titleMenu;//未登录显示头部标题
    private LinearLayout ll_logined;//登录后如果有切换外显号权限,则显示,否则只显示标题
    private TextView tv_waixian;//登录后外显规则
    private TextView tv_mobile;//登录后手机号码
    private TextView moreMenu;//登录详情
    private TextView callNotifyTip;//未登录提示

    //打开拨号盘按钮
    private LinearLayout ll_open_keyword;

    //登录方式
    private int startupMode = 0;
    //左上角弹窗展示数据 在线座席状态
    private List<SobotActionItem> lineStatusActionItems;
    private PopupWindow popupWindow;
    private SobotCallSlidingTab sobot_call_tab;
    private SobotViewPagerAdapter adapter;
    private CallHistoryV6Fragment historyV6Fragment;
    private CallTaskListV6Fragment taskListV6Fragment;
    private ViewPager vp_call_viewpager;

    //座席信息
    private SobotServiceInfoModel serviceVo;

    // 座席当前状态
    private String call_loingStatus = CallStatusUtils.V6_OFFLINE;

    private String nowStatus;
    private String callModel;

    //本地广播数据类型实例。
    private LocalBroadcastManager localBroadcastManager;
    private LocalReceiver localReceiver;
    private NetWorkChangeReceiver receiverNet;

    //收到 网络变化广播connectivity_action的次数，0的时候不重启janus websocket 的连接
    public int connectivity_action_count = 0;
    private boolean isRequestReleaseBlueGreen, isCalling;//isRequestReleaseBlueGreen:是否需要切换路由，isCalling：是否正在通话中
    //外呼规则
    private SobotOutboundRoutesEntity outboundRoutes;
    private int arrangeDuration;//通话整理中 倒计时
    private int wrapUpDuration;//通话整理中 时长
    private Handler mHandler;

    private Observer<CallStompMsgModel> stompMsgObserver;//stomp 消息事件
    private Observer changeRulesObserver;//切换外显规则
    private Observer woReplyCallObserver;//工单回复 电话回复 打电话


    public SobotCallV6Fragment() {
    }

    /**
     * @param startupMode 启动方式: 8888 activity启动，其他fragment启动
     * @return
     */
    public static SobotCallV6Fragment newInstance(int startupMode) {
        SobotCallV6Fragment fragment = new SobotCallV6Fragment();
        Bundle bundle = new Bundle();
        bundle.putInt("StartupMode", startupMode);
        fragment.setArguments(bundle);
        return fragment;
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        if (getArguments() != null) {
            startupMode = getArguments().getInt("StartupMode", 0);
        }
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        View view = inflater.inflate(R.layout.sobot_fragment_v6_call_main, container, false);
        initView(view);
        return view;
    }

    private void initBrocastReceiver() {
        if (localReceiver == null) {
            localReceiver = new LocalReceiver();
        }
        localBroadcastManager = LocalBroadcastManager.getInstance(getSobotActivity());
        // 创建过滤器，并指定action，使之用于接收同action的广播
        IntentFilter localFilter = new IntentFilter();
        localFilter.addAction(SobotCallConstant.SOBOT_BROADCAST_SESSION_TIMEOUT);//广播超时
        localFilter.addAction(SobotCallConstant.SOBOT_CALL_CURRENT_VERSION);//切换版本广播
        // 注册广播接收器
        localBroadcastManager.registerReceiver(localReceiver, localFilter);
        IntentFilter filter = new IntentFilter();
        filter.addAction(SobotCallConstant.SOBOT_ACTION_CALL_CHANGE_VERSION); // 呼叫版本是否更改
        // 注册广播接收器
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
            getSobotActivity().registerReceiver(receiver, filter, Context.RECEIVER_NOT_EXPORTED);
        } else {
            getSobotActivity().registerReceiver(receiver, filter);
        }
        if (receiverNet == null) {
            receiverNet = new NetWorkChangeReceiver();
        }
        IntentFilter netFilter = new IntentFilter();
        netFilter.addAction(ConnectivityManager.CONNECTIVITY_ACTION);
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
            getSobotActivity().registerReceiver(receiverNet, netFilter, Context.RECEIVER_EXPORTED);
        } else {
            getSobotActivity().registerReceiver(receiverNet, netFilter);
        }
        changeRulesObserver = new Observer<Boolean>() {
            @Override
            public void onChanged(@Nullable Boolean aBoolean) {

                getOutboudRoutesRules(false);
            }
        };
        SobotLiveEventBus.get(SobotCallLiveDataBusV6Key.SOBOT_CALL_CHANGE_RULES).observeForever(changeRulesObserver);
        //收到 stomp 消息
        stompMsgObserver = new Observer<CallStompMsgModel>() {
            @Override
            public void onChanged(CallStompMsgModel stompMsgModel) {
                if (stompMsgModel == null) {
                    return;
                }
                SobotLogUtils.i(" SobotCallV6Fragment 收到stomp 消息:" + SobotStringUtils.checkStringIsNull(stompMsgModel.getStompMessageID()));
                String stompMessageID = SobotStringUtils.checkStringIsNull(stompMsgModel.getStompMessageID());
                String stompMessageContent = SobotStringUtils.checkStringIsNull(stompMsgModel.getStompMessageContent());
                String agentStatusInfoStr = SobotStringUtils.checkStringIsNull(stompMsgModel.getAgentStatusInfo());//坐席信息
                String agentCallStatusInfo = SobotStringUtils.checkStringIsNull(stompMsgModel.getAgentCallStatusInfo());//坐席状态
                //当前连接客户端类型 系统-客服APP-Android端  : SysAppAndroid  ; 系统-客服APP-IOS端 : SysAppIos
                String clientType = SobotStringUtils.checkStringIsNull(stompMsgModel.getClientType());
                String errorMessage = SobotStringUtils.checkStringIsNull(stompMsgModel.getErrorMessage());
                if (!TextUtils.isEmpty(stompMessageContent) && !TextUtils.isEmpty(stompMessageID)) {
                    if (SobotStompEventConstant.EventAgentLogin.equals(stompMessageID)) {
                        isCalling = false;
                        //请求外显规则
                        getOutboudRoutesRules(false);
                        //座席签入
                        SobotEventAgentLogin agentStatus = SobotGsonUtil.jsonToBean(stompMessageContent, SobotEventAgentLogin.class);
                        if (agentStatus != null) {
                            if (agentStatus.getAgentState() == 1) {
                                //空闲
                                CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallConstant.callLoginStatus, CallStatusUtils.V6_FREE);
                                getSobotActivity().runOnUiThread(new Runnable() {
                                    @Override
                                    public void run() {
                                        getV6CallSeatLoginStatus();
                                    }
                                });
                            } else if (agentStatus.getAgentState() == 2) {
                                //勿扰
                                CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallConstant.callLoginStatus, CallStatusUtils.V6_DO_NOT_DISTURB);
                                getSobotActivity().runOnUiThread(new Runnable() {
                                    @Override
                                    public void run() {
                                        getV6CallSeatLoginStatus();
                                    }
                                });
                            }
                        }
                        updateTitle(true);
                        //显示键盘启动按钮
                        ll_open_keyword.setVisibility(View.VISIBLE);
                    } else if (SobotStompEventConstant.EventAgentLogout.equals(stompMessageID) || SobotStompEventConstant.EventAgentConnectionChanged.equals(stompMessageID)) {
                        isCalling = false;
                        //座席签出     ||  座席在其它端登录，被挤下线的事件
                        SobotLogUtils.i("sobotallV6Fragment 座席下线");
                        CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallConstant.callLoginStatus, CallStatusUtils.V6_OFFLINE);
                        SobotStompClient.getInstance(getSobotActivity()).disconnect();
                        getSobotActivity().runOnUiThread(new Runnable() {
                            @Override
                            public void run() {
//                                getV6CallSeatLoginStatus();
                                updateTitle(false);
                                //隐藏键盘启动按钮
                                ll_open_keyword.setVisibility(View.GONE);
                            }
                        });
                        int callWay = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.SP_KEY_CALL_MODEL_TYPE_V6, SobotCallConstant.CALL_MODEL_PHONE);
                        if (callWay == SobotCallConstant.CALL_MODEL_SIP) {
                            //如果是sip 方式签出
                            SobotRegistrationListener.getInstance().setRegistrationOk(false);
                            if (serviceVo != null) {
                                SobotSipUtils.logoutUser(true);
                                SobotSipUtils.stopService(true, getSobotActivity());
                            }
                        }
                        if (serviceVo != null) {
                            SobotSipUtils.stopService(true, getSobotActivity());
                        }
                        if (SobotStompEventConstant.EventAgentConnectionChanged.equals(stompMessageID)) {
                            Intent intent1 = new Intent();
                            intent1.setAction(SobotCallConstant.SOBOT_ACTION_CALL_EXIT_LOGIN);//被挤下线事件
                            getSobotActivity().sendBroadcast(intent1);
                            exitPages();
                        }
                        SobotCallEvent event = SobotGsonUtil.jsonToBean(stompMessageContent, SobotCallEvent.class);
                        if (event != null) {
                            Map<String, String> attachedDataMap = event.getAttachedData();
                            if (attachedDataMap != null) {
                                for (Map.Entry<String, String> entry : attachedDataMap.entrySet()) {
                                    if ("reasonCode".equals(entry.getKey())) {
                                        String reasonCode = entry.getValue();
                                        if (SobotStringUtils.checkStringIsNull(reasonCode).equals("97")) {
                                            SobotToastUtil.showCustomToast(getSobotActivity(), getResources().getString(R.string.call_str_update_set_login));
                                        }
                                    }
                                }
                            }
                        }
                    } else if (SobotStompEventConstant.EventTierRemoved.equals(stompMessageID)) {
                        //从技能组移除
                        SobotEventAgentLogin agentStatus = SobotGsonUtil.jsonToBean(stompMessageContent, SobotEventAgentLogin.class);
                        String group = agentStatus.getAttachedData().get("queueName");
                        String tip = String.format(getSobotActivity().getResources().getString(R.string.call_event_tier_removed), com.sobot.callbase.utils.SobotStringUtils.checkStringIsNull(group));
                        Toast.makeText(getContext(), tip, Toast.LENGTH_LONG).show();
                    } else if (SobotStompEventConstant.EventTierAdded.equals(stompMessageID)) {
                        //添加到技能组
                        SobotEventAgentLogin agentStatus = SobotGsonUtil.jsonToBean(stompMessageContent, SobotEventAgentLogin.class);
                        String group = agentStatus.getAttachedData().get("queueName");
                        String tip = String.format(getSobotActivity().getResources().getString(R.string.call_event_tier_add), com.sobot.callbase.utils.SobotStringUtils.checkStringIsNull(group));
                        Toast.makeText(getContext(), tip, Toast.LENGTH_LONG).show();
                    } else if (SobotStompEventConstant.EventAgentReady.equals(stompMessageID)) {
                        isCalling = false;
                        //空闲 销毁通话状态浮层
                        if (SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT) != null) {
                            SobotFloatWindow.destroy(SobotCallConstant.CALL_STATUS_FLOAT);
                        }
                        //座席置闲 sip 登录
                        CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallConstant.callLoginStatus, CallStatusUtils.V6_FREE);
                        getV6CallSeatLoginStatus();
                        //显示键盘启动按钮
                        ll_open_keyword.setVisibility(View.VISIBLE);
                    } else if (SobotStompEventConstant.EventAgentNotReady.equals(stompMessageID)) {
                        isCalling = false;
                        //座席置忙
                        SobotEventAgentLogin agentStatus = SobotGsonUtil.jsonToBean(stompMessageContent, SobotEventAgentLogin.class);
                        if (agentStatus != null) {
                            CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallConstant.callLoginStatus, agentStatus.getReasonCode() + "");
                            getSobotActivity().runOnUiThread(new Runnable() {
                                @Override
                                public void run() {
                                    getV6CallSeatLoginStatus();
                                }
                            });
                        }
                    } else if (SobotStompEventConstant.EventRinging.equals(stompMessageID) || SobotStompEventConstant.EventDialing.equals(stompMessageID) || SobotStompEventConstant.EventEstablished.equals(stompMessageID)) {
                        if (SobotStompEventConstant.EventDialing.equals(stompMessageID)) {
                            if ((tempCurrentTime - System.currentTimeMillis()) > 1000) {
                                //来电了 或者通话中
                                isCalling = true;
                                //隐藏拨号按钮
                                ll_open_keyword.setVisibility(View.GONE);
                            }
                        } else {
                            //来电了 或者通话中
                            isCalling = true;
                            //隐藏拨号按钮
                            ll_open_keyword.setVisibility(View.GONE);
                        }

                    } else if (SobotStompEventConstant.EventCallDeleted.equals(stompMessageID)) {
                        tempCurrentTime = System.currentTimeMillis();
                        isCalling = false;
                        //会话销毁了
                        ll_open_keyword.setVisibility(View.GONE);
                        if (SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT) != null) {
                            if (!SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT).isShowing()) {
                                //显示拨号按钮
                                ll_open_keyword.setVisibility(View.VISIBLE);
                            }
                        } else {
                            //显示拨号按钮
                            ll_open_keyword.setVisibility(View.VISIBLE);
                        }
                    } else if (SobotStompEventConstant.EventReleased.equals(stompMessageID)) {
                        isCalling = false;
                        //显示键盘启动按钮
                        SobotCallEvent eventAgent = SobotGsonUtil.jsonToBean(stompMessageContent, SobotCallEvent.class);
                        if (eventAgent != null) {
                            wrapUpDuration = eventAgent.getWrapUpDuration();
                            arrangeDuration = eventAgent.getWrapUpDuration();
                            if (eventAgent.getWrapUpDuration() > 0) {
                                //拨号浮层逻辑 1、隐藏拨号浮层按钮的情况 EventDialing EventRinging EventEstablished ；2、显示拨号浮层按钮的情况 EventAgentReady EventAgentLogin 3、收到EventReleased时WrapUpDuration>0 隐藏 =0 显示
                                ll_open_keyword.setVisibility(View.GONE);
                            } else {
                                ll_open_keyword.setVisibility(View.VISIBLE);
                                //没打通 销毁通话状态浮层
                                if (SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT) != null) {
                                    SobotFloatWindow.destroy(SobotCallConstant.CALL_STATUS_FLOAT);
                                }
                            }
                        }
                        if (historyV6Fragment != null) {
                            new Handler().postDelayed(new Runnable() {
                                @Override
                                public void run() {
                                    //通话结束后，刷新一次通话记录
                                    historyV6Fragment.getCallRecordList(1);
                                }
                            }, 2000);
                        }
                    } else if (SobotStompEventConstant.EventWebSocketSession.equals(stompMessageID)) {
                        //恢复座席
                        if (!TextUtils.isEmpty(agentStatusInfoStr)) {
                            SobotAgentStatusInfo agentStatusInfo = SobotGsonUtil.jsonToBean(agentStatusInfoStr, SobotAgentStatusInfo.class);
                            if (agentStatusInfo != null && SobotStompEventConstant.clientType.equals(clientType)) {
                                if (agentStatusInfo != null) {
                                    String statusId;
                                    if (!SobotStringUtils.isEmpty(agentStatusInfo.getReasonCode()) && !"0".equals(agentStatusInfo.getReasonCode())) {
                                        //0-非忙碌；2-勿扰；4-话后小结；11-小休；12-培训；13-会议；14-用餐；15-活动；98-系统置忙；99-班长置忙
                                        statusId = agentStatusInfo.getReasonCode();
                                    } else {
                                        statusId = agentStatusInfo.getAgentState();
                                    }
                                    if (!SobotStringUtils.isEmpty(statusId)) {
                                        if (CallStatusUtils.V6_FINISHING.equals(statusId)) {
                                            //会话小结
                                            SobotCallStatusEntity callStatusEntity = SobotGsonUtil.jsonToBean(agentCallStatusInfo, SobotCallStatusEntity.class);
                                            if (callStatusEntity != null) {
                                                if (callStatusEntity.getWrapUpDuration() > 0 && callStatusEntity.getAcwRemainTime() > 0) {
                                                    //弹出会话小结浮层
                                                    wrapUpDuration = callStatusEntity.getWrapUpDuration();
                                                    arrangeDuration = callStatusEntity.getAcwRemainTime();
                                                    showWrapUp();
                                                }
                                            }
                                        } else {
                                            //恢复坐席显示拨号浮层
                                            ll_open_keyword.setVisibility(View.VISIBLE);
                                        }
                                    }

                                    getOutboudRoutesRules(false);

                                    String statusName = SobotCallApiUtils.getLoginStatusV6(getSobotActivity(), statusId);
                                    //同端才处理
                                    if ("webrtc".equals(agentStatusInfo.getPhoneType())) {
                                        //sip方式
                                        CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallConstant.SP_KEY_CALL_MODEL_TYPE_V6, SobotCallConstant.CALL_MODEL_SIP);
                                        //登陆注册sip并修改状态
                                        String agentNumber = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallBaseConstant.SipModel.SIP_NUMBER);
                                        String agentPwd = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallBaseConstant.SipModel.SIP_PWD);
                                        String serverIP = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallBaseConstant.SipModel.SIP_IP);
                                        if (!SobotStringUtils.isEmpty(agentNumber) && !SobotStringUtils.isEmpty(agentPwd) && !SobotStringUtils.isEmpty(serverIP)) {
                                            CallSipModel sipModel = new CallSipModel();
                                            sipModel.setAgentNumber(agentNumber);
                                            sipModel.setAgentPwd(agentPwd);
                                            sipModel.setServerIP(serverIP);
                                            CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallConstant.callLoginStatus, statusId);
                                            if (!SobotStringUtils.isEmpty(statusId)) {
                                                //话机 需要重新注册
                                                registerSipLongin(sipModel, statusId, statusName);
                                            }
                                            getSobotActivity().runOnUiThread(new Runnable() {
                                                @Override
                                                public void run() {
                                                    getV6CallSeatLoginStatus();
                                                }
                                            });
                                        } else {
                                            //获取坐席信息，然后重连
                                            String finalStatusId = statusId;
                                            zhiChiApi.getExtensionList(this, serviceVo.getServiceId(), "1", new SobotResultCallBack<List<SobotExtensionEntity>>() {
                                                @Override
                                                public void onSuccess(List<SobotExtensionEntity> extensionModelList) {
                                                    if (extensionModelList != null) {
                                                        for (int i = 0; i < extensionModelList.size(); i++) {
                                                            SobotExtensionEntity extensionEntity = extensionModelList.get(i);
                                                            if (extensionEntity.getBindStatus() == 1) {
                                                                CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallBaseConstant.SipModel.SIP_NUMBER, extensionEntity.getExt());
                                                                CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallBaseConstant.SipModel.SIP_PWD, extensionEntity.getPassword());//sip账号密码先写死
                                                                CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallBaseConstant.SipModel.SIP_IP, extensionEntity.getDomain());
                                                                CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallBaseConstant.SipModel.SIP_SCHEME, SobotCallConstant.ServerScheme.FS);
                                                                CallSipModel sipModel = new CallSipModel();
                                                                sipModel.setAgentNumber(extensionEntity.getExt());
                                                                sipModel.setAgentPwd(extensionEntity.getPassword());
                                                                sipModel.setServerIP(extensionEntity.getDomain());
                                                                CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallConstant.callLoginStatus, finalStatusId);
                                                                if (!SobotStringUtils.isEmpty(finalStatusId)) {
//                                                              //话机 需要重新注册
                                                                    registerSipLongin(sipModel, finalStatusId, statusName);
                                                                }
                                                                getSobotActivity().runOnUiThread(new Runnable() {
                                                                    @Override
                                                                    public void run() {
                                                                        getV6CallSeatLoginStatus();
                                                                    }
                                                                });
                                                                break;
                                                            }
                                                        }
                                                    }
                                                }

                                                @Override
                                                public void onFailure(Exception e, String des) {

                                                }
                                            });
                                        }
                                    }
                                    if ("pstn".equals(agentStatusInfo.getPhoneType())) {
                                        //手机方式
                                        CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallConstant.SP_KEY_CALL_MODEL_TYPE_V6, SobotCallConstant.CALL_MODEL_PHONE);
                                        CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallConstant.callLoginStatus, statusId);
                                        getSobotActivity().runOnUiThread(new Runnable() {
                                            @Override
                                            public void run() {
                                                getV6CallSeatLoginStatus();
                                            }
                                        });
                                        Intent baresipServiceIntent = new Intent(Intent.ACTION_MAIN);
                                        baresipServiceIntent.setClass(getSobotActivity(), SobotJanusService.class);
                                        baresipServiceIntent.putExtra("callType", 1);//手机号方式
                                        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
                                            getSobotActivity().startForegroundService(baresipServiceIntent);
                                        } else {
                                            getSobotActivity().startService(baresipServiceIntent);
                                        }
                                    }
                                    //检测悬浮窗权限
                                    if (!FloatingWindowPermissionUtil.hasSuspendedWindowPermission(getSobotActivity())) {
                                        SobotPermissionTipDialog dialog = new SobotPermissionTipDialog(getSobotActivity(), getString(R.string.call_str_floating_permissions), getString(R.string.call_str_floating_tip), new SobotPermissionTipDialog.ClickViewListener() {
                                            @Override
                                            public void clickRightView(Context context, SobotPermissionTipDialog dialog) {
                                                dialog.dismiss();
                                                Intent intent = new Intent(Settings.ACTION_MANAGE_OVERLAY_PERMISSION);
                                                intent.setData(Uri.parse("package:" + getSobotActivity().getPackageName()));
                                                startActivityForResult(intent, SobotCallConstant.SOBOT_REQUEST_FLOATING_WINDOW_CODE);
                                            }

                                            @Override
                                            public void clickLeftView(Context context, SobotPermissionTipDialog dialog) {
                                                dialog.dismiss();
                                            }
                                        });
                                        dialog.show();
                                    }
                                }
                            }
                        } else {
                            //座席信息为空，当座席离线处理
                            call_loingStatus = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.callLoginStatus, CallStatusUtils.V6_OFFLINE);
                            if (!CallStatusUtils.V6_OFFLINE.equals(call_loingStatus)) {
                                //当前座席不是离线
                                int callWay = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.SP_KEY_CALL_MODEL_TYPE_V6, SobotCallConstant.CALL_MODEL_PHONE);
                                if (callWay == SobotCallConstant.CALL_MODEL_SIP) {
                                    //如果是sip 方式签出
                                    SobotRegistrationListener.getInstance().setRegistrationOk(false);
                                    if (serviceVo != null) {
                                        SobotSipUtils.logoutUser(true);
                                        SobotSipUtils.stopService(true, getSobotActivity());
                                    }
                                }
                                if (serviceVo != null) {
                                    SobotSipUtils.stopService(true, getSobotActivity());
                                }
                            }

                            CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallConstant.callLoginStatus, CallStatusUtils.V6_OFFLINE);
                            getSobotActivity().runOnUiThread(new Runnable() {
                                @Override
                                public void run() {
//                                getV6CallSeatLoginStatus();
                                    updateTitle(false);
                                    //隐藏键盘启动按钮
                                    ll_open_keyword.setVisibility(View.GONE);
                                }
                            });
                        }
//
                        if (SobotStringUtils.isEmpty(agentCallStatusInfo)) {
                            //没有话务信息，相当于通话已经结束
                            isCalling = false;
                            if (SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT) != null) {
                                SobotFloatWindow.destroy(SobotCallConstant.CALL_STATUS_FLOAT);
                            }
                        }
                    } else if (SobotStompEventConstant.RequestReleaseBlueGreen.equals(stompMessageID)) {
//                        收到 webrtc 的 RequestReleaseBlueGreen 消息
//                        如果没有通话，立即重连 webrtc 和 janus
//                        如果有通话，等通话结束后，立即重连 webrtc 和 janus
                        // 需要执行切换
                        isRequestReleaseBlueGreen = true;
                        doRequestReleaseBlueGreen();
                    } else if (stompMessageID.toLowerCase().contains("error")) {
                        //返回异常事件
                        SobotEventAgentLogin agentStatus = SobotGsonUtil.jsonToBean(stompMessageContent, SobotEventAgentLogin.class);
                        if (agentStatus != null) {
                            String msg = "";
                            try {
                                String idN = "call_retcode_" + agentStatus.getRetCode();
                                int id = SobotResourceUtils.getResStrId(getSobotActivity(), idN);
                                SobotLogUtils.d(idN + "===========id====" + id);
                                msg = getResources().getString(id);
                            } catch (Resources.NotFoundException e) {
                                e.printStackTrace();
                            }
                            if (SobotStringUtils.isEmpty(msg)) {
                                if (!SobotStringUtils.isEmpty(agentStatus.getRetMsg())) {
                                    msg = agentStatus.getRetMsg();
                                } else if (!SobotStringUtils.isEmpty(agentStatus.getErrorMessage())) {
                                    msg = agentStatus.getErrorMessage();
                                }
                            }
                            if (!SobotStringUtils.isEmpty(msg)) {
                                if (msg.contains("{0}") && (!TextUtils.isEmpty(agentStatus.getOtherDN()))) {
                                    msg = msg.replace("{0}", agentStatus.getOtherDN());
                                }
                                SobotToastUtil.showToast(getSobotActivity(), msg);
                            }
                        }
                    }
                }
            }
        };
        SobotLiveEventBus.get(SobotCallLiveDataBusKey.RECEIVE_STOMP_MSG, CallStompMsgModel.class)
                .observeForever(stompMsgObserver);
        //工单回复界面 电话回复
        woReplyCallObserver = new Observer<Map<String, String>>() {
            @Override
            public void onChanged(@Nullable Map<String, String> params) {
                if (params != null) {
                    String privacyNumber = "";
                    String phoneNumber = "";
                    String sourceType = "";
                    String sourceId = "";
                    String customerId = "";

                    if (params.containsKey("privacyNumber")) {
                        privacyNumber = params.get("privacyNumber");
                    }
                    if (params.containsKey("phoneNumber")) {
                        phoneNumber = params.get("phoneNumber");
                    }
                    if (params.containsKey("sourceType")) {
                        sourceType = params.get("sourceType");
                    }
                    if (params.containsKey("sourceId")) {
                        sourceId = params.get("sourceId");
                    }
                    if (params.containsKey("customerId")) {
                        customerId = params.get("customerId");
                    }
                    callNumber(privacyNumber, phoneNumber, sourceType, sourceId, customerId);
                }
            }
        };
        SobotLiveEventBus.get(SobotCallLiveDataBusKey.SOBOT_LIVEBUS_WO_CALL_PHONE).observeForever(woReplyCallObserver);
    }

    /**
     * 开始外呼，跳转到通话界面
     *
     * @param privacyNumber 加密手机号
     * @param screenNum     屏显手机号
     */
    private void callNumber(String privacyNumber, String screenNum, String sourceType, String sourceId, String customerId) {
        if (TextUtils.isEmpty(screenNum) || screenNum.trim().length() > 16 || screenNum.trim().length() < 3) {
            SobotToastUtil.showCustomToast(getSobotActivity(), getString(R.string.call_login_phone_length_hint));
            return;
        }
        //判断是否登录
        String call_loingStatus = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.callLoginStatus, CallStatusUtils.V6_OFFLINE);
        if (call_loingStatus.equals(CallStatusUtils.V6_FINISHING)) {
            //判断是否正在整理中
            SobotToastUtil.showToast(getSobotActivity(), getResources().getString(R.string.sobot_error_switch_status));
        } else if (call_loingStatus.equals(CallStatusUtils.V6_SYSYTEM_BUSY)) {
            SobotToastUtil.showToast(getSobotActivity(), getResources().getString(R.string.call_str_system_Lock_toast));
        } else if (call_loingStatus.equals(CallStatusUtils.V6_OFFLINE)) {
            //跳转到签入页面
            startActivity(new Intent(getContext(), SignInActivity.class));
        } else if (SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT) != null && SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT).isShowing()) {
            //通话没结束，不能拨号
            SobotToastUtil.showCustomToast(getSobotActivity(), getString(R.string.call_retcode_330035));
        } else {
            if (!TextUtils.isEmpty(privacyNumber) || !TextUtils.isEmpty(screenNum)) {
                Intent intent = CallStatusActivity.initIntent(getSobotActivity(), privacyNumber, screenNum, sourceType, sourceId, customerId);
                intent.setFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP | Intent.FLAG_ACTIVITY_CLEAR_TOP |
                        Intent.FLAG_ACTIVITY_NEW_TASK);
                this.startActivity(intent);
                SobotLiveEventBus.get(SobotCallLiveDataBusKey.SOBOT_LIVEBUS_WO_CALL_START).post(true);
            } else {
                SobotToastUtil.showCustomToast(getSobotActivity(), getResources().getString(R.string.sobot_please_input_phone_number));
            }
        }
    }

    @Override
    public void onDestroyView() {
        if (woReplyCallObserver != null) {
            SobotLiveEventBus.get(SobotCallLiveDataBusKey.SOBOT_LIVEBUS_WO_CALL_PHONE).removeObserver(woReplyCallObserver);
        }
        if (stompMsgObserver != null) {
            SobotLiveEventBus.get(SobotCallLiveDataBusKey.RECEIVE_STOMP_MSG, CallStompMsgModel.class).removeObserver(stompMsgObserver);
        }
        if (changeRulesObserver != null) {
            SobotLiveEventBus.get(SobotCallLiveDataBusV6Key.SOBOT_CALL_CHANGE_RULES).removeObserver(changeRulesObserver);
        }
        try {
            if (receiverNet != null) {
                getSobotActivity().unregisterReceiver(receiverNet);
                receiverNet = null;
            }
        } catch (Exception e) {
        }
        try {
            // 取消广播接受者
            if (localBroadcastManager != null && localReceiver != null) {
                localBroadcastManager.unregisterReceiver(localReceiver);
            }
            if (receiver != null) {
                getSobotActivity().unregisterReceiver(receiver);
                receiver = null;
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        super.onDestroyView();
    }

    //更新头部信息
    private void updateTitle(boolean isSigned) {
        if (isSigned) {
            //已签入
            ll_logined.setVisibility(View.VISIBLE);
            titleMenu.setVisibility(View.GONE);
            statusMenu.setVisibility(View.VISIBLE);
            moreMenu.setVisibility(View.VISIBLE);

            loginMenu.setVisibility(View.GONE);
            callNotifyTip.setVisibility(View.GONE);
        } else {
            //离线
            ll_logined.setVisibility(View.GONE);
            titleMenu.setVisibility(View.VISIBLE);
            statusMenu.setVisibility(View.GONE);
            moreMenu.setVisibility(View.GONE);
            if (serviceVo != null && CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_DHT)) {
                loginMenu.setVisibility(View.VISIBLE);
                callNotifyTip.setText(getContext().getResources().getString(R.string.sobot_call_not_login_tip));
                callNotifyTip.setVisibility(View.VISIBLE);
                if (SobotPermissionManager.SUPER_ADMINISTRATORS == serviceVo.getCusRoleId()) {
                    //超管
                    loginMenu.setVisibility(View.GONE);
                    callNotifyTip.setVisibility(View.GONE);
                }
            } else {
                loginMenu.setVisibility(View.GONE);
                callNotifyTip.setVisibility(View.GONE);
            }
        }
    }

    private long tempCurrentTime;

    class LocalReceiver extends BroadcastReceiver {
        @Override
        public void onReceive(Context context, Intent intent) {
            SobotLogUtils.i("广播是  SobotCallV6Fragment:" + intent.getAction());
            if (SobotCallConstant.SOBOT_BROADCAST_SESSION_TIMEOUT.equals(intent.getAction())) {
                int callWay = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.SP_KEY_CALL_MODEL_TYPE_V6, SobotCallConstant.CALL_MODEL_PHONE);
                if (callWay == SobotCallConstant.CALL_MODEL_SIP) {
                    SobotStompClient.getInstance(getSobotActivity()).disconnect();
                    //如果是sip 方式签出
                    SobotSipUtils.logoutUser(true);
                    SobotSipUtils.stopService(true, getSobotActivity());
                }
                CallSharedPreferencesUtils.getInstance(getSobotActivity()).put(SobotCallConstant.callLoginStatus, CallStatusUtils.V6_OFFLINE);
                getSobotActivity().runOnUiThread(new Runnable() {
                    @Override
                    public void run() {
                        getV6CallSeatLoginStatus();
                    }
                });
                //弹出重新登录框
                Intent intent2 = new Intent();
                String httpinfo = intent.getStringExtra("httpinfo");
                intent2.putExtra("httpinfo", httpinfo);
                intent2.setAction("sobot_broadcast_session_timeout");
                getSobotActivity().sendBroadcast(intent2);
                exitPages();
            }
        }
    }

    //上次token失效时间，两次间隔时间小于2s 不处理
    private long lastSessionTimeoutTime;

    //如果是SDK token 无效或者被挤下线 直接关闭所有sobot界面
    private void exitPages() {
        int fromType = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.SOBOT_CALL_KEY_LOGIN_FROM, 0);
        if (fromType == 0) {
            long intervalTime = System.currentTimeMillis() - lastSessionTimeoutTime;
//                    SobotLogUtils.i(System.currentTimeMillis() + "======" + lastSessionTimeoutTime + "-----" + intervalTime);
            if (intervalTime > 2000) {
                lastSessionTimeoutTime = System.currentTimeMillis();
                //如果是sdk 登录 清理登录信息，关闭所有界面
                SobotLoginTools.getInstance().clearLoginInfo();
                SobotGlobalContext.getInstance().finishAllActivity();
            }
        }
    }

    private BroadcastReceiver receiver = new BroadcastReceiver() {
        @Override
        public void onReceive(Context context, Intent intent) {
            serviceVo = SobotLoginTools.getInstance().getServiceInfo();
            SobotLogUtils.d("=====SOBOT_CALL_CURRENT_VERSION==" + ZCSobotCallApi.getCallVersion(context, serviceVo.getServiceId()));
            if (intent.getAction().equals(SobotCallConstant.SOBOT_ACTION_CALL_CHANGE_VERSION)) {
                if (ZCSobotCallApi.getCallVersion(context, serviceVo.getServiceId()) == 6) {
                    //v6 获取到当前公司设置的呼叫客服状态列表
                    SobotCallApiUtils.getLoginStatusV6(zhiChiApi, this, context, null);
                } else {
                    //获取到当前公司设置的呼叫客服状态列表v1
                    SobotCallApiUtils.getCallServiceStatusList(zhiChiApi, this, context, null);
                }
            }
        }
    };

    @Override
    public void onResume() {
        super.onResume();
        serviceVo = SobotLoginTools.getInstance().getServiceInfo();
        stompConnect();
        try {
            getV6CallSeatLoginStatus();
            RxJavaPlugins.setErrorHandler(new Consumer<Throwable>() {
                @Override
                public void accept(Throwable throwable) throws Exception {
                    // 这里打印log trace也要注意，太频繁会损耗性能，
                    // 不能过分依靠这个全局的异常处理，
                    // 尽量在自己的业务代码逻辑中处理完善
                    Log.d(TAG, "RxJava error handler accept: " + Log.getStackTraceString(throwable));
                }
            });
        } catch (Exception e) {
        }
        if (serviceVo != null && SobotStompClient.getInstance(getSobotActivity()).isConnected()) {
            call_loingStatus = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.callLoginStatus, CallStatusUtils.V6_OFFLINE);
            if (!CallStatusUtils.V6_OFFLINE.equals(call_loingStatus)) {
                //显示键盘启动按钮
                ll_open_keyword.setVisibility(View.VISIBLE);
            }
        }
    }

    private void initView(View view) {
        isCalling = false;
        mHandler = new Handler();
        loginMenu = view.findViewById(R.id.sobot_call_title_login);
        titleMenu = view.findViewById(R.id.sobot_text_title);
        ll_logined = view.findViewById(R.id.ll_logined);
        tv_mobile = view.findViewById(R.id.tv_mobile);
        tv_waixian = view.findViewById(R.id.tv_waixian);
        sobot_call_tab = view.findViewById(R.id.call_fragment_tab);
        vp_call_viewpager = view.findViewById(R.id.vp_call_viewpager);
        ll_open_keyword = view.findViewById(R.id.ll_open_keyword);
        ll_open_keyword.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                //跳转到拨号界面
                Intent keywordIntent = new Intent(getSobotActivity(), CallNumberActivity.class);
                startActivity(keywordIntent);
            }
        });

        serviceVo = SobotLoginTools.getInstance().getServiceInfo();
        initBrocastReceiver();
        lineStatusActionItems = new ArrayList<>();
        statusMenu = view.findViewById(R.id.sobot_call_title_status);
        moreMenu = view.findViewById(R.id.sobot_call_title_more);
        callNotifyTip = view.findViewById(R.id.sobot_call_task_notify_tip);


        statusMenu.setOnClickListener(this);
        loginMenu.setOnClickListener(this);
        moreMenu.setOnClickListener(this);
        ll_logined.setOnClickListener(this);

        List<String> titleList = new ArrayList<>();
        if (CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_THJL)) {
            titleList.add(getContext().getResources().getString(R.string.sobot_call_record));
        }
        if (CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_WHRW)) {
            titleList.add(getContext().getResources().getString(R.string.call_out_task));
        }
        String[] titleStr = new String[titleList.size()];
        for (int i = 0; i < titleList.size(); i++) {
            titleStr[i] = titleList.get(i);
        }
        List<SobotBaseFragment> fragments = new ArrayList<>();
        historyV6Fragment = new CallHistoryV6Fragment();
        taskListV6Fragment = new CallTaskListV6Fragment();
        if (CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_THJL) || CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_WHRW)) {
            sobot_call_tab.setVisibility(View.VISIBLE);
        } else {
            sobot_call_tab.setVisibility(View.GONE);
        }
        if (CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_THJL)) {
            fragments.add(historyV6Fragment);
        }
        if (CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_WHRW)) {
            fragments.add(taskListV6Fragment);
        }
        adapter = new SobotViewPagerAdapter(getContext(), getFragmentManager(), titleStr, fragments);
        vp_call_viewpager.setAdapter(adapter);
        sobot_call_tab.setViewPager(vp_call_viewpager);

        call_loingStatus = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.callLoginStatus, CallStatusUtils.V6_OFFLINE);

        if (call_loingStatus.equals(CallStatusUtils.V6_OFFLINE)) {
            //当前状态是离线:未登录
            titleMenu.setVisibility(View.VISIBLE);
            statusMenu.setVisibility(View.GONE);
            ll_logined.setVisibility(View.GONE);
            moreMenu.setVisibility(View.GONE);

            if (serviceVo != null && CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_DHT)) {
                //如果有登录电话条权限
                callNotifyTip.setText(getContext().getResources().getString(R.string.sobot_call_not_login_tip));
                callNotifyTip.setVisibility(View.VISIBLE);
                loginMenu.setVisibility(View.VISIBLE);
                if (SobotPermissionManager.SUPER_ADMINISTRATORS == serviceVo.getCusRoleId()) {
                    //超管
                    callNotifyTip.setVisibility(View.GONE);
                    loginMenu.setVisibility(View.GONE);
                }
            } else {
                loginMenu.setVisibility(View.GONE);
                callNotifyTip.setVisibility(View.GONE);
            }
        } else {
            loginMenu.setVisibility(View.GONE);
            callNotifyTip.setVisibility(View.GONE);
            if (serviceVo != null) {
                titleMenu.setVisibility(View.VISIBLE);
                ll_logined.setVisibility(View.GONE);
                //外显规则权限
                getOutboudRoutesRules(false);
            } else {
                titleMenu.setVisibility(View.GONE);
                ll_logined.setVisibility(View.VISIBLE);
            }

            statusMenu.setVisibility(View.VISIBLE);
            moreMenu.setVisibility(View.VISIBLE);
            //列表view
            new Handler().postDelayed(new Runnable() {
                @Override
                public void run() {
                    stompConnect();
                    getV6CallSeatLoginStatus();
                }
            }, 500);
        }
    }

    @Override
    public void onClick(View v) {
        if (v == statusMenu) {
            //权限判断
            permissionListener = new SobotPermissionListenerImpl() {
                @Override
                public void onPermissionSuccessListener() {
                    onStatusClike();
                }
            };
            //判断是否有权限
            if (checkIsShowPermissionPop(getSobotActivity().getResources().getString(R.string.sobot_microphone), getSobotActivity().getResources().getString(R.string.sobot_microphone_yongtu))) {
                return;
            }
            if (!checkAudioPermission()) {
                return;
            }
            //判断是否有网络
            if (CommonUtils.isNetWorkConnected(getSobotActivity())) {
                onStatusClike();
            } else {
                SobotToastUtil.showToast(getContext(), getContext().getResources().getString(R.string.sobot_call_net_error_string));
            }
        } else if (v == moreMenu) {
            //跳转到个人信息页面
            startActivity(new Intent(getContext(), SignInInfoActivity.class));
        } else if (v == ll_logined) {
            //弹窗,打开切换外显号
            getOutboudRoutesRules(true);

        } else if (v == loginMenu) {
            if (!CommonUtils.isNetWorkConnected(getSobotActivity())) {
                SobotToastUtil.showToast(getContext(), getContext().getResources().getString(R.string.sobot_call_net_error_string));
                return;
            }
            if (!FloatingWindowPermissionUtil.hasSuspendedWindowPermission(getSobotActivity())) {
                SobotPermissionTipDialog dialog = new SobotPermissionTipDialog(getSobotActivity(), getString(R.string.call_str_floating_permissions), getString(R.string.call_str_floating_tip), new SobotPermissionTipDialog.ClickViewListener() {
                    @Override
                    public void clickRightView(Context context, SobotPermissionTipDialog dialog) {
                        dialog.dismiss();
                        Intent intent = new Intent(Settings.ACTION_MANAGE_OVERLAY_PERMISSION);
                        intent.setData(Uri.parse("package:" + getSobotActivity().getPackageName()));
                        startActivityForResult(intent, SobotCallConstant.SOBOT_REQUEST_FLOATING_WINDOW_CODE);
                    }

                    @Override
                    public void clickLeftView(Context context, SobotPermissionTipDialog dialog) {
                        dialog.dismiss();
                    }
                });
                dialog.show();
            } else {
                //跳转到签入页面
                startActivity(new Intent(getContext(), SignInActivity.class));
            }
        }
    }

    private void showRulesDialog() {
        if (outboundRoutes != null) {
            OutboundRulesPopDialog dialog = new OutboundRulesPopDialog(getSobotActivity(), outboundRoutes, new OutboundRulesPopDialog.PopItemClick() {

                @Override
                public void onPopItemClick(SobotOutboundRoutesEntity item, SobotExplicitRuleEntity leftRule, SobotExplicitRuleEntity rightRule) {
                    outboundRoutes = item;
                    String text = leftRule.getName();
                    if (null != rightRule) {
                        if (!TextUtils.isEmpty(rightRule.getNumber())) {
                            text = rightRule.getNumber();
                        }
                        if (!TextUtils.isEmpty(rightRule.getCode())) {
                            text = rightRule.getPlanName();
                        }
                        if (Integer.parseInt(leftRule.getCode()) > 0) {
                            changeOutboudRoutesRules(leftRule.getCode(), rightRule.getCode(), rightRule.getNumber());
                        }
                    } else {
                        //设置外显号
                        if (Integer.parseInt(leftRule.getCode()) > 0) {
                            changeOutboudRoutesRules(leftRule.getCode(), "", "");
                        }
                    }
                    tv_mobile.setText(text);
                    if (popupWindow != null)
                        popupWindow.dismiss();
                }
            });
            popupWindow = dialog.getPopWindow();
            popupWindow.showAsDropDown(ll_logined, 0, 0);
        }
    }

    private void onStatusClike() {
        if (isCalling) {
            //通话没结束，不能切换坐席状态
            SobotToastUtil.showCustomToast(getSobotActivity(), getString(R.string.call_retcode_330035));
            return;
        }
        call_loingStatus = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.callLoginStatus, CallStatusUtils.V6_OFFLINE);
        boolean isOFF = true;
        if (CallStatusUtils.V6_OFFLINE.equals(call_loingStatus)) {
            isOFF = true;
        } else {
            isOFF = false;
        }
        if (isOFF) {
            stompConnect();
            //离线状态跳转座席登录界面
            startActivity(new Intent(getContext(), SignInActivity.class));
        } else {
            lineStatusActionItems.clear();
            if (CallStatusUtils.V6_FINISHING.equals(call_loingStatus)) {
                SobotToastUtil.showToast(getSobotActivity(), getSobotActivity().getResources().getString(R.string.sobot_error_switch_status));
                return;
            }
            List<SobotLoginStatusEntity> data = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.callStatusList_v6, ArrayList.class);
            if (data != null) {
                for (int i = 0; i < data.size(); i++) {
                    if (!data.get(i).getCode().equals(CallStatusUtils.V6_SYSYTEM_BUSY)) {
                        //只显示启用的
                        if (data.get(i).getEnabled() == 1) {
                            Drawable drawable = getSobotActivity().getDrawable(R.drawable.custom_service_other);
                            if (data.get(i).getCode().equals(CallStatusUtils.V6_FREE)) {
                                drawable = getSobotActivity().getDrawable(R.drawable.custom_service_online);
                            } else if (data.get(i).getCode().equals(CallStatusUtils.V6_DO_NOT_DISTURB)) {
                                drawable = getSobotActivity().getDrawable(R.drawable.custom_service_busy);
                            } else if (data.get(i).getCode().equals(CallStatusUtils.V6_OFFLINE)) {
                                drawable = getSobotActivity().getDrawable(R.drawable.custom_service_offline);
                            }
                            lineStatusActionItems.add(new SobotActionItem(data.get(i).getName(), drawable, call_loingStatus.equals(data.get(i).getCode()), data.get(i).getCode()));
                        }
                    }
                }
            }
            //座席状态切换点击事件
            SobotTitileMoreMenuV6.PopItemClick mPopItemClick = new SobotTitileMoreMenuV6.PopItemClick() {
                @Override
                public void onPopItemClick(SobotActionItem item, int index) {
                    if (!CommonUtils.isNetWorkConnected(getSobotActivity())) {
                        SobotToastUtil.showToast(getContext(), getContext().getResources().getString(R.string.sobot_call_net_error_string));
                        return;
                    }
                    serviceVo = SobotLoginTools.getInstance().getServiceInfo();
                    if (serviceVo == null) {
                        return;
                    }
                    call_loingStatus = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.callLoginStatus, CallStatusUtils.V6_OFFLINE);
                    String currentTime = System.currentTimeMillis() + "";
                    SobotRegistrationListener.getInstance().setLineStatus(item.getDicId() + "");
                    SobotRegistrationListener.getInstance().setLineStatusName(item.getmTitle());
                    if (CallStatusUtils.V6_FREE.equals(item.getDicId())) {
                        //座席置闲
                        SobotStompClient.getInstance(getSobotActivity()).send("/cc/app/request", "{\n" +
                                "    \"messageID\": \"" + SobotStompEventConstant.RequestAgentReady + "\",\n" +
                                "    \"referenceID\": " + currentTime + ",\n" +
                                "    \"companyId\": \"" + serviceVo.getCompanyId() + "\",\n" +
                                "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                                "    \"agentType\": \"1\",\n" +
                                "    \"creationTime\": " + currentTime + "\n" +
                                "}\n").subscribe();
                    } else if (CallStatusUtils.V6_OFFLINE.equals(item.getDicId()) || CallStatusUtils.V6_OFFLINE.equals(item.getDicId())) {
                        //座席签出
                        SobotStompClient.getInstance(getSobotActivity()).send("/cc/app/request", "{\n" +
                                "    \"messageID\": \"" + SobotStompEventConstant.RequestAgentLogout + "\",\n" +
                                "    \"referenceID\": " + currentTime + ",\n" +
                                "    \"companyId\": \"" + serviceVo.getCompanyId() + "\",\n" +
                                "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                                "    \"agentType\": \"1\",\n" +
                                "    \"creationTime\": " + currentTime + "\n" +
                                "}\n").subscribe();
                    } else {
                        //座席置忙
                        SobotStompClient.getInstance(getSobotActivity()).send("/cc/app/request", "{\n" +
                                "    \"messageID\": \"" + SobotStompEventConstant.RequestAgentNotReady + "\",\n" +
                                "    \"referenceID\": " + currentTime + ",\n" +
                                "    \"companyId\": \"" + serviceVo.getCompanyId() + "\",\n" +
                                "    \"agentID\": \"" + serviceVo.getServiceId() + "\",\n" +
                                "    \"agentType\": \"1\",\n" +
                                "    \"reasonCode\": \"" + item.getDicId() + "\",\n" +
                                "    \"creationTime\": " + currentTime + "\n" +
                                "}\n").subscribe();
                    }
                    // switchTitle(item.mTitle, true);
                    if (popupWindow != null)
                        popupWindow.dismiss();
                }
            };
            //非离线状态弹出切换座席弹窗
            SobotTitileMoreMenuV6 sobotSelectSearchTypePop = new SobotTitileMoreMenuV6(getContext(), lineStatusActionItems, SobotTitileMoreMenuV6.TYPE_BOTTOM_CIRCULAR, true, mPopItemClick);
            popupWindow = sobotSelectSearchTypePop.getPopWindow();
            popupWindow.showAsDropDown(statusMenu, 0, 0);
        }
    }

    /**
     * 连接stomp
     */
    private void stompConnect() {
        //判断是否有电话条权限
        if (CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_DHT)) {
            if (!SobotStompClient.getInstance(getSobotActivity()).isConnected()) {
                String accesstoken = SobotLoginTools.getInstance().getAccessToken();
                String languageStr = CallBaseSharedPreferencesUtils.getInstance(getSobotActivity()).get("SobotLanguageStr", "zh");
                //v6 需要连接stomp
                SobotStompClient.getInstance(getSobotActivity()).over(SobotStompClient.ConnectionProviderType.OKHTTP, SobotCallBaseUrl.getStompSocketUri() + "?authorization=Bearer " + accesstoken + "&language=" + languageStr, null, null);
                SobotLogUtils.i("stomp 链接地址=====" + SobotCallBaseUrl.getStompSocketUri() + "?authorization=Bearer " + accesstoken);
                SobotStompClient.getInstance(getSobotActivity()).connectStomp(0);
            }
        }
    }

    private void getV6CallSeatLoginStatus() {
        call_loingStatus = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.callLoginStatus, CallStatusUtils.V6_OFFLINE);
        SobotLogUtils.i("---------------------------" + call_loingStatus);
        if (CallStatusUtils.V6_OFFLINE.equals(call_loingStatus)) {
            updateTitle(false);
            //隐藏键盘启动按钮
            ll_open_keyword.setVisibility(View.GONE);
        } else {
            updateTitle(true);
        }
        Drawable dra;
        SobotLogUtils.i("---------------------------" + call_loingStatus);
        switch (call_loingStatus) {
            case CallStatusUtils.V6_FREE://1：空闲
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_online);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                statusMenu.setText(getHeadText(getSobotActivity().getResources().getString(R.string.sobot_custom_v6_free)));
                break;
            case CallStatusUtils.V6_FINISHING://4 //整理中（话务总结）
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_busy);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                statusMenu.setText(getHeadText(getSobotActivity().getResources().getString(R.string.sobot_call_finishing)));
                break;
            case CallStatusUtils.V6_DO_NOT_DISTURB://2：勿扰
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_busy);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                statusMenu.setText(getHeadText(getSobotActivity().getResources().getString(R.string.sobot_custom_do_not_disturb)));
                break;
            case CallStatusUtils.V6_LITTLE_HUGH:// 11：小休
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_other);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                statusMenu.setText(getHeadText(getSobotActivity().getResources().getString(R.string.sobot_custom_little_rest)));
                break;
            case CallStatusUtils.V6_TRAIN:// 12：培训
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_other);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                statusMenu.setText(getHeadText(getSobotActivity().getResources().getString(R.string.sobot_custom_peixun)));
                break;
            case CallStatusUtils.V6_MEETING:// 13：会议
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_other);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                statusMenu.setText(getHeadText(getSobotActivity().getResources().getString(R.string.sobot_custom_huiyi)));
                break;
            case CallStatusUtils.V6_HAVE_MEALS:// 14：用餐
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_other);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                statusMenu.setText(getHeadText(getSobotActivity().getResources().getString(R.string.sobot_custom_yongcan)));
                break;
            case CallStatusUtils.V6_ACTIVITY:// 活动
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_other);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                statusMenu.setText(getHeadText(getSobotActivity().getResources().getString(R.string.sobot_custom_huodong)));
                break;
            case CallStatusUtils.V6_SYSYTEM_BUSY:// 活动
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_other);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                statusMenu.setText(getHeadText(getSobotActivity().getResources().getString(R.string.sobot_call_system_busy)));
                break;
            case CallStatusUtils.V6_OFFLINE:
                statusMenu.setText(call_loingStatus.equals(CallStatusUtils.V6_OFFLINE) ? getSobotActivity().getResources().getString(R.string.sobot_custom_offline_and_click_login) : getHeadText(getSobotActivity().getResources().getString(R.string.sobot_custom_offline)));
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_offline);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                break;
            default:
                dra = getSobotActivity().getDrawable(R.drawable.custom_service_other);
                dra.setBounds(0, 0, dra.getIntrinsicWidth(), dra.getIntrinsicHeight());
                statusMenu.setCompoundDrawables(dra, null, null, null);
                String statusName = SobotCallApiUtils.getLoginStatusV6(getSobotActivity(), call_loingStatus);
                statusMenu.setText(getHeadText(TextUtils.isEmpty(statusName) ? getSobotActivity().getResources().getString(R.string.sobot_custom_do_not_disturb) : statusName));
                break;
        }
    }

    private String getHeadText(String text) {
        String lineStatus = text;
        serviceVo = SobotLoginTools.getInstance().getServiceInfo();
        if (serviceVo != null) {
            int callWay = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.SP_KEY_CALL_MODEL_TYPE_V6, SobotCallConstant.CALL_MODEL_PHONE);
            nowStatus = lineStatus;
            if (getSobotActivity().getResources().getString(R.string.sobot_custom_offline).equals(lineStatus)) {
                if (callNotifyTip != null) {
                    callNotifyTip.setVisibility(View.GONE);
                    if (SobotCallConstant.CALL_MODEL_SIP == callWay) {
                        if (SobotSipUtils.isServiceRun(true)) {
                            SobotSipUtils.logoutUser(true);
                            SobotRegistrationListener.getInstance().setRegistrationOk(false);
                            SobotSipUtils.stopService(true, getActivity());
                        }
                    }
                }
            }
            if (SobotCallConstant.CALL_MODEL_NETWORK == callWay/*||SobotCallConstant.CALL_MODEL_SIP==callWay*/) {
                notifyTipChange(callWay);
            }
        }
        return text;

    }


    /**
     * 改变提示信息
     */
    private void notifyTipChange(final int callWay) {
        if (SobotCallConstant.CALL_MODEL_SIP == callWay) {
            String serverScheme = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallBaseConstant.SipModel.SIP_SCHEME, SobotCallConstant.ServerScheme.vos);
            if (SobotCallConstant.ServerScheme.FS.equals(serverScheme)) {
                if (callNotifyTip != null) {
                    callNotifyTip.setVisibility(View.GONE);
                }
                return;
            }
        }
        if (callNotifyTip != null) {
            callNotifyTip.setVisibility(View.VISIBLE);
            String tipString = String.format(getString(R.string.sobot_call_tip_app_no_support), SobotCallConstant.CALL_MODEL_NETWORK == callWay ? "网络电话" : SobotCallConstant.CALL_MODEL_SIP == callWay ? "SIP电话" : "手机电话");
            callNotifyTip.setText(tipString);
        }
    }

    /**
     * 注册登录sip
     *
     * @param sipModel
     * @param lineStatus
     */
    public void registerSipLongin(final CallSipModel sipModel, String lineStatus, String
            lineStatusName) {
        SobotLogUtils.i("registerSipLongin");
        if (sipModel == null || TextUtils.isEmpty(sipModel.getAgentNumber())) {
            return;
        }
        try {
            SobotSipUtils.startService(true, getSobotActivity());
            stompConnect();
            new Handler().postDelayed(new Runnable() {
                @Override
                public void run() {
                    SobotRegistrationListener registerListener = SobotRegistrationListener.getInstance();
                    registerListener.setContext(getSobotActivity().getApplicationContext());
                    registerListener.setLineStatus(lineStatus);
                    registerListener.setLineStatusName(lineStatusName);
                    registerListener.setSipModel(sipModel);
                    SobotPhoneStatusListener phoneStatusListener = SobotPhoneStatusListener.getInstance();
                    phoneStatusListener.setContext(getSobotActivity());
                    if (serviceVo != null) {
                        SobotSipUtils.addPhoneCallStatesback(true, registerListener, phoneStatusListener);
                        SobotSipUtils.setAccount(true, sipModel.getAgentNumber(), sipModel.getAgentPwd(), sipModel.getServerIP());
                        SobotSipUtils.login(true, getSobotActivity());
                    }
                }
            }, 1500);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @Override
    public void onActivityResult(int requestCode, int resultCode, @Nullable Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        if (resultCode == RESULT_OK) {
        }
    }


    //上次网络变化时间
    private long lastConnectivitytime = 0;

    /**
     * 检测网络状态的广播
     */
    public class NetWorkChangeReceiver extends BroadcastReceiver {

        @Override
        public void onReceive(Context context, Intent intent) {
            if (ConnectivityManager.CONNECTIVITY_ACTION.equals(intent.getAction())) {
                //CONNECTIVITY_ACTION 粘性广播，一注册就会收到这个广播，第一次不处理
                if (connectivity_action_count > 0) {
                    long currentTime = Calendar.getInstance().getTimeInMillis();
                    if (currentTime - lastConnectivitytime > 2000) {
                        //两次收到网络变化广播时间超过2s 才执行逻辑
                        lastConnectivitytime = currentTime;
                        ConnectivityManager manager = (ConnectivityManager) context
                                .getSystemService(Context.CONNECTIVITY_SERVICE);
                        if (manager == null) return;
                        try {
                            if (PermissionUtil.checkPermission(context, Manifest.permission.ACCESS_NETWORK_STATE)) {
                                NetworkInfo activeNetwork = manager.getActiveNetworkInfo();
                                if (activeNetwork != null) {
                                    if (activeNetwork.isConnected()) {
                                        serviceVo = SobotLoginTools.getInstance().getServiceInfo();
                                        stompConnect();
                                    } else {
                                        SobotLogUtils.i(TAG + " 当前没有可用网络");
                                    }
                                }
                            }
                        } catch (Exception e) {
                            SobotLogUtils.e(TAG + " 网络状态获取错误", e);
                        }
                    }
                }
                connectivity_action_count++;
            }
        }

    }

    // 执行路由切换
    private void doRequestReleaseBlueGreen() {
        if (isCalling) {
            return;
        }
        if (!isRequestReleaseBlueGreen) {
            return;
        }
        // 执行后，还原
        isRequestReleaseBlueGreen = false;
        //重连webRtc
        SobotStompClient.getInstance(getSobotActivity()).disconnect();
        SobotStompClient.getInstance(getSobotActivity()).connectStomp(0);
        //重连janus
        CallSipModel sipModel = new CallSipModel();
        sipModel.setAgentNumber(CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallBaseConstant.SipModel.SIP_NUMBER));
        sipModel.setAgentPwd(CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallBaseConstant.SipModel.SIP_PWD));
        sipModel.setServerIP(CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallBaseConstant.SipModel.SIP_IP));
        String status = CallSharedPreferencesUtils.getInstance(getSobotActivity()).get(SobotCallConstant.callLoginStatus, CallStatusUtils.V6_FREE);
        registerSipLongin(sipModel, status, "");
    }


    //获取外呼规则
    private void getOutboudRoutesRules(boolean isShowDialog) {
        if (serviceVo == null) return;
        zhiChiApi.queryOutBoudRoutesRules(getContext(), serviceVo.getServiceId(), new SobotResultCallBack<SobotOutboundRoutesEntity>() {
            @Override
            public void onSuccess(SobotOutboundRoutesEntity o) {
                outboundRoutes = o;
                new Handler().post(new Runnable() {
                    @Override
                    public void run() {
                        if (outboundRoutes != null) {
                            if (null != outboundRoutes.getExplicitRule() && outboundRoutes.getExplicitRule().size() > 0) {
                                //坐席号码池
                                String text = "";
                                for (int i = 0; i < outboundRoutes.getExplicitRule().size(); i++) {
                                    if (outboundRoutes.getExplicitRule().get(i).isHasSet()) {
                                        if ("1".equals(outboundRoutes.getExplicitRule().get(i).getCode())) {
                                            text = outboundRoutes.getExplicitRule().get(i).getName();
                                        } else if ("2".equals(outboundRoutes.getExplicitRule().get(i).getCode())) {
                                            if (null != outboundRoutes.getExplicitSchema() && outboundRoutes.getExplicitSchema().size() > 0) {
                                                //外显方案
                                                for (int j = 0; j < outboundRoutes.getExplicitSchema().size(); j++) {
                                                    if (outboundRoutes.getExplicitSchema().get(j).isHasSet()) {
                                                        text = outboundRoutes.getExplicitSchema().get(j).getPlanName();
                                                    }
                                                }
                                            }
                                        } else if ("3".equals(outboundRoutes.getExplicitRule().get(i).getCode())) {
                                            if (null != outboundRoutes.getExplicitNumbers() && outboundRoutes.getExplicitNumbers().size() > 0) {
                                                //外显号
                                                for (int j = 0; j < outboundRoutes.getExplicitNumbers().size(); j++) {
                                                    if (outboundRoutes.getExplicitNumbers().get(j).isHasSet()) {
                                                        text = outboundRoutes.getExplicitNumbers().get(j).getNumber();
                                                        if (!TextUtils.isEmpty(outboundRoutes.getExplicitNumbers().get(j).getNickName())) {
                                                            text = outboundRoutes.getExplicitNumbers().get(j).getNumber() + "(" + outboundRoutes.getExplicitNumbers().get(j).getNickName() + ")";
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                                String finalText = text;
                                new Handler().post(new Runnable() {
                                    @Override
                                    public void run() {
                                        tv_mobile.setText(TextUtils.isEmpty(finalText) ? getSobotActivity().getResources().getString(R.string.call_select_hint) : finalText);
                                    }
                                });
                                if (isShowDialog) {
                                    showRulesDialog();
                                }
                            } else {
                                new Handler().post(new Runnable() {
                                    @Override
                                    public void run() {
                                        tv_mobile.setText(getSobotActivity().getResources().getString(R.string.call_select_hint));
                                    }
                                });
                                if (isShowDialog) {
                                    showRulesDialog();
                                }
                            }
                        } else {
                            new Handler().post(new Runnable() {
                                @Override
                                public void run() {
                                    tv_mobile.setText(getSobotActivity().getResources().getString(R.string.call_select_hint));
                                }
                            });
                            if (isShowDialog) {
                                outboundRoutes = new SobotOutboundRoutesEntity();
                                showRulesDialog();
                            }
                        }
                    }
                });

            }

            @Override
            public void onFailure(Exception e, String des) {
            }
        });
    }

    /**
     * 切换座席的外呼外显规则
     *
     * @param explicitRule   外显规则:1：企业号码池随机匹配；2：动态外显号码方案匹配；3：座席号码池指定；单选；
     * @param explicitCode   动态外显方案编码: 外显规则为动态外显号码方案时必传
     * @param explicitNumber 外显号码:不使用外显规则，直接指定企业的某外显号码呼叫客户，外显号码和外显规则至少需要传一个
     */
    private void changeOutboudRoutesRules(String explicitRule, String explicitCode, String
            explicitNumber) {
        zhiChiApi.switchOutBoudRoutesRules(getContext(), serviceVo.getServiceId(), explicitRule, explicitCode, explicitNumber, new SobotResultCallBack<SobotOutboundRoutesEntity>() {
            @Override
            public void onSuccess(SobotOutboundRoutesEntity outboundRoutesEntity) {
                getOutboudRoutesRules(false);
            }

            @Override
            public void onFailure(Exception e, String des) {
            }
        });
    }


    //显示会话小结弹窗
    private void showWrapUp() {
        if (FloatingWindowPermissionUtil.hasSuspendedWindowPermission(getSobotActivity().getApplicationContext())) {
            //更新通话状态浮层 为通话中
            IFloatWindow iFloatWindow = SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT);
            View statusFloatView;
            if (iFloatWindow != null) {
                statusFloatView = iFloatWindow.getView();
                if (iFloatWindow.getX() > (Screen.width / 2)) {
                    iFloatWindow.updateX(Screen.width, 0.73f);
                }
                iFloatWindow.show();
            } else {
                statusFloatView = LayoutInflater.from(getSobotActivity().getApplicationContext()).inflate(R.layout.call_float_window, null, false);
                SobotFloatWindow.B floatWindow = SobotFloatWindow
                        .with(getSobotActivity().getApplicationContext())
                        .setView(statusFloatView)
                        .setTag(SobotCallConstant.CALL_STATUS_FLOAT)
                        .setX(Screen.width, 0.73f)
                        .setY(Screen.height, 0.2f)
                        .setMoveType(MoveType.slide)
                        .setMoveStyle(500, new BounceInterpolator())
                        .setDesktopShow(true);
                floatWindow.build();
                if (SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT) != null) {
                    SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT).show();
                }
            }
            ImageView iv_call = statusFloatView.findViewById(R.id.iv_call);
            iv_call.setVisibility(View.GONE);
            TextView tv_call_statue = statusFloatView.findViewById(R.id.tv_call_statue);
            TextView tv_complete = statusFloatView.findViewById(R.id.tv_complete);
            TextView tv_extend = statusFloatView.findViewById(R.id.tv_extend);
            TextView tv_set_busy = statusFloatView.findViewById(R.id.tv_set_busy);
            ImageView iv_expand = statusFloatView.findViewById(R.id.iv_expand);
            tv_complete.setVisibility(View.VISIBLE);
            tv_extend.setVisibility(View.GONE);
            tv_set_busy.setVisibility(View.GONE);
            tv_call_statue.setText(getResources().getString(R.string.sobot_call_finishing) + " " + arrangeDuration + getResources().getString(R.string.sobot_call_second));

            if (CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_DHT_YCZLSC) || CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_DHT_JSZLBZM)) {
                iv_expand.setVisibility(View.VISIBLE);
            } else {
                iv_expand.setVisibility(View.GONE);
            }

            String finishing = getResources().getString(R.string.sobot_call_finishing);
            String second = getResources().getString(R.string.sobot_call_second);
            mHandler.postDelayed(new Runnable() {
                @Override
                public void run() {
                    tv_call_statue.setText(finishing + " " + (arrangeDuration > 0 ? (--arrangeDuration) : 0) + second);
                    SobotLogUtils.i("会话小结倒计时：" + arrangeDuration);
                    if (arrangeDuration == 0) {
                        if (SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT) != null) {
                            SobotFloatWindow.destroy(SobotCallConstant.CALL_STATUS_FLOAT);
                        }
                        mHandler.removeCallbacks(this);
                    } else {
                        mHandler.postDelayed(this, 1000);
                    }
                }
            }, 1000);
            iv_expand.setTag(0);//收起
            iv_expand.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    int isExpand = (int) iv_expand.getTag();
                    if (isExpand == 0) {
                        //展开
                        tv_complete.setVisibility(View.VISIBLE);
                        iv_expand.setVisibility(View.VISIBLE);
                        iv_expand.setImageResource(R.drawable.icon_call_arraw_up);
                        iv_expand.setTag(1);
                        //延长整理时间
                        if (CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_DHT_YCZLSC)) {
                            tv_extend.setVisibility(View.VISIBLE);
                        } else {
                            tv_extend.setVisibility(View.GONE);
                        }
                        //结束整理并置忙
                        if (CallPermissionManager.isHasPermission(SobotPermissionManager.CCCV6_DHT_JSZLBZM)) {
                            tv_set_busy.setVisibility(View.VISIBLE);
                        } else {
                            tv_set_busy.setVisibility(View.GONE);
                        }
                    } else {
                        //收起
                        tv_complete.setVisibility(View.VISIBLE);
                        tv_extend.setVisibility(View.GONE);
                        tv_set_busy.setVisibility(View.GONE);
                        iv_expand.setVisibility(View.VISIBLE);
                        iv_expand.setImageResource(R.drawable.icon_call_arraw_down);
                        iv_expand.setTag(0);
                    }
                }
            });
            tv_complete.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    arrangeDuration = 0;//重置  0 会移除会话小结倒计时
                    //结束整理
                    SobotCallOpenApi.finishCallAfterWork(getSobotActivity().getApplicationContext(), new SobotResultBlock() {
                        @Override
                        public void resultBolok(SobotResultCode code, String msg, Object obj) {
                            if (SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT) != null) {
                                SobotFloatWindow.destroy(SobotCallConstant.CALL_STATUS_FLOAT);
                            }
                        }
                    });
                }
            });
            tv_extend.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    //延长整理时长
                    SobotCallOpenApi.delayCallAfterWork(getSobotActivity().getApplicationContext(), 60, new SobotResultBlock() {
                        @Override
                        public void resultBolok(SobotResultCode code, String msg, Object obj) {
                        }
                    });
                }
            });
            tv_set_busy.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    arrangeDuration = 0;//重置  0 会移除会话小结倒计时
                    //勿扰
                    SobotCallOpenApi.agentNotReady(getSobotActivity().getApplicationContext(), "2", new SobotResultBlock() {
                        @Override
                        public void resultBolok(SobotResultCode code, String msg, Object obj) {
                            if (SobotFloatWindow.get(SobotCallConstant.CALL_STATUS_FLOAT) != null) {
                                SobotFloatWindow.destroy(SobotCallConstant.CALL_STATUS_FLOAT);
                            }
                        }
                    });
                }
            });
            statusFloatView.setOnClickListener(null);
        }
    }
}